(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 8.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       157,          7]
NotebookDataLength[    133346,       3335]
NotebookOptionsPosition[    131201,       3262]
NotebookOutlinePosition[    131636,       3279]
CellTagsIndexPosition[    131593,       3276]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["\<\
CO2 Songs
\
\>", "Title",
 CellChangeTimes->{{3.527202916859186*^9, 3.527202924204114*^9}}],

Cell["\<\
Dara O Shayda
Oct 9 2011

License: http://www.gnu.org/licenses/gpl.html 
\
\>", "Text",
 CellChangeTimes->{{3.5272029333962107`*^9, 3.527202950708982*^9}, {
  3.527203093163124*^9, 3.527203094970357*^9}}],

Cell[TextData[{
 StyleBox["\n\n\n\nGas Age Data\n", "Subtitle"],
 "\nftp://ftp.ncdc.noaa.gov/pub/data/paleo/icecore/antarctica/vostok/co2nat.\
txt \n\nCO2 data: file\[CloseCurlyDoubleQuote]co2nat.txt\
\[CloseCurlyDoubleQuote]\nColumn 1: Gas Age as deduced from the Barnola et \
al. (1991) model \nColumn  2: CO2 concentration (ppmv). \nCO2 and CH4 \
measurements have been performed using the methods and analytical \n\
procedures previously described (Barnola et al., 1987, Chappellaz et al, \
1990). \nHowever, the CO2 measuring system has been slightly modified in \
order to increase \nthe sensitivity of the CO2 detection. The thermal \
conductivity chromatographic \ndetector has been replaced by a flame \
ionisation detector which measures CO2 \nafter its transformation into CH4. \
The overall accuracy for CH4 and CO2 measurements \nare \[PlusMinus] 20 ppbv \
and 2-3 ppmv respectively. No gravitational correction has been applied.\n\n\
ftp://ftp.ncdc.noaa.gov/pub/data/paleo/icecore/antarctica/vostok/readme_\
petit1999.txt \n\nAir trapped in ice core bubbles provides our primary source \
of information about past atmospheres. Air isotopic composition (15N/14N and \
40Ar/36Ar) permits an estimate of the temperature shifts associated with \
abrupt climate changes because of isotope fractionation occurring in response \
to temperature gradients in the snow layer on top of polar ice sheets. A \
rapid surface temperature change modifies temporarily the flrn temperature \
gradient, which causes a detectable anomaly in the isotopic composition of \
nitrogen and argon. The location of this anomaly in depth characterizes the \
gas age.\n\nhttp://www.agu.org/pubs/crossref/2001/2001JD900145.shtml\n"
}], "Text",
 CellChangeTimes->{{3.527040551186716*^9, 3.527040557102645*^9}, {
  3.527040601070524*^9, 3.52704062317741*^9}, {3.5271110666869907`*^9, 
  3.527111085138887*^9}, {3.527203105130431*^9, 3.527203110404317*^9}, {
  3.5272031611487007`*^9, 3.527203161516831*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{"Read", " ", "Directly", " ", "from", " ", "Internet"}], ",", " ", 
    RowBox[{"in", " ", "this", " ", "case", " ", "FTP", " ", "site"}]}], " ", 
   "*)"}], "\[IndentingNewLine]", 
  RowBox[{"co2data", "=", 
   RowBox[{"Import", "[", 
    RowBox[{
    "\"\<ftp://ftp.ncdc.noaa.gov/pub/data/paleo/icecore/antarctica/vostok/\
co2nat.txt \>\"", ",", "\"\<Table\>\""}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.52704066649159*^9, 3.527040674211138*^9}, {
  3.5270407238575497`*^9, 3.52704073585884*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"\<\"Gas\"\>", ",", "\<\"age\"\>", ",", "\<\"CO2\"\>", 
     ",", "\<\"(ppmv)\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"2342", ",", "284.7`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"3634", ",", "272.8`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"3833", ",", "268.1`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"6220", ",", "262.2`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"7327", ",", "254.6`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"8113", ",", "259.6`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"10123", ",", "261.6`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"11013", ",", "263.7`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"11326", ",", "244.8`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"11719", ",", "238.3`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"13405", ",", "236.2`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"13989", ",", "225.3`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"17695", ",", "182.2`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"19988", ",", "189.2`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"22977", ",", "191.6`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"26303", ",", "188.5`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"27062", ",", "191.7`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"31447", ",", "205.4`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"33884", ",", "209.1`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"39880", ",", "209.1`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"44766", ",", "189.3`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"47024", ",", "188.4`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"48229", ",", "210.1`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"49414", ",", "215.7`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"51174", ",", "190.4`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"57068", ",", "221.8`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"57799", ",", "210.4`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"63687", ",", "195.4`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"65701", ",", "191.4`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"66883", ",", "195"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"72849", ",", "227.4`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"75360", ",", "229.2`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"78995", ",", "217.1`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"80059", ",", "221.8`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"82858", ",", "231"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"84929", ",", "241.1`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"85727", ",", "236.4`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"86323", ",", "228.1`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"87180", ",", "214.2`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"88051", ",", "217"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"89363", ",", "208"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"91691", ",", "224.3`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"92460", ",", "228.4`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"95349", ",", "232.1`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"99842", ",", "225.9`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"100833", ",", "230.9`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"101829", ",", "236.9`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"103372", ",", "228.2`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"105213", ",", "236.9`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"106203", ",", "230.7`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"108308", ",", "238.2`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"108994", ",", "245.7`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"110253", ",", "251.3`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"111456", ",", "256.8`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"112577", ",", "266.3`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"113472", ",", "261.4`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"114082", ",", "274.6`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"114738", ",", "273.3`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"116175", ",", "262.5`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"117519", ",", "267.6`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"118396", ",", "273.8`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"119273", ",", "272"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"120002", ",", "265.2`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"120652", ",", "277.7`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"121961", ",", "272.2`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"122606", ",", "276.5`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"123815", ",", "268.7`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"123858", ",", "266.6`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"124306", ",", "266.3`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"124571", ",", "279.8`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"124876", ",", "277.2`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"125746", ",", "273.8`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"126023", ",", "267.1`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"126475", ",", "262.5`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"126809", ",", "262.6`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"127445", ",", "275.4`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"128300", ",", "274.1`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"128399", ",", "287.1`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"128652", ",", "286.8`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"129007", ",", "282.7`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"129411", ",", "264.1`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"129755", ",", "263.4`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"130167", ",", "259"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"131789", ",", "240.4`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"133334", ",", "224"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"134205", ",", "208.9`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"135003", ",", "204.6`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"135683", ",", "198.1`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"135976", ",", "201.8`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"136359", ",", "202.5`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"136659", ",", "195.9`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"137383", ",", "194.4`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"137694", ",", "193.4`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"138226", ",", "190.2`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"139445", ",", "192.3`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"141312", ",", "196.5`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"142357", ",", "190.4`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"145435", ",", "197"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"150303", ",", "191.9`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"154471", ",", "189"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"155299", ",", "185.5`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"160494", ",", "204.4`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"162996", ",", "191.6`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"165278", ",", "183.8`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"169870", ",", "197.9`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"172596", ",", "197.8`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"175440", ",", "190.3`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"176271", ",", "190.1`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"178550", ",", "207.7`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"180779", ",", "213.2`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"181617", ",", "217.7`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"183355", ",", "199.8`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"185063", ",", "203.5`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"187199", ",", "210.7`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"189335", ",", "231.4`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"191057", ",", "231.5`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"192632", ",", "218"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"195625", ",", "220.1`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"199025", ",", "242.6`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"202212", ",", "251"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"203191", ",", "239.1`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"204283", ",", "247.7`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"205148", ",", "244.4`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"205715", ",", "232.2`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"206119", ",", "228.7`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"207991", ",", "238.2`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"209414", ",", "242.2`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"210022", ",", "244.6`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"210830", ",", "247.3`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"211005", ",", "252"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"212281", ",", "257.4`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"214153", ",", "251.2`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"215041", ",", "241.4`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"215593", ",", "240.3`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"215879", ",", "242.7`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"216459", ",", "247.5`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"217009", ",", "251.7`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"217271", ",", "251.2`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"217676", ",", "245.4`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"218342", ",", "240.5`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"219680", ",", "212.2`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"220182", ",", "216.2`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"220760", ",", "207.2`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"221054", ",", "208.9`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"221612", ",", "205.7`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"222958", ",", "203.4`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"223446", ",", "215.7`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"224630", ",", "236.9`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"225299", ",", "234.5`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"225509", ",", "233.1`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"225888", ",", "224.5`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"226710", ",", "232.4`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"227384", ",", "233.9`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"227840", ",", "241.7`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"230703", ",", "245.2`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"231382", ",", "252.2`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"231990", ",", "241.4`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"232570", ",", "247.4`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"233102", ",", "243.1`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"233646", ",", "239.2`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"234126", ",", "245.7`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"234470", ",", "245.9`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"234781", ",", "247.4`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"235213", ",", "252.9`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"236236", ",", "259.8`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"237831", ",", "279"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"238935", ",", "263.8`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"239250", ",", "252.4`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"239545", ",", "249.9`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"240201", ",", "230.4`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"240577", ",", "219.4`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"242068", ",", "214.7`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"243653", ",", "200.2`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"244215", ",", "213.9`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"244863", ",", "195.4`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"245483", ",", "196.7`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"247447", ",", "199"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"248087", ",", "201.9`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"248980", ",", "204"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"250461", ",", "203.9`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"251521", ",", "209.7`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"252959", ",", "208.9`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"253880", ",", "214.7`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"255233", ",", "228.2`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"256053", ",", "199.9`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"256501", ",", "211.7`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"257247", ",", "188.7`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"258477", ",", "194.2`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"259228", ",", "198.9`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"259958", ",", "184.7`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"260754", ",", "190.4`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"261595", ",", "193.9`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"262411", ",", "194.2`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"263207", ",", "198.4`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"264046", ",", "193.2`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"264834", ",", "202.2`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"266492", ",", "211"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"267434", ",", "215.4`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"268679", ",", "223.7`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"270680", ",", "231.4`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"273012", ",", "226.4`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"274445", ",", "230.4`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"275218", ",", "231"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"277925", ",", "220.4`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"278602", ",", "217.2`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"279543", ",", "207.7`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"282301", ",", "212.7`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"283492", ",", "213.2`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"286217", ",", "224.4`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"287846", ",", "236.2`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"290571", ",", "240.2`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"291769", ",", "240.7`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"292474", ",", "250.2`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"293676", ",", "244.9`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"294615", ",", "225.9`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"295849", ",", "227.9`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"297131", ",", "233.2`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"298051", ",", "237.9`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"299020", ",", "239"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"299877", ",", "241.9`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"300646", ",", "251.7`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"301496", ",", "256.8`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"302456", ",", "257.2`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"303334", ",", "246.9`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"303953", ",", "272.7`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"304590", ",", "251.7`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"305306", ",", "244.7`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"307131", ",", "255.9`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"308101", ",", "249.2`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"310039", ",", "256.3`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"310930", ",", "260.4`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"311774", ",", "260.3`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"313493", ",", "266.3`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"315143", ",", "266.2`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"315940", ",", "270.2`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"316681", ",", "271.9`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"317445", ",", "275.2`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"318980", ",", "265"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"319754", ",", "271.8`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"320378", ",", "272.7`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"321386", ",", "273.2`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"322111", ",", "282.4`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"322582", ",", "289.2`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"322827", ",", "288.4`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"323485", ",", "298.7`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"324189", ",", "278.2`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"324991", ",", "285.8`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"325527", ",", "278.7`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"326239", ",", "270.5`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"327114", ",", "255.7`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"328097", ",", "241.9`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"329267", ",", "239.7`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"330208", ",", "234.2`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"332293", ",", "250.2`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"333627", ",", "200.7`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"335290", ",", "205.2`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"336972", ",", "204.9`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"340165", ",", "220.4`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"342998", ",", "221.2`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"344735", ",", "216.2`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"347610", ",", "209.2`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"350765", ",", "193"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"352412", ",", "186.2`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"356838", ",", "201.2`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"359688", ",", "206.4`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"362766", ",", "201.9`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"366221", ",", "214.7`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"369563", ",", "229.7`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"373014", ",", "227"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"374561", ",", "240"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"378194", ",", "246.9`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"379633", ",", "245.9`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"384909", ",", "264.7`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"386579", ",", "259.3`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"390589", ",", "255.2`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"392451", ",", "250.2`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"394628", ",", "266.3`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"396713", ",", "274.7`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"400390", ",", "278"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"405844", ",", "279.7`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"409022", ",", "283.7`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"410831", ",", "276.3`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"414085", ",", "285.5`"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.527040700773011*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
   "Read", " ", "from", " ", "a", " ", "file", " ", "on", " ", "your", " ", 
    "machine"}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"co2data", "=", 
    RowBox[{"Import", "[", 
     RowBox[{
     "\"\</Users/darashayda/Desktop/R/co2nat2.txt\>\"", ",", 
      "\"\<Table\>\""}], "]"}]}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"co2", " ", "=", " ", 
     RowBox[{"co2data", "[", 
      RowBox[{"[", 
       RowBox[{"All", ",", "2"}], "]"}], "]"}]}], ";"}]}]}]], "Input",
 CellChangeTimes->{{3.5270350661983232`*^9, 3.527035104176713*^9}, {
   3.527035138138061*^9, 3.5270351417141743`*^9}, {3.527035764354788*^9, 
   3.527035786404714*^9}, 3.52703582133885*^9, {3.5270407476627083`*^9, 
   3.527040755355363*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"2342", ",", "284.7`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"3634", ",", "272.8`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"3833", ",", "268.1`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"6220", ",", "262.2`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"7327", ",", "254.6`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"8113", ",", "259.6`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"10123", ",", "261.6`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"11013", ",", "263.7`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"11326", ",", "244.8`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"11719", ",", "238.3`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"13405", ",", "236.2`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"13989", ",", "225.3`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"17695", ",", "182.2`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"19988", ",", "189.2`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"22977", ",", "191.6`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"26303", ",", "188.5`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"27062", ",", "191.7`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"31447", ",", "205.4`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"33884", ",", "209.1`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"39880", ",", "209.1`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"44766", ",", "189.3`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"47024", ",", "188.4`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"48229", ",", "210.1`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"49414", ",", "215.7`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"51174", ",", "190.4`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"57068", ",", "221.8`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"57799", ",", "210.4`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"63687", ",", "195.4`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"65701", ",", "191.4`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"66883", ",", "195"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"72849", ",", "227.4`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"75360", ",", "229.2`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"78995", ",", "217.1`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"80059", ",", "221.8`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"82858", ",", "231"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"84929", ",", "241.1`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"85727", ",", "236.4`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"86323", ",", "228.1`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"87180", ",", "214.2`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"88051", ",", "217"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"89363", ",", "208"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"91691", ",", "224.3`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"92460", ",", "228.4`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"95349", ",", "232.1`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"99842", ",", "225.9`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"100833", ",", "230.9`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"101829", ",", "236.9`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"103372", ",", "228.2`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"105213", ",", "236.9`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"106203", ",", "230.7`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"108308", ",", "238.2`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"108994", ",", "245.7`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"110253", ",", "251.3`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"111456", ",", "256.8`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"112577", ",", "266.3`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"113472", ",", "261.4`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"114082", ",", "274.6`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"114738", ",", "273.3`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"116175", ",", "262.5`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"117519", ",", "267.6`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"118396", ",", "273.8`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"119273", ",", "272"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"120002", ",", "265.2`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"120652", ",", "277.7`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"121961", ",", "272.2`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"122606", ",", "276.5`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"123815", ",", "268.7`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"123858", ",", "266.6`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"124306", ",", "266.3`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"124571", ",", "279.8`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"124876", ",", "277.2`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"125746", ",", "273.8`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"126023", ",", "267.1`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"126475", ",", "262.5`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"126809", ",", "262.6`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"127445", ",", "275.4`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"128300", ",", "274.1`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"128399", ",", "287.1`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"128652", ",", "286.8`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"129007", ",", "282.7`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"129411", ",", "264.1`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"129755", ",", "263.4`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"130167", ",", "259"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"131789", ",", "240.4`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"133334", ",", "224"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"134205", ",", "208.9`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"135003", ",", "204.6`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"135683", ",", "198.1`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"135976", ",", "201.8`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"136359", ",", "202.5`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"136659", ",", "195.9`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"137383", ",", "194.4`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"137694", ",", "193.4`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"138226", ",", "190.2`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"139445", ",", "192.3`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"141312", ",", "196.5`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"142357", ",", "190.4`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"145435", ",", "197"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"150303", ",", "191.9`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"154471", ",", "189"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"155299", ",", "185.5`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"160494", ",", "204.4`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"162996", ",", "191.6`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"165278", ",", "183.8`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"169870", ",", "197.9`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"172596", ",", "197.8`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"175440", ",", "190.3`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"176271", ",", "190.1`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"178550", ",", "207.7`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"180779", ",", "213.2`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"181617", ",", "217.7`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"183355", ",", "199.8`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"185063", ",", "203.5`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"187199", ",", "210.7`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"189335", ",", "231.4`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"191057", ",", "231.5`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"192632", ",", "218"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"195625", ",", "220.1`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"199025", ",", "242.6`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"202212", ",", "251"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"203191", ",", "239.1`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"204283", ",", "247.7`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"205148", ",", "244.4`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"205715", ",", "232.2`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"206119", ",", "228.7`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"207991", ",", "238.2`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"209414", ",", "242.2`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"210022", ",", "244.6`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"210830", ",", "247.3`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"211005", ",", "252"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"212281", ",", "257.4`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"214153", ",", "251.2`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"215041", ",", "241.4`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"215593", ",", "240.3`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"215879", ",", "242.7`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"216459", ",", "247.5`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"217009", ",", "251.7`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"217271", ",", "251.2`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"217676", ",", "245.4`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"218342", ",", "240.5`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"219680", ",", "212.2`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"220182", ",", "216.2`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"220760", ",", "207.2`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"221054", ",", "208.9`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"221612", ",", "205.7`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"222958", ",", "203.4`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"223446", ",", "215.7`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"224630", ",", "236.9`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"225299", ",", "234.5`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"225509", ",", "233.1`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"225888", ",", "224.5`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"226710", ",", "232.4`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"227384", ",", "233.9`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"227840", ",", "241.7`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"230703", ",", "245.2`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"231382", ",", "252.2`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"231990", ",", "241.4`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"232570", ",", "247.4`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"233102", ",", "243.1`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"233646", ",", "239.2`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"234126", ",", "245.7`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"234470", ",", "245.9`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"234781", ",", "247.4`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"235213", ",", "252.9`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"236236", ",", "259.8`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"237831", ",", "279"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"238935", ",", "263.8`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"239250", ",", "252.4`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"239545", ",", "249.9`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"240201", ",", "230.4`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"240577", ",", "219.4`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"242068", ",", "214.7`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"243653", ",", "200.2`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"244215", ",", "213.9`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"244863", ",", "195.4`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"245483", ",", "196.7`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"247447", ",", "199"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"248087", ",", "201.9`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"248980", ",", "204"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"250461", ",", "203.9`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"251521", ",", "209.7`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"252959", ",", "208.9`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"253880", ",", "214.7`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"255233", ",", "228.2`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"256053", ",", "199.9`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"256501", ",", "211.7`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"257247", ",", "188.7`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"258477", ",", "194.2`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"259228", ",", "198.9`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"259958", ",", "184.7`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"260754", ",", "190.4`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"261595", ",", "193.9`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"262411", ",", "194.2`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"263207", ",", "198.4`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"264046", ",", "193.2`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"264834", ",", "202.2`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"266492", ",", "211"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"267434", ",", "215.4`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"268679", ",", "223.7`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"270680", ",", "231.4`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"273012", ",", "226.4`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"274445", ",", "230.4`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"275218", ",", "231"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"277925", ",", "220.4`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"278602", ",", "217.2`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"279543", ",", "207.7`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"282301", ",", "212.7`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"283492", ",", "213.2`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"286217", ",", "224.4`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"287846", ",", "236.2`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"290571", ",", "240.2`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"291769", ",", "240.7`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"292474", ",", "250.2`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"293676", ",", "244.9`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"294615", ",", "225.9`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"295849", ",", "227.9`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"297131", ",", "233.2`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"298051", ",", "237.9`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"299020", ",", "239"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"299877", ",", "241.9`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"300646", ",", "251.7`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"301496", ",", "256.8`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"302456", ",", "257.2`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"303334", ",", "246.9`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"303953", ",", "272.7`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"304590", ",", "251.7`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"305306", ",", "244.7`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"307131", ",", "255.9`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"308101", ",", "249.2`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"310039", ",", "256.3`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"310930", ",", "260.4`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"311774", ",", "260.3`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"313493", ",", "266.3`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"315143", ",", "266.2`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"315940", ",", "270.2`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"316681", ",", "271.9`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"317445", ",", "275.2`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"318980", ",", "265"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"319754", ",", "271.8`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"320378", ",", "272.7`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"321386", ",", "273.2`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"322111", ",", "282.4`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"322582", ",", "289.2`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"322827", ",", "288.4`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"323485", ",", "298.7`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"324189", ",", "278.2`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"324991", ",", "285.8`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"325527", ",", "278.7`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"326239", ",", "270.5`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"327114", ",", "255.7`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"328097", ",", "241.9`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"329267", ",", "239.7`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"330208", ",", "234.2`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"332293", ",", "250.2`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"333627", ",", "200.7`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"335290", ",", "205.2`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"336972", ",", "204.9`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"340165", ",", "220.4`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"342998", ",", "221.2`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"344735", ",", "216.2`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"347610", ",", "209.2`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"350765", ",", "193"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"352412", ",", "186.2`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"356838", ",", "201.2`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"359688", ",", "206.4`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"362766", ",", "201.9`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"366221", ",", "214.7`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"369563", ",", "229.7`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"373014", ",", "227"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"374561", ",", "240"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"378194", ",", "246.9`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"379633", ",", "245.9`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"384909", ",", "264.7`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"386579", ",", "259.3`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"390589", ",", "255.2`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"392451", ",", "250.2`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"394628", ",", "266.3`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"396713", ",", "274.7`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"400390", ",", "278"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"405844", ",", "279.7`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"409022", ",", "283.7`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"410831", ",", "276.3`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"414085", ",", "285.5`"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{{3.527035122668295*^9, 3.5270351430555077`*^9}, 
   3.52703578754662*^9, 3.527035821797226*^9}]
}, Open  ]],

Cell["\<\


Plot the data and visualize best you can:
\
\>", "Text",
 CellChangeTimes->{{3.527040765052141*^9, 3.527040777503921*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ListPlot", "[", "co2", "]"}]], "Input",
 CellChangeTimes->{{3.527037715963079*^9, 3.527037719830846*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, 
   {Hue[0.67, 0.6, 0.6], PointBox[CompressedData["
1:eJxdl01oXFUUx0crwaKLQEsQzOJVJfhRZGxqtDra2yYdY03bydekadL0ZSaZ
ZDKTzIyLbprFEyEbuwgIgUoWA0pA6qJuCsUsngiF0giCIC66eFAQhSwiQkEI
YtLz+yt3ZnP55X/OPfeee+65L0cKtaHZJ1Op1PNPpFL7o/12Tnbv/+43HH9w
P27t/Z4VP+2+uLH3+74Ot7vH9kXxYeOfa/BzZn9CeqfxuDgw+2viF0y/sQS/
ZHxvEe5ypf3fivhl01+pwq+afrcEHzXemINft3h/idM2rorfMPtH4mO2/2/K
cLf5v7gAH2/hN209X8u/x/yvi98y+17Zv0088Qmz35L9OzbfnQr8rukDss8Y
V+fh94y35f++jaH0k9grX478wJFjP4p3yo8fnbIxkf9p7Dmv6DT71fn0mv6p
5u/lfLT+PhsDzQ+npJ+x+Aflf4b5FT9r8x8gXpQ1PSP9A+MH8ofXtb5+6kl6
f4v+oem/SIfvSj9rfFv7P2vrLav+P+L+UN8R/JXqfcD889IHqGfdt3NmfxiO
ztk4L//znI/8z5t9p/wvMMr/guXrc/nnjCfQHXxA9jkb++EY/b78B6l32A36
+4vgZfkPmv+w1jfkr9cN2Xzfyn/I32+MXlb8Yctfj/yHTT+i9cN/Kv4w90Px
R2w9N+U/YvafKP6IzX9V8UdsTCv+KOfL+btR/q56Qe+knuNR8q9+kjf+gfvp
8vRL9ChvYw6O8+RT93mMfiB/+CgcjVGv9IN4jPsk/4s2rsr/ot9/IvQmeoy+
q/4yjg47OC3/ce6r1j/e0n8v2Xr+pl+7S2a/qfWj31F8+J78J8if4k/QT5U/
eEP5h3vU3yaJr/1P2liX/yT3U/6T1I/6y2Ubd2AHO/Wzy/Q/OIaH9b5N2RjS
L9yU6Q/Vz6bYD/bxFPmU/xXT27B38Jrq74rfr2I4K/+QeoSD0PLxh+o5ZB7W
F4bm36H7AZfQmyH1p/Uy30E4wT6v+NPkT/GnuW/Kx7Q/fzjNe6x+i3873MR+
RecFt5H/BP5N96/g38+gQD9Hd+hVOCz473VU8N+LZsHGnPJd4H2EE/R21U+R
/oEewBmdZ5F6ZX8hvKH9wyvKf7El//C28l/ke035nyEfij/jv2duhvuo+DP+
fBG8rvhwRv1yxsY6/TVBX1b/nKWe8Q/gjM4f3iJfIVzV/ZrlfeY8mnCb+g32
m+iJ/NX/StwXOKAPJeoHJdaj80eP1B/Ql+Em8/Wo/kp+fSUlf72pOf/7I5ij
vyo++lXsQ3hN/RXOYt/E/4H6JXoH9slcy/flPPvT/uf9+Rz6Fhyid6k/y177
l532j/+29o/9I/Xfst9PA3hA/bTccv7E0fdnhH6d+Zpl1qd+W/bfgwReU/4X
/PchWOA+Kv6C//9GCLep/uEO9R84S/3GzLeu+7fQ8n1aoX60/wrr1/1H31R8
9TG9D+gZxa/4/TOu+N+fScXu/yHdvyr1ov5bNf0ZfQ9V/flCeE37x39X9x+9
S/HRn1J89KziL5reBweL/vejW7T1fAmH8EO9P4s23z9wE71b33vkaVXxmX9X
8Zf8/QbwIe1/ifqAQ+kfEx+9DW6i34RjuKj+t0S+9f1ZM72i+OTtd+2/Rv0q
/zX/vCPpen/grN6fml+PCdyh96/O/uD2OvUKB3X/fqVlD7u6/77m4C71K50r
faGOnlX/kn35v3Oy+65+Uvf776263z9j+Db35yfVCZz8f86Ph526X+97/xd5
71t7w87jM60b/TicbvBe6n1q+PnNNfz6DZnvNc5X72Co/0/Qr8Gr8Hdwk/n6
4FuMvzbcv4nA5f8=
     "]]}, {}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesOrigin->{0, 180.},
  PlotRange->{{0., 283.}, {180., 298.7}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02]}]], "Output",
 CellChangeTimes->{3.527037720690586*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{"ListLinePlot", "[", "co2", "]"}]}]], "Input",
 CellChangeTimes->{{3.527037613654027*^9, 3.527037628604097*^9}, {
  3.52703769246274*^9, 3.527037706151183*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJxdl01oXFUUx0crwaKLQEsQzOJVJfhRZGxqtDra2yYdY03bydekadL0ZSaZ
ZDKTzIyLbprFEyEbuwgIgUoWA0pA6qJuCsUsngiF0giCIC66eFAQhSwiQkEI
YtLz+yt3ZnP55X/OPfeee+65L0cKtaHZJ1Op1PNPpFL7o/12Tnbv/+43HH9w
P27t/Z4VP+2+uLH3+74Ot7vH9kXxYeOfa/BzZn9CeqfxuDgw+2viF0y/sQS/
ZHxvEe5ypf3fivhl01+pwq+afrcEHzXemINft3h/idM2rorfMPtH4mO2/2/K
cLf5v7gAH2/hN209X8u/x/yvi98y+17Zv0088Qmz35L9OzbfnQr8rukDss8Y
V+fh94y35f++jaH0k9grX478wJFjP4p3yo8fnbIxkf9p7Dmv6DT71fn0mv6p
5u/lfLT+PhsDzQ+npJ+x+Aflf4b5FT9r8x8gXpQ1PSP9A+MH8ofXtb5+6kl6
f4v+oem/SIfvSj9rfFv7P2vrLav+P+L+UN8R/JXqfcD889IHqGfdt3NmfxiO
ztk4L//znI/8z5t9p/wvMMr/guXrc/nnjCfQHXxA9jkb++EY/b78B6l32A36
+4vgZfkPmv+w1jfkr9cN2Xzfyn/I32+MXlb8Yctfj/yHTT+i9cN/Kv4w90Px
R2w9N+U/YvafKP6IzX9V8UdsTCv+KOfL+btR/q56Qe+knuNR8q9+kjf+gfvp
8vRL9ChvYw6O8+RT93mMfiB/+CgcjVGv9IN4jPsk/4s2rsr/ot9/IvQmeoy+
q/4yjg47OC3/ce6r1j/e0n8v2Xr+pl+7S2a/qfWj31F8+J78J8if4k/QT5U/
eEP5h3vU3yaJr/1P2liX/yT3U/6T1I/6y2Ubd2AHO/Wzy/Q/OIaH9b5N2RjS
L9yU6Q/Vz6bYD/bxFPmU/xXT27B38Jrq74rfr2I4K/+QeoSD0PLxh+o5ZB7W
F4bm36H7AZfQmyH1p/Uy30E4wT6v+NPkT/GnuW/Kx7Q/fzjNe6x+i3873MR+
RecFt5H/BP5N96/g38+gQD9Hd+hVOCz473VU8N+LZsHGnPJd4H2EE/R21U+R
/oEewBmdZ5F6ZX8hvKH9wyvKf7El//C28l/ke035nyEfij/jv2duhvuo+DP+
fBG8rvhwRv1yxsY6/TVBX1b/nKWe8Q/gjM4f3iJfIVzV/ZrlfeY8mnCb+g32
m+iJ/NX/StwXOKAPJeoHJdaj80eP1B/Ql+Em8/Wo/kp+fSUlf72pOf/7I5ij
vyo++lXsQ3hN/RXOYt/E/4H6JXoH9slcy/flPPvT/uf9+Rz6Fhyid6k/y177
l532j/+29o/9I/Xfst9PA3hA/bTccv7E0fdnhH6d+Zpl1qd+W/bfgwReU/4X
/PchWOA+Kv6C//9GCLep/uEO9R84S/3GzLeu+7fQ8n1aoX60/wrr1/1H31R8
9TG9D+gZxa/4/TOu+N+fScXu/yHdvyr1ov5bNf0ZfQ9V/flCeE37x39X9x+9
S/HRn1J89KziL5reBweL/vejW7T1fAmH8EO9P4s23z9wE71b33vkaVXxmX9X
8Zf8/QbwIe1/ifqAQ+kfEx+9DW6i34RjuKj+t0S+9f1ZM72i+OTtd+2/Rv0q
/zX/vCPpen/grN6fml+PCdyh96/O/uD2OvUKB3X/fqVlD7u6/77m4C71K50r
faGOnlX/kn35v3Oy+65+Uvf776263z9j+Db35yfVCZz8f86Ph526X+97/xd5
71t7w87jM60b/TicbvBe6n1q+PnNNfz6DZnvNc5X72Co/0/Qr8Gr8Hdwk/n6
4FuMvzbcv4nA5f8=
     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesOrigin->{0, 180.},
  PlotRange->{{0., 283.}, {180., 298.7}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02]}]], "Output",
 CellChangeTimes->{3.527037629596279*^9, 3.527037695834721*^9}]
}, Open  ]],

Cell[TextData[{
 "\n\n\n\n",
 StyleBox["Wavelet Analysis \n", "Subtitle"],
 "\n\nUse Wavelets to find the Trend and shape of the underlying data, in \
this case the real shape is {0,0,0,0} in the plot below i.e. fairly periodic, \
Haar Wavelet is used as the default:"
}], "Text",
 CellChangeTimes->{{3.527040786742173*^9, 3.527040829266326*^9}, {
  3.527203135033688*^9, 3.527203157217142*^9}, {3.527203225676219*^9, 
  3.527203237734541*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"co2dwd", "=", 
   RowBox[{"DiscreteWaveletTransform", "[", 
    RowBox[{"co2", ",", "Automatic", ",", "4"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"WaveletListPlot", "[", 
  RowBox[{"co2dwd", ",", 
   RowBox[{"Ticks", "\[Rule]", "Full"}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.5270351622816267`*^9, 3.527035234561227*^9}, 
   3.527035296754675*^9}],

Cell[BoxData[
 GraphicsBox[{{
    TagBox[
     TooltipBox[{{}, {}, 
       {RGBColor[0.24720000000000014`, 0.24, 0.6], 
        LineBox[{{0., 0.8730419692195278}, {16.647058823529413`, 
         0.7489153765355985}, {33.294117647058826`, 0.826916929259716}, {
         49.94117647058824, 0.9485317623418734}, {66.58823529411765, 1.}, {
         83.23529411764706, 0.7830981412978947}, {99.88235294117648, 
         0.7188427638489291}, {116.52941176470587`, 0.8507786454765492}, {
         133.1764705882353, 0.8706900488651412}, {149.8235294117647, 
         0.8517833493172581}, {166.47058823529412`, 0.8602776636068866}, {
         183.11764705882354`, 0.7381604786043752}, {199.76470588235296`, 
         0.7828697995159154}, {216.41176470588235`, 0.8802575695300725}, {
         233.05882352941174`, 0.961433073023702}, {249.70588235294116`, 
         0.9528017536648854}, {266.3529411764706, 0.7911586062017628}, {283., 
         0.9923962186600906}}]}},
      RowBox[{"{", 
        RowBox[{"0", ",", "0", ",", "0", ",", "0"}], "}"}]],
     Annotation[#, {0, 0, 0, 0}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[{{}, {}, 
       {RGBColor[0.6, 0.24, 0.4428931686004542], 
        LineBox[{{0., 3.5}, {16.647058823529413`, 2.402133580705008}, {
         33.294117647058826`, 2.481447124304267}, {49.94117647058824, 
         2.0839517625231907`}, {66.58823529411765, 2.460111317254175}, {
         83.23529411764706, 3.18529684601113}, {99.88235294117648, 
         2.312384044526902}, {116.52941176470587`, 2.2488404452690167`}, {
         133.1764705882353, 2.839749536178107}, {149.8235294117647, 
         2.133812615955473}, {166.47058823529412`, 3.2567254174397022`}, {
         183.11764705882354`, 2.750231910946197}, {199.76470588235296`, 
         2.2924397031539883`}, {216.41176470588235`, 2.327922077922078}, {
         233.05882352941174`, 2.2493042671614107`}, {249.70588235294116`, 
         3.373144712430425}, {266.3529411764706, 2.12847866419295}, {283., 
         2.2915120593692024`}}]}},
      RowBox[{"{", 
        RowBox[{"0", ",", "0", ",", "0", ",", "1"}], "}"}]],
     Annotation[#, {0, 0, 0, 1}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[{{}, {}, 
       {RGBColor[0.6, 0.5470136627990908, 0.24], LineBox[CompressedData["
1:eJxTTMoPSmViYGBQAWIQDQNfTaM/KDKIOux7pA1ECg4QUQko38DhW7W2xmQ7
EQfZK45AZOFQYbVVOrdaGCrv4MD0j2eWUqCIQ+7tbbm3zVwc8la6Ka5PFYaq
93Awcp/K981ByOHsGSDw8XHQPdWo7nQcpj/Awb7Pl7Vjl7CDaPxH0XjDIAdd
5h02SRuFoOaFOPBfjkgr+SbucDS85mi4TZiDt1bynp2lMPdEOLzwOrjqBb+I
Q2kAe2mAe5TDpYNyHgu2wuyLcdi35nZp6T0hBxXPSSqeQXEO7cdtvQqMRaD2
JzjcbOJnfLFPxOHVAr5XC/QSHZ5NavEw/ysGdU+Sw7qufw0/Nwk5gGyTNUl2
OMoiEi3MBfNvioM+1L0zQcAy1cHMgqPtuK0Y1L1pDi0b31/oeCHk8BFkoH26
wyUnid98vTD3Zzhc3FberSMg5ABy3iSXTIfGd9ybkg1Eof7Jcpg0p1Ps0A1h
h4VA5/F5ZTu8F4tUWLIP5r8cB45HT98t+ins8LNr/Y8u/1wHjZt8GwpOCUP9
m+fw7q4Sd8sVYQeQceyh+Q7ZCyadksgXg/q/wOGq95nApc2iDmDnrC1weM27
9CTvCUFoeBQ6bN0bndI4QQiSLjYUOvwud4258UDEAQAY7u4k
         "]]}},
      RowBox[{"{", 
        RowBox[{"0", ",", "0", ",", "1"}], "}"}]],
     Annotation[#, {0, 0, 1}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[{{}, {}, 
       {RGBColor[0.24, 0.6, 0.33692049419863584`], LineBox[CompressedData["
1:eJw1VAtQTGsc3+t5zVDMcBvt+c7ZZRWzXVd0GyXXT9JGSXrcQlltj5W2dpNt
hptnNIpETR7jtZkQM9Q0Wd1KE1kRKpd7zdySIQyhsVHousZ32u/85ztz5pvz
nf//9zpHqTOGJw2TyWQaeol3qf4PPufcrhPQ8ExN13g8na3a4WUkbK+AuvDP
6KbJAsjDhXRNxzwtNzlnv/R8FvRtAXHX33JI67CmdXh7IbPz+C/798nZ+bl4
r3izIDuCx727tEL8YO19PmWxwZW9D0xdbNj4JpTDJK19ktbTH/H64mxdlcD6
BaBrYHWu6gAHW3S2LdovEEET5I9riwnrHwRu+q8FWjWBOWy0OUyzFEpxnIyw
eSE49sF20PMVD9WSItWS8FD05g+EPJzGs/lh6Ke7u5d49FiceiwzV+D2oPOT
iY2E4QlHc6L8raGIQJxGvCIQzOY78EXiRGzZnoJ0AUfF8omCIefEsr48geH9
HWNj/rpzysrDLjZcEI35/ePHqusl/DHIvNczqyWShwivKGAlTlnbt0+7yjM+
q9Dg2vpjSTOPUgrPaelqbHv98YdVHpKesYi9fzKvdpccX/IrPucvj0Pct+rd
ozzkjO8abK3vGum0m4fYbnSUFiUvcD7lK8f4r4Uqks+syCUYgnNxLRbWyP/j
DxKmRzy2FN4ac/0xj6GwVMYjtPtRywYLz/TRQdFZQI/I4SE2rNJhSJ69PNMr
AW0umpuWbg4xVI7sywkwM74O/RLhy/K0y7c8x7cmEWEh1mutbpKeSXh2oTor
8mcFKj9TgrVJ8B0CKOmbjMEHP7lWlhF00nbWq8l4/9vy+SOaOKa3HtX60zPj
swSI9M2NeuiDhqV0DUj6r8Nh5ZiyTR0Ec8RqWofgI3FUUY75kYKWhN6/TYE8
RLp2Wwr+9R9+6GOflLf1yJ3j/8LzE4e9VP6KW+uhKfd7uWacgvmVisJ+oWHG
doIrIuE7qThz1p6a5CP5Z8AfuqpxWd4CukU7Wg24QdNa40OYn2k4GipYbDsJ
nEVD2tPwhLr5qpkwf9PR3KB5PuIph3lUvvIH6bhf+KiusVTy24gbgVfoF6eA
PpnWP0aHjzIl89+EOrO7ywwdcfA1mKCub4twvsazPJjgXSse4Bz835kwd6oY
GI7lIwN19O9Q2sfyasyAU5b3bXc3wvKSgR2LlIP2zQTfAaWf4U8=
         "]]}},
      RowBox[{"{", 
        RowBox[{"0", ",", "1"}], "}"}]],
     Annotation[#, {0, 1}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[{{}, {}, 
       {RGBColor[0.24, 0.3531726744018182, 0.6], LineBox[CompressedData["
1:eJxFlglMVEccxlGiVq0UpN7V2p1ZsdYTrQdV+bxFKLCcyyGyCwssyx7YVmtb
KxqL1gtRRAQKNWrReNSrtsZqjFcPalBExINS8arGSkTrUU3TmXkzr5tsNi9v
3rz///t+33/2Las7ytbWy8trDfvyX/VZs7Dg544nKFK//ykx38cLT1qrhoxK
Vde+qLcU7fh4D4Hv+neW/9KtJz7nyxuJvN8f5/OMR1/aKcZtW/AwoCtFv0L/
pUf2Ubl+IJ4tL+9/bTXB3bzGfo5eg9GafCBoVaDafzgaG56yFQRhe/oPiPcN
hFaV2m8UqmPGX9rlQ0HLa3985j8azy907713q6pnrFxvwMsvl0aX9gjCoiuT
vYsfU/m+8WjY5bMl7DRB3fzR997rMxGOuGWmb5pV/cCpgdEPkw8Q1Ad+eNz1
2iR0GHz3VkSSqmcyMgZVsEcoTrx9dmWw3xS8tHfuYq4lsr6poHOXeMY8MUAs
95+Gkd1q3t15ksh6p+v6lfVYZLj++gw8F3oofWbixuGMj3raKJb5NPy1r3sI
jq9L+ffgF0T2MwsVomCCue1GHF7SMxT57XmBqr8wzOZydqNI4Q/0fh/Df+WC
qX7DsYG9PaEvReij5gj6RgSKH3ODVf+REHIcJujz91er/1kTCd7NBAOVepgQ
8Mr8tCZCUOiZ9ai5wIQmwhumUp8olAQ7N7cJpehw/4m5em0UdjB6QoYRqVc0
eDftBxMszNxy7EBhNCwhw5hFyt8YLOb4dKbg5ZWvi8F28bxR6hkr9aWw8wbX
x+Kc5E3TN076TfDH5e0tOUVxqGrmglKpd7zslyKWfzbE44UAVPFjxso7pRct
RQTV59ocmVBslvUrPxKQze2uNmAyb3hjAsTtRVT6k4itG7kAFELOkkTM4u15
U+lXku7f0ClMoZIkDBB6GqV/yWDmTN+0goCpY2ralIzkLE4AkX7O1vPWK4g5
VjobzBxmifI3Bbs53h8QrP3u1b57y1Lw2dRw3wdnlN9zJF8EvJyS8jkQ2zUo
/1N1/idyw8NTdR41HlLB09ziR/Hcv2PVqJpUmW+VFwvGioIoDpqaLm+PsOh8
arxYMI2Xc4zAVcAKPGcBv5pxU+XLit8qDzFLKTguhZFWqZdB8mRFm9BPWOQp
bnWyzm133oqhQn/FVxouVPMNCL6eOXbbAlOaPm803tKQyboZVEGQlM8MPZ+G
Hmx6bAxW/KXjkACKoPupm52sUem6XxqP6VJPAzge9bXpiBd5oZJPGwSeE4xY
Fcw6jraBT6stYYpXG36X820GL+iCDVuZW2fvqfmQgfha3gBBW7Z9YEyGzpPG
cwZEPLpQHH3GDKjL0POo8Z0p+yEQOMRm6vVrvGcikeN1h2Iks6vgYqbsR/Gf
pefhwb7izd5xWRDbOVUesrC/xW/cpB8IdrTk1M2vz8K8ND4BiMyHXfc3fQgD
PM6OEWL+UJkXO8TrSynedDCCL9kh8Huq5lu2Xv8V1m5dfLZ+X8tTNrh7jjiK
DbdPV85syAbRBJD5cuj8RnJBzQ5dTy1vDn0edmb4jLjsAJ8WrVVqfuagl9jf
iDOVDKCEHDzix1+IymMO+O5BqwjE8is5uj9aPp3YJq/H88AkOuEn+dby6pR+
UDw1M0WvOjF650lWscqvS56fBPuZ/POSXLrfWp5duO66/+nUcCOc/IGrLuwR
eVf5dsv9KAK6httTkt0YKOShMu9udGXu9XlhwA2Gc+01N/g0qzyk8u+BGMfe
BDXTGaBDPRDHnYnKeeDBGJFvI3bb/sxrdHnkvFbnhUfqRbGC2/nt//e1eeHB
HDn/s7igLR64eTu+6nzJhWjXTDGNB3pYrv5+bZ7k6vPOcL3o9ml3rq6vNl9y
UXaRH7BU+x+wN1fX7z91WLau
         "]]}},
      RowBox[{"{", "1", "}"}]],
     Annotation[#, {1}, "Tooltip"]& ]}, 
   {AbsoluteThickness[0.1], 
    StyleBox[{
      {GrayLevel[0.45], 
       StyleBox[{LineBox[{{{0., 0.}, {283., 0.}}}], {
          DynamicBox[Directive[
            CurrentValue[{GraphicsBoxOptions, TicksStyle}]],
           
           ImageSizeCache->{{4.503599627370496*^15, -4.503599627370496*^15}, {
            4.503599627370496*^15, -4.503599627370496*^15}}], 
          {GrayLevel[0.45]}, {
           {GrayLevel[0.45], 
            LineBox[{{{0., 0.}, Offset[{0., 3.}, {0., 0.}]}, {{50., 0.}, 
               Offset[{0., 3.}, {50., 0.}]}, {{100., 0.}, 
               Offset[{0., 3.}, {100., 0.}]}, {{150., 0.}, 
               Offset[{0., 3.}, {150., 0.}]}, {{200., 0.}, 
               Offset[{0., 3.}, {200., 0.}]}, {{250., 0.}, 
               Offset[{0., 3.}, {250., 0.}]}}]}, 
           {GrayLevel[0.45], 
            LineBox[{{{10., 0.}, Offset[{0., 1.5}, {10., 0.}]}, {{20., 0.}, 
               Offset[{0., 1.5}, {20., 0.}]}, {{30., 0.}, 
               Offset[{0., 1.5}, {30., 0.}]}, {{40., 0.}, 
               Offset[{0., 1.5}, {40., 0.}]}, {{60., 0.}, 
               Offset[{0., 1.5}, {60., 0.}]}, {{70., 0.}, 
               Offset[{0., 1.5}, {70., 0.}]}, {{80., 0.}, 
               Offset[{0., 1.5}, {80., 0.}]}, {{90., 0.}, 
               Offset[{0., 1.5}, {90., 0.}]}, {{110., 0.}, 
               Offset[{0., 1.5}, {110., 0.}]}, {{120., 0.}, 
               Offset[{0., 1.5}, {120., 0.}]}, {{130., 0.}, 
               Offset[{0., 1.5}, {130., 0.}]}, {{140., 0.}, 
               Offset[{0., 1.5}, {140., 0.}]}, {{160., 0.}, 
               Offset[{0., 1.5}, {160., 0.}]}, {{170., 0.}, 
               Offset[{0., 1.5}, {170., 0.}]}, {{180., 0.}, 
               Offset[{0., 1.5}, {180., 0.}]}, {{190., 0.}, 
               Offset[{0., 1.5}, {190., 0.}]}, {{210., 0.}, 
               Offset[{0., 1.5}, {210., 0.}]}, {{220., 0.}, 
               Offset[{0., 1.5}, {220., 0.}]}, {{230., 0.}, 
               Offset[{0., 1.5}, {230., 0.}]}, {{240., 0.}, 
               Offset[{0., 1.5}, {240., 0.}]}, {{260., 0.}, 
               Offset[{0., 1.5}, {260., 0.}]}, {{270., 0.}, 
               Offset[{0., 1.5}, {270., 0.}]}, {{280., 0.}, 
               Offset[{0., 1.5}, {280., 0.}]}}]}}, {
           DynamicBox[Directive[
             CurrentValue[{GraphicsBoxOptions, LabelStyle}]],
            
            ImageSizeCache->{{
             4.503599627370496*^15, -4.503599627370496*^15}, {
             4.503599627370496*^15, -4.503599627370496*^15}}], {{}, {}}, \
{{{}, {{}, {}, {}, {}, {}, {}}}, {{}, {{}, {}, {}, {}, {}, {}, {}, {}, {}, \
{}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}}}}, {}}}},
        Antialiasing->False]}, 
      {GrayLevel[0.45], 
       StyleBox[{LineBox[{{{0., 2.5}, {283., 2.5}}}], {
          DynamicBox[Directive[
            CurrentValue[{GraphicsBoxOptions, TicksStyle}]],
           
           ImageSizeCache->{{4.503599627370496*^15, -4.503599627370496*^15}, {
            4.503599627370496*^15, -4.503599627370496*^15}}], 
          {GrayLevel[0.45]}, {
           {GrayLevel[0.45], 
            LineBox[{{{0., 2.5}, Offset[{0., 3.}, {0., 2.5}]}, {{50., 2.5}, 
               Offset[{0., 3.}, {50., 2.5}]}, {{100., 2.5}, 
               Offset[{0., 3.}, {100., 2.5}]}, {{150., 2.5}, 
               Offset[{0., 3.}, {150., 2.5}]}, {{200., 2.5}, 
               Offset[{0., 3.}, {200., 2.5}]}, {{250., 2.5}, 
               Offset[{0., 3.}, {250., 2.5}]}}]}, 
           {GrayLevel[0.45], 
            LineBox[{{{10., 2.5}, Offset[{0., 1.5}, {10., 2.5}]}, {{20., 2.5},
                Offset[{0., 1.5}, {20., 2.5}]}, {{30., 2.5}, 
               Offset[{0., 1.5}, {30., 2.5}]}, {{40., 2.5}, 
               Offset[{0., 1.5}, {40., 2.5}]}, {{60., 2.5}, 
               Offset[{0., 1.5}, {60., 2.5}]}, {{70., 2.5}, 
               Offset[{0., 1.5}, {70., 2.5}]}, {{80., 2.5}, 
               Offset[{0., 1.5}, {80., 2.5}]}, {{90., 2.5}, 
               Offset[{0., 1.5}, {90., 2.5}]}, {{110., 2.5}, 
               Offset[{0., 1.5}, {110., 2.5}]}, {{120., 2.5}, 
               Offset[{0., 1.5}, {120., 2.5}]}, {{130., 2.5}, 
               Offset[{0., 1.5}, {130., 2.5}]}, {{140., 2.5}, 
               Offset[{0., 1.5}, {140., 2.5}]}, {{160., 2.5}, 
               Offset[{0., 1.5}, {160., 2.5}]}, {{170., 2.5}, 
               Offset[{0., 1.5}, {170., 2.5}]}, {{180., 2.5}, 
               Offset[{0., 1.5}, {180., 2.5}]}, {{190., 2.5}, 
               Offset[{0., 1.5}, {190., 2.5}]}, {{210., 2.5}, 
               Offset[{0., 1.5}, {210., 2.5}]}, {{220., 2.5}, 
               Offset[{0., 1.5}, {220., 2.5}]}, {{230., 2.5}, 
               Offset[{0., 1.5}, {230., 2.5}]}, {{240., 2.5}, 
               Offset[{0., 1.5}, {240., 2.5}]}, {{260., 2.5}, 
               Offset[{0., 1.5}, {260., 2.5}]}, {{270., 2.5}, 
               Offset[{0., 1.5}, {270., 2.5}]}, {{280., 2.5}, 
               Offset[{0., 1.5}, {280., 2.5}]}}]}}, {
           DynamicBox[Directive[
             CurrentValue[{GraphicsBoxOptions, LabelStyle}]],
            
            ImageSizeCache->{{
             4.503599627370496*^15, -4.503599627370496*^15}, {
             4.503599627370496*^15, -4.503599627370496*^15}}], {{}, {}}, \
{{{}, {{}, {}, {}, {}, {}, {}}}, {{}, {{}, {}, {}, {}, {}, {}, {}, {}, {}, \
{}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}}}}, {}}}},
        Antialiasing->False]}, 
      {GrayLevel[0.45], 
       StyleBox[{LineBox[{{{0., 5.}, {283., 5.}}}], {
          DynamicBox[Directive[
            CurrentValue[{GraphicsBoxOptions, TicksStyle}]],
           
           ImageSizeCache->{{4.503599627370496*^15, -4.503599627370496*^15}, {
            4.503599627370496*^15, -4.503599627370496*^15}}], 
          {GrayLevel[0.45]}, {
           {GrayLevel[0.45], 
            LineBox[{{{0., 5.}, Offset[{0., 3.}, {0., 5.}]}, {{50., 5.}, 
               Offset[{0., 3.}, {50., 5.}]}, {{100., 5.}, 
               Offset[{0., 3.}, {100., 5.}]}, {{150., 5.}, 
               Offset[{0., 3.}, {150., 5.}]}, {{200., 5.}, 
               Offset[{0., 3.}, {200., 5.}]}, {{250., 5.}, 
               Offset[{0., 3.}, {250., 5.}]}}]}, 
           {GrayLevel[0.45], 
            LineBox[{{{10., 5.}, Offset[{0., 1.5}, {10., 5.}]}, {{20., 5.}, 
               Offset[{0., 1.5}, {20., 5.}]}, {{30., 5.}, 
               Offset[{0., 1.5}, {30., 5.}]}, {{40., 5.}, 
               Offset[{0., 1.5}, {40., 5.}]}, {{60., 5.}, 
               Offset[{0., 1.5}, {60., 5.}]}, {{70., 5.}, 
               Offset[{0., 1.5}, {70., 5.}]}, {{80., 5.}, 
               Offset[{0., 1.5}, {80., 5.}]}, {{90., 5.}, 
               Offset[{0., 1.5}, {90., 5.}]}, {{110., 5.}, 
               Offset[{0., 1.5}, {110., 5.}]}, {{120., 5.}, 
               Offset[{0., 1.5}, {120., 5.}]}, {{130., 5.}, 
               Offset[{0., 1.5}, {130., 5.}]}, {{140., 5.}, 
               Offset[{0., 1.5}, {140., 5.}]}, {{160., 5.}, 
               Offset[{0., 1.5}, {160., 5.}]}, {{170., 5.}, 
               Offset[{0., 1.5}, {170., 5.}]}, {{180., 5.}, 
               Offset[{0., 1.5}, {180., 5.}]}, {{190., 5.}, 
               Offset[{0., 1.5}, {190., 5.}]}, {{210., 5.}, 
               Offset[{0., 1.5}, {210., 5.}]}, {{220., 5.}, 
               Offset[{0., 1.5}, {220., 5.}]}, {{230., 5.}, 
               Offset[{0., 1.5}, {230., 5.}]}, {{240., 5.}, 
               Offset[{0., 1.5}, {240., 5.}]}, {{260., 5.}, 
               Offset[{0., 1.5}, {260., 5.}]}, {{270., 5.}, 
               Offset[{0., 1.5}, {270., 5.}]}, {{280., 5.}, 
               Offset[{0., 1.5}, {280., 5.}]}}]}}, {
           DynamicBox[Directive[
             CurrentValue[{GraphicsBoxOptions, LabelStyle}]],
            
            ImageSizeCache->{{
             4.503599627370496*^15, -4.503599627370496*^15}, {
             4.503599627370496*^15, -4.503599627370496*^15}}], {{}, {}}, \
{{{}, {{}, {}, {}, {}, {}, {}}}, {{}, {{}, {}, {}, {}, {}, {}, {}, {}, {}, \
{}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}}}}, {}}}},
        Antialiasing->False]}, 
      {GrayLevel[0.45], 
       StyleBox[{LineBox[{{{0., 7.5}, {283., 7.5}}}], {
          DynamicBox[Directive[
            CurrentValue[{GraphicsBoxOptions, TicksStyle}]],
           
           ImageSizeCache->{{4.503599627370496*^15, -4.503599627370496*^15}, {
            4.503599627370496*^15, -4.503599627370496*^15}}], 
          {GrayLevel[0.45]}, {
           {GrayLevel[0.45], 
            LineBox[{{{0., 7.5}, Offset[{0., 3.}, {0., 7.5}]}, {{50., 7.5}, 
               Offset[{0., 3.}, {50., 7.5}]}, {{100., 7.5}, 
               Offset[{0., 3.}, {100., 7.5}]}, {{150., 7.5}, 
               Offset[{0., 3.}, {150., 7.5}]}, {{200., 7.5}, 
               Offset[{0., 3.}, {200., 7.5}]}, {{250., 7.5}, 
               Offset[{0., 3.}, {250., 7.5}]}}]}, 
           {GrayLevel[0.45], 
            LineBox[{{{10., 7.5}, Offset[{0., 1.5}, {10., 7.5}]}, {{20., 7.5},
                Offset[{0., 1.5}, {20., 7.5}]}, {{30., 7.5}, 
               Offset[{0., 1.5}, {30., 7.5}]}, {{40., 7.5}, 
               Offset[{0., 1.5}, {40., 7.5}]}, {{60., 7.5}, 
               Offset[{0., 1.5}, {60., 7.5}]}, {{70., 7.5}, 
               Offset[{0., 1.5}, {70., 7.5}]}, {{80., 7.5}, 
               Offset[{0., 1.5}, {80., 7.5}]}, {{90., 7.5}, 
               Offset[{0., 1.5}, {90., 7.5}]}, {{110., 7.5}, 
               Offset[{0., 1.5}, {110., 7.5}]}, {{120., 7.5}, 
               Offset[{0., 1.5}, {120., 7.5}]}, {{130., 7.5}, 
               Offset[{0., 1.5}, {130., 7.5}]}, {{140., 7.5}, 
               Offset[{0., 1.5}, {140., 7.5}]}, {{160., 7.5}, 
               Offset[{0., 1.5}, {160., 7.5}]}, {{170., 7.5}, 
               Offset[{0., 1.5}, {170., 7.5}]}, {{180., 7.5}, 
               Offset[{0., 1.5}, {180., 7.5}]}, {{190., 7.5}, 
               Offset[{0., 1.5}, {190., 7.5}]}, {{210., 7.5}, 
               Offset[{0., 1.5}, {210., 7.5}]}, {{220., 7.5}, 
               Offset[{0., 1.5}, {220., 7.5}]}, {{230., 7.5}, 
               Offset[{0., 1.5}, {230., 7.5}]}, {{240., 7.5}, 
               Offset[{0., 1.5}, {240., 7.5}]}, {{260., 7.5}, 
               Offset[{0., 1.5}, {260., 7.5}]}, {{270., 7.5}, 
               Offset[{0., 1.5}, {270., 7.5}]}, {{280., 7.5}, 
               Offset[{0., 1.5}, {280., 7.5}]}}]}}, {
           DynamicBox[Directive[
             CurrentValue[{GraphicsBoxOptions, LabelStyle}]],
            
            ImageSizeCache->{{
             4.503599627370496*^15, -4.503599627370496*^15}, {
             4.503599627370496*^15, -4.503599627370496*^15}}], {{}, {}}, \
{{{}, {{}, {}, {}, {}, {}, {}}}, {{}, {{}, {}, {}, {}, {}, {}, {}, {}, {}, \
{}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}}}}, {}}}},
        Antialiasing->False]}, 
      {GrayLevel[0.45], 
       StyleBox[{LineBox[{{{0., 10.}, {283., 10.}}}], {
          DynamicBox[Directive[
            CurrentValue[{GraphicsBoxOptions, TicksStyle}]],
           
           ImageSizeCache->{{4.503599627370496*^15, -4.503599627370496*^15}, {
            4.503599627370496*^15, -4.503599627370496*^15}}], 
          {GrayLevel[0.45]}, {
           {GrayLevel[0.45], 
            LineBox[{{{0., 10.}, Offset[{0., 3.}, {0., 10.}]}, {{50., 10.}, 
               Offset[{0., 3.}, {50., 10.}]}, {{100., 10.}, 
               Offset[{0., 3.}, {100., 10.}]}, {{150., 10.}, 
               Offset[{0., 3.}, {150., 10.}]}, {{200., 10.}, 
               Offset[{0., 3.}, {200., 10.}]}, {{250., 10.}, 
               Offset[{0., 3.}, {250., 10.}]}}]}, 
           {GrayLevel[0.45], 
            LineBox[{{{10., 10.}, Offset[{0., 1.5}, {10., 10.}]}, {{20., 10.},
                Offset[{0., 1.5}, {20., 10.}]}, {{30., 10.}, 
               Offset[{0., 1.5}, {30., 10.}]}, {{40., 10.}, 
               Offset[{0., 1.5}, {40., 10.}]}, {{60., 10.}, 
               Offset[{0., 1.5}, {60., 10.}]}, {{70., 10.}, 
               Offset[{0., 1.5}, {70., 10.}]}, {{80., 10.}, 
               Offset[{0., 1.5}, {80., 10.}]}, {{90., 10.}, 
               Offset[{0., 1.5}, {90., 10.}]}, {{110., 10.}, 
               Offset[{0., 1.5}, {110., 10.}]}, {{120., 10.}, 
               Offset[{0., 1.5}, {120., 10.}]}, {{130., 10.}, 
               Offset[{0., 1.5}, {130., 10.}]}, {{140., 10.}, 
               Offset[{0., 1.5}, {140., 10.}]}, {{160., 10.}, 
               Offset[{0., 1.5}, {160., 10.}]}, {{170., 10.}, 
               Offset[{0., 1.5}, {170., 10.}]}, {{180., 10.}, 
               Offset[{0., 1.5}, {180., 10.}]}, {{190., 10.}, 
               Offset[{0., 1.5}, {190., 10.}]}, {{210., 10.}, 
               Offset[{0., 1.5}, {210., 10.}]}, {{220., 10.}, 
               Offset[{0., 1.5}, {220., 10.}]}, {{230., 10.}, 
               Offset[{0., 1.5}, {230., 10.}]}, {{240., 10.}, 
               Offset[{0., 1.5}, {240., 10.}]}, {{260., 10.}, 
               Offset[{0., 1.5}, {260., 10.}]}, {{270., 10.}, 
               Offset[{0., 1.5}, {270., 10.}]}, {{280., 10.}, 
               Offset[{0., 1.5}, {280., 10.}]}}]}}, {
           DynamicBox[Directive[
             CurrentValue[{GraphicsBoxOptions, LabelStyle}]],
            ImageSizeCache->{{
             4.503599627370496*^15, -4.503599627370496*^15}, {
             4.503599627370496*^15, -4.503599627370496*^15}}], {{}, {}}, \
{{{}, {{}, {}, {}, {}, {}, {}}}, {{}, {{}, {}, {}, {}, {}, {}, {}, {}, {}, \
{}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}}}}, {}}}},
        Antialiasing->False]}},
     Antialiasing->False]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesOrigin->{0, -2.5},
  AxesStyle->Automatic,
  FrameTicks->{{{{-2.5, 
       FormBox["\"\"", TraditionalForm]}, {0., 
       FormBox["\"\"", TraditionalForm]}, {2.5, 
       FormBox["4", TraditionalForm]}, {5., 
       FormBox["3", TraditionalForm]}, {7.5, 
       FormBox["2", TraditionalForm]}, {10., 
       FormBox["1", TraditionalForm]}}, {{-2.5, 
       FormBox["\"\"", TraditionalForm]}, {0., 
       FormBox["\"\"", TraditionalForm]}, {2.5, 
       FormBox["\"\"", TraditionalForm]}, {5., 
       FormBox["\"\"", TraditionalForm]}, {7.5, 
       FormBox["\"\"", TraditionalForm]}, {10., 
       FormBox["\"\"", TraditionalForm]}}}, {Automatic, Automatic}},
  GridLines->{None, None},
  PlotRange->{All, {-2.5, 12.5}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02]},
  Ticks->{Automatic, {{-2.5, 
      FormBox["\"\"", TraditionalForm]}, {0., 
      FormBox[
       RowBox[{"{", 
         RowBox[{"0", ",", "0", ",", "0", ",", "0"}], "}"}], 
       TraditionalForm]}, {2.5, 
      FormBox[
       RowBox[{"{", 
         RowBox[{"0", ",", "0", ",", "0", ",", "1"}], "}"}], 
       TraditionalForm]}, {5., 
      FormBox[
       RowBox[{"{", 
         RowBox[{"0", ",", "0", ",", "1"}], "}"}], TraditionalForm]}, {7.5, 
      FormBox[
       RowBox[{"{", 
         RowBox[{"0", ",", "1"}], "}"}], TraditionalForm]}, {10., 
      FormBox[
       RowBox[{"{", "1", "}"}], TraditionalForm]}}},
  TicksStyle->Automatic]], "Output",
 CellChangeTimes->{{3.527035218339472*^9, 3.527035235465905*^9}, 
   3.527035793875266*^9, 3.527035826183642*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"co2dwd", "[", 
  RowBox[{"Automatic", ",", 
   RowBox[{"{", "\"\<ListPlot\>\"", "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.5270366176463547`*^9, 3.5270366243486223`*^9}, {
  3.527037867829064*^9, 3.527037882666803*^9}, {3.527044289475748*^9, 
  3.527044309451997*^9}, {3.527044355512539*^9, 3.5270443575135183`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"{", "1", "}"}], "\[Rule]", 
    GraphicsBox[{{}, {}, 
      {RGBColor[0.24, 0.3531726744018182, 0.6], LineBox[CompressedData["
1:eJxFlgtQVFUYxy8goIjsCstThAVW8QUGMoii3k9MIV+wLMhTXJbHArvswxyN
nPSOk5pmroTii5LG8dmoiDVmWnuilEoNtA1FM/ARI5FgokJq0bn3nHvbmZ2d
b869537n///9v7thOnN6iTPDMNvxl/8VP3JTYl2SQwnas825m7wY4My7DV4N
clrLAXmEMpdSPJG8ZvJ7P/gGABdzoIdtGrCTdSXUa5PPcDpvmHGo6q9IbxVw
Tw8brI4QINdPAG3Gqb1br/igbu5OiCFwCjBlZlvyFie6/2sgz/7WvXdFBFp8
Ujk+Sx4LYl9kvzhg0tj8vOUPWFXd9QuDPvHAPVpnO35CRvtJgLfYGodTXDx6
teVdzT7/mSBP8ed2xo8D8rxZAKn8/cOQY038H4lj5gAn1E9p/wBcoPkLTa0H
aotdhUyyuQDD9YXR1cG0nyTg4rK23qjyh6aJV99nR8+jzx+yk/5eB2WCYXDm
qEgkXO4zH7iFLSFTeoch0u8CSb/9/uvD7yqSAU1aI6vaH0D1SaF6jIbNXjcf
nfZ7A5RC/770PAsBnvReaQ+WoZWuMec2BCwCJLPNfnZ2JD3fYmCc2I36ikds
AX9D0BJg3E411bZ70vMuFc/LLuq/l6oKToWGUh+09kQYIudPA4iaelKuGY7G
PPvogxfb00R/WaKHGrjctYc3+kegasvC/ns2NTA5oTfOJboA0ScduJCOZxtc
PcD9z+fZl3ekw2PdkDogKBwRvTSUj3D0jv7g12eqNcBMl000x7hTXjKA6eX1
7GD59uo+zIDOMZFZPUsmAdEzE1oXnG/4PncclPMHrMkEjvJG9F0m3m/vbD/a
Z9yJ68qOK6sHH7NE7yxgivh+nCGT/+zCdSx/PnfKTzYoC2yK7uPe6HKr0/nZ
tdnArEz1OKxnqB85AAE+3Zu/nISS+APvzoF66Dt4VeYHxJ9cYLT8/o2sIOce
XJfxdRNL/MqT/IuehxXakwcW1afO69ImUv/yqT8KhNVRd+zNF/ezEz+XS3kL
nIkd27ec9u9P/S0ARvAvAO343HNsw/4CsFRERndAGBC/VwDjfzbwwm9BiG9n
Tx2ufYfeVkW+pPxrJf7n8IYv1Uo8Eh5wPcFuuXv/Ifu3z4gjcS1aQAr+/pE0
L4XAzFpf+nF9G/uZuqP9aGqhxCfhBdeJ/LobMtlwg62FwAn89NsJPzrKzwuW
x6U6TQfyVz8lJ7yMQoQnHTBC3vrY3z10K12v6QDmTHeNz/ajfBWJfqD6lIRD
VeoiADpvCG9FgIw8D3KUtwkbeg3XwvVulL9iYIoFv+x+3z3w0KUXS34RHouB
E847GfF4tF3H66vcj80OVVI+S6BT3uP5Tc1k2MbiE2tKRD0pryXA0PmWzDf0
M64ZIa92wm+pyBtyxtvHZpRKPBGeSym/99ivBrEBjlKw0DwSvvUAwrxWIgGH
TL3UP+FdD53qgRdPFCqYhu2y/aKn+rhQ/sukPPServ3EZVkZQETqtMZVgTQP
uBb8H46O9Rkda9pwPe9IUkmzLyL5KJf8LY7CgC8rB0bwbyyQvJSL/EGoARN8
o1zkxU7yUyH1fwsf15FVIa2TPFXQ/UbBrq6LB1JuVgAnPO+5neTLIPGbxgua
bZD0JHkzSPNwJMYnpt0A4DIQMRQ2lubPCNy/m7paGqPg0gEMUI4RtAJvoTSP
RqqfAgmX3zJiP4k/JJ+VNO+N7Cw+MLmVdD7207xWQqcr//xgGMjGit7G60Le
H9hJfk2gFfgPQo1Y/tV5JslvkmcT1A/T9P/4zxSo5G+4jdfThX5ovs30faOC
SO+l5QX5uBb8GmRJ3s3QKug1Ht3HOF//1Uz9HUHnvwUez1305t6ecahlAQY0
2iK+r4DMAwukzWhuduseDydKHnJ3TBbx/UrfFxZxP9jK23nq/3UyLyywg87/
Ml7QPgv1t4u+X6zADBR4jNjmBfP5QE+1Ss8n88Qqzbvwuzu7Lpqtkr5kvljp
+RXkf0ODVdLvPxvd0GY=
        "]]}},
     AspectRatio->0.4,
     AxesOrigin->{0, 0},
     AxesStyle->Automatic,
     FrameTicks->{{Append[
         N[
          FindDivisions[{
            SlotSequence[1]}, 4]], {
          Mean[{
            SlotSequence[1]}], 
          Invisible["-1234"], {0, 0}}]& , Map[{#, 
          Spacer[{0, 0}]}& , 
         FindDivisions[{
           SlotSequence[1]}, 4]]& }, {N[
         FindDivisions[{
           SlotSequence[1]}, 5]]& , Map[{#, 
          Spacer[{0, 0}]}& , 
         FindDivisions[{
           SlotSequence[1]}, 4]]& }},
     ImageSize->Scaled[0.2],
     PlotRange->{{0., 283.}, {-45, 1095}},
     PlotRangeClipping->True,
     PlotRangePadding->{
       Scaled[0.02], 
       Scaled[0.02]},
     Ticks->{N[
        FindDivisions[{
          SlotSequence[1]}, 5]]& , Append[
        N[
         FindDivisions[{
           SlotSequence[1]}, 4]], {
         Mean[{
           SlotSequence[1]}], 
         Invisible["-1234"], {0, 0}}]& },
     TicksStyle->Automatic]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"0", ",", "1"}], "}"}], "\[Rule]", 
    GraphicsBox[{{}, {}, 
      {RGBColor[0.24, 0.6, 0.33692049419863584`], LineBox[CompressedData["
1:eJw1U11I01EUn31gVtiWLrRSZjozHLJq2VJhP0syZdSybNqX35tfc/PBNx+E
erIewqd8ar2IL6EUmQS1AyEIrRCKXuxhFPQgBO2ljIL6n3uOh40/9557z/l9
nFvWG28b2Gaz2ZqtP3+3Aic5qvH6S7X1s8Nm1gdI1i4kZzncKPnYaP2qgAiH
Q/NeLHK62E2x9aXYeq0Pa2kr9vpJzvsxZe7n4R3vBxskf79R7wMPTd5Lzq6s
s+v4WXRz+TkvpF4TvAaPh1bCkyvhhvOKx671L0i9oIsmQrkToeZWPDD5cpJ+
QRB/02WoaJmpaGm7CJuP6/0KSP8Qpkz+IDaS+RvJmsuKd7viadO8nbhbie8K
oP0F31U5X+yR7TPtcBm8NRC815D5x3EIWS4YCCueHYq/A2TyeWB4M02dev4w
hM915VuKxxa8/NYb6s+fgPC7KflOP/2eXticvnQLu9hUqifhe1v0jBSCy+W2
dyHBy2/lqn+38t1PBs6TbshUOEj06MEPg8cl+4s9iqcIok+v7NMp8nDBp73a
zwnRq0/5uqnDkmPyeR/kwm71t1/PO+hu3fyduuV+rV+peg7IfBSfxuKmRfDl
AOzmfqXqG1H99tBnq9zSq4jOQxWJ3lHx45kHTH+CorD1c79PKdF/EFOm/8+U
kfXNICDnSfwYUn12gulmV4ZUn0xK/BlGxvSroHuW/Aurw6LvnE/9GgGZ+wX0
ggm/HdF6OfoeRpE0+hzFV7bj/SjI4ClVP2PqdwHtY0PWttY56u+Y4qmkeku+
+Q9jqneR+h2XdbAWUUM7jr8s16Nz+t4TOq9Fwnc0ofqXQOYhgVXznk+Q4f89
Ifqmj+l8jMv7nz0i8xofV71dJPMyrvoW0n+evP6b
        "]]}},
     AspectRatio->0.4,
     AxesOrigin->{0, 0},
     AxesStyle->Automatic,
     FrameTicks->{{Append[
         N[
          FindDivisions[{
            SlotSequence[1]}, 4]], {
          Mean[{
            SlotSequence[1]}], 
          Invisible["-1234"], {0, 0}}]& , Map[{#, 
          Spacer[{0, 0}]}& , 
         FindDivisions[{
           SlotSequence[1]}, 4]]& }, {N[
         FindDivisions[{
           SlotSequence[1]}, 5]]& , Map[{#, 
          Spacer[{0, 0}]}& , 
         FindDivisions[{
           SlotSequence[1]}, 4]]& }},
     ImageSize->Scaled[0.2],
     PlotRange->{{0., 283.}, {-45, 1095}},
     PlotRangeClipping->True,
     PlotRangePadding->{
       Scaled[0.02], 
       Scaled[0.02]},
     Ticks->{N[
        FindDivisions[{
          SlotSequence[1]}, 5]]& , Append[
        N[
         FindDivisions[{
           SlotSequence[1]}, 4]], {
         Mean[{
           SlotSequence[1]}], 
         Invisible["-1234"], {0, 0}}]& },
     TicksStyle->Automatic]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"0", ",", "0", ",", "1"}], "}"}], "\[Rule]", 
    GraphicsBox[{{}, {}, 
      {RGBColor[0.6, 0.5470136627990908, 0.24], LineBox[CompressedData["
1:eJxTTMoPSmViYGBQAWIQDQMfsqM+zhU2dNj3SBuIFBwYdALWRQkGQvkGDg35
07P5Ngg4yF5xBCILhwVpwgeq1yoegMg7ODi4MAsZLhZ1yL29Lfe2mYvDAl/T
pSsnqxyAqPdwaPjLyP39rO2Bs2eAwMfHoeGn2MoFznxQ/QEOB+JfP97SJnRA
NP6jaLxhkMMCO76fGv5mByDmhTikrJ3+ff6LAIej4TVHw23CHBg+mOk5pcpD
3RPhwJB7/0zZjw/2pQHspQHuUQ4CjsemH2Azg9oX47AgovD9ZV/jAyqek1Q8
g+IcGoTc7/Tkc0P9l+CgoOxvvKlE0+HVAr5XC/QSHR4s6jnq2uTpAHFPkkOC
/eQrjCZmB0C2yZokOzC4xD/8U/fUHuK+FIcGqHtngoBlqoNG1JJNkxScoe5N
cyiIS+O4s9DowEeQgfbpDgyxxq6y55Wg7s9w2PDh3pbgdocDIOdNcsl0EAh4
6+zobeIA8U+WQ4PXeTmddywHFgKdx+eV7eDgxnvyUY4p1H85Dgwy/6tU1G/v
/9m1/keXf64DA0d6ot5EHqh/8xwazPg18w3ZD4CMYw/Nd3hxWiyj8KgL1P8F
Dg/khXY63rB0ADtnbYHDjduH3p9653QAEh6FDgu0/7wKbLA4AE4sGwodFP6c
c7f4resAALOC+sQ=
        "]]}},
     AspectRatio->0.4,
     AxesOrigin->{0, 0},
     AxesStyle->Automatic,
     FrameTicks->{{Append[
         N[
          FindDivisions[{
            SlotSequence[1]}, 4]], {
          Mean[{
            SlotSequence[1]}], 
          Invisible["-1234"], {0, 0}}]& , Map[{#, 
          Spacer[{0, 0}]}& , 
         FindDivisions[{
           SlotSequence[1]}, 4]]& }, {N[
         FindDivisions[{
           SlotSequence[1]}, 5]]& , Map[{#, 
          Spacer[{0, 0}]}& , 
         FindDivisions[{
           SlotSequence[1]}, 4]]& }},
     ImageSize->Scaled[0.2],
     PlotRange->{{0., 283.}, {-45, 1095}},
     PlotRangeClipping->True,
     PlotRangePadding->{
       Scaled[0.02], 
       Scaled[0.02]},
     Ticks->{N[
        FindDivisions[{
          SlotSequence[1]}, 5]]& , Append[
        N[
         FindDivisions[{
           SlotSequence[1]}, 4]], {
         Mean[{
           SlotSequence[1]}], 
         Invisible["-1234"], {0, 0}}]& },
     TicksStyle->Automatic]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"0", ",", "0", ",", "0", ",", "1"}], "}"}], "\[Rule]", 
    GraphicsBox[{{}, {}, 
      {RGBColor[0.6, 0.24, 0.4428931686004542], 
       LineBox[{{0., 107.80000000000018`}, {
        16.647058823529413`, -10.550000000000125`}, {
        33.294117647058826`, -2.}, {
        49.94117647058824, -44.850000000000136`}, {
        66.58823529411765, -4.2999999999999545`}, {83.23529411764706, 
        73.87499999999994}, {99.88235294117648, -20.225000000000023`}, {
        116.52941176470587`, -27.075000000000045`}, {133.1764705882353, 
        36.625}, {149.8235294117647, -39.47500000000008}, {
        166.47058823529412`, 81.57500000000005}, {183.11764705882354`, 
        26.97500000000008}, {199.76470588235296`, -22.375000000000114`}, {
        216.41176470588235`, -18.55000000000001}, {
        233.05882352941174`, -27.024999999999977`}, {249.70588235294116`, 
        94.12499999999994}, {266.3529411764706, -40.05000000000007}, {
        283., -22.475000000000023`}}]}},
     AspectRatio->0.4,
     AxesOrigin->{0, 0},
     AxesStyle->Automatic,
     FrameTicks->{{Append[
         N[
          FindDivisions[{
            SlotSequence[1]}, 4]], {
          Mean[{
            SlotSequence[1]}], 
          Invisible["-1234"], {0, 0}}]& , Map[{#, 
          Spacer[{0, 0}]}& , 
         FindDivisions[{
           SlotSequence[1]}, 4]]& }, {N[
         FindDivisions[{
           SlotSequence[1]}, 5]]& , Map[{#, 
          Spacer[{0, 0}]}& , 
         FindDivisions[{
           SlotSequence[1]}, 4]]& }},
     ImageSize->Scaled[0.2],
     PlotRange->{{0., 283.}, {-45, 1095}},
     PlotRangeClipping->True,
     PlotRangePadding->{
       Scaled[0.02], 
       Scaled[0.02]},
     Ticks->{N[
        FindDivisions[{
          SlotSequence[1]}, 5]]& , Append[
        N[
         FindDivisions[{
           SlotSequence[1]}, 4]], {
         Mean[{
           SlotSequence[1]}], 
         Invisible["-1234"], {0, 0}}]& },
     TicksStyle->Automatic]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"0", ",", "0", ",", "0", ",", "0"}], "}"}], "\[Rule]", 
    GraphicsBox[{{}, {}, 
      {RGBColor[0.24720000000000014`, 0.24, 0.6], 
       LineBox[{{0., 955.8500000000004}, {16.647058823529413`, 
        819.9500000000003}, {33.294117647058826`, 905.3500000000004}, {
        49.94117647058824, 1038.5000000000005`}, {66.58823529411765, 
        1094.8500000000004`}, {83.23529411764706, 857.3750000000002}, {
        99.88235294117648, 787.0250000000003}, {116.52941176470587`, 
        931.4750000000003}, {133.1764705882353, 953.2750000000002}, {
        149.8235294117647, 932.5750000000003}, {166.47058823529412`, 
        941.8750000000001}, {183.11764705882354`, 808.1750000000004}, {
        199.76470588235296`, 857.1250000000002}, {216.41176470588235`, 
        963.7500000000002}, {233.05882352941174`, 1052.6250000000005`}, {
        249.70588235294116`, 1043.1750000000002`}, {266.3529411764706, 
        866.2000000000003}, {283., 1086.5250000000005`}}]}},
     AspectRatio->0.4,
     AxesOrigin->{0, 0},
     AxesStyle->Automatic,
     FrameTicks->{{Append[
         N[
          FindDivisions[{
            SlotSequence[1]}, 4]], {
          Mean[{
            SlotSequence[1]}], 
          Invisible["-1234"], {0, 0}}]& , Map[{#, 
          Spacer[{0, 0}]}& , 
         FindDivisions[{
           SlotSequence[1]}, 4]]& }, {N[
         FindDivisions[{
           SlotSequence[1]}, 5]]& , Map[{#, 
          Spacer[{0, 0}]}& , 
         FindDivisions[{
           SlotSequence[1]}, 4]]& }},
     ImageSize->Scaled[0.2],
     PlotRange->{{0., 283.}, {-45, 1095}},
     PlotRangeClipping->True,
     PlotRangePadding->{
       Scaled[0.02], 
       Scaled[0.02]},
     Ticks->{N[
        FindDivisions[{
          SlotSequence[1]}, 5]]& , Append[
        N[
         FindDivisions[{
           SlotSequence[1]}, 4]], {
         Mean[{
           SlotSequence[1]}], 
         Invisible["-1234"], {0, 0}}]& },
     TicksStyle->Automatic]}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.5270366255697203`*^9, {3.527037873685713*^9, 3.527037883796715*^9}, {
   3.5270442919458027`*^9, 3.527044310366582*^9}, 3.527044358533218*^9}]
}, Open  ]],

Cell["\<\


Calculate the energy of the Wavelt decoposition this would tell you which \
decomoposition has more impact on the shape of the data. In this case \
{0,0,0,0}\[Rule]0.994732 is the largest contribution i.e. the periodicity of \
the data:
\
\>", "Text",
 CellChangeTimes->{{3.527040838223136*^9, 3.527040895091675*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"co2dwd", "[", "\"\<EnergyFraction\>\"", "]"}]], "Input",
 CellChangeTimes->{{3.5270374679762287`*^9, 3.527037471686953*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"{", "1", "}"}], "\[Rule]", "0.00036201296955004056`"}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"0", ",", "1"}], "}"}], "\[Rule]", "0.0007073179372740873`"}], 
   ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"0", ",", "0", ",", "1"}], "}"}], "\[Rule]", 
    "0.001516310136680061`"}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"0", ",", "0", ",", "0", ",", "1"}], "}"}], "\[Rule]", 
    "0.0026828530394155015`"}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"0", ",", "0", ",", "0", ",", "0"}], "}"}], "\[Rule]", 
    "0.9947315059170803`"}]}], "}"}]], "Output",
 CellChangeTimes->{3.527037473401516*^9}]
}, Open  ]],

Cell["\<\

Darker colors indicate larger coefficients and lighter colors indicate \
smaller coefficients, therefore most of the CO2 emission range of frequency \
change is in low frequencies: \
\>", "Text",
 CellChangeTimes->{{3.527038908758791*^9, 3.527038944317037*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"WaveletScalogram", "[", 
  RowBox[{"co2dwd", ",", 
   RowBox[{"AxesLabel", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"\"\<Time\>\"", ",", "\"\<Frequency of Co2 Emission\>\""}], 
     "}"}]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.527036677452148*^9, 3.527036681195541*^9}, {
  3.527038866842135*^9, 3.527038884333274*^9}}],

Cell[BoxData[
 GraphicsBox[{
   TagBox[
    TooltipBox[
     RasterBox[{{0.8730419692195278, 0.7489153765355985, 0.8269169292597159, 
      0.9485317623418734, 1., 0.7830981412978946, 0.7188427638489291, 
      0.8507786454765492, 0.8706900488651412, 0.851783349317258, 
      0.8602776636068866, 0.7381604786043752, 0.7828697995159154, 
      0.8802575695300725, 0.961433073023702, 0.9528017536648854, 
      0.7911586062017628, 0.9923962186600905}}, {{0, 0}, {283, 1}},
      ColorFunction->ColorDataFunction[
       "SunsetColors", "Gradients", {1, 0}, Blend[{{1., 
           RGBColor[0., 0., 0.]}, {0.8333333333333334, 
           RGBColor[0.372793, 0.1358, 0.506503]}, {0.6666666666666667, 
           RGBColor[0.788287, 0.259816, 0.270778]}, {0.5, 
           RGBColor[0.979377, 0.451467, 0.0511329]}, {0.33333333333333337`, 
           RGBColor[1., 0.682688, 0.129771]}, {0.16666666666666674`, 
           RGBColor[1., 0.882236, 0.491094]}, {0., 
           RGBColor[1., 1., 1.]}}, #]& ],
      ColorFunctionScaling->True],
     RowBox[{"{", 
       RowBox[{"0", ",", "0", ",", "0", ",", "0"}], "}"}]],
    Annotation[#, {0, 0, 0, 0}, "Tooltip"]& ], 
   TagBox[
    TooltipBox[
     RasterBox[{{0.09846097638945987, 0.009636023199525159, 
      0.0018267342558341319`, 0.04096451568708053, 0.003927478650043342, 
      0.0674749965748732, 0.01847285016212268, 0.0247294149883546, 
      0.03345207105996254, 0.03605516737452625, 0.0745079234598347, 
      0.024638078275562927`, 0.020436589487144455`, 0.016942960222861583`, 
      0.024683746631958686`, 0.08597068091519378, 0.03658035347307855, 
      0.020527926199936077`}}, {{0, 1}, {283, 2}},
      ColorFunction->ColorDataFunction[
       "SunsetColors", "Gradients", {1, 0}, Blend[{{1., 
           RGBColor[0., 0., 0.]}, {0.8333333333333334, 
           RGBColor[0.372793, 0.1358, 0.506503]}, {0.6666666666666667, 
           RGBColor[0.788287, 0.259816, 0.270778]}, {0.5, 
           RGBColor[0.979377, 0.451467, 0.0511329]}, {0.33333333333333337`, 
           RGBColor[1., 0.682688, 0.129771]}, {0.16666666666666674`, 
           RGBColor[1., 0.882236, 0.491094]}, {0., 
           RGBColor[1., 1., 1.]}}, #]& ],
      ColorFunctionScaling->True],
     RowBox[{"{", 
       RowBox[{"0", ",", "0", ",", "0", ",", "1"}], "}"}]],
    Annotation[#, {0, 0, 0, 1}, "Tooltip"]& ], 
   TagBox[
    TooltipBox[
     RasterBox[{{0.015597231370192376`, 0.062356633076276306`, 
      0.003810503730191966, 0.008073101123287938, 0.004940737887452214, 
      0.009397089707507224, 0.027222496987727, 0.0034552872807672454`, 
      0.0042303049886029806`, 0.020376507235178906`, 0.06177536979539961, 
      0.0071689137974797704`, 0.000968772134794565, 0.02011816799923368, 
      0.01763165285326095, 0.003132363235835776, 0.011625265617534623`, 
      0.0465979396836183, 0.020279630021699312`, 0.0006135556853698444, 
      0.020376507235178806`, 0.03494038166159037, 0.01701809716789105, 
      0.008589779595178445, 0.03019339820109704, 0.01853584017906922, 
      0.0023896379324932393`, 0.019569197122850077`, 0.00038750885391791945`, 
      0.0032615328538083115`, 0.0026479771684384153`, 0.03794357527945351, 
      0.02360574768449402, 0.0345851652121657, 0.022378636313754332`, 
      0.013691979505096446`}}, {{0, 2}, {283, 3}},
      ColorFunction->ColorDataFunction[
       "SunsetColors", "Gradients", {1, 0}, Blend[{{1., 
           RGBColor[0., 0., 0.]}, {0.8333333333333334, 
           RGBColor[0.372793, 0.1358, 0.506503]}, {0.6666666666666667, 
           RGBColor[0.788287, 0.259816, 0.270778]}, {0.5, 
           RGBColor[0.979377, 0.451467, 0.0511329]}, {0.33333333333333337`, 
           RGBColor[1., 0.682688, 0.129771]}, {0.16666666666666674`, 
           RGBColor[1., 0.882236, 0.491094]}, {0., 
           RGBColor[1., 1., 1.]}}, #]& ],
      ColorFunctionScaling->True],
     RowBox[{"{", 
       RowBox[{"0", ",", "0", ",", "1"}], "}"}]],
    Annotation[#, {0, 0, 1}, "Tooltip"]& ], 
   TagBox[
    TooltipBox[RasterBox[CompressedData["
1:eJxTTMoPSmViYGBgBGJ3IE7/Vn55RkGnfWX9jDW5h0vsdwS9W37EuMX+vLh7
u6pbgb2/LrcK755me/+uX1WJddPsY+rYjzd8TLc3WVx4gj9rgf3v7bJMxrz9
9oX7nzSpqPbbezra3WZP6LLn2gESz7fn6y7+21lbZ39iT+KMZyFN9g9Nk7te
L22wjzwdt+XOplB7qRvRFy4JVNrvBMsn2WdetWT9mZNvH74don+rZXmUmEeX
vfT1U6+e2vXYGxptuKliUGW/SWzbQouSZHujOcqn3AIz7BVryx5Olq+21/36
7O3qeTX22mB/RdqfXeD/1/TYNPtZ8/eJe36Zab/vx8x5RSLF9qGXt0ntntNk
f6Jw9oTy1EL7T59DOfafybe/Aqbr7TuNHfcLMpXbf7gr8XJd+BT79c4Jyx4y
l9gvTqxZuTy5xX4V1N630HBaMXfLemPlVnvJw9ONX8+aar+7gGt11+QWe2Gw
e7PsuWXf2NjuarPflKYYv/96l316j9q6gM8m9nv7QHSI/QWo+Cxw+KfYC8ad
/PHgra19xMdLso1/muy7ursT/AIm238Fh1OR/Q21qx0cZQn2ad85drY6tdnX
PYt4cyKvxn75PNepCl8L7Y+BhMUS7NdA3VHidP7AF8Nye+n2eN3421Ps19ZN
/vEoapF9hajqHu9FZfY2qxSe2ayvtl9yIsTn+MMJ9iW9U08kK3bYfwWHT6P9
9WOrmcVs6+3vQMMPAEqdC+c=
      "], {{0, 3}, {283, 4}},
      ColorFunction->ColorDataFunction[
       "SunsetColors", "Gradients", {1, 0}, Blend[{{1., 
           RGBColor[0., 0., 0.]}, {0.8333333333333334, 
           RGBColor[0.372793, 0.1358, 0.506503]}, {0.6666666666666667, 
           RGBColor[0.788287, 0.259816, 0.270778]}, {0.5, 
           RGBColor[0.979377, 0.451467, 0.0511329]}, {0.33333333333333337`, 
           RGBColor[1., 0.682688, 0.129771]}, {0.16666666666666674`, 
           RGBColor[1., 0.882236, 0.491094]}, {0., 
           RGBColor[1., 1., 1.]}}, #]& ],
      ColorFunctionScaling->True],
     RowBox[{"{", 
       RowBox[{"0", ",", "1"}], "}"}]],
    Annotation[#, {0, 1}, "Tooltip"]& ], 
   TagBox[
    TooltipBox[RasterBox[CompressedData["
1:eJxVU3sslWEYP6hNaKwkl9hBQm2WhWpmP03RGDquMbmfc1zO6Tgcl1zCOcwt
mfiDlhIb2pjpqIxcxmHyh0ZZUzP+KWnCTOSWfN/5vnf1be/ePd/7XH6/3/M8
lrGSAL4mh8PRODwPD8/WTbvMn9n5mN1YeOJ0WQJ3rTkPZ1kS6nqFz1qvhCAs
/Yxo1VEK5W7kWvdMLpbNCjsrilLxMdNzTiWIhr25UcKmhRwc5ksd1Y/f1/XA
o22n/PlGMa4mza84qGqRMvx13faTAgMq6j0OO/QdCGdtx3MLcwnoCT1rsfIm
G3UC7ujKRjoTfwdjwld5YVXFWBI/NZbUxBF8yh43h2mtTAZHCvLp/GkQ3GqZ
EJuIwQv3qxpZTkRE8E67scIHovbk3y27SaSuhlWS9/PSArjGbwaaDAkI3+bx
yUq3L4VoTl3fMdmPgWdUk/RuSAK6uTPVLisFjB6F4J6Y/eHcxYfODoXTDY3K
JR/bx6VoFx2LPrKtgCujG/s+3iDhtQz4Y4TOEw39PqqeAFPv4jzb0qVY8gn4
PtwZCenLoJq3B6VYHOwrDGiS4Zc55W8AqQ11cwm/97pr/tyOEoZPGvFjeajz
Z+AgjuKXAV/rA0096wJ0RGRx6i3voaFr8DOPH0b0Z3Vc1SvWrvDyQgz9noiL
id4uKntnoudGAmXzYZpG6cNj9LmN8D+lMeU6D2BK980XuYZaEbrfZITHJDM3
PFoHCY4OUf/jobT8n5cNXbcM8qaRSzy7+9jqPG+1OFFGcJox8yYKUveV1Y3l
r9bXHbVMH2Pouc4n+eNTxsuuj8sZPLGkD6avT/bvTWbiwnGKvxCVybLW+kgZ
4etD88sl+rG6sPlZW+0nQg8dF0xwszjZOWzjKKejkIMPL66VTI1VQEbrlsfg
S0W20b99N2DmkQc/Oj4bcpV6z+xo/bMI7/KQKr7CvAJyJo96bxQQ0rxCoUXj
LGb4CtF7qs4wo6CI7FVOf7VBnriY7Cvrx9rezPyr+d6Aa+tpo71qEYln547F
q66fRvD9BfBWCmo=
      "], {{0, 4}, {283, 5}},
      ColorFunction->ColorDataFunction[
       "SunsetColors", "Gradients", {1, 0}, Blend[{{1., 
           RGBColor[0., 0., 0.]}, {0.8333333333333334, 
           RGBColor[0.372793, 0.1358, 0.506503]}, {0.6666666666666667, 
           RGBColor[0.788287, 0.259816, 0.270778]}, {0.5, 
           RGBColor[0.979377, 0.451467, 0.0511329]}, {0.33333333333333337`, 
           RGBColor[1., 0.682688, 0.129771]}, {0.16666666666666674`, 
           RGBColor[1., 0.882236, 0.491094]}, {0., 
           RGBColor[1., 1., 1.]}}, #]& ],
      ColorFunctionScaling->True],
     RowBox[{"{", "1", "}"}]],
    Annotation[#, {1}, "Tooltip"]& ]},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesLabel->{
    FormBox["\"Time\"", TraditionalForm], 
    FormBox["\"Frequency of Co2 Emission\"", TraditionalForm]},
  ContentSelectable->False,
  FrameTicks->{{{{1, 
       FormBox["\"\"", TraditionalForm]}, {2, 
       FormBox["4", TraditionalForm]}, {3, 
       FormBox["3", TraditionalForm]}, {4, 
       FormBox["2", TraditionalForm]}, {5, 
       FormBox["1", TraditionalForm]}}, {{1, 
       FormBox["\"\"", TraditionalForm]}, {2, 
       FormBox["\"\"", TraditionalForm]}, {3, 
       FormBox["\"\"", TraditionalForm]}, {4, 
       FormBox["\"\"", TraditionalForm]}, {5, 
       FormBox["\"\"", TraditionalForm]}}}, {Automatic, Automatic}},
  Method->{"GridLinesInFront" -> True},
  Ticks->{Automatic, {{1, 
      FormBox["\"\"", TraditionalForm]}, {2, 
      FormBox["4", TraditionalForm]}, {3, 
      FormBox["3", TraditionalForm]}, {4, 
      FormBox["2", TraditionalForm]}, {5, 
      FormBox["1", TraditionalForm]}}}]], "Output",
 CellChangeTimes->{3.527036682943619*^9, 3.527038885409442*^9, 
  3.527203188029909*^9, 3.527204238323819*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
   "Get", " ", "the", " ", "data", " ", "for", " ", "individual", " ", 
    "decomposition"}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{"co2dwd", "[", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "0", ",", "0"}], "}"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.527037773248451*^9, 3.5270377966240473`*^9}, {
  3.527037936332078*^9, 3.527037942933032*^9}, {3.527037973027274*^9, 
  3.527037974377068*^9}, {3.527038058002138*^9, 3.527038098747732*^9}, {
  3.5270409095848503`*^9, 3.527040920664598*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "0", ",", "0"}], "}"}], "\[Rule]", 
   RowBox[{"{", 
    RowBox[{
    "955.8500000000004`", ",", "819.9500000000003`", ",", 
     "905.3500000000004`", ",", "1038.5000000000005`", ",", 
     "1094.8500000000004`", ",", "857.3750000000002`", ",", 
     "787.0250000000003`", ",", "931.4750000000003`", ",", 
     "953.2750000000002`", ",", "932.5750000000003`", ",", 
     "941.8750000000001`", ",", "808.1750000000004`", ",", 
     "857.1250000000002`", ",", "963.7500000000002`", ",", 
     "1052.6250000000005`", ",", "1043.1750000000002`", ",", 
     "866.2000000000003`", ",", "1086.5250000000005`"}], "}"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{{3.527037781991624*^9, 3.527037797938486*^9}, 
   3.527037944392359*^9, 3.52703797532362*^9, {3.527038067069829*^9, 
   3.527038099585683*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
   "Use", " ", "each", " ", "decomposition", " ", "alone", " ", "and", " ", 
    "inverse", " ", "it", " ", "back", " ", "to", " ", "reconstruct", " ", 
    "the", " ", "original", " ", 
    RowBox[{"data", ".", " ", "This"}], " ", "removes", " ", "the", " ", 
    "unwated", " ", "features", " ", 
    RowBox[{"e", ".", "g", ".", " ", "jitters", "."}]}], " ", "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{"co2dwd", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", "1", "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"0", ",", "1"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"0", ",", "0", ",", "1"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"0", ",", "0", ",", "0", ",", "1"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"0", ",", "0", ",", "0", ",", "0"}], "}"}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"\"\<Inverse\>\"", ",", "\"\<ListPlot\>\""}], "}"}]}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.527039352296932*^9, 3.5270393564314137`*^9}, {
  3.527039393033292*^9, 3.52703940180726*^9}, {3.5270409948723993`*^9, 
  3.527041035271206*^9}, {3.5270437120285883`*^9, 3.5270437169097023`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"{", "1", "}"}], "\[Rule]", 
    GraphicsBox[{{}, {}, 
      {RGBColor[0.24, 0.3531726744018182, 0.6], LineBox[CompressedData["
1:eJxdl3twltURxhNCRJCGBAIJBEIMAUsRkBDCVc4iqKg0kAAhJCGE3ENuXyiX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        "]]}},
     AspectRatio->0.4,
     AxesOrigin->{0, 0},
     AxesStyle->Automatic,
     FrameTicks->{{Append[
         N[
          FindDivisions[{
            SlotSequence[1]}, 4]], {
          Mean[{
            SlotSequence[1]}], 
          Invisible["-1234"], {0, 0}}]& , Map[{#, 
          Spacer[{0, 0}]}& , 
         FindDivisions[{
           SlotSequence[1]}, 4]]& }, {N[
         FindDivisions[{
           SlotSequence[1]}, 5]]& , Map[{#, 
          Spacer[{0, 0}]}& , 
         FindDivisions[{
           SlotSequence[1]}, 4]]& }},
     ImageSize->Scaled[0.2],
     PlotRange->{{0., 283.}, {-27, 274}},
     PlotRangeClipping->True,
     PlotRangePadding->{
       Scaled[0.02], 
       Scaled[0.02]},
     Ticks->{N[
        FindDivisions[{
          SlotSequence[1]}, 5]]& , Append[
        N[
         FindDivisions[{
           SlotSequence[1]}, 4]], {
         Mean[{
           SlotSequence[1]}], 
         Invisible["-1234"], {0, 0}}]& },
     TicksStyle->Automatic]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"0", ",", "1"}], "}"}], "\[Rule]", 
    GraphicsBox[{{}, {}, 
      {RGBColor[0.24, 0.6, 0.33692049419863584`], LineBox[CompressedData["
1:eJxV13lQV1UUB3B+LolLhiIouSFjLrkiuC/v4L4QCG6Iioriighmmlm5TJmW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        "]]}},
     AspectRatio->0.4,
     AxesOrigin->{0, 0},
     AxesStyle->Automatic,
     FrameTicks->{{Append[
         N[
          FindDivisions[{
            SlotSequence[1]}, 4]], {
          Mean[{
            SlotSequence[1]}], 
          Invisible["-1234"], {0, 0}}]& , Map[{#, 
          Spacer[{0, 0}]}& , 
         FindDivisions[{
           SlotSequence[1]}, 4]]& }, {N[
         FindDivisions[{
           SlotSequence[1]}, 5]]& , Map[{#, 
          Spacer[{0, 0}]}& , 
         FindDivisions[{
           SlotSequence[1]}, 4]]& }},
     ImageSize->Scaled[0.2],
     PlotRange->{{0., 283.}, {-27, 274}},
     PlotRangeClipping->True,
     PlotRangePadding->{
       Scaled[0.02], 
       Scaled[0.02]},
     Ticks->{N[
        FindDivisions[{
          SlotSequence[1]}, 5]]& , Append[
        N[
         FindDivisions[{
           SlotSequence[1]}, 4]], {
         Mean[{
           SlotSequence[1]}], 
         Invisible["-1234"], {0, 0}}]& },
     TicksStyle->Automatic]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"0", ",", "0", ",", "1"}], "}"}], "\[Rule]", 
    GraphicsBox[{{}, {}, 
      {RGBColor[0.6, 0.5470136627990908, 0.24], LineBox[CompressedData["
1:eJxV2HlQVlUYBnBMTTEzFRcUBSXD3GUREZfvKO4SCLgAIhqKSygimWhUOk2Z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        "]]}},
     AspectRatio->0.4,
     AxesOrigin->{0, 0},
     AxesStyle->Automatic,
     FrameTicks->{{Append[
         N[
          FindDivisions[{
            SlotSequence[1]}, 4]], {
          Mean[{
            SlotSequence[1]}], 
          Invisible["-1234"], {0, 0}}]& , Map[{#, 
          Spacer[{0, 0}]}& , 
         FindDivisions[{
           SlotSequence[1]}, 4]]& }, {N[
         FindDivisions[{
           SlotSequence[1]}, 5]]& , Map[{#, 
          Spacer[{0, 0}]}& , 
         FindDivisions[{
           SlotSequence[1]}, 4]]& }},
     ImageSize->Scaled[0.2],
     PlotRange->{{0., 283.}, {-27, 274}},
     PlotRangeClipping->True,
     PlotRangePadding->{
       Scaled[0.02], 
       Scaled[0.02]},
     Ticks->{N[
        FindDivisions[{
          SlotSequence[1]}, 5]]& , Append[
        N[
         FindDivisions[{
           SlotSequence[1]}, 4]], {
         Mean[{
           SlotSequence[1]}], 
         Invisible["-1234"], {0, 0}}]& },
     TicksStyle->Automatic]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"0", ",", "0", ",", "0", ",", "1"}], "}"}], "\[Rule]", 
    GraphicsBox[{{}, {}, 
      {RGBColor[0.6, 0.24, 0.4428931686004542], LineBox[CompressedData["
1:eJxd1nlQVlUYBnDUyLDGTBQX3CIGM1cW2fU74L7EqoKAaAguiYhEEFnpNOVS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        "]]}},
     AspectRatio->0.4,
     AxesOrigin->{0, 0},
     AxesStyle->Automatic,
     FrameTicks->{{Append[
         N[
          FindDivisions[{
            SlotSequence[1]}, 4]], {
          Mean[{
            SlotSequence[1]}], 
          Invisible["-1234"], {0, 0}}]& , Map[{#, 
          Spacer[{0, 0}]}& , 
         FindDivisions[{
           SlotSequence[1]}, 4]]& }, {N[
         FindDivisions[{
           SlotSequence[1]}, 5]]& , Map[{#, 
          Spacer[{0, 0}]}& , 
         FindDivisions[{
           SlotSequence[1]}, 4]]& }},
     ImageSize->Scaled[0.2],
     PlotRange->{{0., 283.}, {-27, 274}},
     PlotRangeClipping->True,
     PlotRangePadding->{
       Scaled[0.02], 
       Scaled[0.02]},
     Ticks->{N[
        FindDivisions[{
          SlotSequence[1]}, 5]]& , Append[
        N[
         FindDivisions[{
           SlotSequence[1]}, 4]], {
         Mean[{
           SlotSequence[1]}], 
         Invisible["-1234"], {0, 0}}]& },
     TicksStyle->Automatic]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"0", ",", "0", ",", "0", ",", "0"}], "}"}], "\[Rule]", 
    GraphicsBox[{{}, {}, 
      {RGBColor[0.24720000000000014`, 0.24, 0.6], LineBox[CompressedData["
1:eJxd1nlQllUUBnDcxrTG3JdQNIbRTEVZRBaVi7hLIKsIiIaiIHzwSSYZlUyT
pi0u4YKokTWOthluGWnLOFpj5oZkIi5pZdZUqOSGTHXP+4znGXn/cX7j933c
995znnMfz8iPy2zu4eHh2czDQ/69/5z63j4XXGbG3m9TlrS7Fv6gPcx9ty8Z
sPRwl4fMg//fXh2yZeH1fh07N/l8d/Xvxee9cnr0bPL9Puqo7X36Tmnv3eT3
fNQ+G6v23+nUt8nvP6FuXPZKfFm3J5v8vYHq6sKgP8I8fZv8/SHm7fX2Kc82
p/3nf533qJ8a6/FXH+h/9PXwDgFqrC9Q7Xy801A11huk3tBtkfelzsPUWH+w
+tV2Z/7a0TVEjfcJVRe08qt8uXuYGu83XJ0uX3hshBrvO1I9qf5yjE/PcDXe
35gq2Y+Jucbz5qY3G5bT2I8I9Sr3xPrLK2jszyh16z9vJR9ZSWO/ItUvznnv
y12raOzfaLUsb+NbNPZzjDpbXrCExv6OVf9Us60udzWN/R6nTpRnDY39H29a
ShOEus2RE832jVhL4zwmqEfJC6+jcT4T1c52ltI4r0lq30i7Q6U0zi9KbXcn
9uJ6Guf5lLpHqD2xMhrnG61eueeRXhUbaJx3jFqWU7qRxvlPNtmz7eM5z4yU
A4+mUQ/03U5ttgYep1EfserdsRdrtsXQqBc6b4Vd4Aka9ROnlnJZNZlGPdG/
ts0oaHWSRn3Fq98ZH7xlYSyNeqNTl9gDPUmj/hKwH0fmmq4Hf2mbEUejHmkp
j9NVNOozUf1GuH3jeBr1So+TBZ2iUb9J6ub25/0TaNQz/cUdewDVNOp7itop
h0Qa9U4H2ONa8QON+k82IQH2Kc0yf+9Yu7lFEo1+oN+vy60uPE2jP6aqZw2y
BZ5Eo1/o3jm2gn+k0T8p6rP2daun0Ognes2VQ+Xjz9Dor1T1ZNnQZBr9Rj9s
y8evhkb/pSEPPF3mm3JbQFNp9CPtfPwsjf6cph4uDZNCo1/p28l2R2tp9G+6
eqfd/gWpNPqZdskXamn093R1v47R2elpNPqd/tmWc9U5Gv0/wwyT/fjOZY6P
tQXqSyMP6I8zrxafz6ORD/Rrcpyf0MgLOks2tI5GfjytHiMNPZhGntDel1Zf
OZRPI19o5zJTQSNv6Av2+EKv0cifDMxDH5eR9ps/hEYe0evTIqK2u2nkE72g
6KPMqxU08opOKLMNe51Gfs1Uy3Gl+dHIM1rabe08GvlGy3JO7KCRd/ThLjbg
btDIv1nIg3yX2Ro4+N/R/jTykF5sj3dRAY18pKW9KnfSyEvaObAbNPIzU92r
onbmoAAaeUrfO2YL9Bka+UrX2O3ZvItG3tLSTrX1NPJ3tsmReRCRbZw4DKSR
x7SUW8x8GvlMR8uCdtPIa3qg/fmD/9DI7znqNnIAgTTynP7Nxl/wszTynZbj
KthDI+/pd1vYCr1JI/+zTCvZj8NzTbE02FAa84CeZsu/zwIa84GWuEv5lMa8
oOV1V9+iMT+y1RInx4JozBNaTqtNIY35Qkv5RO6lMW/o5Q22gG7TmD9zYa88
Ix/fO4zGPKIn2Ha8XkhjPtG2mksGfEZjXtEtJSDu0JhfOWqJt/JgGvOMlnFU
8xyN+UY75VxJY97R0u3Rd2nMv1zTwrK4wG1k+UtDaMxDeqiNhwMLacxHWsZP
YyWNeUlfs+UQ1EBjfrrUErfuUBrzlP7wA/s8T2O+0ssk4D6nMW9pGV9e92jM
3zwTZMfBrii3ke1MDqMxj2mJq5IiGvOZtrvT/+g+GvOaPmfLs3Ujjfmdr5b4
jxhOY57T6+xyil6gMd9pafc9+2nMezrOjtO6Rhrz3202yTzokGO6S3960bgP
0E6/jqRxP6Cd/k2ncV+gnX5+icb9gXb6u5zGfYKW+On7FY37Be30/0Ua9w3a
yYP/aNw/5jnzsEeDG/nQm8Z9hHbyIpzG/YR28mM6jfsK7eTJIhr3F9rJl3Ia
9xn6fxs+DVI=
        "]]}},
     AspectRatio->0.4,
     AxesOrigin->{0, 0},
     AxesStyle->Automatic,
     FrameTicks->{{Append[
         N[
          FindDivisions[{
            SlotSequence[1]}, 4]], {
          Mean[{
            SlotSequence[1]}], 
          Invisible["-1234"], {0, 0}}]& , Map[{#, 
          Spacer[{0, 0}]}& , 
         FindDivisions[{
           SlotSequence[1]}, 4]]& }, {N[
         FindDivisions[{
           SlotSequence[1]}, 5]]& , Map[{#, 
          Spacer[{0, 0}]}& , 
         FindDivisions[{
           SlotSequence[1]}, 4]]& }},
     ImageSize->Scaled[0.2],
     PlotRange->{{0., 283.}, {-27, 274}},
     PlotRangeClipping->True,
     PlotRangePadding->{
       Scaled[0.02], 
       Scaled[0.02]},
     Ticks->{N[
        FindDivisions[{
          SlotSequence[1]}, 5]]& , Append[
        N[
         FindDivisions[{
           SlotSequence[1]}, 4]], {
         Mean[{
           SlotSequence[1]}], 
         Invisible["-1234"], {0, 0}}]& },
     TicksStyle->Automatic]}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.527039357424848*^9, 3.5270394021998053`*^9, {3.527043713411603*^9, 
   3.527043717567439*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"co2dwd", "[", 
  RowBox[{"Automatic", ",", 
   RowBox[{"{", 
    RowBox[{"\"\<ListPlot\>\"", ",", 
     RowBox[{"Background", "\[Rule]", "Black"}], ",", 
     RowBox[{"PlotStyle", "\[Rule]", "White"}]}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{
  3.5270443453991327`*^9, {3.527049638732607*^9, 3.5270496825043573`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"{", "1", "}"}], "\[Rule]", 
    GraphicsBox[{{}, {}, 
      {GrayLevel[1], LineBox[CompressedData["
1:eJxFlgtQVFUYxy8goIjsCstThAVW8QUGMoii3k9MIV+wLMhTXJbHArvswxyN
nPSOk5pmroTii5LG8dmoiDVmWnuilEoNtA1FM/ARI5FgokJq0bn3nHvbmZ2d
b869537n///9v7thOnN6iTPDMNvxl/8VP3JTYl2SQwnas825m7wY4My7DV4N
clrLAXmEMpdSPJG8ZvJ7P/gGABdzoIdtGrCTdSXUa5PPcDpvmHGo6q9IbxVw
Tw8brI4QINdPAG3Gqb1br/igbu5OiCFwCjBlZlvyFie6/2sgz/7WvXdFBFp8
Ujk+Sx4LYl9kvzhg0tj8vOUPWFXd9QuDPvHAPVpnO35CRvtJgLfYGodTXDx6
teVdzT7/mSBP8ed2xo8D8rxZAKn8/cOQY038H4lj5gAn1E9p/wBcoPkLTa0H
aotdhUyyuQDD9YXR1cG0nyTg4rK23qjyh6aJV99nR8+jzx+yk/5eB2WCYXDm
qEgkXO4zH7iFLSFTeoch0u8CSb/9/uvD7yqSAU1aI6vaH0D1SaF6jIbNXjcf
nfZ7A5RC/770PAsBnvReaQ+WoZWuMec2BCwCJLPNfnZ2JD3fYmCc2I36ikds
AX9D0BJg3E411bZ70vMuFc/LLuq/l6oKToWGUh+09kQYIudPA4iaelKuGY7G
PPvogxfb00R/WaKHGrjctYc3+kegasvC/ns2NTA5oTfOJboA0ScduJCOZxtc
PcD9z+fZl3ekw2PdkDogKBwRvTSUj3D0jv7g12eqNcBMl000x7hTXjKA6eX1
7GD59uo+zIDOMZFZPUsmAdEzE1oXnG/4PncclPMHrMkEjvJG9F0m3m/vbD/a
Z9yJ68qOK6sHH7NE7yxgivh+nCGT/+zCdSx/PnfKTzYoC2yK7uPe6HKr0/nZ
tdnArEz1OKxnqB85AAE+3Zu/nISS+APvzoF66Dt4VeYHxJ9cYLT8/o2sIOce
XJfxdRNL/MqT/IuehxXakwcW1afO69ImUv/yqT8KhNVRd+zNF/ezEz+XS3kL
nIkd27ec9u9P/S0ARvAvAO343HNsw/4CsFRERndAGBC/VwDjfzbwwm9BiG9n
Tx2ufYfeVkW+pPxrJf7n8IYv1Uo8Eh5wPcFuuXv/Ifu3z4gjcS1aQAr+/pE0
L4XAzFpf+nF9G/uZuqP9aGqhxCfhBdeJ/LobMtlwg62FwAn89NsJPzrKzwuW
x6U6TQfyVz8lJ7yMQoQnHTBC3vrY3z10K12v6QDmTHeNz/ajfBWJfqD6lIRD
VeoiADpvCG9FgIw8D3KUtwkbeg3XwvVulL9iYIoFv+x+3z3w0KUXS34RHouB
E847GfF4tF3H66vcj80OVVI+S6BT3uP5Tc1k2MbiE2tKRD0pryXA0PmWzDf0
M64ZIa92wm+pyBtyxtvHZpRKPBGeSym/99ivBrEBjlKw0DwSvvUAwrxWIgGH
TL3UP+FdD53qgRdPFCqYhu2y/aKn+rhQ/sukPPServ3EZVkZQETqtMZVgTQP
uBb8H46O9Rkda9pwPe9IUkmzLyL5KJf8LY7CgC8rB0bwbyyQvJSL/EGoARN8
o1zkxU7yUyH1fwsf15FVIa2TPFXQ/UbBrq6LB1JuVgAnPO+5neTLIPGbxgua
bZD0JHkzSPNwJMYnpt0A4DIQMRQ2lubPCNy/m7paGqPg0gEMUI4RtAJvoTSP
RqqfAgmX3zJiP4k/JJ+VNO+N7Cw+MLmVdD7207xWQqcr//xgGMjGit7G60Le
H9hJfk2gFfgPQo1Y/tV5JslvkmcT1A/T9P/4zxSo5G+4jdfThX5ovs30faOC
SO+l5QX5uBb8GmRJ3s3QKug1Ht3HOF//1Uz9HUHnvwUez1305t6ecahlAQY0
2iK+r4DMAwukzWhuduseDydKHnJ3TBbx/UrfFxZxP9jK23nq/3UyLyywg87/
Ml7QPgv1t4u+X6zADBR4jNjmBfP5QE+1Ss8n88Qqzbvwuzu7Lpqtkr5kvljp
+RXkf0ODVdLvPxvd0GY=
        "]]}},
     AspectRatio->0.4,
     AxesOrigin->{0, 0},
     AxesStyle->Automatic,
     Background->GrayLevel[0],
     FrameTicks->{{Append[
         N[
          FindDivisions[{
            SlotSequence[1]}, 4]], {
          Mean[{
            SlotSequence[1]}], 
          Invisible["-1234"], {0, 0}}]& , Map[{#, 
          Spacer[{0, 0}]}& , 
         FindDivisions[{
           SlotSequence[1]}, 4]]& }, {N[
         FindDivisions[{
           SlotSequence[1]}, 5]]& , Map[{#, 
          Spacer[{0, 0}]}& , 
         FindDivisions[{
           SlotSequence[1]}, 4]]& }},
     ImageSize->Scaled[0.2],
     PlotRange->{{0., 283.}, {-45, 1095}},
     PlotRangeClipping->True,
     PlotRangePadding->{
       Scaled[0.02], 
       Scaled[0.02]},
     Ticks->{N[
        FindDivisions[{
          SlotSequence[1]}, 5]]& , Append[
        N[
         FindDivisions[{
           SlotSequence[1]}, 4]], {
         Mean[{
           SlotSequence[1]}], 
         Invisible["-1234"], {0, 0}}]& },
     TicksStyle->Automatic]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"0", ",", "1"}], "}"}], "\[Rule]", 
    GraphicsBox[{{}, {}, 
      {GrayLevel[1], LineBox[CompressedData["
1:eJw1U11I01EUn31gVtiWLrRSZjozHLJq2VJhP0syZdSybNqX35tfc/PBNx+E
erIewqd8ar2IL6EUmQS1AyEIrRCKXuxhFPQgBO2ljIL6n3uOh40/9557z/l9
nFvWG28b2Gaz2ZqtP3+3Aic5qvH6S7X1s8Nm1gdI1i4kZzncKPnYaP2qgAiH
Q/NeLHK62E2x9aXYeq0Pa2kr9vpJzvsxZe7n4R3vBxskf79R7wMPTd5Lzq6s
s+v4WXRz+TkvpF4TvAaPh1bCkyvhhvOKx671L0i9oIsmQrkToeZWPDD5cpJ+
QRB/02WoaJmpaGm7CJuP6/0KSP8Qpkz+IDaS+RvJmsuKd7viadO8nbhbie8K
oP0F31U5X+yR7TPtcBm8NRC815D5x3EIWS4YCCueHYq/A2TyeWB4M02dev4w
hM915VuKxxa8/NYb6s+fgPC7KflOP/2eXticvnQLu9hUqifhe1v0jBSCy+W2
dyHBy2/lqn+38t1PBs6TbshUOEj06MEPg8cl+4s9iqcIok+v7NMp8nDBp73a
zwnRq0/5uqnDkmPyeR/kwm71t1/PO+hu3fyduuV+rV+peg7IfBSfxuKmRfDl
AOzmfqXqG1H99tBnq9zSq4jOQxWJ3lHx45kHTH+CorD1c79PKdF/EFOm/8+U
kfXNICDnSfwYUn12gulmV4ZUn0xK/BlGxvSroHuW/Aurw6LvnE/9GgGZ+wX0
ggm/HdF6OfoeRpE0+hzFV7bj/SjI4ClVP2PqdwHtY0PWttY56u+Y4qmkeku+
+Q9jqneR+h2XdbAWUUM7jr8s16Nz+t4TOq9Fwnc0ofqXQOYhgVXznk+Q4f89
Ifqmj+l8jMv7nz0i8xofV71dJPMyrvoW0n+evP6b
        "]]}},
     AspectRatio->0.4,
     AxesOrigin->{0, 0},
     AxesStyle->Automatic,
     Background->GrayLevel[0],
     FrameTicks->{{Append[
         N[
          FindDivisions[{
            SlotSequence[1]}, 4]], {
          Mean[{
            SlotSequence[1]}], 
          Invisible["-1234"], {0, 0}}]& , Map[{#, 
          Spacer[{0, 0}]}& , 
         FindDivisions[{
           SlotSequence[1]}, 4]]& }, {N[
         FindDivisions[{
           SlotSequence[1]}, 5]]& , Map[{#, 
          Spacer[{0, 0}]}& , 
         FindDivisions[{
           SlotSequence[1]}, 4]]& }},
     ImageSize->Scaled[0.2],
     PlotRange->{{0., 283.}, {-45, 1095}},
     PlotRangeClipping->True,
     PlotRangePadding->{
       Scaled[0.02], 
       Scaled[0.02]},
     Ticks->{N[
        FindDivisions[{
          SlotSequence[1]}, 5]]& , Append[
        N[
         FindDivisions[{
           SlotSequence[1]}, 4]], {
         Mean[{
           SlotSequence[1]}], 
         Invisible["-1234"], {0, 0}}]& },
     TicksStyle->Automatic]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"0", ",", "0", ",", "1"}], "}"}], "\[Rule]", 
    GraphicsBox[{{}, {}, 
      {GrayLevel[1], LineBox[CompressedData["
1:eJxTTMoPSmViYGBQAWIQDQMfsqM+zhU2dNj3SBuIFBwYdALWRQkGQvkGDg35
07P5Ngg4yF5xBCILhwVpwgeq1yoegMg7ODi4MAsZLhZ1yL29Lfe2mYvDAl/T
pSsnqxyAqPdwaPjLyP39rO2Bs2eAwMfHoeGn2MoFznxQ/QEOB+JfP97SJnRA
NP6jaLxhkMMCO76fGv5mByDmhTikrJ3+ff6LAIej4TVHw23CHBg+mOk5pcpD
3RPhwJB7/0zZjw/2pQHspQHuUQ4CjsemH2Azg9oX47AgovD9ZV/jAyqek1Q8
g+IcGoTc7/Tkc0P9l+CgoOxvvKlE0+HVAr5XC/QSHR4s6jnq2uTpAHFPkkOC
/eQrjCZmB0C2yZokOzC4xD/8U/fUHuK+FIcGqHtngoBlqoNG1JJNkxScoe5N
cyiIS+O4s9DowEeQgfbpDgyxxq6y55Wg7s9w2PDh3pbgdocDIOdNcsl0EAh4
6+zobeIA8U+WQ4PXeTmddywHFgKdx+eV7eDgxnvyUY4p1H85Dgwy/6tU1G/v
/9m1/keXf64DA0d6ot5EHqh/8xwazPg18w3ZD4CMYw/Nd3hxWiyj8KgL1P8F
Dg/khXY63rB0ADtnbYHDjduH3p9653QAEh6FDgu0/7wKbLA4AE4sGwodFP6c
c7f4resAALOC+sQ=
        "]]}},
     AspectRatio->0.4,
     AxesOrigin->{0, 0},
     AxesStyle->Automatic,
     Background->GrayLevel[0],
     FrameTicks->{{Append[
         N[
          FindDivisions[{
            SlotSequence[1]}, 4]], {
          Mean[{
            SlotSequence[1]}], 
          Invisible["-1234"], {0, 0}}]& , Map[{#, 
          Spacer[{0, 0}]}& , 
         FindDivisions[{
           SlotSequence[1]}, 4]]& }, {N[
         FindDivisions[{
           SlotSequence[1]}, 5]]& , Map[{#, 
          Spacer[{0, 0}]}& , 
         FindDivisions[{
           SlotSequence[1]}, 4]]& }},
     ImageSize->Scaled[0.2],
     PlotRange->{{0., 283.}, {-45, 1095}},
     PlotRangeClipping->True,
     PlotRangePadding->{
       Scaled[0.02], 
       Scaled[0.02]},
     Ticks->{N[
        FindDivisions[{
          SlotSequence[1]}, 5]]& , Append[
        N[
         FindDivisions[{
           SlotSequence[1]}, 4]], {
         Mean[{
           SlotSequence[1]}], 
         Invisible["-1234"], {0, 0}}]& },
     TicksStyle->Automatic]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"0", ",", "0", ",", "0", ",", "1"}], "}"}], "\[Rule]", 
    GraphicsBox[{{}, {}, 
      {GrayLevel[1], 
       LineBox[{{0., 107.80000000000018`}, {
        16.647058823529413`, -10.550000000000125`}, {
        33.294117647058826`, -2.}, {
        49.94117647058824, -44.850000000000136`}, {
        66.58823529411765, -4.2999999999999545`}, {83.23529411764706, 
        73.87499999999994}, {99.88235294117648, -20.225000000000023`}, {
        116.52941176470587`, -27.075000000000045`}, {133.1764705882353, 
        36.625}, {149.8235294117647, -39.47500000000008}, {
        166.47058823529412`, 81.57500000000005}, {183.11764705882354`, 
        26.97500000000008}, {199.76470588235296`, -22.375000000000114`}, {
        216.41176470588235`, -18.55000000000001}, {
        233.05882352941174`, -27.024999999999977`}, {249.70588235294116`, 
        94.12499999999994}, {266.3529411764706, -40.05000000000007}, {
        283., -22.475000000000023`}}]}},
     AspectRatio->0.4,
     AxesOrigin->{0, 0},
     AxesStyle->Automatic,
     Background->GrayLevel[0],
     FrameTicks->{{Append[
         N[
          FindDivisions[{
            SlotSequence[1]}, 4]], {
          Mean[{
            SlotSequence[1]}], 
          Invisible["-1234"], {0, 0}}]& , Map[{#, 
          Spacer[{0, 0}]}& , 
         FindDivisions[{
           SlotSequence[1]}, 4]]& }, {N[
         FindDivisions[{
           SlotSequence[1]}, 5]]& , Map[{#, 
          Spacer[{0, 0}]}& , 
         FindDivisions[{
           SlotSequence[1]}, 4]]& }},
     ImageSize->Scaled[0.2],
     PlotRange->{{0., 283.}, {-45, 1095}},
     PlotRangeClipping->True,
     PlotRangePadding->{
       Scaled[0.02], 
       Scaled[0.02]},
     Ticks->{N[
        FindDivisions[{
          SlotSequence[1]}, 5]]& , Append[
        N[
         FindDivisions[{
           SlotSequence[1]}, 4]], {
         Mean[{
           SlotSequence[1]}], 
         Invisible["-1234"], {0, 0}}]& },
     TicksStyle->Automatic]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"0", ",", "0", ",", "0", ",", "0"}], "}"}], "\[Rule]", 
    GraphicsBox[{{}, {}, 
      {GrayLevel[1], 
       LineBox[{{0., 955.8500000000004}, {16.647058823529413`, 
        819.9500000000003}, {33.294117647058826`, 905.3500000000004}, {
        49.94117647058824, 1038.5000000000005`}, {66.58823529411765, 
        1094.8500000000004`}, {83.23529411764706, 857.3750000000002}, {
        99.88235294117648, 787.0250000000003}, {116.52941176470587`, 
        931.4750000000003}, {133.1764705882353, 953.2750000000002}, {
        149.8235294117647, 932.5750000000003}, {166.47058823529412`, 
        941.8750000000001}, {183.11764705882354`, 808.1750000000004}, {
        199.76470588235296`, 857.1250000000002}, {216.41176470588235`, 
        963.7500000000002}, {233.05882352941174`, 1052.6250000000005`}, {
        249.70588235294116`, 1043.1750000000002`}, {266.3529411764706, 
        866.2000000000003}, {283., 1086.5250000000005`}}]}},
     AspectRatio->0.4,
     AxesOrigin->{0, 0},
     AxesStyle->Automatic,
     Background->GrayLevel[0],
     FrameTicks->{{Append[
         N[
          FindDivisions[{
            SlotSequence[1]}, 4]], {
          Mean[{
            SlotSequence[1]}], 
          Invisible["-1234"], {0, 0}}]& , Map[{#, 
          Spacer[{0, 0}]}& , 
         FindDivisions[{
           SlotSequence[1]}, 4]]& }, {N[
         FindDivisions[{
           SlotSequence[1]}, 5]]& , Map[{#, 
          Spacer[{0, 0}]}& , 
         FindDivisions[{
           SlotSequence[1]}, 4]]& }},
     ImageSize->Scaled[0.2],
     PlotRange->{{0., 283.}, {-45, 1095}},
     PlotRangeClipping->True,
     PlotRangePadding->{
       Scaled[0.02], 
       Scaled[0.02]},
     Ticks->{N[
        FindDivisions[{
          SlotSequence[1]}, 5]]& , Append[
        N[
         FindDivisions[{
           SlotSequence[1]}, 4]], {
         Mean[{
           SlotSequence[1]}], 
         Invisible["-1234"], {0, 0}}]& },
     TicksStyle->Automatic]}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.527044346438467*^9, {3.527049639459346*^9, 3.5270496438355722`*^9}, 
   3.527049683471788*^9}]
}, Open  ]],

Cell[TextData[StyleBox["\n\nTrend", "Subtitle"]], "Text",
 CellChangeTimes->{{3.527203257466617*^9, 3.527203278043158*^9}}],

Cell["\<\
This curve was used as the main melody for the composition and it was used, \
with a different synthesizer, as its own counter-point. Note that the lines \
are anti-aliased and no matter how they are plotted there will alawys be \
artifact.

This curve and the one after are then cut & paste into the IMAGE SYNTH room \
in MetaSynth:

http://www.uisoftware.com/MetaSynth/index.php 
\
\>", "Text",
 CellChangeTimes->{{3.52720352543428*^9, 3.527203569241427*^9}, {
  3.5272038630296392`*^9, 3.527203933217115*^9}, {3.527203970480863*^9, 
  3.5272039719973173`*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {GrayLevel[1], 
    LineBox[{{0., 955.8500000000004}, {16.647058823529413`, 
     819.9500000000003}, {33.294117647058826`, 905.3500000000004}, {
     49.94117647058824, 1038.5000000000005`}, {66.58823529411765, 
     1094.8500000000004`}, {83.23529411764706, 857.3750000000002}, {
     99.88235294117648, 787.0250000000003}, {116.52941176470587`, 
     931.4750000000003}, {133.1764705882353, 953.2750000000002}, {
     149.8235294117647, 932.5750000000003}, {166.47058823529412`, 
     941.8750000000001}, {183.11764705882354`, 808.1750000000004}, {
     199.76470588235296`, 857.1250000000002}, {216.41176470588235`, 
     963.7500000000002}, {233.05882352941174`, 1052.6250000000005`}, {
     249.70588235294116`, 1043.1750000000002`}, {266.3529411764706, 
     866.2000000000003}, {283., 1086.5250000000005`}}]}},
  AspectRatio->0.4,
  AxesOrigin->{0, 0},
  AxesStyle->Automatic,
  Background->GrayLevel[0],
  FrameTicks->{{Append[
      N[
       FindDivisions[{
         SlotSequence[1]}, 4]], {
       Mean[{
         SlotSequence[1]}], 
       Invisible["-1234"], {0, 0}}]& , Map[{#, 
       Spacer[{0, 0}]}& , 
      FindDivisions[{
        SlotSequence[1]}, 4]]& }, {N[
      FindDivisions[{
        SlotSequence[1]}, 5]]& , Map[{#, 
       Spacer[{0, 0}]}& , 
      FindDivisions[{
        SlotSequence[1]}, 4]]& }},
  ImageSize->{647.8, Automatic},
  PlotRange->{{0., 283.}, {-45, 1095}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02]},
  Ticks->{N[
     FindDivisions[{
       SlotSequence[1]}, 5]]& , Append[
     N[
      FindDivisions[{
        SlotSequence[1]}, 4]], {
      Mean[{
        SlotSequence[1]}], 
      Invisible["-1234"], {0, 0}}]& },
  TicksStyle->Automatic]], "Input",
 CellChangeTimes->{3.5270496941390553`*^9}],

Cell[TextData[StyleBox["\n\n\n\nDeTrend ", "Subtitle"]], "Text",
 CellChangeTimes->{{3.527203284299099*^9, 3.527203297449512*^9}}],

Cell["This jitter-like curve was used for the background beat:", "Text",
 CellChangeTimes->{{3.527203581786834*^9, 3.527203597985387*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {GrayLevel[1], LineBox[CompressedData["
1:eJxFlgtQVFUYxy8goIjsCstThAVW8QUGMoii3k9MIV+wLMhTXJbHArvswxyN
nPSOk5pmroTii5LG8dmoiDVmWnuilEoNtA1FM/ARI5FgokJq0bn3nHvbmZ2d
b869537n///9v7thOnN6iTPDMNvxl/8VP3JTYl2SQwnas825m7wY4My7DV4N
clrLAXmEMpdSPJG8ZvJ7P/gGABdzoIdtGrCTdSXUa5PPcDpvmHGo6q9IbxVw
Tw8brI4QINdPAG3Gqb1br/igbu5OiCFwCjBlZlvyFie6/2sgz/7WvXdFBFp8
Ujk+Sx4LYl9kvzhg0tj8vOUPWFXd9QuDPvHAPVpnO35CRvtJgLfYGodTXDx6
teVdzT7/mSBP8ed2xo8D8rxZAKn8/cOQY038H4lj5gAn1E9p/wBcoPkLTa0H
aotdhUyyuQDD9YXR1cG0nyTg4rK23qjyh6aJV99nR8+jzx+yk/5eB2WCYXDm
qEgkXO4zH7iFLSFTeoch0u8CSb/9/uvD7yqSAU1aI6vaH0D1SaF6jIbNXjcf
nfZ7A5RC/770PAsBnvReaQ+WoZWuMec2BCwCJLPNfnZ2JD3fYmCc2I36ikds
AX9D0BJg3E411bZ70vMuFc/LLuq/l6oKToWGUh+09kQYIudPA4iaelKuGY7G
PPvogxfb00R/WaKHGrjctYc3+kegasvC/ns2NTA5oTfOJboA0ScduJCOZxtc
PcD9z+fZl3ekw2PdkDogKBwRvTSUj3D0jv7g12eqNcBMl000x7hTXjKA6eX1
7GD59uo+zIDOMZFZPUsmAdEzE1oXnG/4PncclPMHrMkEjvJG9F0m3m/vbD/a
Z9yJ68qOK6sHH7NE7yxgivh+nCGT/+zCdSx/PnfKTzYoC2yK7uPe6HKr0/nZ
tdnArEz1OKxnqB85AAE+3Zu/nISS+APvzoF66Dt4VeYHxJ9cYLT8/o2sIOce
XJfxdRNL/MqT/IuehxXakwcW1afO69ImUv/yqT8KhNVRd+zNF/ezEz+XS3kL
nIkd27ec9u9P/S0ARvAvAO343HNsw/4CsFRERndAGBC/VwDjfzbwwm9BiG9n
Tx2ufYfeVkW+pPxrJf7n8IYv1Uo8Eh5wPcFuuXv/Ifu3z4gjcS1aQAr+/pE0
L4XAzFpf+nF9G/uZuqP9aGqhxCfhBdeJ/LobMtlwg62FwAn89NsJPzrKzwuW
x6U6TQfyVz8lJ7yMQoQnHTBC3vrY3z10K12v6QDmTHeNz/ajfBWJfqD6lIRD
VeoiADpvCG9FgIw8D3KUtwkbeg3XwvVulL9iYIoFv+x+3z3w0KUXS34RHouB
E847GfF4tF3H66vcj80OVVI+S6BT3uP5Tc1k2MbiE2tKRD0pryXA0PmWzDf0
M64ZIa92wm+pyBtyxtvHZpRKPBGeSym/99ivBrEBjlKw0DwSvvUAwrxWIgGH
TL3UP+FdD53qgRdPFCqYhu2y/aKn+rhQ/sukPPServ3EZVkZQETqtMZVgTQP
uBb8H46O9Rkda9pwPe9IUkmzLyL5KJf8LY7CgC8rB0bwbyyQvJSL/EGoARN8
o1zkxU7yUyH1fwsf15FVIa2TPFXQ/UbBrq6LB1JuVgAnPO+5neTLIPGbxgua
bZD0JHkzSPNwJMYnpt0A4DIQMRQ2lubPCNy/m7paGqPg0gEMUI4RtAJvoTSP
RqqfAgmX3zJiP4k/JJ+VNO+N7Cw+MLmVdD7207xWQqcr//xgGMjGit7G60Le
H9hJfk2gFfgPQo1Y/tV5JslvkmcT1A/T9P/4zxSo5G+4jdfThX5ovs30faOC
SO+l5QX5uBb8GmRJ3s3QKug1Ht3HOF//1Uz9HUHnvwUez1305t6ecahlAQY0
2iK+r4DMAwukzWhuduseDydKHnJ3TBbx/UrfFxZxP9jK23nq/3UyLyywg87/
Ml7QPgv1t4u+X6zADBR4jNjmBfP5QE+1Ss8n88Qqzbvwuzu7Lpqtkr5kvljp
+RXkf0ODVdLvPxvd0GY=
     "]]}},
  AspectRatio->0.4,
  AxesOrigin->{0, 0},
  AxesStyle->Automatic,
  Background->GrayLevel[0],
  FrameTicks->{{Append[
      N[
       FindDivisions[{
         SlotSequence[1]}, 4]], {
       Mean[{
         SlotSequence[1]}], 
       Invisible["-1234"], {0, 0}}]& , Map[{#, 
       Spacer[{0, 0}]}& , 
      FindDivisions[{
        SlotSequence[1]}, 4]]& }, {N[
      FindDivisions[{
        SlotSequence[1]}, 5]]& , Map[{#, 
       Spacer[{0, 0}]}& , 
      FindDivisions[{
        SlotSequence[1]}, 4]]& }},
  ImageSize->{648., Automatic},
  PlotRange->{{0., 283.}, {-45, 1095}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02]},
  Ticks->{N[
     FindDivisions[{
       SlotSequence[1]}, 5]]& , Append[
     N[
      FindDivisions[{
        SlotSequence[1]}, 4]], {
      Mean[{
        SlotSequence[1]}], 
      Invisible["-1234"], {0, 0}}]& },
  TicksStyle->Automatic]], "Input",
 CellChangeTimes->{3.527053112018301*^9}]
}, Open  ]]
},
WindowSize->{871, 877},
WindowMargins->{{188, Automatic}, {57, Automatic}},
PrivateNotebookOptions->{"VersionedStylesheet"->{"Default.nb"[8.] -> False}},
FrontEndVersion->"9.0 for Mac OS X x86 (32-bit, 64-bit Kernel) (January 25, \
2013)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[579, 22, 101, 4, 148, "Title"],
Cell[683, 28, 214, 8, 106, "Text"],
Cell[900, 38, 1988, 28, 646, "Text"],
Cell[CellGroupData[{
Cell[2913, 70, 572, 13, 63, "Input"],
Cell[3488, 85, 19630, 572, 964, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[23155, 662, 800, 20, 63, "Input"],
Cell[23958, 684, 19575, 570, 964, "Output"]
}, Open  ]],
Cell[43548, 1257, 134, 6, 87, "Text"],
Cell[CellGroupData[{
Cell[43707, 1267, 129, 2, 28, "Input"],
Cell[43839, 1271, 2231, 43, 243, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[46107, 1319, 217, 4, 46, "Input"],
Cell[46327, 1325, 2252, 43, 243, "Output"]
}, Open  ]],
Cell[48594, 1371, 444, 9, 195, "Text"],
Cell[CellGroupData[{
Cell[49063, 1384, 402, 10, 46, "Input"],
Cell[49468, 1396, 21681, 406, 222, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[71186, 1807, 345, 6, 28, "Input"],
Cell[71534, 1815, 11388, 289, 152, "Output"]
}, Open  ]],
Cell[82937, 2107, 329, 9, 106, "Text"],
Cell[CellGroupData[{
Cell[83291, 2120, 148, 2, 28, "Input"],
Cell[83442, 2124, 695, 21, 46, "Output"]
}, Open  ]],
Cell[84152, 2148, 272, 6, 68, "Text"],
Cell[CellGroupData[{
Cell[84449, 2158, 350, 8, 28, "Input"],
Cell[84802, 2168, 8374, 160, 214, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[93213, 2333, 570, 12, 46, "Input"],
Cell[93786, 2347, 887, 19, 46, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[94710, 2371, 1205, 29, 63, "Input"],
Cell[95918, 2402, 17613, 395, 152, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[113568, 2802, 348, 8, 28, "Input"],
Cell[113919, 2812, 11356, 294, 152, "Output"]
}, Open  ]],
Cell[125290, 3109, 123, 1, 107, "Text"],
Cell[125416, 3112, 573, 14, 144, "Text"],
Cell[125992, 3128, 1825, 50, 274, "Input"],
Cell[127820, 3180, 130, 1, 171, "Text"],
Cell[127953, 3183, 138, 1, 30, "Text"],
Cell[128094, 3186, 3091, 73, 274, "Input"]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
