(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 8.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       157,          7]
NotebookDataLength[    165990,       5696]
NotebookOptionsPosition[    161925,       5558]
NotebookOutlinePosition[    162360,       5575]
CellTagsIndexPosition[    162317,       5572]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["Discrete Wavelet Transform", "Title",
 CellChangeTimes->{{3.521736514893429*^9, 3.521736523205187*^9}}],

Cell[TextData[{
 "\n\n\n\nThe following uses the Haar Wavelet for the purpose of \
visualization however the calculations are general. It also seems that there \
is no definite and clear \[OpenCurlyQuote]begining\[CloseCurlyQuote] or \
\[OpenCurlyQuote]introduction\[CloseCurlyQuote] is possible for the Wavelets, \
so the authors decided that the best place is to start with the natural \
filters and continue building the theory and visualizations and applications \
onwards. \n\nFrom every Wavelet two default (natural) Filters can be \
extracted:\n\n1. ",
 StyleBox["LowPass",
  FontWeight->"Bold"],
 "  \n\n",
 Cell[BoxData[
  FormBox[
   RowBox[{" ", 
    RowBox[{
     RowBox[{
      FractionBox["1", "2"], 
      RowBox[{"x", "(", "n", ")"}]}], " ", "+", " ", 
     RowBox[{
      FractionBox["1", "2"], 
      RowBox[{"x", "(", 
       RowBox[{"n", "-", "1"}], ")"}]}]}]}], TraditionalForm]]],
 "\n\n\nWhere signal is of the form allowing for negative indeces:\n\n\n",
 Cell[BoxData[
  FormBox[
   RowBox[{
    StyleBox["x",
     FontWeight->"Bold"], "=", " ", 
    RowBox[{"(", 
     RowBox[{"...", " ", ",", " ", 
      RowBox[{
       StyleBox["x",
        FontWeight->"Bold"], "(", 
       RowBox[{"-", "2"}], ")"}], "  ", ",", " ", 
      RowBox[{
       StyleBox["x",
        FontWeight->"Bold"], "(", 
       RowBox[{"-", "1"}], ")"}], "  ", ",", " ", 
      RowBox[{
       StyleBox["x",
        FontWeight->"Bold"], "(", "0", ")"}], "  ", ",", " ", 
      RowBox[{
       StyleBox["x",
        FontWeight->"Bold"], "(", "1", ")"}], "  ", ",", " ", 
      RowBox[{
       StyleBox["x",
        FontWeight->"Bold"], "(", "2", ")"}], "  ", ",", " ", "...", "  ", 
      ",", " ", 
      RowBox[{
       StyleBox["x",
        FontWeight->"Bold"], "(", "n", ")"}], "  ", ",", " ", 
      RowBox[{
       StyleBox["x",
        FontWeight->"Bold"], "(", 
       RowBox[{"n", "-", "1"}], ")"}], ",", " ", "..."}], " ", ")"}]}], 
   TraditionalForm]]],
 "\n\n\nAnd the LowPass filter a\n\n",
 Cell[BoxData[
  FormBox[
   RowBox[{
    StyleBox["a",
     FontWeight->"Bold"], "=", " ", 
    RowBox[{"(", " ", 
     RowBox[{
      FractionBox["1", "2"], "  ", ",", " ", 
      FractionBox["1", "2"]}], " ", ")"}]}], TraditionalForm]]],
 " \n\n\nThen calculate \n\n",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     UnderoverscriptBox["\[Sum]", 
      RowBox[{"k", "=", "0"}], "1"], 
     RowBox[{
      RowBox[{"a", "(", "k", ")"}], 
      RowBox[{"x", "(", 
       RowBox[{"n", "-", "k"}], ")"}]}]}], " ", "=", " ", 
    RowBox[{
     RowBox[{
      RowBox[{
       FractionBox["1", "2"], 
       RowBox[{"x", "(", 
        RowBox[{"n", "-", "0"}], ")"}]}], " ", "+", " ", 
      RowBox[{
       FractionBox["1", "2"], 
       RowBox[{"x", "(", 
        RowBox[{"n", "-", "1"}], ")"}]}]}], "  ", "=", " ", 
     RowBox[{
      RowBox[{
       FractionBox["1", "2"], 
       RowBox[{"x", "(", "n", ")"}]}], " ", "+", " ", 
      RowBox[{
       FractionBox["1", "2"], 
       RowBox[{"x", "(", 
        RowBox[{"n", "-", "1"}], ")"}]}]}]}]}], TraditionalForm]]],
 "\n\n\nThe latter is called the ",
 StyleBox["Moving Averages",
  FontSlant->"Italic"],
 ".\n\nIn order to \[OpenCurlyQuote]move\[CloseCurlyQuote] this averaging \
along the different parts of the signal pad \[OpenCurlyQuote]a\
\[CloseCurlyQuote] with 0s\n\n",
 Cell[BoxData[
  FormBox[
   RowBox[{
    StyleBox["a",
     FontWeight->"Bold"], "=", " ", 
    RowBox[{"(", " ", 
     RowBox[{"0", ",", " ", "0", ",", " ", "...", " ", ",", " ", 
      FractionBox["1", "2"], "  ", ",", " ", 
      FractionBox["1", "2"], ",", " ", "...", ",", " ", "0", ",", " ", "0"}], 
     " ", ")"}]}], TraditionalForm]]],
 " \n"
}], "Text",
 CellChangeTimes->{{3.521769374908181*^9, 3.521769383814288*^9}, {
   3.521914010598323*^9, 3.521914096664672*^9}, {3.5219144075639057`*^9, 
   3.521914409553049*^9}, {3.52191448097577*^9, 3.521914481772477*^9}, {
   3.521917257407992*^9, 3.521917298082695*^9}, {3.52191758624896*^9, 
   3.521917703918346*^9}, {3.521917977890902*^9, 3.52191803615913*^9}, {
   3.521918237946842*^9, 3.521918254536881*^9}, {3.521918286505726*^9, 
   3.521918463296842*^9}, {3.521918493922163*^9, 3.521918494338293*^9}, {
   3.5219187172778873`*^9, 3.521918844950458*^9}, {3.5219205679317293`*^9, 
   3.5219205897539062`*^9}, {3.5219208720820827`*^9, 3.521920874857373*^9}, 
   3.521921098737865*^9, 3.52192127114574*^9, {3.521948700936322*^9, 
   3.521948704545389*^9}, {3.521952959339999*^9, 3.521953056525342*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
   "Grab", " ", "the", " ", "LowPass", " ", "filter", " ", "coefficients", 
    " ", "for", " ", "HaarWavelet"}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"lp", "=", 
     RowBox[{"WaveletFilterCoefficients", "[", 
      RowBox[{
       RowBox[{"HaarWavelet", "[", "]"}], ",", "\"\<PrimalLowpass\>\""}], 
      "]"}]}], ";"}], "\[IndentingNewLine]", "lp"}]}]], "Input",
 CellChangeTimes->{{3.521759791993965*^9, 3.521759807739674*^9}, {
  3.521917207782815*^9, 3.5219172345696*^9}, {3.521920105693589*^9, 
  3.5219201083459063`*^9}, {3.5219593214427567`*^9, 3.521959341905553*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"0", ",", "0.5`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1", ",", "0.5`"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.521759809391652*^9, 3.5219189933389*^9, 
  3.6025442888353357`*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
   "Make", " ", "an", " ", "array", " ", "that", " ", "is", " ", "of", " ", 
    "the", " ", "form", " ", 
    RowBox[{"(", " ", 
     RowBox[{"0", ",", " ", "0", ",", " ", "...", " ", ",", 
      FractionBox["1", "2"], " ", ",", 
      FractionBox["1", "2"], ",", " ", "...", ",", " ", "0", ",", " ", "0"}], 
     " ", ")"}], " ", "\[IndentingNewLine]", "Note", " ", "that", " ", "the", 
    " ", "array", " ", "is", " ", "emulated", " ", "via", " ", "a", " ", 
    "function", " ", "call", " ", "in", " ", "Mathematica"}], " ", "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"a", "[", "n_", "]"}], ":=", " ", 
    RowBox[{"If", "[", 
     RowBox[{
      RowBox[{"1", "\[LessEqual]", "n", "\[LessEqual]", 
       RowBox[{"Length", "[", "lp", "]"}]}], ",", 
      RowBox[{"lp", "\[LeftDoubleBracket]", 
       RowBox[{"n", ",", "2"}], "\[RightDoubleBracket]"}], ",", "0"}], 
     "]"}]}], "\n"}]}]], "Input",
 CellChangeTimes->{
  3.5217602403656054`*^9, {3.521920146308728*^9, 3.521920229294422*^9}, {
   3.521920262643943*^9, 3.521920277254669*^9}, {3.521920369627948*^9, 
   3.521920378792614*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{"DiscretePlot", "[", 
   RowBox[{
    RowBox[{"a", "[", "n", "]"}], ",", " ", 
    RowBox[{"{", 
     RowBox[{"n", ",", " ", 
      RowBox[{"-", "20"}], ",", "20"}], " ", "}"}], ",", 
    RowBox[{"PlotRange", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "20"}], ",", "20"}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.7"}], ",", " ", "0.7"}], "}"}]}], "}"}]}]}], 
   "]"}]}]], "Input",
 CellChangeTimes->{
  3.5217602507344646`*^9, {3.521760292328155*^9, 3.521760294454825*^9}, {
   3.521778938211323*^9, 3.521778992159582*^9}, 3.5217790441928387`*^9, {
   3.5217796121419783`*^9, 3.52177964640959*^9}}],

Cell[BoxData[
 GraphicsBox[{
   {RGBColor[0.24720000000000014`, 0.24, 0.6], 
    {Opacity[0.2], 
     LineBox[{{{-20., 0.}, {-20., 0}}, {{-19., 0.}, {-19., 0}}, {{-18., 
        0.}, {-18., 0}}, {{-17., 0.}, {-17., 0}}, {{-16., 
        0.}, {-16., 0}}, {{-15., 0.}, {-15., 0}}, {{-14., 
        0.}, {-14., 0}}, {{-13., 0.}, {-13., 0}}, {{-12., 
        0.}, {-12., 0}}, {{-11., 0.}, {-11., 0}}, {{-10., 
        0.}, {-10., 0}}, {{-9., 0.}, {-9., 0}}, {{-8., 0.}, {-8., 0}}, {{-7., 
        0.}, {-7., 0}}, {{-6., 0.}, {-6., 0}}, {{-5., 0.}, {-5., 0}}, {{-4., 
        0.}, {-4., 0}}, {{-3., 0.}, {-3., 0}}, {{-2., 0.}, {-2., 0}}, {{-1., 
        0.}, {-1., 0}}, {{0., 0.}, {0., 0}}, {{3., 0.}, {3., 0}}, {{4., 0.}, {
        4., 0}}, {{5., 0.}, {5., 0}}, {{6., 0.}, {6., 0}}, {{7., 0.}, {
        7., 0}}, {{8., 0.}, {8., 0}}, {{9., 0.}, {9., 0}}, {{10., 0.}, {
        10., 0}}, {{11., 0.}, {11., 0}}, {{12., 0.}, {12., 0}}, {{13., 0.}, {
        13., 0}}, {{14., 0.}, {14., 0}}, {{15., 0.}, {15., 0}}, {{16., 0.}, {
        16., 0}}, {{17., 0.}, {17., 0}}, {{18., 0.}, {18., 0}}, {{19., 0.}, {
        19., 0}}, {{20., 0.}, {20., 0}}},
      VertexColors->None]}, 
    {Opacity[0.2], LineBox[{{{1., 0.5}, {1., 0}}, {{2., 0.5}, {2., 0}}},
      VertexColors->None]}}, 
   {RGBColor[0.24720000000000014`, 0.24, 0.6], {}, PointBox[CompressedData["
1:eJx9zTEOQEAQRuGJSqlQKBSICLIRa7fnDI4gUTsiR3GEPQJCJF7hJZM/XzXp
tIyzJyLVedfe2U0+GbiDNdzCDazgGi7hAs7hDE7gGI7gEA5gHxbYrfKb6+/d
n5Xha3/AfziEIziGEziDc7iAS7iGFdzALazhDjawfX0Au+wfFw==
     "]], {}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesOrigin->{0, 0},
  Method->{"MessagesHead" -> DiscretePlot},
  PlotRange->{{-20, 20}, {-0.7, 0.7}},
  PlotRangePadding->{{Automatic, Automatic}, {
    Automatic, Automatic}}]], "Output",
 CellChangeTimes->{
  3.521760251032634*^9, 3.5217602956484327`*^9, 3.5217789940292063`*^9, 
   3.521779045335785*^9, {3.5217796132775097`*^9, 3.521779647455769*^9}, 
   3.521919077604767*^9}]
}, Open  ]],

Cell["\<\



Let\[CloseCurlyQuote]s illustrate the moving aspect of the \
\[CloseCurlyQuote]Moving Average\[CloseCurlyQuote]:\
\>", "Text",
 CellChangeTimes->{{3.521920502360283*^9, 3.5219205422769127`*^9}, {
  3.521959350265417*^9, 3.521959350792696*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Manipulate", "[", 
   RowBox[{
    RowBox[{"DiscretePlot", "[", 
     RowBox[{
      RowBox[{"a", "[", 
       RowBox[{"m", "-", 
        RowBox[{"2", " ", "n"}], "+", "2"}], "]"}], ",", " ", 
      RowBox[{"{", 
       RowBox[{"m", ",", " ", 
        RowBox[{"-", "20"}], ",", "20"}], " ", "}"}], ",", " ", 
      RowBox[{"PlotRange", "\[Rule]", "All"}]}], "]"}], ",", " ", 
    RowBox[{"{", 
     RowBox[{"n", ",", " ", "1", ",", " ", 
      RowBox[{"(", 
       RowBox[{"20", "/", "2"}], ")"}], ",", "1"}], "}"}]}], "]"}], 
  "\n"}]], "Input",
 CellChangeTimes->{
  3.52191898009239*^9, 3.5219190977966022`*^9, 3.521919141715475*^9, {
   3.52191929535533*^9, 3.521919295758576*^9}, {3.5219195006046047`*^9, 
   3.5219195006809883`*^9}, {3.521919580675558*^9, 3.521919582081024*^9}, {
   3.521919631493916*^9, 3.5219196401464863`*^9}, {3.521919736700604*^9, 
   3.52191975718956*^9}}],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{$CellContext`n$$ = 1, Typeset`show$$ = True, 
    Typeset`bookmarkList$$ = {}, Typeset`bookmarkMode$$ = "Menu", 
    Typeset`animator$$, Typeset`animvar$$ = 1, Typeset`name$$ = 
    "\"untitled\"", Typeset`specs$$ = {{
      Hold[$CellContext`n$$], 1, 10, 1}}, Typeset`size$$ = {
    360., {113., 118.}}, Typeset`update$$ = 0, Typeset`initDone$$, 
    Typeset`skipInitDone$$ = True, $CellContext`n$73496$$ = 0}, 
    DynamicBox[Manipulate`ManipulateBoxes[
     1, StandardForm, "Variables" :> {$CellContext`n$$ = 1}, 
      "ControllerVariables" :> {
        Hold[$CellContext`n$$, $CellContext`n$73496$$, 0]}, 
      "OtherVariables" :> {
       Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
        Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
        Typeset`specs$$, Typeset`size$$, Typeset`update$$, Typeset`initDone$$,
         Typeset`skipInitDone$$}, "Body" :> DiscretePlot[
        $CellContext`a[$CellContext`m - 2 $CellContext`n$$ + 
         2], {$CellContext`m, -20, 20}, PlotRange -> All], 
      "Specifications" :> {{$CellContext`n$$, 1, 10, 1}}, "Options" :> {}, 
      "DefaultOptions" :> {}],
     ImageSizeCache->{405., {157., 162.}},
     SingleEvaluation->True],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    SynchronousInitialization->True,
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "Manipulate",
   Deployed->True,
   StripOnInput->False],
  Manipulate`InterpretManipulate[1]]], "Output",
 CellChangeTimes->{{3.52191908261478*^9, 3.521919099624378*^9}, 
   3.521919143881167*^9, 3.5219192966486597`*^9, 3.52191950173882*^9, 
   3.5219196664386463`*^9, {3.5219197379176283`*^9, 3.521919763777871*^9}, 
   3.60254429473591*^9}]
}, Open  ]],

Cell[TextData[{
 "\n2. ",
 StyleBox["HighPass",
  FontWeight->"Bold"],
 "  \n\n",
 Cell[BoxData[
  FormBox[
   RowBox[{" ", 
    RowBox[{
     RowBox[{
      FractionBox["1", "2"], 
      RowBox[{"x", "(", "n", ")"}]}], " ", "-", " ", 
     RowBox[{
      FractionBox["1", "2"], 
      RowBox[{"x", "(", 
       RowBox[{"n", "-", "1"}], ")"}]}]}]}], TraditionalForm]]],
 "\n\n\nWhere signal is of the form allowing for negative indeces:\n\n\n",
 Cell[BoxData[
  FormBox[
   RowBox[{
    StyleBox["x",
     FontWeight->"Bold"], "=", " ", 
    RowBox[{"(", 
     RowBox[{"...", " ", ",", " ", 
      RowBox[{
       StyleBox["x",
        FontWeight->"Bold"], "(", 
       RowBox[{"-", "2"}], ")"}], "  ", ",", " ", 
      RowBox[{
       StyleBox["x",
        FontWeight->"Bold"], "(", 
       RowBox[{"-", "1"}], ")"}], "  ", ",", " ", 
      RowBox[{
       StyleBox["x",
        FontWeight->"Bold"], "(", "0", ")"}], "  ", ",", " ", 
      RowBox[{
       StyleBox["x",
        FontWeight->"Bold"], "(", "1", ")"}], "  ", ",", " ", 
      RowBox[{
       StyleBox["x",
        FontWeight->"Bold"], "(", "2", ")"}], "  ", ",", " ", "...", "  ", 
      ",", " ", 
      RowBox[{
       StyleBox["x",
        FontWeight->"Bold"], "(", "n", ")"}], "  ", ",", " ", 
      RowBox[{
       StyleBox["x",
        FontWeight->"Bold"], "(", 
       RowBox[{"n", "-", "1"}], ")"}], ",", " ", "..."}], " ", ")"}]}], 
   TraditionalForm]]],
 "\n\n\nAnd the HighPass filter a\n\n",
 Cell[BoxData[
  FormBox[
   RowBox[{
    StyleBox["a",
     FontWeight->"Bold"], "=", " ", 
    RowBox[{"(", " ", 
     RowBox[{
      FractionBox["1", "2"], "  ", ",", " ", 
      RowBox[{"-", 
       FractionBox["1", "2"]}]}], " ", ")"}]}], TraditionalForm]]],
 " \n\n\nThen calculate \n\n",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     UnderoverscriptBox["\[Sum]", 
      RowBox[{"k", "=", "0"}], "1"], 
     RowBox[{
      RowBox[{"a", "(", "k", ")"}], 
      RowBox[{"x", "(", 
       RowBox[{"n", "-", "k"}], ")"}]}]}], " ", "=", " ", 
    RowBox[{
     RowBox[{
      RowBox[{
       FractionBox["1", "2"], 
       RowBox[{"x", "(", 
        RowBox[{"n", "-", "0"}], ")"}]}], " ", "-", " ", 
      RowBox[{
       FractionBox["1", "2"], 
       RowBox[{"x", "(", 
        RowBox[{"n", "-", "1"}], ")"}]}]}], "  ", "=", " ", 
     RowBox[{
      RowBox[{
       FractionBox["1", "2"], 
       RowBox[{"x", "(", "n", ")"}]}], " ", "-", " ", 
      RowBox[{
       FractionBox["1", "2"], 
       RowBox[{"x", "(", 
        RowBox[{"n", "-", "1"}], ")"}]}]}]}]}], TraditionalForm]]],
 "\n\n\nThe latter is called the ",
 StyleBox["Moving Differences",
  FontSlant->"Italic"],
 ".\n\nIn order to \[OpenCurlyQuote]move\[CloseCurlyQuote] this difference \
along the different parts of the signal pad \[OpenCurlyQuote]a\
\[CloseCurlyQuote] with 0s\n\n",
 Cell[BoxData[
  FormBox[
   RowBox[{
    StyleBox["a",
     FontWeight->"Bold"], "=", " ", 
    RowBox[{"(", " ", 
     RowBox[{"0", ",", " ", "0", ",", " ", "...", " ", ",", " ", 
      FractionBox["1", "2"], "  ", ",", " ", 
      RowBox[{"-", 
       FractionBox["1", "2"]}], ",", " ", "...", ",", " ", "0", ",", " ", 
      "0"}], " ", ")"}]}], TraditionalForm]]],
 " \n"
}], "Text",
 CellChangeTimes->{{3.521921032671423*^9, 3.5219210892624083`*^9}, {
   3.5219211397769814`*^9, 3.521921155676692*^9}, {3.52192193707171*^9, 
   3.521921937071835*^9}, 3.521949718875286*^9}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"hp", "=", 
   RowBox[{"WaveletFilterCoefficients", "[", 
    RowBox[{
     RowBox[{"HaarWavelet", "[", "]"}], ",", "\"\<PrimalHighpass\>\""}], 
    "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"hp", "\n"}], "\n"}], "Input",
 CellChangeTimes->{{3.521949835759192*^9, 3.521949839527714*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"0", ",", "0.5`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1", ",", 
     RowBox[{"-", "0.5`"}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.521949841716236*^9, 3.6025473140351143`*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"b", "[", "n_", "]"}], ":=", " ", 
  RowBox[{"If", "[", 
   RowBox[{
    RowBox[{"1", "\[LessEqual]", "n", "\[LessEqual]", 
     RowBox[{"Length", "[", "hp", "]"}]}], ",", 
    RowBox[{"hp", "\[LeftDoubleBracket]", 
     RowBox[{"n", ",", "2"}], "\[RightDoubleBracket]"}], ",", "0"}], 
   "]"}]}]], "Input",
 CellChangeTimes->{3.5219498591190653`*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"DiscretePlot", "[", 
   RowBox[{
    RowBox[{"b", "[", "n", "]"}], ",", " ", 
    RowBox[{"{", 
     RowBox[{"n", ",", " ", 
      RowBox[{"-", "20"}], ",", "20"}], " ", "}"}], ",", " ", 
    RowBox[{"PlotRange", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "20"}], ",", "20"}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.7"}], ",", " ", "0.7"}], "}"}]}], "}"}]}]}], "]"}], 
  "\n"}]], "Input",
 CellChangeTimes->{3.521949888469944*^9}],

Cell[BoxData[
 GraphicsBox[{
   {RGBColor[0.24720000000000014`, 0.24, 0.6], 
    {Opacity[0.2], 
     LineBox[{{{-20., 0.}, {-20., 0}}, {{-19., 0.}, {-19., 0}}, {{-18., 
        0.}, {-18., 0}}, {{-17., 0.}, {-17., 0}}, {{-16., 
        0.}, {-16., 0}}, {{-15., 0.}, {-15., 0}}, {{-14., 
        0.}, {-14., 0}}, {{-13., 0.}, {-13., 0}}, {{-12., 
        0.}, {-12., 0}}, {{-11., 0.}, {-11., 0}}, {{-10., 
        0.}, {-10., 0}}, {{-9., 0.}, {-9., 0}}, {{-8., 0.}, {-8., 0}}, {{-7., 
        0.}, {-7., 0}}, {{-6., 0.}, {-6., 0}}, {{-5., 0.}, {-5., 0}}, {{-4., 
        0.}, {-4., 0}}, {{-3., 0.}, {-3., 0}}, {{-2., 0.}, {-2., 0}}, {{-1., 
        0.}, {-1., 0}}, {{0., 0.}, {0., 0}}, {{2., -0.5}, {2., 0}}, {{3., 
        0.}, {3., 0}}, {{4., 0.}, {4., 0}}, {{5., 0.}, {5., 0}}, {{6., 0.}, {
        6., 0}}, {{7., 0.}, {7., 0}}, {{8., 0.}, {8., 0}}, {{9., 0.}, {
        9., 0}}, {{10., 0.}, {10., 0}}, {{11., 0.}, {11., 0}}, {{12., 0.}, {
        12., 0}}, {{13., 0.}, {13., 0}}, {{14., 0.}, {14., 0}}, {{15., 0.}, {
        15., 0}}, {{16., 0.}, {16., 0}}, {{17., 0.}, {17., 0}}, {{18., 0.}, {
        18., 0}}, {{19., 0.}, {19., 0}}, {{20., 0.}, {20., 0}}},
      VertexColors->None]}, 
    {Opacity[0.2], LineBox[{{{1., 0.5}, {1., 0}}},
      VertexColors->None]}}, 
   {RGBColor[0.24720000000000014`, 0.24, 0.6], {}, PointBox[CompressedData["
1:eJx9zbsJgEAQhOHFyNDgAgMDlUNUjsNXrjVYgmBsiVqKJViCiofgHziwDF8w
bDIt4+yJSHHd3U+6TT5p4Qau4Qq2sIFLOIczWMMpHMMRHMIKDmAfFvhY5TdH
//TuWgZnt/MH/IcVHMIRHMMprOEMzuESNrCFK7iGG7iFu9cnTHsflw==
     "]], {}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesOrigin->{0, 0},
  Method->{"MessagesHead" -> DiscretePlot},
  PlotRange->{{-20, 20}, {-0.7, 0.7}},
  PlotRangePadding->{{Automatic, Automatic}, {
    Automatic, Automatic}}]], "Output",
 CellChangeTimes->{3.521949891455265*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Manipulate", "[", 
  RowBox[{
   RowBox[{"DiscretePlot", "[", 
    RowBox[{
     RowBox[{"b", "[", 
      RowBox[{"m", "-", 
       RowBox[{"2", " ", "n"}], "+", "2"}], "]"}], ",", " ", 
     RowBox[{"{", 
      RowBox[{"m", ",", " ", 
       RowBox[{"-", "20"}], ",", "20"}], " ", "}"}], ",", " ", 
     RowBox[{"PlotRange", "\[Rule]", "All"}]}], "]"}], ",", " ", 
   RowBox[{"{", 
    RowBox[{"n", ",", " ", "1", ",", " ", 
     RowBox[{"(", 
      RowBox[{"20", "/", "2"}], ")"}], ",", "1"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.521920405233341*^9, 3.521920409082253*^9}}],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{$CellContext`n$$ = 5, Typeset`show$$ = True, 
    Typeset`bookmarkList$$ = {}, Typeset`bookmarkMode$$ = "Menu", 
    Typeset`animator$$, Typeset`animvar$$ = 1, Typeset`name$$ = 
    "\"untitled\"", Typeset`specs$$ = {{
      Hold[$CellContext`n$$], 1, 10, 1}}, Typeset`size$$ = {
    360., {109., 113.}}, Typeset`update$$ = 0, Typeset`initDone$$, 
    Typeset`skipInitDone$$ = True, $CellContext`n$73937$$ = 0}, 
    DynamicBox[Manipulate`ManipulateBoxes[
     1, StandardForm, "Variables" :> {$CellContext`n$$ = 1}, 
      "ControllerVariables" :> {
        Hold[$CellContext`n$$, $CellContext`n$73937$$, 0]}, 
      "OtherVariables" :> {
       Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
        Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
        Typeset`specs$$, Typeset`size$$, Typeset`update$$, Typeset`initDone$$,
         Typeset`skipInitDone$$}, "Body" :> DiscretePlot[
        $CellContext`b[$CellContext`m - 2 $CellContext`n$$ + 
         2], {$CellContext`m, -20, 20}, PlotRange -> All], 
      "Specifications" :> {{$CellContext`n$$, 1, 10, 1}}, "Options" :> {}, 
      "DefaultOptions" :> {}],
     ImageSizeCache->{405., {153., 158.}},
     SingleEvaluation->True],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    SynchronousInitialization->True,
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "Manipulate",
   Deployed->True,
   StripOnInput->False],
  Manipulate`InterpretManipulate[1]]], "Output",
 CellChangeTimes->{3.521920411882135*^9, 3.602547308027671*^9}]
}, Open  ]],

Cell["\<\


Now let\[CloseCurlyQuote]s make a simple signal comprised of 8 numbers:
\
\>", "Text",
 CellChangeTimes->{{3.521921315430039*^9, 3.521921329357737*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{"Input", " ", "Data", " ", "is", " ", "in", " ", "x"}], ",", " ", 
    
    RowBox[{"just", " ", "an", " ", "array", " ", "of", " ", "numbders"}]}], 
   " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{
   "Length", " ", "of", " ", "x", " ", "is", " ", "a", " ", "power", " ", 
    "of", " ", "2", " ", "or", " ", "x", " ", "is", " ", "dyadic"}], " ", 
   "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"x", " ", "=", 
     RowBox[{"Range", "[", "8", "]"}]}], ";"}], "\[IndentingNewLine]", 
   "x"}]}]], "Input",
 CellChangeTimes->{{3.5217607475757523`*^9, 3.5217607848603573`*^9}, {
  3.5217609545048847`*^9, 3.521760971041209*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "1", ",", "2", ",", "3", ",", "4", ",", "5", ",", "6", ",", "7", ",", "8"}],
   "}"}]], "Output",
 CellChangeTimes->{3.521760785394053*^9, 3.5219301702651577`*^9}]
}, Open  ]],

Cell[TextData[{
 "The tree of wavelet coefficients at level ",
 Cell[BoxData[
  FormBox["j", TraditionalForm]], "InlineMath"],
 " consists of coarse coefficients ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["c", 
    RowBox[{"j", ",", "n"}]], TraditionalForm]], "InlineMath"],
 " and detail coefficients ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["d", 
    RowBox[{"j", ",", "n"}]], TraditionalForm]], "InlineMath"],
 ", with ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["c", 
     RowBox[{"0", ",", "n"}]], "=", 
    SubscriptBox["x", "n"]}], TraditionalForm]], "InlineMath"],
 " representing the input ",
 Cell[BoxData[
  StyleBox["data", "TI"]], "InlineFormula"],
 ". \n"
}], "Text",
 CellChangeTimes->{3.521921285708427*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    SubscriptBox["c", 
     RowBox[{"0", ",", "n"}]], " ", "which", " ", "is", " ", "the", " ", 
    "finest", " ", "level", " ", "of", " ", "detail", " ", 
    RowBox[{"i", ".", "e", ".", " ", "the"}], " ", "input", " ", "data", " ", 
    "namely", " ", "x"}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{
   "Make", " ", "variable", " ", "c", " ", "like", " ", "a", " ", "list", " ",
     "or", " ", "array", " ", "or", " ", "matrix"}], " ", "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"SetAttributes", "[", 
    RowBox[{"c", ",", "Listable"}], "]"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"c", "[", 
      RowBox[{"0", ",", "n_"}], "]"}], ":=", 
     RowBox[{"x", "\[LeftDoubleBracket]", "n", "\[RightDoubleBracket]"}]}], 
    ";"}], " "}]}]], "Input",
 CellChangeTimes->{{3.521760739869432*^9, 3.5217607409597597`*^9}, {
  3.521760797272162*^9, 3.5217608467069063`*^9}, {3.521921343198992*^9, 
  3.521921343548238*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", "Test", " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{"c", "[", 
   RowBox[{"0", ",", " ", "1"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.521761388248871*^9, 3.5217613917689133`*^9}, {
  3.521761424444063*^9, 3.521761429212368*^9}}],

Cell[BoxData["1"], "Output",
 CellChangeTimes->{3.521761392703195*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"c", "[", 
  RowBox[{"0", ",", " ", "4"}], "]"}]], "Input",
 CellChangeTimes->{{3.521761404798358*^9, 3.5217614083645077`*^9}}],

Cell[BoxData["4"], "Output",
 CellChangeTimes->{3.521761412942197*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"DiscretePlot", "[", 
  RowBox[{
   RowBox[{"c", "[", 
    RowBox[{"0", ",", "n"}], "]"}], ",", " ", 
   RowBox[{"{", 
    RowBox[{"n", ",", " ", "1", ",", "8"}], " ", "}"}], ",", " ", 
   RowBox[{"PlotRange", "\[Rule]", "All"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.521780113497141*^9, 3.521780149904647*^9}}],

Cell[BoxData[
 GraphicsBox[{
   {RGBColor[0.24720000000000014`, 0.24, 0.6], 
    {Opacity[0.2], LineBox[{{{1., 1.}, {1., 1.}}},
      VertexColors->None]}, 
    {Opacity[0.2], 
     LineBox[{{{2., 2.}, {2., 1.}}, {{3., 3.}, {3., 1.}}, {{4., 4.}, {4., 
      1.}}, {{5., 5.}, {5., 1.}}, {{6., 6.}, {6., 1.}}, {{7., 7.}, {7., 
      1.}}, {{8., 8.}, {8., 1.}}},
      VertexColors->None]}}, 
   {RGBColor[0.24720000000000014`, 0.24, 0.6], {}, 
    PointBox[{{1., 1.}, {2., 2.}, {3., 3.}, {4., 4.}, {5., 5.}, {6., 6.}, {7.,
      7.}, {8., 8.}}], {}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesOrigin->{1., 1.},
  Method->{"MessagesHead" -> DiscretePlot},
  PlotRange->{{1., 8.}, {1., 8.}},
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.02], 
     Scaled[0.02]}}]], "Output",
 CellChangeTimes->{{3.521780118779632*^9, 3.521780156574903*^9}, 
   3.5219301765737543`*^9}]
}, Open  ]],

Cell["Low Pass Visualization ", "Text",
 CellChangeTimes->{{3.521949745852488*^9, 3.5219497515102997`*^9}}],

Cell[TextData[{
 "Coarse coefficients at level ",
 StyleBox["j",
  FontSlant->"Italic"],
 " are given by ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["c", 
     RowBox[{"j", ",", "n"}]], "=", 
    RowBox[{
     SqrtBox["2"], 
     RowBox[{
      UnderscriptBox["\[Sum]", "m"], 
      RowBox[{
       SubscriptBox["a", 
        RowBox[{"m", "-", 
         RowBox[{"2", "n"}], "+", "2"}]], " ", 
       SubscriptBox["c", 
        RowBox[{
         RowBox[{"j", "-", "1"}], ",", "m"}]]}]}]}]}], TraditionalForm]], 
  "InlineMath"],
 " from level",
 StyleBox[" ",
  FontSlant->"Italic"],
 Cell[BoxData[
  FormBox[
   RowBox[{"j", "-", "1"}], TraditionalForm]]]
}], "Text",
 CellChangeTimes->{
  3.521761543313582*^9, {3.5217625148397627`*^9, 3.521762542737946*^9}, {
   3.521763139602449*^9, 3.5217631744098787`*^9}, {3.521951224859344*^9, 
   3.521951232251782*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", 
   RowBox[{
    RowBox[{
     RowBox[{"Reason", " ", "for", " ", 
      RowBox[{"the", " ", "'"}], "2", "n"}], " ", "+", 
     RowBox[{
      RowBox[{"2", "'"}], " ", "is", " ", "to", " ", "sum", " ", "only", " ", 
      "the", " ", "even", " ", "indices"}]}], ",", " ", 
    RowBox[{
     RowBox[{"while", " ", "'"}], 
     RowBox[{"m", "'"}], " ", "serves", "\[IndentingNewLine]", "as", " ", 
     "the", " ", "moving", " ", "param", " ", "that", " ", "pushes", " ", 
     "the", " ", "calculations", " ", "up", " ", "the", " ", "signal"}]}], 
   " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{
    RowBox[{"FIXME", ":", " ", 
     RowBox[{
     "Calculations", " ", "go", " ", "beyond", " ", "the", " ", "bound", " ", 
      "of", " ", "the", " ", "signal"}]}], ",", "   ", 
    RowBox[{
    "therefore", " ", "out", " ", "of", " ", "range", " ", "indices", " ", 
     "are", " ", "handled", " ", "via", " ", "wrapping", " ", "the", " ", 
     "sigan", " ", "around", " ", 
     RowBox[{"i", ".", "e", ".", "  ", 
      RowBox[{"Mod", "[", 
       RowBox[{"m", ",", 
        RowBox[{"Length", "[", "x", "]"}], ",", "1"}], "]"}], ".", " ", 
      "Is"}], " ", "there", " ", "a", " ", "better", " ", 
     RowBox[{"way", "?"}]}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{"Kludge", ":", " ", 
    RowBox[{"'", "-", 
     RowBox[{
      RowBox[{"20", "'"}], " ", 
      RowBox[{"and", " ", "'"}]}], "+", 
     RowBox[{
      RowBox[{"20", "'"}], " ", "are", " ", "large", " ", "enough", " ", 
      "bounds", " ", "for", " ", "an", " ", "array", " ", "to", " ", 
      "contain", " ", "the", " ", "standard", " ", "filter", " ", 
      "coefficients", " ", "that", " ", "are", " ", "usually", " ", "a", " ", 
      "few", " ", "numbers"}]}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"c", "[", 
    RowBox[{"j_", ",", "n_"}], "]"}], ":=", 
   RowBox[{
    SqrtBox["2"], " ", 
    RowBox[{
     UnderoverscriptBox["\[Sum]", 
      RowBox[{"m", "=", 
       RowBox[{"-", "20"}]}], "20"], 
     RowBox[{
      RowBox[{"a", "[", 
       RowBox[{"m", "-", 
        RowBox[{"2", " ", "n"}], "+", "2"}], "]"}], " ", 
      RowBox[{"c", "[", 
       RowBox[{
        RowBox[{"j", "-", "1"}], ",", 
        RowBox[{"Mod", "[", 
         RowBox[{"m", ",", 
          RowBox[{"Length", "[", "x", "]"}], ",", "1"}], "]"}]}], 
       "]"}]}]}]}]}]}]], "Input",
 CellChangeTimes->{
  3.5217614708088627`*^9, {3.521766643411302*^9, 3.521766687847911*^9}, {
   3.521766857673603*^9, 3.521766862104272*^9}, 3.521767118031322*^9, {
   3.5217673460179167`*^9, 3.5217673482784147`*^9}, {3.5217691383043947`*^9, 
   3.521769149440151*^9}, {3.521779878868531*^9, 3.521779956800972*^9}, {
   3.521921991386464*^9, 3.521921992689783*^9}, {3.521922393141219*^9, 
   3.52192251947396*^9}, {3.5219299133427553`*^9, 3.521929913879066*^9}, {
   3.52193002186421*^9, 3.521930049416039*^9}, {3.5219481694980497`*^9, 
   3.52194827025877*^9}, {3.5219488548374987`*^9, 3.521948856631627*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{
     RowBox[{"We", " ", "started", " ", "with", " ", "j"}], " ", "=", " ", 
     RowBox[{
      RowBox[{
      "0", " ", "and", " ", "now", " ", "we", " ", "have", " ", "the", " ", 
       "next", " ", "coarser", " ", "level", " ", "j"}], " ", "=", " ", 
      "1"}]}], ",", " ", 
    RowBox[{
     RowBox[{"so", " ", "j"}], " ", "-", " ", 
     RowBox[{
     "1", " ", "is", " ", "the", " ", "more", " ", "detailed", " ", "level", 
      " ", "in", " ", "case", " ", "of", " ", "0", " ", "the", " ", 
      "original", " ", "input", " ", "singal"}]}], ",", " ", 
    RowBox[{
     RowBox[{"and", " ", "j"}], " ", "+", " ", 
     RowBox[{"1", " ", "the", " ", "coarser", " ", "next", " ", "level"}]}]}],
    " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{"c", "[", 
   RowBox[{"1", ",", "1"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.52176148388113*^9, 3.52176148706428*^9}, 
   3.5217674454868803`*^9, 3.521767479564129*^9, {3.5217677248593283`*^9, 
   3.5217677553466263`*^9}, {3.5217677857686443`*^9, 3.521767801328841*^9}, 
   3.521769141303348*^9, {3.521930203293889*^9, 3.521930225018882*^9}, {
   3.521948308871381*^9, 3.521948363502129*^9}}],

Cell[BoxData["2.121320343559643`"], "Output",
 CellChangeTimes->{
  3.5217614875587873`*^9, 3.521766869208518*^9, {3.521767457304741*^9, 
   3.52176748384648*^9}, {3.521767725515073*^9, 3.52176775589854*^9}, {
   3.521767786699768*^9, 3.521767802951828*^9}, {3.521769145185689*^9, 
   3.5217691525264063`*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"j", " ", "=", " ", "1"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"n", " ", "=", "5"}], ";"}], "\[IndentingNewLine]", 
  "\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{
    "For", " ", "particular", " ", "values", " ", "of", " ", "j", " ", "and", 
     " ", "n"}], ",", " ", 
    RowBox[{
    "tabulate", " ", "how", " ", "the", " ", "interim", " ", "calculations", 
     " ", "result", " ", "within", " ", "the", " ", 
     SqrtBox["2"], 
     RowBox[{
      UnderscriptBox["\[Sum]", "m"], 
      RowBox[{
       SubscriptBox["a", 
        RowBox[{"m", "-", 
         RowBox[{"2", "n"}], "+", "2"}]], " ", 
       SubscriptBox["c", 
        RowBox[{
         RowBox[{"j", "-", "1"}], ",", "m"}]]}]}]}]}], " ", "*)"}], 
  " "}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Table", "[", 
   RowBox[{
    RowBox[{
     SqrtBox["2"], "*", 
     RowBox[{"a", "[", 
      RowBox[{"m", "-", 
       RowBox[{"2", " ", "n"}], "+", "2"}], "]"}], " ", 
     RowBox[{"c", "[", 
      RowBox[{
       RowBox[{"j", "-", "1"}], ",", 
       RowBox[{"Mod", "[", 
        RowBox[{"m", ",", 
         RowBox[{"Length", "[", "x", "]"}], ",", "1"}], "]"}]}], "]"}]}], ",",
     " ", 
    RowBox[{"{", 
     RowBox[{"m", ",", " ", 
      RowBox[{"-", "20"}], ",", " ", "20"}], "}"}]}], "]"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]"}], "Input",
 CellChangeTimes->{{3.52176806950602*^9, 3.521768104092404*^9}, {
   3.521768236287724*^9, 3.5217683554959393`*^9}, {3.5217683882464933`*^9, 
   3.521768445569375*^9}, {3.521768479154421*^9, 3.5217684817173767`*^9}, {
   3.521768585396111*^9, 3.5217686530140667`*^9}, {3.521768702033681*^9, 
   3.521768788762488*^9}, {3.521768849587867*^9, 3.521768888984179*^9}, 
   3.521779773716753*^9, {3.521780283829808*^9, 3.521780290305951*^9}, 
   3.521930110038473*^9, {3.5219501745346203`*^9, 3.52195021778047*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
   ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", 
   "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
   ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", 
   "0.7071067811865476`", ",", "1.4142135623730951`", ",", "0", ",", "0", ",",
    "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", 
   "0"}], "}"}]], "Output",
 CellChangeTimes->{{3.521768342801306*^9, 3.521768355866716*^9}, {
   3.5217683935415382`*^9, 3.52176844631765*^9}, {3.521768634500242*^9, 
   3.521768656599926*^9}, {3.521768702548287*^9, 3.5217687891464643`*^9}, {
   3.521768850964099*^9, 3.521768889522676*^9}, 3.52177977449701*^9, 
   3.521780291175446*^9, 3.521930110826132*^9, 3.5219301814949102`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{"DiscretePlot", "[", 
   RowBox[{
    RowBox[{"c", "[", 
     RowBox[{"1", ",", "n"}], "]"}], ",", " ", 
    RowBox[{"{", 
     RowBox[{"n", ",", " ", "1", ",", "20"}], " ", "}"}], ",", " ", 
    RowBox[{"PlotRange", "\[Rule]", "All"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.521780061674123*^9, 3.521780081440584*^9}, {
  3.5217801645870743`*^9, 3.521780243061852*^9}}],

Cell[BoxData[
 GraphicsBox[{
   {RGBColor[0.24720000000000014`, 0.24, 0.6], 
    {Opacity[0.2], 
     LineBox[{{{11., 0.}, {11., 0}}, {{12., 0.}, {12., 0}}, {{13., 0.}, {
        13., 0}}, {{14., 0.}, {14., 0}}, {{15., 0.}, {15., 0}}, {{16., 0.}, {
        16., 0}}, {{17., 0.}, {17., 0}}, {{18., 0.}, {18., 0}}, {{19., 0.}, {
        19., 0}}, {{20., 0.}, {20., 0}}},
      VertexColors->None]}, 
    {Opacity[0.2], 
     LineBox[{{{1., 2.121320343559643}, {1., 0}}, {{2., 4.949747468305833}, {
        2., 0}}, {{3., 7.778174593052023}, {3., 0}}, {{4., 
        10.606601717798213`}, {4., 0}}, {{5., 2.121320343559643}, {5., 0}}, {{
        6., 4.949747468305833}, {6., 0}}, {{7., 7.778174593052023}, {
        7., 0}}, {{8., 10.606601717798213`}, {8., 0}}, {{9., 
        2.121320343559643}, {9., 0}}, {{10., 4.949747468305833}, {10., 0}}},
      VertexColors->None]}}, 
   {RGBColor[0.24720000000000014`, 0.24, 0.6], {}, PointBox[CompressedData["
1:eJxTTMoPSmViYGAQAWIQDQEf7G/l3D9T9oPBASrgEByyfmbXGWEon8PB6tO7
Mzdl5KF8AQcBD/GGKWaqUL6IA6p+CTT9Mmj6FdD0K6HpV0HTrwZzFxRooPG1
0Pg6aHw9NL4BGt8QjW+ExjdG45vA+QCQui+Y
     "]], {}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesOrigin->{1., 0},
  Method->{"MessagesHead" -> DiscretePlot},
  PlotRange->{{1., 20.}, {0., 10.606601717798213`}},
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.02], 
     Scaled[0.02]}}]], "Output",
 CellChangeTimes->{
  3.5217800823075666`*^9, {3.521780168923964*^9, 3.521780244657419*^9}}]
}, Open  ]],

Cell[TextData[{
 "And similarly ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["d", 
     RowBox[{
      RowBox[{"j", "+", "1"}], ",", "n"}]], "=", 
    RowBox[{
     SqrtBox["2"], 
     RowBox[{
      UnderscriptBox["\[Sum]", "m"], 
      RowBox[{
       SubscriptBox["b", 
        RowBox[{"m", "-", 
         RowBox[{"2", "n"}], "+", "2"}]], " ", 
       SubscriptBox["c", 
        RowBox[{"j", ",", "m"}]]}]}]}]}], TraditionalForm]], "InlineMath"]
}], "Text",
 CellChangeTimes->{{3.521949551588028*^9, 3.5219495609214687`*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"SetAttributes", "[", 
   RowBox[{"d", ",", "Listable"}], "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"d", "[", 
   RowBox[{"j_", ",", "n_"}], "]"}], ":=", 
  RowBox[{
   SqrtBox["2"], 
   RowBox[{
    UnderoverscriptBox["\[Sum]", 
     RowBox[{"m", "=", 
      RowBox[{"-", "20"}]}], "20"], 
    RowBox[{
     RowBox[{"b", "[", 
      RowBox[{"m", "-", 
       RowBox[{"2", " ", "n"}], "+", "2"}], "]"}], " ", 
     RowBox[{"c", "[", 
      RowBox[{
       RowBox[{"j", "-", "1"}], ",", 
       RowBox[{"Mod", "[", 
        RowBox[{"m", ",", 
         RowBox[{"Length", "[", "x", "]"}], ",", "1"}], "]"}]}], 
      "]"}]}]}]}]}]}], "Input",
 CellChangeTimes->{{3.521761591135317*^9, 3.52176162941319*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", "Test", " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{"d", "[", 
   RowBox[{"1", ",", "1"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.521761652138966*^9, 3.521761653870913*^9}, {
  3.521949611248321*^9, 3.521949640949729*^9}}],

Cell[BoxData[
 RowBox[{"-", "0.7071067811865476`"}]], "Output",
 CellChangeTimes->{
  3.521761654727681*^9, 3.521949345154771*^9, {3.5219495893552094`*^9, 
   3.521949619772348*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"j", " ", "=", " ", "1"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"n", " ", "=", "5"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"Table", "[", 
  RowBox[{
   RowBox[{
    SqrtBox["2"], "*", 
    RowBox[{"b", "[", 
     RowBox[{"m", "-", 
      RowBox[{"2", " ", "n"}], "+", "2"}], "]"}], " ", 
    RowBox[{"c", "[", 
     RowBox[{
      RowBox[{"j", "-", "1"}], ",", 
      RowBox[{"Mod", "[", 
       RowBox[{"m", ",", 
        RowBox[{"Length", "[", "x", "]"}], ",", "1"}], "]"}]}], "]"}]}], ",", 
   " ", 
   RowBox[{"{", 
    RowBox[{"m", ",", " ", 
     RowBox[{"-", "20"}], ",", " ", "20"}], "}"}]}], 
  "]"}], "\[IndentingNewLine]"}], "Input",
 CellChangeTimes->{{3.521949074384138*^9, 3.521949078097767*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
   ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", 
   "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
   ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", 
   "0.7071067811865476`", ",", 
   RowBox[{"-", "1.4142135623730951`"}], ",", "0", ",", "0", ",", "0", ",", 
   "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0"}], 
  "}"}]], "Output",
 CellChangeTimes->{3.521949083982902*^9, 3.521949347171878*^9, 
  3.521949415680649*^9, 3.5219495909076357`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"DiscretePlot", "[", 
  RowBox[{
   RowBox[{"d", "[", 
    RowBox[{"1", ",", "n"}], "]"}], ",", " ", 
   RowBox[{"{", 
    RowBox[{"n", ",", " ", "1", ",", "20"}], " ", "}"}], ",", " ", 
   RowBox[{"PlotRange", "\[Rule]", "All"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.521949113468919*^9, 3.521949123313793*^9}}],

Cell[BoxData[
 GraphicsBox[{
   {RGBColor[0.24720000000000014`, 0.24, 0.6], 
    {Opacity[0.2], 
     LineBox[{{{1., -0.7071067811865476}, {1., 0}}, {{
        2., -0.7071067811865476}, {2., 0}}, {{3., -0.7071067811865476}, {
        3., 0}}, {{4., -0.7071067811865476}, {4., 0}}, {{
        5., -0.7071067811865476}, {5., 0}}, {{6., -0.7071067811865476}, {
        6., 0}}, {{7., -0.7071067811865476}, {7., 0}}, {{
        8., -0.7071067811865476}, {8., 0}}, {{9., -0.7071067811865476}, {
        9., 0}}, {{10., -0.7071067811865476}, {10., 0}}, {{11., 0.}, {
        11., 0}}, {{12., 0.}, {12., 0}}, {{13., 0.}, {13., 0}}, {{14., 0.}, {
        14., 0}}, {{15., 0.}, {15., 0}}, {{16., 0.}, {16., 0}}, {{17., 0.}, {
        17., 0}}, {{18., 0.}, {18., 0}}, {{19., 0.}, {19., 0}}, {{20., 0.}, {
        20., 0}}},
      VertexColors->None]}, 
    {Opacity[0.2], LineBox[{},
      VertexColors->None]}}, 
   {RGBColor[0.24720000000000014`, 0.24, 0.6], {}, PointBox[CompressedData["
1:eJxTTMoPSmViYGAQAWIQDQEf7M9a16fNW/BsP1TAAZXPgcYXQOOLoPEl0Pgy
aHwFNL4SGl8Fja/mwIACNND4Wmh8HTS+HhrfAI1viMY3QuMbo/FN4HwALIc6
Yw==
     "]], {}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesOrigin->{1., 0},
  Method->{"MessagesHead" -> DiscretePlot},
  PlotRange->{{1., 20.}, {-0.7071067811865476, 0.}},
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.02], 
     Scaled[0.02]}}]], "Output",
 CellChangeTimes->{{3.5219491150148582`*^9, 3.521949124364297*^9}, {
   3.521949350630076*^9, 3.521949352365819*^9}, {3.5219493999184027`*^9, 
   3.521949417220283*^9}, 3.521949592509647*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"Undefine", " ", "the", " ", "above", " ", "used", " ", "vars"}], 
   " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"a", " ", "=", " ", "."}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"b", " ", "=", " ", "."}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"c", " ", "=", " ", "."}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"d", " ", "=", " ", "."}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"j", " ", "=", " ", "."}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"n", " ", "=", " ", "."}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"dwd", "=", 
     RowBox[{"DiscreteWaveletTransform", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "a", ",", "b", ",", "c", ",", "d", ",", " ", "e", ",", " ", "f", ",", 
         " ", "g", ",", " ", "h", ",", " ", "k", ",", " ", "i", ",", " ", "j",
          ",", " ", "k", ",", " ", "l", ",", " ", "m", ",", " ", "n", ",", 
         " ", "o"}], "}"}], ",", 
       RowBox[{"HaarWavelet", "[", "]"}], ",", 
       RowBox[{"WorkingPrecision", "\[Rule]", "\[Infinity]"}]}], "]"}]}], 
    ";"}]}]}]], "Input",
 CellChangeTimes->{{3.521954363647231*^9, 3.521954440860783*^9}, {
  3.521954484460024*^9, 3.521954516005405*^9}, {3.5219550778982763`*^9, 
  3.521955078448681*^9}, {3.521958618611026*^9, 3.521958628903387*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Normal", "[", "dwd", "]"}], "//", "Simplify"}]], "Input",
 CellChangeTimes->{3.521954373580639*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"{", "0", "}"}], "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      FractionBox[
       RowBox[{"a", "+", "b"}], 
       SqrtBox["2"]], ",", 
      FractionBox[
       RowBox[{"c", "+", "d"}], 
       SqrtBox["2"]], ",", 
      FractionBox[
       RowBox[{"e", "+", "f"}], 
       SqrtBox["2"]], ",", 
      FractionBox[
       RowBox[{"g", "+", "h"}], 
       SqrtBox["2"]], ",", 
      FractionBox[
       RowBox[{"i", "+", "k"}], 
       SqrtBox["2"]], ",", 
      FractionBox[
       RowBox[{"j", "+", "k"}], 
       SqrtBox["2"]], ",", 
      FractionBox[
       RowBox[{"l", "+", "m"}], 
       SqrtBox["2"]], ",", 
      FractionBox[
       RowBox[{"n", "+", "o"}], 
       SqrtBox["2"]]}], "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", "1", "}"}], "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      FractionBox[
       RowBox[{"a", "-", "b"}], 
       SqrtBox["2"]], ",", 
      FractionBox[
       RowBox[{"c", "-", "d"}], 
       SqrtBox["2"]], ",", 
      FractionBox[
       RowBox[{"e", "-", "f"}], 
       SqrtBox["2"]], ",", 
      FractionBox[
       RowBox[{"g", "-", "h"}], 
       SqrtBox["2"]], ",", 
      FractionBox[
       RowBox[{
        RowBox[{"-", "i"}], "+", "k"}], 
       SqrtBox["2"]], ",", 
      FractionBox[
       RowBox[{"j", "-", "k"}], 
       SqrtBox["2"]], ",", 
      FractionBox[
       RowBox[{"l", "-", "m"}], 
       SqrtBox["2"]], ",", 
      FractionBox[
       RowBox[{"n", "-", "o"}], 
       SqrtBox["2"]]}], "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"0", ",", "0"}], "}"}], "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       FractionBox["1", "2"], " ", 
       RowBox[{"(", 
        RowBox[{"a", "+", "b", "+", "c", "+", "d"}], ")"}]}], ",", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       RowBox[{"(", 
        RowBox[{"e", "+", "f", "+", "g", "+", "h"}], ")"}]}], ",", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       RowBox[{"(", 
        RowBox[{"i", "+", "j", "+", 
         RowBox[{"2", " ", "k"}]}], ")"}]}], ",", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       RowBox[{"(", 
        RowBox[{"l", "+", "m", "+", "n", "+", "o"}], ")"}]}]}], "}"}]}], ",", 
   
   RowBox[{
    RowBox[{"{", 
     RowBox[{"0", ",", "1"}], "}"}], "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       FractionBox["1", "2"], " ", 
       RowBox[{"(", 
        RowBox[{"a", "+", "b", "-", "c", "-", "d"}], ")"}]}], ",", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       RowBox[{"(", 
        RowBox[{"e", "+", "f", "-", "g", "-", "h"}], ")"}]}], ",", 
      FractionBox[
       RowBox[{"i", "-", "j"}], "2"], ",", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       RowBox[{"(", 
        RowBox[{"l", "+", "m", "-", "n", "-", "o"}], ")"}]}]}], "}"}]}], ",", 
   
   RowBox[{
    RowBox[{"{", 
     RowBox[{"0", ",", "0", ",", "0"}], "}"}], "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      FractionBox[
       RowBox[{
       "a", "+", "b", "+", "c", "+", "d", "+", "e", "+", "f", "+", "g", "+", 
        "h"}], 
       RowBox[{"2", " ", 
        SqrtBox["2"]}]], ",", 
      FractionBox[
       RowBox[{"i", "+", "j", "+", 
        RowBox[{"2", " ", "k"}], "+", "l", "+", "m", "+", "n", "+", "o"}], 
       RowBox[{"2", " ", 
        SqrtBox["2"]}]]}], "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"0", ",", "0", ",", "1"}], "}"}], "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      FractionBox[
       RowBox[{
       "a", "+", "b", "+", "c", "+", "d", "-", "e", "-", "f", "-", "g", "-", 
        "h"}], 
       RowBox[{"2", " ", 
        SqrtBox["2"]}]], ",", 
      FractionBox[
       RowBox[{"i", "+", "j", "+", 
        RowBox[{"2", " ", "k"}], "-", "l", "-", "m", "-", "n", "-", "o"}], 
       RowBox[{"2", " ", 
        SqrtBox["2"]}]]}], "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"0", ",", "0", ",", "0", ",", "0"}], "}"}], "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      FractionBox["1", "4"], " ", 
      RowBox[{"(", 
       RowBox[{
       "a", "+", "b", "+", "c", "+", "d", "+", "e", "+", "f", "+", "g", "+", 
        "h", "+", "i", "+", "j", "+", 
        RowBox[{"2", " ", "k"}], "+", "l", "+", "m", "+", "n", "+", "o"}], 
       ")"}]}], "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"0", ",", "0", ",", "0", ",", "1"}], "}"}], "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      FractionBox["1", "4"], " ", 
      RowBox[{"(", 
       RowBox[{
       "a", "+", "b", "+", "c", "+", "d", "+", "e", "+", "f", "+", "g", "+", 
        "h", "-", "i", "-", "j", "-", 
        RowBox[{"2", " ", "k"}], "-", "l", "-", "m", "-", "n", "-", "o"}], 
       ")"}]}], "}"}]}]}], "}"}]], "Output",
 CellChangeTimes->{3.521954374769319*^9, 3.52195445135699*^9, 
  3.5219545222955523`*^9, 3.521955084836318*^9, 3.521958203668779*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"dwd", "[", 
  RowBox[{"{", 
   RowBox[{"\"\<TreeView\>\"", ",", "Left"}], "}"}], "]"}]], "Input",
 CellChangeTimes->{{3.5219546286388397`*^9, 3.521954637681995*^9}}],

Cell[BoxData[
 GraphicsBox[
  TagBox[GraphicsComplexBox[{{0., 1.7888543819998282`}, {0.8944271909999165, 
    1.3416407864998712`}, {0.8944271909999155, 2.2360679774997867`}, {
    1.788854381999833, 0.8944271909999141}, {1.788854381999832, 
    1.7888543819998302`}, {2.6832815729997495`, 0.44721359549995704`}, {
    2.683281572999748, 1.341640786499873}, {3.5777087639996656`, 0.}, {
    3.577708763999665, 0.8944271909999159}}, {
     {RGBColor[0.5, 0., 0.], Arrowheads[{{0.026842225325783998`, 0.7}}], 
      ArrowBox[{1, 2}], ArrowBox[{1, 3}], ArrowBox[{2, 4}], ArrowBox[{2, 5}], 
      ArrowBox[{4, 6}], ArrowBox[{4, 7}], ArrowBox[{6, 8}], 
      ArrowBox[{6, 9}]}, {
      TagBox[
       TooltipBox[InsetBox[
         FrameBox[
          RowBox[{"{", "\<\"\"\>", "}"}],
          Background->RGBColor[1, 1, 0.8],
          FrameStyle->RGBColor[0.94, 0.85, 0.36],
          StripOnInput->False], 1],
        RowBox[{"{", "\"\"", "}"}]],
       Annotation[#, {""}, "Tooltip"]& ], 
      TagBox[
       TooltipBox[InsetBox[
         FrameBox[
          RowBox[{"{", "0", "}"}],
          Background->RGBColor[1, 1, 0.8],
          FrameStyle->RGBColor[0.94, 0.85, 0.36],
          StripOnInput->False], 2],
        RowBox[{"{", "0", "}"}]],
       Annotation[#, {0}, "Tooltip"]& ], 
      TagBox[
       TooltipBox[InsetBox[
         FrameBox[
          RowBox[{"{", "1", "}"}],
          Background->RGBColor[0.87, 0.94, 1],
          FrameStyle->GrayLevel[0.3],
          StripOnInput->False], 3],
        RowBox[{"{", "1", "}"}]],
       Annotation[#, {1}, "Tooltip"]& ], 
      TagBox[
       TooltipBox[InsetBox[
         FrameBox[
          RowBox[{"{", 
           RowBox[{"0", ",", "0"}], "}"}],
          Background->RGBColor[1, 1, 0.8],
          FrameStyle->RGBColor[0.94, 0.85, 0.36],
          StripOnInput->False], 4],
        RowBox[{"{", 
          RowBox[{"0", ",", "0"}], "}"}]],
       Annotation[#, {0, 0}, "Tooltip"]& ], 
      TagBox[
       TooltipBox[InsetBox[
         FrameBox[
          RowBox[{"{", 
           RowBox[{"0", ",", "1"}], "}"}],
          Background->RGBColor[0.87, 0.94, 1],
          FrameStyle->GrayLevel[0.3],
          StripOnInput->False], 5],
        RowBox[{"{", 
          RowBox[{"0", ",", "1"}], "}"}]],
       Annotation[#, {0, 1}, "Tooltip"]& ], 
      TagBox[
       TooltipBox[InsetBox[
         FrameBox[
          RowBox[{"{", 
           RowBox[{"0", ",", "0", ",", "0"}], "}"}],
          Background->RGBColor[1, 1, 0.8],
          FrameStyle->RGBColor[0.94, 0.85, 0.36],
          StripOnInput->False], 6],
        RowBox[{"{", 
          RowBox[{"0", ",", "0", ",", "0"}], "}"}]],
       Annotation[#, {0, 0, 0}, "Tooltip"]& ], 
      TagBox[
       TooltipBox[InsetBox[
         FrameBox[
          RowBox[{"{", 
           RowBox[{"0", ",", "0", ",", "1"}], "}"}],
          Background->RGBColor[0.87, 0.94, 1],
          FrameStyle->GrayLevel[0.3],
          StripOnInput->False], 7],
        RowBox[{"{", 
          RowBox[{"0", ",", "0", ",", "1"}], "}"}]],
       Annotation[#, {0, 0, 1}, "Tooltip"]& ], 
      TagBox[
       TooltipBox[InsetBox[
         FrameBox[
          RowBox[{"{", 
           RowBox[{"0", ",", "0", ",", "0", ",", "0"}], "}"}],
          Background->RGBColor[0.87, 0.94, 1],
          FrameStyle->GrayLevel[0.3],
          StripOnInput->False], 8],
        RowBox[{"{", 
          RowBox[{"0", ",", "0", ",", "0", ",", "0"}], "}"}]],
       Annotation[#, {0, 0, 0, 0}, "Tooltip"]& ], 
      TagBox[
       TooltipBox[InsetBox[
         FrameBox[
          RowBox[{"{", 
           RowBox[{"0", ",", "0", ",", "0", ",", "1"}], "}"}],
          Background->RGBColor[0.87, 0.94, 1],
          FrameStyle->GrayLevel[0.3],
          StripOnInput->False], 9],
        RowBox[{"{", 
          RowBox[{"0", ",", "0", ",", "0", ",", "1"}], "}"}]],
       Annotation[#, {0, 0, 0, 1}, "Tooltip"]& ]}}],
   Annotation[#, 
    VertexCoordinateRules -> {{0., 1.7888543819998282`}, {0.8944271909999165, 
     1.3416407864998712`}, {0.8944271909999155, 2.2360679774997867`}, {
     1.788854381999833, 0.8944271909999141}, {1.788854381999832, 
     1.7888543819998302`}, {2.6832815729997495`, 0.44721359549995704`}, {
     2.683281572999748, 1.341640786499873}, {3.5777087639996656`, 0.}, {
     3.577708763999665, 0.8944271909999159}}]& ],
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  FrameTicks->None,
  PlotRange->All,
  PlotRangePadding->Scaled[0.1]]], "Output",
 CellChangeTimes->{3.5219546382724457`*^9, 3.5219550879840612`*^9, 
  3.5219582063592787`*^9, 3.52195860498592*^9}]
}, Open  ]],

Cell["\<\
Sum up the blue leaves of the above tree:
\
\>", "Text",
 CellChangeTimes->{{3.521958657377344*^9, 3.521958670663546*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"data1", "=", 
  RowBox[{"InverseWaveletTransform", "[", 
   RowBox[{"dwd", ",", "Automatic", ",", 
    RowBox[{"{", "1", "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.52195470794582*^9, 3.521954712039352*^9}, {
   3.5219547770950823`*^9, 3.521954788569062*^9}, 3.521957698036008*^9, {
   3.521957728625383*^9, 3.521957729008086*^9}, {3.521957897570327*^9, 
   3.52195789899544*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   FractionBox[
    RowBox[{
     FractionBox["a", 
      SqrtBox["2"]], "-", 
     FractionBox["b", 
      SqrtBox["2"]]}], 
    SqrtBox["2"]], ",", 
   RowBox[{"-", 
    FractionBox[
     RowBox[{
      FractionBox["a", 
       SqrtBox["2"]], "-", 
      FractionBox["b", 
       SqrtBox["2"]]}], 
     SqrtBox["2"]]}], ",", 
   FractionBox[
    RowBox[{
     FractionBox["c", 
      SqrtBox["2"]], "-", 
     FractionBox["d", 
      SqrtBox["2"]]}], 
    SqrtBox["2"]], ",", 
   RowBox[{"-", 
    FractionBox[
     RowBox[{
      FractionBox["c", 
       SqrtBox["2"]], "-", 
      FractionBox["d", 
       SqrtBox["2"]]}], 
     SqrtBox["2"]]}], ",", 
   FractionBox[
    RowBox[{
     FractionBox["e", 
      SqrtBox["2"]], "-", 
     FractionBox["f", 
      SqrtBox["2"]]}], 
    SqrtBox["2"]], ",", 
   RowBox[{"-", 
    FractionBox[
     RowBox[{
      FractionBox["e", 
       SqrtBox["2"]], "-", 
      FractionBox["f", 
       SqrtBox["2"]]}], 
     SqrtBox["2"]]}], ",", 
   FractionBox[
    RowBox[{
     FractionBox["g", 
      SqrtBox["2"]], "-", 
     FractionBox["h", 
      SqrtBox["2"]]}], 
    SqrtBox["2"]], ",", 
   RowBox[{"-", 
    FractionBox[
     RowBox[{
      FractionBox["g", 
       SqrtBox["2"]], "-", 
      FractionBox["h", 
       SqrtBox["2"]]}], 
     SqrtBox["2"]]}], ",", 
   FractionBox[
    RowBox[{
     RowBox[{"-", 
      FractionBox["i", 
       SqrtBox["2"]]}], "+", 
     FractionBox["k", 
      SqrtBox["2"]]}], 
    SqrtBox["2"]], ",", 
   RowBox[{"-", 
    FractionBox[
     RowBox[{
      RowBox[{"-", 
       FractionBox["i", 
        SqrtBox["2"]]}], "+", 
      FractionBox["k", 
       SqrtBox["2"]]}], 
     SqrtBox["2"]]}], ",", 
   FractionBox[
    RowBox[{
     FractionBox["j", 
      SqrtBox["2"]], "-", 
     FractionBox["k", 
      SqrtBox["2"]]}], 
    SqrtBox["2"]], ",", 
   RowBox[{"-", 
    FractionBox[
     RowBox[{
      FractionBox["j", 
       SqrtBox["2"]], "-", 
      FractionBox["k", 
       SqrtBox["2"]]}], 
     SqrtBox["2"]]}], ",", 
   FractionBox[
    RowBox[{
     FractionBox["l", 
      SqrtBox["2"]], "-", 
     FractionBox["m", 
      SqrtBox["2"]]}], 
    SqrtBox["2"]], ",", 
   RowBox[{"-", 
    FractionBox[
     RowBox[{
      FractionBox["l", 
       SqrtBox["2"]], "-", 
      FractionBox["m", 
       SqrtBox["2"]]}], 
     SqrtBox["2"]]}], ",", 
   FractionBox[
    RowBox[{
     FractionBox["n", 
      SqrtBox["2"]], "-", 
     FractionBox["o", 
      SqrtBox["2"]]}], 
    SqrtBox["2"]], ",", 
   RowBox[{"-", 
    FractionBox[
     RowBox[{
      FractionBox["n", 
       SqrtBox["2"]], "-", 
      FractionBox["o", 
       SqrtBox["2"]]}], 
     SqrtBox["2"]]}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.5219547146933107`*^9, {3.521954777504409*^9, 3.5219547888664913`*^9}, 
   3.521954944689362*^9, 3.521955092603108*^9, {3.521957700811347*^9, 
   3.521957729746354*^9}, 3.521957899781208*^9, 3.5219585197387114`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"data2", "=", 
  RowBox[{"InverseWaveletTransform", "[", 
   RowBox[{"dwd", ",", "Automatic", ",", 
    RowBox[{"{", 
     RowBox[{"0", ",", "1"}], "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.521957944137896*^9, 3.5219579563216743`*^9}, 
   3.521958470661457*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    FractionBox["1", "2"], " ", 
    RowBox[{"(", 
     RowBox[{
      FractionBox[
       RowBox[{
        FractionBox["a", 
         SqrtBox["2"]], "+", 
        FractionBox["b", 
         SqrtBox["2"]]}], 
       SqrtBox["2"]], "-", 
      FractionBox[
       RowBox[{
        FractionBox["c", 
         SqrtBox["2"]], "+", 
        FractionBox["d", 
         SqrtBox["2"]]}], 
       SqrtBox["2"]]}], ")"}]}], ",", 
   RowBox[{
    FractionBox["1", "2"], " ", 
    RowBox[{"(", 
     RowBox[{
      FractionBox[
       RowBox[{
        FractionBox["a", 
         SqrtBox["2"]], "+", 
        FractionBox["b", 
         SqrtBox["2"]]}], 
       SqrtBox["2"]], "-", 
      FractionBox[
       RowBox[{
        FractionBox["c", 
         SqrtBox["2"]], "+", 
        FractionBox["d", 
         SqrtBox["2"]]}], 
       SqrtBox["2"]]}], ")"}]}], ",", 
   RowBox[{
    FractionBox["1", "2"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", 
       FractionBox[
        RowBox[{
         FractionBox["a", 
          SqrtBox["2"]], "+", 
         FractionBox["b", 
          SqrtBox["2"]]}], 
        SqrtBox["2"]]}], "+", 
      FractionBox[
       RowBox[{
        FractionBox["c", 
         SqrtBox["2"]], "+", 
        FractionBox["d", 
         SqrtBox["2"]]}], 
       SqrtBox["2"]]}], ")"}]}], ",", 
   RowBox[{
    FractionBox["1", "2"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", 
       FractionBox[
        RowBox[{
         FractionBox["a", 
          SqrtBox["2"]], "+", 
         FractionBox["b", 
          SqrtBox["2"]]}], 
        SqrtBox["2"]]}], "+", 
      FractionBox[
       RowBox[{
        FractionBox["c", 
         SqrtBox["2"]], "+", 
        FractionBox["d", 
         SqrtBox["2"]]}], 
       SqrtBox["2"]]}], ")"}]}], ",", 
   RowBox[{
    FractionBox["1", "2"], " ", 
    RowBox[{"(", 
     RowBox[{
      FractionBox[
       RowBox[{
        FractionBox["e", 
         SqrtBox["2"]], "+", 
        FractionBox["f", 
         SqrtBox["2"]]}], 
       SqrtBox["2"]], "-", 
      FractionBox[
       RowBox[{
        FractionBox["g", 
         SqrtBox["2"]], "+", 
        FractionBox["h", 
         SqrtBox["2"]]}], 
       SqrtBox["2"]]}], ")"}]}], ",", 
   RowBox[{
    FractionBox["1", "2"], " ", 
    RowBox[{"(", 
     RowBox[{
      FractionBox[
       RowBox[{
        FractionBox["e", 
         SqrtBox["2"]], "+", 
        FractionBox["f", 
         SqrtBox["2"]]}], 
       SqrtBox["2"]], "-", 
      FractionBox[
       RowBox[{
        FractionBox["g", 
         SqrtBox["2"]], "+", 
        FractionBox["h", 
         SqrtBox["2"]]}], 
       SqrtBox["2"]]}], ")"}]}], ",", 
   RowBox[{
    FractionBox["1", "2"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", 
       FractionBox[
        RowBox[{
         FractionBox["e", 
          SqrtBox["2"]], "+", 
         FractionBox["f", 
          SqrtBox["2"]]}], 
        SqrtBox["2"]]}], "+", 
      FractionBox[
       RowBox[{
        FractionBox["g", 
         SqrtBox["2"]], "+", 
        FractionBox["h", 
         SqrtBox["2"]]}], 
       SqrtBox["2"]]}], ")"}]}], ",", 
   RowBox[{
    FractionBox["1", "2"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", 
       FractionBox[
        RowBox[{
         FractionBox["e", 
          SqrtBox["2"]], "+", 
         FractionBox["f", 
          SqrtBox["2"]]}], 
        SqrtBox["2"]]}], "+", 
      FractionBox[
       RowBox[{
        FractionBox["g", 
         SqrtBox["2"]], "+", 
        FractionBox["h", 
         SqrtBox["2"]]}], 
       SqrtBox["2"]]}], ")"}]}], ",", 
   RowBox[{
    FractionBox["1", "2"], " ", 
    RowBox[{"(", 
     RowBox[{
      FractionBox[
       RowBox[{
        FractionBox["i", 
         SqrtBox["2"]], "+", 
        FractionBox["k", 
         SqrtBox["2"]]}], 
       SqrtBox["2"]], "-", 
      FractionBox[
       RowBox[{
        FractionBox["j", 
         SqrtBox["2"]], "+", 
        FractionBox["k", 
         SqrtBox["2"]]}], 
       SqrtBox["2"]]}], ")"}]}], ",", 
   RowBox[{
    FractionBox["1", "2"], " ", 
    RowBox[{"(", 
     RowBox[{
      FractionBox[
       RowBox[{
        FractionBox["i", 
         SqrtBox["2"]], "+", 
        FractionBox["k", 
         SqrtBox["2"]]}], 
       SqrtBox["2"]], "-", 
      FractionBox[
       RowBox[{
        FractionBox["j", 
         SqrtBox["2"]], "+", 
        FractionBox["k", 
         SqrtBox["2"]]}], 
       SqrtBox["2"]]}], ")"}]}], ",", 
   RowBox[{
    FractionBox["1", "2"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", 
       FractionBox[
        RowBox[{
         FractionBox["i", 
          SqrtBox["2"]], "+", 
         FractionBox["k", 
          SqrtBox["2"]]}], 
        SqrtBox["2"]]}], "+", 
      FractionBox[
       RowBox[{
        FractionBox["j", 
         SqrtBox["2"]], "+", 
        FractionBox["k", 
         SqrtBox["2"]]}], 
       SqrtBox["2"]]}], ")"}]}], ",", 
   RowBox[{
    FractionBox["1", "2"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", 
       FractionBox[
        RowBox[{
         FractionBox["i", 
          SqrtBox["2"]], "+", 
         FractionBox["k", 
          SqrtBox["2"]]}], 
        SqrtBox["2"]]}], "+", 
      FractionBox[
       RowBox[{
        FractionBox["j", 
         SqrtBox["2"]], "+", 
        FractionBox["k", 
         SqrtBox["2"]]}], 
       SqrtBox["2"]]}], ")"}]}], ",", 
   RowBox[{
    FractionBox["1", "2"], " ", 
    RowBox[{"(", 
     RowBox[{
      FractionBox[
       RowBox[{
        FractionBox["l", 
         SqrtBox["2"]], "+", 
        FractionBox["m", 
         SqrtBox["2"]]}], 
       SqrtBox["2"]], "-", 
      FractionBox[
       RowBox[{
        FractionBox["n", 
         SqrtBox["2"]], "+", 
        FractionBox["o", 
         SqrtBox["2"]]}], 
       SqrtBox["2"]]}], ")"}]}], ",", 
   RowBox[{
    FractionBox["1", "2"], " ", 
    RowBox[{"(", 
     RowBox[{
      FractionBox[
       RowBox[{
        FractionBox["l", 
         SqrtBox["2"]], "+", 
        FractionBox["m", 
         SqrtBox["2"]]}], 
       SqrtBox["2"]], "-", 
      FractionBox[
       RowBox[{
        FractionBox["n", 
         SqrtBox["2"]], "+", 
        FractionBox["o", 
         SqrtBox["2"]]}], 
       SqrtBox["2"]]}], ")"}]}], ",", 
   RowBox[{
    FractionBox["1", "2"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", 
       FractionBox[
        RowBox[{
         FractionBox["l", 
          SqrtBox["2"]], "+", 
         FractionBox["m", 
          SqrtBox["2"]]}], 
        SqrtBox["2"]]}], "+", 
      FractionBox[
       RowBox[{
        FractionBox["n", 
         SqrtBox["2"]], "+", 
        FractionBox["o", 
         SqrtBox["2"]]}], 
       SqrtBox["2"]]}], ")"}]}], ",", 
   RowBox[{
    FractionBox["1", "2"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", 
       FractionBox[
        RowBox[{
         FractionBox["l", 
          SqrtBox["2"]], "+", 
         FractionBox["m", 
          SqrtBox["2"]]}], 
        SqrtBox["2"]]}], "+", 
      FractionBox[
       RowBox[{
        FractionBox["n", 
         SqrtBox["2"]], "+", 
        FractionBox["o", 
         SqrtBox["2"]]}], 
       SqrtBox["2"]]}], ")"}]}]}], "}"}]], "Output",
 CellChangeTimes->{3.521957956897842*^9, 3.521958521172441*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"data3", "=", 
  RowBox[{"InverseWaveletTransform", "[", 
   RowBox[{"dwd", ",", "Automatic", ",", 
    RowBox[{"{", 
     RowBox[{"0", ",", "0", ",", "1"}], "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.5219580057597446`*^9, 3.521958022938077*^9}, 
   3.521958473639208*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   FractionBox[
    RowBox[{
     FractionBox[
      RowBox[{
       FractionBox[
        RowBox[{
         FractionBox["a", 
          SqrtBox["2"]], "+", 
         FractionBox["b", 
          SqrtBox["2"]]}], 
        SqrtBox["2"]], "+", 
       FractionBox[
        RowBox[{
         FractionBox["c", 
          SqrtBox["2"]], "+", 
         FractionBox["d", 
          SqrtBox["2"]]}], 
        SqrtBox["2"]]}], 
      SqrtBox["2"]], "-", 
     FractionBox[
      RowBox[{
       FractionBox[
        RowBox[{
         FractionBox["e", 
          SqrtBox["2"]], "+", 
         FractionBox["f", 
          SqrtBox["2"]]}], 
        SqrtBox["2"]], "+", 
       FractionBox[
        RowBox[{
         FractionBox["g", 
          SqrtBox["2"]], "+", 
         FractionBox["h", 
          SqrtBox["2"]]}], 
        SqrtBox["2"]]}], 
      SqrtBox["2"]]}], 
    RowBox[{"2", " ", 
     SqrtBox["2"]}]], ",", 
   FractionBox[
    RowBox[{
     FractionBox[
      RowBox[{
       FractionBox[
        RowBox[{
         FractionBox["a", 
          SqrtBox["2"]], "+", 
         FractionBox["b", 
          SqrtBox["2"]]}], 
        SqrtBox["2"]], "+", 
       FractionBox[
        RowBox[{
         FractionBox["c", 
          SqrtBox["2"]], "+", 
         FractionBox["d", 
          SqrtBox["2"]]}], 
        SqrtBox["2"]]}], 
      SqrtBox["2"]], "-", 
     FractionBox[
      RowBox[{
       FractionBox[
        RowBox[{
         FractionBox["e", 
          SqrtBox["2"]], "+", 
         FractionBox["f", 
          SqrtBox["2"]]}], 
        SqrtBox["2"]], "+", 
       FractionBox[
        RowBox[{
         FractionBox["g", 
          SqrtBox["2"]], "+", 
         FractionBox["h", 
          SqrtBox["2"]]}], 
        SqrtBox["2"]]}], 
      SqrtBox["2"]]}], 
    RowBox[{"2", " ", 
     SqrtBox["2"]}]], ",", 
   FractionBox[
    RowBox[{
     FractionBox[
      RowBox[{
       FractionBox[
        RowBox[{
         FractionBox["a", 
          SqrtBox["2"]], "+", 
         FractionBox["b", 
          SqrtBox["2"]]}], 
        SqrtBox["2"]], "+", 
       FractionBox[
        RowBox[{
         FractionBox["c", 
          SqrtBox["2"]], "+", 
         FractionBox["d", 
          SqrtBox["2"]]}], 
        SqrtBox["2"]]}], 
      SqrtBox["2"]], "-", 
     FractionBox[
      RowBox[{
       FractionBox[
        RowBox[{
         FractionBox["e", 
          SqrtBox["2"]], "+", 
         FractionBox["f", 
          SqrtBox["2"]]}], 
        SqrtBox["2"]], "+", 
       FractionBox[
        RowBox[{
         FractionBox["g", 
          SqrtBox["2"]], "+", 
         FractionBox["h", 
          SqrtBox["2"]]}], 
        SqrtBox["2"]]}], 
      SqrtBox["2"]]}], 
    RowBox[{"2", " ", 
     SqrtBox["2"]}]], ",", 
   FractionBox[
    RowBox[{
     FractionBox[
      RowBox[{
       FractionBox[
        RowBox[{
         FractionBox["a", 
          SqrtBox["2"]], "+", 
         FractionBox["b", 
          SqrtBox["2"]]}], 
        SqrtBox["2"]], "+", 
       FractionBox[
        RowBox[{
         FractionBox["c", 
          SqrtBox["2"]], "+", 
         FractionBox["d", 
          SqrtBox["2"]]}], 
        SqrtBox["2"]]}], 
      SqrtBox["2"]], "-", 
     FractionBox[
      RowBox[{
       FractionBox[
        RowBox[{
         FractionBox["e", 
          SqrtBox["2"]], "+", 
         FractionBox["f", 
          SqrtBox["2"]]}], 
        SqrtBox["2"]], "+", 
       FractionBox[
        RowBox[{
         FractionBox["g", 
          SqrtBox["2"]], "+", 
         FractionBox["h", 
          SqrtBox["2"]]}], 
        SqrtBox["2"]]}], 
      SqrtBox["2"]]}], 
    RowBox[{"2", " ", 
     SqrtBox["2"]}]], ",", 
   FractionBox[
    RowBox[{
     RowBox[{"-", 
      FractionBox[
       RowBox[{
        FractionBox[
         RowBox[{
          FractionBox["a", 
           SqrtBox["2"]], "+", 
          FractionBox["b", 
           SqrtBox["2"]]}], 
         SqrtBox["2"]], "+", 
        FractionBox[
         RowBox[{
          FractionBox["c", 
           SqrtBox["2"]], "+", 
          FractionBox["d", 
           SqrtBox["2"]]}], 
         SqrtBox["2"]]}], 
       SqrtBox["2"]]}], "+", 
     FractionBox[
      RowBox[{
       FractionBox[
        RowBox[{
         FractionBox["e", 
          SqrtBox["2"]], "+", 
         FractionBox["f", 
          SqrtBox["2"]]}], 
        SqrtBox["2"]], "+", 
       FractionBox[
        RowBox[{
         FractionBox["g", 
          SqrtBox["2"]], "+", 
         FractionBox["h", 
          SqrtBox["2"]]}], 
        SqrtBox["2"]]}], 
      SqrtBox["2"]]}], 
    RowBox[{"2", " ", 
     SqrtBox["2"]}]], ",", 
   FractionBox[
    RowBox[{
     RowBox[{"-", 
      FractionBox[
       RowBox[{
        FractionBox[
         RowBox[{
          FractionBox["a", 
           SqrtBox["2"]], "+", 
          FractionBox["b", 
           SqrtBox["2"]]}], 
         SqrtBox["2"]], "+", 
        FractionBox[
         RowBox[{
          FractionBox["c", 
           SqrtBox["2"]], "+", 
          FractionBox["d", 
           SqrtBox["2"]]}], 
         SqrtBox["2"]]}], 
       SqrtBox["2"]]}], "+", 
     FractionBox[
      RowBox[{
       FractionBox[
        RowBox[{
         FractionBox["e", 
          SqrtBox["2"]], "+", 
         FractionBox["f", 
          SqrtBox["2"]]}], 
        SqrtBox["2"]], "+", 
       FractionBox[
        RowBox[{
         FractionBox["g", 
          SqrtBox["2"]], "+", 
         FractionBox["h", 
          SqrtBox["2"]]}], 
        SqrtBox["2"]]}], 
      SqrtBox["2"]]}], 
    RowBox[{"2", " ", 
     SqrtBox["2"]}]], ",", 
   FractionBox[
    RowBox[{
     RowBox[{"-", 
      FractionBox[
       RowBox[{
        FractionBox[
         RowBox[{
          FractionBox["a", 
           SqrtBox["2"]], "+", 
          FractionBox["b", 
           SqrtBox["2"]]}], 
         SqrtBox["2"]], "+", 
        FractionBox[
         RowBox[{
          FractionBox["c", 
           SqrtBox["2"]], "+", 
          FractionBox["d", 
           SqrtBox["2"]]}], 
         SqrtBox["2"]]}], 
       SqrtBox["2"]]}], "+", 
     FractionBox[
      RowBox[{
       FractionBox[
        RowBox[{
         FractionBox["e", 
          SqrtBox["2"]], "+", 
         FractionBox["f", 
          SqrtBox["2"]]}], 
        SqrtBox["2"]], "+", 
       FractionBox[
        RowBox[{
         FractionBox["g", 
          SqrtBox["2"]], "+", 
         FractionBox["h", 
          SqrtBox["2"]]}], 
        SqrtBox["2"]]}], 
      SqrtBox["2"]]}], 
    RowBox[{"2", " ", 
     SqrtBox["2"]}]], ",", 
   FractionBox[
    RowBox[{
     RowBox[{"-", 
      FractionBox[
       RowBox[{
        FractionBox[
         RowBox[{
          FractionBox["a", 
           SqrtBox["2"]], "+", 
          FractionBox["b", 
           SqrtBox["2"]]}], 
         SqrtBox["2"]], "+", 
        FractionBox[
         RowBox[{
          FractionBox["c", 
           SqrtBox["2"]], "+", 
          FractionBox["d", 
           SqrtBox["2"]]}], 
         SqrtBox["2"]]}], 
       SqrtBox["2"]]}], "+", 
     FractionBox[
      RowBox[{
       FractionBox[
        RowBox[{
         FractionBox["e", 
          SqrtBox["2"]], "+", 
         FractionBox["f", 
          SqrtBox["2"]]}], 
        SqrtBox["2"]], "+", 
       FractionBox[
        RowBox[{
         FractionBox["g", 
          SqrtBox["2"]], "+", 
         FractionBox["h", 
          SqrtBox["2"]]}], 
        SqrtBox["2"]]}], 
      SqrtBox["2"]]}], 
    RowBox[{"2", " ", 
     SqrtBox["2"]}]], ",", 
   FractionBox[
    RowBox[{
     FractionBox[
      RowBox[{
       FractionBox[
        RowBox[{
         FractionBox["i", 
          SqrtBox["2"]], "+", 
         FractionBox["k", 
          SqrtBox["2"]]}], 
        SqrtBox["2"]], "+", 
       FractionBox[
        RowBox[{
         FractionBox["j", 
          SqrtBox["2"]], "+", 
         FractionBox["k", 
          SqrtBox["2"]]}], 
        SqrtBox["2"]]}], 
      SqrtBox["2"]], "-", 
     FractionBox[
      RowBox[{
       FractionBox[
        RowBox[{
         FractionBox["l", 
          SqrtBox["2"]], "+", 
         FractionBox["m", 
          SqrtBox["2"]]}], 
        SqrtBox["2"]], "+", 
       FractionBox[
        RowBox[{
         FractionBox["n", 
          SqrtBox["2"]], "+", 
         FractionBox["o", 
          SqrtBox["2"]]}], 
        SqrtBox["2"]]}], 
      SqrtBox["2"]]}], 
    RowBox[{"2", " ", 
     SqrtBox["2"]}]], ",", 
   FractionBox[
    RowBox[{
     FractionBox[
      RowBox[{
       FractionBox[
        RowBox[{
         FractionBox["i", 
          SqrtBox["2"]], "+", 
         FractionBox["k", 
          SqrtBox["2"]]}], 
        SqrtBox["2"]], "+", 
       FractionBox[
        RowBox[{
         FractionBox["j", 
          SqrtBox["2"]], "+", 
         FractionBox["k", 
          SqrtBox["2"]]}], 
        SqrtBox["2"]]}], 
      SqrtBox["2"]], "-", 
     FractionBox[
      RowBox[{
       FractionBox[
        RowBox[{
         FractionBox["l", 
          SqrtBox["2"]], "+", 
         FractionBox["m", 
          SqrtBox["2"]]}], 
        SqrtBox["2"]], "+", 
       FractionBox[
        RowBox[{
         FractionBox["n", 
          SqrtBox["2"]], "+", 
         FractionBox["o", 
          SqrtBox["2"]]}], 
        SqrtBox["2"]]}], 
      SqrtBox["2"]]}], 
    RowBox[{"2", " ", 
     SqrtBox["2"]}]], ",", 
   FractionBox[
    RowBox[{
     FractionBox[
      RowBox[{
       FractionBox[
        RowBox[{
         FractionBox["i", 
          SqrtBox["2"]], "+", 
         FractionBox["k", 
          SqrtBox["2"]]}], 
        SqrtBox["2"]], "+", 
       FractionBox[
        RowBox[{
         FractionBox["j", 
          SqrtBox["2"]], "+", 
         FractionBox["k", 
          SqrtBox["2"]]}], 
        SqrtBox["2"]]}], 
      SqrtBox["2"]], "-", 
     FractionBox[
      RowBox[{
       FractionBox[
        RowBox[{
         FractionBox["l", 
          SqrtBox["2"]], "+", 
         FractionBox["m", 
          SqrtBox["2"]]}], 
        SqrtBox["2"]], "+", 
       FractionBox[
        RowBox[{
         FractionBox["n", 
          SqrtBox["2"]], "+", 
         FractionBox["o", 
          SqrtBox["2"]]}], 
        SqrtBox["2"]]}], 
      SqrtBox["2"]]}], 
    RowBox[{"2", " ", 
     SqrtBox["2"]}]], ",", 
   FractionBox[
    RowBox[{
     FractionBox[
      RowBox[{
       FractionBox[
        RowBox[{
         FractionBox["i", 
          SqrtBox["2"]], "+", 
         FractionBox["k", 
          SqrtBox["2"]]}], 
        SqrtBox["2"]], "+", 
       FractionBox[
        RowBox[{
         FractionBox["j", 
          SqrtBox["2"]], "+", 
         FractionBox["k", 
          SqrtBox["2"]]}], 
        SqrtBox["2"]]}], 
      SqrtBox["2"]], "-", 
     FractionBox[
      RowBox[{
       FractionBox[
        RowBox[{
         FractionBox["l", 
          SqrtBox["2"]], "+", 
         FractionBox["m", 
          SqrtBox["2"]]}], 
        SqrtBox["2"]], "+", 
       FractionBox[
        RowBox[{
         FractionBox["n", 
          SqrtBox["2"]], "+", 
         FractionBox["o", 
          SqrtBox["2"]]}], 
        SqrtBox["2"]]}], 
      SqrtBox["2"]]}], 
    RowBox[{"2", " ", 
     SqrtBox["2"]}]], ",", 
   FractionBox[
    RowBox[{
     RowBox[{"-", 
      FractionBox[
       RowBox[{
        FractionBox[
         RowBox[{
          FractionBox["i", 
           SqrtBox["2"]], "+", 
          FractionBox["k", 
           SqrtBox["2"]]}], 
         SqrtBox["2"]], "+", 
        FractionBox[
         RowBox[{
          FractionBox["j", 
           SqrtBox["2"]], "+", 
          FractionBox["k", 
           SqrtBox["2"]]}], 
         SqrtBox["2"]]}], 
       SqrtBox["2"]]}], "+", 
     FractionBox[
      RowBox[{
       FractionBox[
        RowBox[{
         FractionBox["l", 
          SqrtBox["2"]], "+", 
         FractionBox["m", 
          SqrtBox["2"]]}], 
        SqrtBox["2"]], "+", 
       FractionBox[
        RowBox[{
         FractionBox["n", 
          SqrtBox["2"]], "+", 
         FractionBox["o", 
          SqrtBox["2"]]}], 
        SqrtBox["2"]]}], 
      SqrtBox["2"]]}], 
    RowBox[{"2", " ", 
     SqrtBox["2"]}]], ",", 
   FractionBox[
    RowBox[{
     RowBox[{"-", 
      FractionBox[
       RowBox[{
        FractionBox[
         RowBox[{
          FractionBox["i", 
           SqrtBox["2"]], "+", 
          FractionBox["k", 
           SqrtBox["2"]]}], 
         SqrtBox["2"]], "+", 
        FractionBox[
         RowBox[{
          FractionBox["j", 
           SqrtBox["2"]], "+", 
          FractionBox["k", 
           SqrtBox["2"]]}], 
         SqrtBox["2"]]}], 
       SqrtBox["2"]]}], "+", 
     FractionBox[
      RowBox[{
       FractionBox[
        RowBox[{
         FractionBox["l", 
          SqrtBox["2"]], "+", 
         FractionBox["m", 
          SqrtBox["2"]]}], 
        SqrtBox["2"]], "+", 
       FractionBox[
        RowBox[{
         FractionBox["n", 
          SqrtBox["2"]], "+", 
         FractionBox["o", 
          SqrtBox["2"]]}], 
        SqrtBox["2"]]}], 
      SqrtBox["2"]]}], 
    RowBox[{"2", " ", 
     SqrtBox["2"]}]], ",", 
   FractionBox[
    RowBox[{
     RowBox[{"-", 
      FractionBox[
       RowBox[{
        FractionBox[
         RowBox[{
          FractionBox["i", 
           SqrtBox["2"]], "+", 
          FractionBox["k", 
           SqrtBox["2"]]}], 
         SqrtBox["2"]], "+", 
        FractionBox[
         RowBox[{
          FractionBox["j", 
           SqrtBox["2"]], "+", 
          FractionBox["k", 
           SqrtBox["2"]]}], 
         SqrtBox["2"]]}], 
       SqrtBox["2"]]}], "+", 
     FractionBox[
      RowBox[{
       FractionBox[
        RowBox[{
         FractionBox["l", 
          SqrtBox["2"]], "+", 
         FractionBox["m", 
          SqrtBox["2"]]}], 
        SqrtBox["2"]], "+", 
       FractionBox[
        RowBox[{
         FractionBox["n", 
          SqrtBox["2"]], "+", 
         FractionBox["o", 
          SqrtBox["2"]]}], 
        SqrtBox["2"]]}], 
      SqrtBox["2"]]}], 
    RowBox[{"2", " ", 
     SqrtBox["2"]}]], ",", 
   FractionBox[
    RowBox[{
     RowBox[{"-", 
      FractionBox[
       RowBox[{
        FractionBox[
         RowBox[{
          FractionBox["i", 
           SqrtBox["2"]], "+", 
          FractionBox["k", 
           SqrtBox["2"]]}], 
         SqrtBox["2"]], "+", 
        FractionBox[
         RowBox[{
          FractionBox["j", 
           SqrtBox["2"]], "+", 
          FractionBox["k", 
           SqrtBox["2"]]}], 
         SqrtBox["2"]]}], 
       SqrtBox["2"]]}], "+", 
     FractionBox[
      RowBox[{
       FractionBox[
        RowBox[{
         FractionBox["l", 
          SqrtBox["2"]], "+", 
         FractionBox["m", 
          SqrtBox["2"]]}], 
        SqrtBox["2"]], "+", 
       FractionBox[
        RowBox[{
         FractionBox["n", 
          SqrtBox["2"]], "+", 
         FractionBox["o", 
          SqrtBox["2"]]}], 
        SqrtBox["2"]]}], 
      SqrtBox["2"]]}], 
    RowBox[{"2", " ", 
     SqrtBox["2"]}]]}], "}"}]], "Output",
 CellChangeTimes->{3.521958025278219*^9, 3.521958523895296*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"data4", "=", 
  RowBox[{"InverseWaveletTransform", "[", 
   RowBox[{"dwd", ",", "Automatic", ",", 
    RowBox[{"{", 
     RowBox[{"0", ",", "0", ",", "0", ",", "0"}], "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.521958039152193*^9, 3.521958047734729*^9}, {
  3.5219584780273123`*^9, 3.521958479523017*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    FractionBox["1", "4"], " ", 
    RowBox[{"(", 
     RowBox[{
      FractionBox[
       RowBox[{
        FractionBox[
         RowBox[{
          FractionBox[
           RowBox[{
            FractionBox["a", 
             SqrtBox["2"]], "+", 
            FractionBox["b", 
             SqrtBox["2"]]}], 
           SqrtBox["2"]], "+", 
          FractionBox[
           RowBox[{
            FractionBox["c", 
             SqrtBox["2"]], "+", 
            FractionBox["d", 
             SqrtBox["2"]]}], 
           SqrtBox["2"]]}], 
         SqrtBox["2"]], "+", 
        FractionBox[
         RowBox[{
          FractionBox[
           RowBox[{
            FractionBox["e", 
             SqrtBox["2"]], "+", 
            FractionBox["f", 
             SqrtBox["2"]]}], 
           SqrtBox["2"]], "+", 
          FractionBox[
           RowBox[{
            FractionBox["g", 
             SqrtBox["2"]], "+", 
            FractionBox["h", 
             SqrtBox["2"]]}], 
           SqrtBox["2"]]}], 
         SqrtBox["2"]]}], 
       SqrtBox["2"]], "+", 
      FractionBox[
       RowBox[{
        FractionBox[
         RowBox[{
          FractionBox[
           RowBox[{
            FractionBox["i", 
             SqrtBox["2"]], "+", 
            FractionBox["k", 
             SqrtBox["2"]]}], 
           SqrtBox["2"]], "+", 
          FractionBox[
           RowBox[{
            FractionBox["j", 
             SqrtBox["2"]], "+", 
            FractionBox["k", 
             SqrtBox["2"]]}], 
           SqrtBox["2"]]}], 
         SqrtBox["2"]], "+", 
        FractionBox[
         RowBox[{
          FractionBox[
           RowBox[{
            FractionBox["l", 
             SqrtBox["2"]], "+", 
            FractionBox["m", 
             SqrtBox["2"]]}], 
           SqrtBox["2"]], "+", 
          FractionBox[
           RowBox[{
            FractionBox["n", 
             SqrtBox["2"]], "+", 
            FractionBox["o", 
             SqrtBox["2"]]}], 
           SqrtBox["2"]]}], 
         SqrtBox["2"]]}], 
       SqrtBox["2"]]}], ")"}]}], ",", 
   RowBox[{
    FractionBox["1", "4"], " ", 
    RowBox[{"(", 
     RowBox[{
      FractionBox[
       RowBox[{
        FractionBox[
         RowBox[{
          FractionBox[
           RowBox[{
            FractionBox["a", 
             SqrtBox["2"]], "+", 
            FractionBox["b", 
             SqrtBox["2"]]}], 
           SqrtBox["2"]], "+", 
          FractionBox[
           RowBox[{
            FractionBox["c", 
             SqrtBox["2"]], "+", 
            FractionBox["d", 
             SqrtBox["2"]]}], 
           SqrtBox["2"]]}], 
         SqrtBox["2"]], "+", 
        FractionBox[
         RowBox[{
          FractionBox[
           RowBox[{
            FractionBox["e", 
             SqrtBox["2"]], "+", 
            FractionBox["f", 
             SqrtBox["2"]]}], 
           SqrtBox["2"]], "+", 
          FractionBox[
           RowBox[{
            FractionBox["g", 
             SqrtBox["2"]], "+", 
            FractionBox["h", 
             SqrtBox["2"]]}], 
           SqrtBox["2"]]}], 
         SqrtBox["2"]]}], 
       SqrtBox["2"]], "+", 
      FractionBox[
       RowBox[{
        FractionBox[
         RowBox[{
          FractionBox[
           RowBox[{
            FractionBox["i", 
             SqrtBox["2"]], "+", 
            FractionBox["k", 
             SqrtBox["2"]]}], 
           SqrtBox["2"]], "+", 
          FractionBox[
           RowBox[{
            FractionBox["j", 
             SqrtBox["2"]], "+", 
            FractionBox["k", 
             SqrtBox["2"]]}], 
           SqrtBox["2"]]}], 
         SqrtBox["2"]], "+", 
        FractionBox[
         RowBox[{
          FractionBox[
           RowBox[{
            FractionBox["l", 
             SqrtBox["2"]], "+", 
            FractionBox["m", 
             SqrtBox["2"]]}], 
           SqrtBox["2"]], "+", 
          FractionBox[
           RowBox[{
            FractionBox["n", 
             SqrtBox["2"]], "+", 
            FractionBox["o", 
             SqrtBox["2"]]}], 
           SqrtBox["2"]]}], 
         SqrtBox["2"]]}], 
       SqrtBox["2"]]}], ")"}]}], ",", 
   RowBox[{
    FractionBox["1", "4"], " ", 
    RowBox[{"(", 
     RowBox[{
      FractionBox[
       RowBox[{
        FractionBox[
         RowBox[{
          FractionBox[
           RowBox[{
            FractionBox["a", 
             SqrtBox["2"]], "+", 
            FractionBox["b", 
             SqrtBox["2"]]}], 
           SqrtBox["2"]], "+", 
          FractionBox[
           RowBox[{
            FractionBox["c", 
             SqrtBox["2"]], "+", 
            FractionBox["d", 
             SqrtBox["2"]]}], 
           SqrtBox["2"]]}], 
         SqrtBox["2"]], "+", 
        FractionBox[
         RowBox[{
          FractionBox[
           RowBox[{
            FractionBox["e", 
             SqrtBox["2"]], "+", 
            FractionBox["f", 
             SqrtBox["2"]]}], 
           SqrtBox["2"]], "+", 
          FractionBox[
           RowBox[{
            FractionBox["g", 
             SqrtBox["2"]], "+", 
            FractionBox["h", 
             SqrtBox["2"]]}], 
           SqrtBox["2"]]}], 
         SqrtBox["2"]]}], 
       SqrtBox["2"]], "+", 
      FractionBox[
       RowBox[{
        FractionBox[
         RowBox[{
          FractionBox[
           RowBox[{
            FractionBox["i", 
             SqrtBox["2"]], "+", 
            FractionBox["k", 
             SqrtBox["2"]]}], 
           SqrtBox["2"]], "+", 
          FractionBox[
           RowBox[{
            FractionBox["j", 
             SqrtBox["2"]], "+", 
            FractionBox["k", 
             SqrtBox["2"]]}], 
           SqrtBox["2"]]}], 
         SqrtBox["2"]], "+", 
        FractionBox[
         RowBox[{
          FractionBox[
           RowBox[{
            FractionBox["l", 
             SqrtBox["2"]], "+", 
            FractionBox["m", 
             SqrtBox["2"]]}], 
           SqrtBox["2"]], "+", 
          FractionBox[
           RowBox[{
            FractionBox["n", 
             SqrtBox["2"]], "+", 
            FractionBox["o", 
             SqrtBox["2"]]}], 
           SqrtBox["2"]]}], 
         SqrtBox["2"]]}], 
       SqrtBox["2"]]}], ")"}]}], ",", 
   RowBox[{
    FractionBox["1", "4"], " ", 
    RowBox[{"(", 
     RowBox[{
      FractionBox[
       RowBox[{
        FractionBox[
         RowBox[{
          FractionBox[
           RowBox[{
            FractionBox["a", 
             SqrtBox["2"]], "+", 
            FractionBox["b", 
             SqrtBox["2"]]}], 
           SqrtBox["2"]], "+", 
          FractionBox[
           RowBox[{
            FractionBox["c", 
             SqrtBox["2"]], "+", 
            FractionBox["d", 
             SqrtBox["2"]]}], 
           SqrtBox["2"]]}], 
         SqrtBox["2"]], "+", 
        FractionBox[
         RowBox[{
          FractionBox[
           RowBox[{
            FractionBox["e", 
             SqrtBox["2"]], "+", 
            FractionBox["f", 
             SqrtBox["2"]]}], 
           SqrtBox["2"]], "+", 
          FractionBox[
           RowBox[{
            FractionBox["g", 
             SqrtBox["2"]], "+", 
            FractionBox["h", 
             SqrtBox["2"]]}], 
           SqrtBox["2"]]}], 
         SqrtBox["2"]]}], 
       SqrtBox["2"]], "+", 
      FractionBox[
       RowBox[{
        FractionBox[
         RowBox[{
          FractionBox[
           RowBox[{
            FractionBox["i", 
             SqrtBox["2"]], "+", 
            FractionBox["k", 
             SqrtBox["2"]]}], 
           SqrtBox["2"]], "+", 
          FractionBox[
           RowBox[{
            FractionBox["j", 
             SqrtBox["2"]], "+", 
            FractionBox["k", 
             SqrtBox["2"]]}], 
           SqrtBox["2"]]}], 
         SqrtBox["2"]], "+", 
        FractionBox[
         RowBox[{
          FractionBox[
           RowBox[{
            FractionBox["l", 
             SqrtBox["2"]], "+", 
            FractionBox["m", 
             SqrtBox["2"]]}], 
           SqrtBox["2"]], "+", 
          FractionBox[
           RowBox[{
            FractionBox["n", 
             SqrtBox["2"]], "+", 
            FractionBox["o", 
             SqrtBox["2"]]}], 
           SqrtBox["2"]]}], 
         SqrtBox["2"]]}], 
       SqrtBox["2"]]}], ")"}]}], ",", 
   RowBox[{
    FractionBox["1", "4"], " ", 
    RowBox[{"(", 
     RowBox[{
      FractionBox[
       RowBox[{
        FractionBox[
         RowBox[{
          FractionBox[
           RowBox[{
            FractionBox["a", 
             SqrtBox["2"]], "+", 
            FractionBox["b", 
             SqrtBox["2"]]}], 
           SqrtBox["2"]], "+", 
          FractionBox[
           RowBox[{
            FractionBox["c", 
             SqrtBox["2"]], "+", 
            FractionBox["d", 
             SqrtBox["2"]]}], 
           SqrtBox["2"]]}], 
         SqrtBox["2"]], "+", 
        FractionBox[
         RowBox[{
          FractionBox[
           RowBox[{
            FractionBox["e", 
             SqrtBox["2"]], "+", 
            FractionBox["f", 
             SqrtBox["2"]]}], 
           SqrtBox["2"]], "+", 
          FractionBox[
           RowBox[{
            FractionBox["g", 
             SqrtBox["2"]], "+", 
            FractionBox["h", 
             SqrtBox["2"]]}], 
           SqrtBox["2"]]}], 
         SqrtBox["2"]]}], 
       SqrtBox["2"]], "+", 
      FractionBox[
       RowBox[{
        FractionBox[
         RowBox[{
          FractionBox[
           RowBox[{
            FractionBox["i", 
             SqrtBox["2"]], "+", 
            FractionBox["k", 
             SqrtBox["2"]]}], 
           SqrtBox["2"]], "+", 
          FractionBox[
           RowBox[{
            FractionBox["j", 
             SqrtBox["2"]], "+", 
            FractionBox["k", 
             SqrtBox["2"]]}], 
           SqrtBox["2"]]}], 
         SqrtBox["2"]], "+", 
        FractionBox[
         RowBox[{
          FractionBox[
           RowBox[{
            FractionBox["l", 
             SqrtBox["2"]], "+", 
            FractionBox["m", 
             SqrtBox["2"]]}], 
           SqrtBox["2"]], "+", 
          FractionBox[
           RowBox[{
            FractionBox["n", 
             SqrtBox["2"]], "+", 
            FractionBox["o", 
             SqrtBox["2"]]}], 
           SqrtBox["2"]]}], 
         SqrtBox["2"]]}], 
       SqrtBox["2"]]}], ")"}]}], ",", 
   RowBox[{
    FractionBox["1", "4"], " ", 
    RowBox[{"(", 
     RowBox[{
      FractionBox[
       RowBox[{
        FractionBox[
         RowBox[{
          FractionBox[
           RowBox[{
            FractionBox["a", 
             SqrtBox["2"]], "+", 
            FractionBox["b", 
             SqrtBox["2"]]}], 
           SqrtBox["2"]], "+", 
          FractionBox[
           RowBox[{
            FractionBox["c", 
             SqrtBox["2"]], "+", 
            FractionBox["d", 
             SqrtBox["2"]]}], 
           SqrtBox["2"]]}], 
         SqrtBox["2"]], "+", 
        FractionBox[
         RowBox[{
          FractionBox[
           RowBox[{
            FractionBox["e", 
             SqrtBox["2"]], "+", 
            FractionBox["f", 
             SqrtBox["2"]]}], 
           SqrtBox["2"]], "+", 
          FractionBox[
           RowBox[{
            FractionBox["g", 
             SqrtBox["2"]], "+", 
            FractionBox["h", 
             SqrtBox["2"]]}], 
           SqrtBox["2"]]}], 
         SqrtBox["2"]]}], 
       SqrtBox["2"]], "+", 
      FractionBox[
       RowBox[{
        FractionBox[
         RowBox[{
          FractionBox[
           RowBox[{
            FractionBox["i", 
             SqrtBox["2"]], "+", 
            FractionBox["k", 
             SqrtBox["2"]]}], 
           SqrtBox["2"]], "+", 
          FractionBox[
           RowBox[{
            FractionBox["j", 
             SqrtBox["2"]], "+", 
            FractionBox["k", 
             SqrtBox["2"]]}], 
           SqrtBox["2"]]}], 
         SqrtBox["2"]], "+", 
        FractionBox[
         RowBox[{
          FractionBox[
           RowBox[{
            FractionBox["l", 
             SqrtBox["2"]], "+", 
            FractionBox["m", 
             SqrtBox["2"]]}], 
           SqrtBox["2"]], "+", 
          FractionBox[
           RowBox[{
            FractionBox["n", 
             SqrtBox["2"]], "+", 
            FractionBox["o", 
             SqrtBox["2"]]}], 
           SqrtBox["2"]]}], 
         SqrtBox["2"]]}], 
       SqrtBox["2"]]}], ")"}]}], ",", 
   RowBox[{
    FractionBox["1", "4"], " ", 
    RowBox[{"(", 
     RowBox[{
      FractionBox[
       RowBox[{
        FractionBox[
         RowBox[{
          FractionBox[
           RowBox[{
            FractionBox["a", 
             SqrtBox["2"]], "+", 
            FractionBox["b", 
             SqrtBox["2"]]}], 
           SqrtBox["2"]], "+", 
          FractionBox[
           RowBox[{
            FractionBox["c", 
             SqrtBox["2"]], "+", 
            FractionBox["d", 
             SqrtBox["2"]]}], 
           SqrtBox["2"]]}], 
         SqrtBox["2"]], "+", 
        FractionBox[
         RowBox[{
          FractionBox[
           RowBox[{
            FractionBox["e", 
             SqrtBox["2"]], "+", 
            FractionBox["f", 
             SqrtBox["2"]]}], 
           SqrtBox["2"]], "+", 
          FractionBox[
           RowBox[{
            FractionBox["g", 
             SqrtBox["2"]], "+", 
            FractionBox["h", 
             SqrtBox["2"]]}], 
           SqrtBox["2"]]}], 
         SqrtBox["2"]]}], 
       SqrtBox["2"]], "+", 
      FractionBox[
       RowBox[{
        FractionBox[
         RowBox[{
          FractionBox[
           RowBox[{
            FractionBox["i", 
             SqrtBox["2"]], "+", 
            FractionBox["k", 
             SqrtBox["2"]]}], 
           SqrtBox["2"]], "+", 
          FractionBox[
           RowBox[{
            FractionBox["j", 
             SqrtBox["2"]], "+", 
            FractionBox["k", 
             SqrtBox["2"]]}], 
           SqrtBox["2"]]}], 
         SqrtBox["2"]], "+", 
        FractionBox[
         RowBox[{
          FractionBox[
           RowBox[{
            FractionBox["l", 
             SqrtBox["2"]], "+", 
            FractionBox["m", 
             SqrtBox["2"]]}], 
           SqrtBox["2"]], "+", 
          FractionBox[
           RowBox[{
            FractionBox["n", 
             SqrtBox["2"]], "+", 
            FractionBox["o", 
             SqrtBox["2"]]}], 
           SqrtBox["2"]]}], 
         SqrtBox["2"]]}], 
       SqrtBox["2"]]}], ")"}]}], ",", 
   RowBox[{
    FractionBox["1", "4"], " ", 
    RowBox[{"(", 
     RowBox[{
      FractionBox[
       RowBox[{
        FractionBox[
         RowBox[{
          FractionBox[
           RowBox[{
            FractionBox["a", 
             SqrtBox["2"]], "+", 
            FractionBox["b", 
             SqrtBox["2"]]}], 
           SqrtBox["2"]], "+", 
          FractionBox[
           RowBox[{
            FractionBox["c", 
             SqrtBox["2"]], "+", 
            FractionBox["d", 
             SqrtBox["2"]]}], 
           SqrtBox["2"]]}], 
         SqrtBox["2"]], "+", 
        FractionBox[
         RowBox[{
          FractionBox[
           RowBox[{
            FractionBox["e", 
             SqrtBox["2"]], "+", 
            FractionBox["f", 
             SqrtBox["2"]]}], 
           SqrtBox["2"]], "+", 
          FractionBox[
           RowBox[{
            FractionBox["g", 
             SqrtBox["2"]], "+", 
            FractionBox["h", 
             SqrtBox["2"]]}], 
           SqrtBox["2"]]}], 
         SqrtBox["2"]]}], 
       SqrtBox["2"]], "+", 
      FractionBox[
       RowBox[{
        FractionBox[
         RowBox[{
          FractionBox[
           RowBox[{
            FractionBox["i", 
             SqrtBox["2"]], "+", 
            FractionBox["k", 
             SqrtBox["2"]]}], 
           SqrtBox["2"]], "+", 
          FractionBox[
           RowBox[{
            FractionBox["j", 
             SqrtBox["2"]], "+", 
            FractionBox["k", 
             SqrtBox["2"]]}], 
           SqrtBox["2"]]}], 
         SqrtBox["2"]], "+", 
        FractionBox[
         RowBox[{
          FractionBox[
           RowBox[{
            FractionBox["l", 
             SqrtBox["2"]], "+", 
            FractionBox["m", 
             SqrtBox["2"]]}], 
           SqrtBox["2"]], "+", 
          FractionBox[
           RowBox[{
            FractionBox["n", 
             SqrtBox["2"]], "+", 
            FractionBox["o", 
             SqrtBox["2"]]}], 
           SqrtBox["2"]]}], 
         SqrtBox["2"]]}], 
       SqrtBox["2"]]}], ")"}]}], ",", 
   RowBox[{
    FractionBox["1", "4"], " ", 
    RowBox[{"(", 
     RowBox[{
      FractionBox[
       RowBox[{
        FractionBox[
         RowBox[{
          FractionBox[
           RowBox[{
            FractionBox["a", 
             SqrtBox["2"]], "+", 
            FractionBox["b", 
             SqrtBox["2"]]}], 
           SqrtBox["2"]], "+", 
          FractionBox[
           RowBox[{
            FractionBox["c", 
             SqrtBox["2"]], "+", 
            FractionBox["d", 
             SqrtBox["2"]]}], 
           SqrtBox["2"]]}], 
         SqrtBox["2"]], "+", 
        FractionBox[
         RowBox[{
          FractionBox[
           RowBox[{
            FractionBox["e", 
             SqrtBox["2"]], "+", 
            FractionBox["f", 
             SqrtBox["2"]]}], 
           SqrtBox["2"]], "+", 
          FractionBox[
           RowBox[{
            FractionBox["g", 
             SqrtBox["2"]], "+", 
            FractionBox["h", 
             SqrtBox["2"]]}], 
           SqrtBox["2"]]}], 
         SqrtBox["2"]]}], 
       SqrtBox["2"]], "+", 
      FractionBox[
       RowBox[{
        FractionBox[
         RowBox[{
          FractionBox[
           RowBox[{
            FractionBox["i", 
             SqrtBox["2"]], "+", 
            FractionBox["k", 
             SqrtBox["2"]]}], 
           SqrtBox["2"]], "+", 
          FractionBox[
           RowBox[{
            FractionBox["j", 
             SqrtBox["2"]], "+", 
            FractionBox["k", 
             SqrtBox["2"]]}], 
           SqrtBox["2"]]}], 
         SqrtBox["2"]], "+", 
        FractionBox[
         RowBox[{
          FractionBox[
           RowBox[{
            FractionBox["l", 
             SqrtBox["2"]], "+", 
            FractionBox["m", 
             SqrtBox["2"]]}], 
           SqrtBox["2"]], "+", 
          FractionBox[
           RowBox[{
            FractionBox["n", 
             SqrtBox["2"]], "+", 
            FractionBox["o", 
             SqrtBox["2"]]}], 
           SqrtBox["2"]]}], 
         SqrtBox["2"]]}], 
       SqrtBox["2"]]}], ")"}]}], ",", 
   RowBox[{
    FractionBox["1", "4"], " ", 
    RowBox[{"(", 
     RowBox[{
      FractionBox[
       RowBox[{
        FractionBox[
         RowBox[{
          FractionBox[
           RowBox[{
            FractionBox["a", 
             SqrtBox["2"]], "+", 
            FractionBox["b", 
             SqrtBox["2"]]}], 
           SqrtBox["2"]], "+", 
          FractionBox[
           RowBox[{
            FractionBox["c", 
             SqrtBox["2"]], "+", 
            FractionBox["d", 
             SqrtBox["2"]]}], 
           SqrtBox["2"]]}], 
         SqrtBox["2"]], "+", 
        FractionBox[
         RowBox[{
          FractionBox[
           RowBox[{
            FractionBox["e", 
             SqrtBox["2"]], "+", 
            FractionBox["f", 
             SqrtBox["2"]]}], 
           SqrtBox["2"]], "+", 
          FractionBox[
           RowBox[{
            FractionBox["g", 
             SqrtBox["2"]], "+", 
            FractionBox["h", 
             SqrtBox["2"]]}], 
           SqrtBox["2"]]}], 
         SqrtBox["2"]]}], 
       SqrtBox["2"]], "+", 
      FractionBox[
       RowBox[{
        FractionBox[
         RowBox[{
          FractionBox[
           RowBox[{
            FractionBox["i", 
             SqrtBox["2"]], "+", 
            FractionBox["k", 
             SqrtBox["2"]]}], 
           SqrtBox["2"]], "+", 
          FractionBox[
           RowBox[{
            FractionBox["j", 
             SqrtBox["2"]], "+", 
            FractionBox["k", 
             SqrtBox["2"]]}], 
           SqrtBox["2"]]}], 
         SqrtBox["2"]], "+", 
        FractionBox[
         RowBox[{
          FractionBox[
           RowBox[{
            FractionBox["l", 
             SqrtBox["2"]], "+", 
            FractionBox["m", 
             SqrtBox["2"]]}], 
           SqrtBox["2"]], "+", 
          FractionBox[
           RowBox[{
            FractionBox["n", 
             SqrtBox["2"]], "+", 
            FractionBox["o", 
             SqrtBox["2"]]}], 
           SqrtBox["2"]]}], 
         SqrtBox["2"]]}], 
       SqrtBox["2"]]}], ")"}]}], ",", 
   RowBox[{
    FractionBox["1", "4"], " ", 
    RowBox[{"(", 
     RowBox[{
      FractionBox[
       RowBox[{
        FractionBox[
         RowBox[{
          FractionBox[
           RowBox[{
            FractionBox["a", 
             SqrtBox["2"]], "+", 
            FractionBox["b", 
             SqrtBox["2"]]}], 
           SqrtBox["2"]], "+", 
          FractionBox[
           RowBox[{
            FractionBox["c", 
             SqrtBox["2"]], "+", 
            FractionBox["d", 
             SqrtBox["2"]]}], 
           SqrtBox["2"]]}], 
         SqrtBox["2"]], "+", 
        FractionBox[
         RowBox[{
          FractionBox[
           RowBox[{
            FractionBox["e", 
             SqrtBox["2"]], "+", 
            FractionBox["f", 
             SqrtBox["2"]]}], 
           SqrtBox["2"]], "+", 
          FractionBox[
           RowBox[{
            FractionBox["g", 
             SqrtBox["2"]], "+", 
            FractionBox["h", 
             SqrtBox["2"]]}], 
           SqrtBox["2"]]}], 
         SqrtBox["2"]]}], 
       SqrtBox["2"]], "+", 
      FractionBox[
       RowBox[{
        FractionBox[
         RowBox[{
          FractionBox[
           RowBox[{
            FractionBox["i", 
             SqrtBox["2"]], "+", 
            FractionBox["k", 
             SqrtBox["2"]]}], 
           SqrtBox["2"]], "+", 
          FractionBox[
           RowBox[{
            FractionBox["j", 
             SqrtBox["2"]], "+", 
            FractionBox["k", 
             SqrtBox["2"]]}], 
           SqrtBox["2"]]}], 
         SqrtBox["2"]], "+", 
        FractionBox[
         RowBox[{
          FractionBox[
           RowBox[{
            FractionBox["l", 
             SqrtBox["2"]], "+", 
            FractionBox["m", 
             SqrtBox["2"]]}], 
           SqrtBox["2"]], "+", 
          FractionBox[
           RowBox[{
            FractionBox["n", 
             SqrtBox["2"]], "+", 
            FractionBox["o", 
             SqrtBox["2"]]}], 
           SqrtBox["2"]]}], 
         SqrtBox["2"]]}], 
       SqrtBox["2"]]}], ")"}]}], ",", 
   RowBox[{
    FractionBox["1", "4"], " ", 
    RowBox[{"(", 
     RowBox[{
      FractionBox[
       RowBox[{
        FractionBox[
         RowBox[{
          FractionBox[
           RowBox[{
            FractionBox["a", 
             SqrtBox["2"]], "+", 
            FractionBox["b", 
             SqrtBox["2"]]}], 
           SqrtBox["2"]], "+", 
          FractionBox[
           RowBox[{
            FractionBox["c", 
             SqrtBox["2"]], "+", 
            FractionBox["d", 
             SqrtBox["2"]]}], 
           SqrtBox["2"]]}], 
         SqrtBox["2"]], "+", 
        FractionBox[
         RowBox[{
          FractionBox[
           RowBox[{
            FractionBox["e", 
             SqrtBox["2"]], "+", 
            FractionBox["f", 
             SqrtBox["2"]]}], 
           SqrtBox["2"]], "+", 
          FractionBox[
           RowBox[{
            FractionBox["g", 
             SqrtBox["2"]], "+", 
            FractionBox["h", 
             SqrtBox["2"]]}], 
           SqrtBox["2"]]}], 
         SqrtBox["2"]]}], 
       SqrtBox["2"]], "+", 
      FractionBox[
       RowBox[{
        FractionBox[
         RowBox[{
          FractionBox[
           RowBox[{
            FractionBox["i", 
             SqrtBox["2"]], "+", 
            FractionBox["k", 
             SqrtBox["2"]]}], 
           SqrtBox["2"]], "+", 
          FractionBox[
           RowBox[{
            FractionBox["j", 
             SqrtBox["2"]], "+", 
            FractionBox["k", 
             SqrtBox["2"]]}], 
           SqrtBox["2"]]}], 
         SqrtBox["2"]], "+", 
        FractionBox[
         RowBox[{
          FractionBox[
           RowBox[{
            FractionBox["l", 
             SqrtBox["2"]], "+", 
            FractionBox["m", 
             SqrtBox["2"]]}], 
           SqrtBox["2"]], "+", 
          FractionBox[
           RowBox[{
            FractionBox["n", 
             SqrtBox["2"]], "+", 
            FractionBox["o", 
             SqrtBox["2"]]}], 
           SqrtBox["2"]]}], 
         SqrtBox["2"]]}], 
       SqrtBox["2"]]}], ")"}]}], ",", 
   RowBox[{
    FractionBox["1", "4"], " ", 
    RowBox[{"(", 
     RowBox[{
      FractionBox[
       RowBox[{
        FractionBox[
         RowBox[{
          FractionBox[
           RowBox[{
            FractionBox["a", 
             SqrtBox["2"]], "+", 
            FractionBox["b", 
             SqrtBox["2"]]}], 
           SqrtBox["2"]], "+", 
          FractionBox[
           RowBox[{
            FractionBox["c", 
             SqrtBox["2"]], "+", 
            FractionBox["d", 
             SqrtBox["2"]]}], 
           SqrtBox["2"]]}], 
         SqrtBox["2"]], "+", 
        FractionBox[
         RowBox[{
          FractionBox[
           RowBox[{
            FractionBox["e", 
             SqrtBox["2"]], "+", 
            FractionBox["f", 
             SqrtBox["2"]]}], 
           SqrtBox["2"]], "+", 
          FractionBox[
           RowBox[{
            FractionBox["g", 
             SqrtBox["2"]], "+", 
            FractionBox["h", 
             SqrtBox["2"]]}], 
           SqrtBox["2"]]}], 
         SqrtBox["2"]]}], 
       SqrtBox["2"]], "+", 
      FractionBox[
       RowBox[{
        FractionBox[
         RowBox[{
          FractionBox[
           RowBox[{
            FractionBox["i", 
             SqrtBox["2"]], "+", 
            FractionBox["k", 
             SqrtBox["2"]]}], 
           SqrtBox["2"]], "+", 
          FractionBox[
           RowBox[{
            FractionBox["j", 
             SqrtBox["2"]], "+", 
            FractionBox["k", 
             SqrtBox["2"]]}], 
           SqrtBox["2"]]}], 
         SqrtBox["2"]], "+", 
        FractionBox[
         RowBox[{
          FractionBox[
           RowBox[{
            FractionBox["l", 
             SqrtBox["2"]], "+", 
            FractionBox["m", 
             SqrtBox["2"]]}], 
           SqrtBox["2"]], "+", 
          FractionBox[
           RowBox[{
            FractionBox["n", 
             SqrtBox["2"]], "+", 
            FractionBox["o", 
             SqrtBox["2"]]}], 
           SqrtBox["2"]]}], 
         SqrtBox["2"]]}], 
       SqrtBox["2"]]}], ")"}]}], ",", 
   RowBox[{
    FractionBox["1", "4"], " ", 
    RowBox[{"(", 
     RowBox[{
      FractionBox[
       RowBox[{
        FractionBox[
         RowBox[{
          FractionBox[
           RowBox[{
            FractionBox["a", 
             SqrtBox["2"]], "+", 
            FractionBox["b", 
             SqrtBox["2"]]}], 
           SqrtBox["2"]], "+", 
          FractionBox[
           RowBox[{
            FractionBox["c", 
             SqrtBox["2"]], "+", 
            FractionBox["d", 
             SqrtBox["2"]]}], 
           SqrtBox["2"]]}], 
         SqrtBox["2"]], "+", 
        FractionBox[
         RowBox[{
          FractionBox[
           RowBox[{
            FractionBox["e", 
             SqrtBox["2"]], "+", 
            FractionBox["f", 
             SqrtBox["2"]]}], 
           SqrtBox["2"]], "+", 
          FractionBox[
           RowBox[{
            FractionBox["g", 
             SqrtBox["2"]], "+", 
            FractionBox["h", 
             SqrtBox["2"]]}], 
           SqrtBox["2"]]}], 
         SqrtBox["2"]]}], 
       SqrtBox["2"]], "+", 
      FractionBox[
       RowBox[{
        FractionBox[
         RowBox[{
          FractionBox[
           RowBox[{
            FractionBox["i", 
             SqrtBox["2"]], "+", 
            FractionBox["k", 
             SqrtBox["2"]]}], 
           SqrtBox["2"]], "+", 
          FractionBox[
           RowBox[{
            FractionBox["j", 
             SqrtBox["2"]], "+", 
            FractionBox["k", 
             SqrtBox["2"]]}], 
           SqrtBox["2"]]}], 
         SqrtBox["2"]], "+", 
        FractionBox[
         RowBox[{
          FractionBox[
           RowBox[{
            FractionBox["l", 
             SqrtBox["2"]], "+", 
            FractionBox["m", 
             SqrtBox["2"]]}], 
           SqrtBox["2"]], "+", 
          FractionBox[
           RowBox[{
            FractionBox["n", 
             SqrtBox["2"]], "+", 
            FractionBox["o", 
             SqrtBox["2"]]}], 
           SqrtBox["2"]]}], 
         SqrtBox["2"]]}], 
       SqrtBox["2"]]}], ")"}]}], ",", 
   RowBox[{
    FractionBox["1", "4"], " ", 
    RowBox[{"(", 
     RowBox[{
      FractionBox[
       RowBox[{
        FractionBox[
         RowBox[{
          FractionBox[
           RowBox[{
            FractionBox["a", 
             SqrtBox["2"]], "+", 
            FractionBox["b", 
             SqrtBox["2"]]}], 
           SqrtBox["2"]], "+", 
          FractionBox[
           RowBox[{
            FractionBox["c", 
             SqrtBox["2"]], "+", 
            FractionBox["d", 
             SqrtBox["2"]]}], 
           SqrtBox["2"]]}], 
         SqrtBox["2"]], "+", 
        FractionBox[
         RowBox[{
          FractionBox[
           RowBox[{
            FractionBox["e", 
             SqrtBox["2"]], "+", 
            FractionBox["f", 
             SqrtBox["2"]]}], 
           SqrtBox["2"]], "+", 
          FractionBox[
           RowBox[{
            FractionBox["g", 
             SqrtBox["2"]], "+", 
            FractionBox["h", 
             SqrtBox["2"]]}], 
           SqrtBox["2"]]}], 
         SqrtBox["2"]]}], 
       SqrtBox["2"]], "+", 
      FractionBox[
       RowBox[{
        FractionBox[
         RowBox[{
          FractionBox[
           RowBox[{
            FractionBox["i", 
             SqrtBox["2"]], "+", 
            FractionBox["k", 
             SqrtBox["2"]]}], 
           SqrtBox["2"]], "+", 
          FractionBox[
           RowBox[{
            FractionBox["j", 
             SqrtBox["2"]], "+", 
            FractionBox["k", 
             SqrtBox["2"]]}], 
           SqrtBox["2"]]}], 
         SqrtBox["2"]], "+", 
        FractionBox[
         RowBox[{
          FractionBox[
           RowBox[{
            FractionBox["l", 
             SqrtBox["2"]], "+", 
            FractionBox["m", 
             SqrtBox["2"]]}], 
           SqrtBox["2"]], "+", 
          FractionBox[
           RowBox[{
            FractionBox["n", 
             SqrtBox["2"]], "+", 
            FractionBox["o", 
             SqrtBox["2"]]}], 
           SqrtBox["2"]]}], 
         SqrtBox["2"]]}], 
       SqrtBox["2"]]}], ")"}]}], ",", 
   RowBox[{
    FractionBox["1", "4"], " ", 
    RowBox[{"(", 
     RowBox[{
      FractionBox[
       RowBox[{
        FractionBox[
         RowBox[{
          FractionBox[
           RowBox[{
            FractionBox["a", 
             SqrtBox["2"]], "+", 
            FractionBox["b", 
             SqrtBox["2"]]}], 
           SqrtBox["2"]], "+", 
          FractionBox[
           RowBox[{
            FractionBox["c", 
             SqrtBox["2"]], "+", 
            FractionBox["d", 
             SqrtBox["2"]]}], 
           SqrtBox["2"]]}], 
         SqrtBox["2"]], "+", 
        FractionBox[
         RowBox[{
          FractionBox[
           RowBox[{
            FractionBox["e", 
             SqrtBox["2"]], "+", 
            FractionBox["f", 
             SqrtBox["2"]]}], 
           SqrtBox["2"]], "+", 
          FractionBox[
           RowBox[{
            FractionBox["g", 
             SqrtBox["2"]], "+", 
            FractionBox["h", 
             SqrtBox["2"]]}], 
           SqrtBox["2"]]}], 
         SqrtBox["2"]]}], 
       SqrtBox["2"]], "+", 
      FractionBox[
       RowBox[{
        FractionBox[
         RowBox[{
          FractionBox[
           RowBox[{
            FractionBox["i", 
             SqrtBox["2"]], "+", 
            FractionBox["k", 
             SqrtBox["2"]]}], 
           SqrtBox["2"]], "+", 
          FractionBox[
           RowBox[{
            FractionBox["j", 
             SqrtBox["2"]], "+", 
            FractionBox["k", 
             SqrtBox["2"]]}], 
           SqrtBox["2"]]}], 
         SqrtBox["2"]], "+", 
        FractionBox[
         RowBox[{
          FractionBox[
           RowBox[{
            FractionBox["l", 
             SqrtBox["2"]], "+", 
            FractionBox["m", 
             SqrtBox["2"]]}], 
           SqrtBox["2"]], "+", 
          FractionBox[
           RowBox[{
            FractionBox["n", 
             SqrtBox["2"]], "+", 
            FractionBox["o", 
             SqrtBox["2"]]}], 
           SqrtBox["2"]]}], 
         SqrtBox["2"]]}], 
       SqrtBox["2"]]}], ")"}]}]}], "}"}]], "Output",
 CellChangeTimes->{3.521958050233198*^9, 3.521958526669142*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"data5", "=", 
  RowBox[{"InverseWaveletTransform", "[", 
   RowBox[{"dwd", ",", "Automatic", ",", 
    RowBox[{"{", 
     RowBox[{"0", ",", "0", ",", "0", ",", "1"}], "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.521958066592852*^9, 3.521958080677786*^9}, 
   3.521958485969631*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    FractionBox["1", "4"], " ", 
    RowBox[{"(", 
     RowBox[{
      FractionBox[
       RowBox[{
        FractionBox[
         RowBox[{
          FractionBox[
           RowBox[{
            FractionBox["a", 
             SqrtBox["2"]], "+", 
            FractionBox["b", 
             SqrtBox["2"]]}], 
           SqrtBox["2"]], "+", 
          FractionBox[
           RowBox[{
            FractionBox["c", 
             SqrtBox["2"]], "+", 
            FractionBox["d", 
             SqrtBox["2"]]}], 
           SqrtBox["2"]]}], 
         SqrtBox["2"]], "+", 
        FractionBox[
         RowBox[{
          FractionBox[
           RowBox[{
            FractionBox["e", 
             SqrtBox["2"]], "+", 
            FractionBox["f", 
             SqrtBox["2"]]}], 
           SqrtBox["2"]], "+", 
          FractionBox[
           RowBox[{
            FractionBox["g", 
             SqrtBox["2"]], "+", 
            FractionBox["h", 
             SqrtBox["2"]]}], 
           SqrtBox["2"]]}], 
         SqrtBox["2"]]}], 
       SqrtBox["2"]], "-", 
      FractionBox[
       RowBox[{
        FractionBox[
         RowBox[{
          FractionBox[
           RowBox[{
            FractionBox["i", 
             SqrtBox["2"]], "+", 
            FractionBox["k", 
             SqrtBox["2"]]}], 
           SqrtBox["2"]], "+", 
          FractionBox[
           RowBox[{
            FractionBox["j", 
             SqrtBox["2"]], "+", 
            FractionBox["k", 
             SqrtBox["2"]]}], 
           SqrtBox["2"]]}], 
         SqrtBox["2"]], "+", 
        FractionBox[
         RowBox[{
          FractionBox[
           RowBox[{
            FractionBox["l", 
             SqrtBox["2"]], "+", 
            FractionBox["m", 
             SqrtBox["2"]]}], 
           SqrtBox["2"]], "+", 
          FractionBox[
           RowBox[{
            FractionBox["n", 
             SqrtBox["2"]], "+", 
            FractionBox["o", 
             SqrtBox["2"]]}], 
           SqrtBox["2"]]}], 
         SqrtBox["2"]]}], 
       SqrtBox["2"]]}], ")"}]}], ",", 
   RowBox[{
    FractionBox["1", "4"], " ", 
    RowBox[{"(", 
     RowBox[{
      FractionBox[
       RowBox[{
        FractionBox[
         RowBox[{
          FractionBox[
           RowBox[{
            FractionBox["a", 
             SqrtBox["2"]], "+", 
            FractionBox["b", 
             SqrtBox["2"]]}], 
           SqrtBox["2"]], "+", 
          FractionBox[
           RowBox[{
            FractionBox["c", 
             SqrtBox["2"]], "+", 
            FractionBox["d", 
             SqrtBox["2"]]}], 
           SqrtBox["2"]]}], 
         SqrtBox["2"]], "+", 
        FractionBox[
         RowBox[{
          FractionBox[
           RowBox[{
            FractionBox["e", 
             SqrtBox["2"]], "+", 
            FractionBox["f", 
             SqrtBox["2"]]}], 
           SqrtBox["2"]], "+", 
          FractionBox[
           RowBox[{
            FractionBox["g", 
             SqrtBox["2"]], "+", 
            FractionBox["h", 
             SqrtBox["2"]]}], 
           SqrtBox["2"]]}], 
         SqrtBox["2"]]}], 
       SqrtBox["2"]], "-", 
      FractionBox[
       RowBox[{
        FractionBox[
         RowBox[{
          FractionBox[
           RowBox[{
            FractionBox["i", 
             SqrtBox["2"]], "+", 
            FractionBox["k", 
             SqrtBox["2"]]}], 
           SqrtBox["2"]], "+", 
          FractionBox[
           RowBox[{
            FractionBox["j", 
             SqrtBox["2"]], "+", 
            FractionBox["k", 
             SqrtBox["2"]]}], 
           SqrtBox["2"]]}], 
         SqrtBox["2"]], "+", 
        FractionBox[
         RowBox[{
          FractionBox[
           RowBox[{
            FractionBox["l", 
             SqrtBox["2"]], "+", 
            FractionBox["m", 
             SqrtBox["2"]]}], 
           SqrtBox["2"]], "+", 
          FractionBox[
           RowBox[{
            FractionBox["n", 
             SqrtBox["2"]], "+", 
            FractionBox["o", 
             SqrtBox["2"]]}], 
           SqrtBox["2"]]}], 
         SqrtBox["2"]]}], 
       SqrtBox["2"]]}], ")"}]}], ",", 
   RowBox[{
    FractionBox["1", "4"], " ", 
    RowBox[{"(", 
     RowBox[{
      FractionBox[
       RowBox[{
        FractionBox[
         RowBox[{
          FractionBox[
           RowBox[{
            FractionBox["a", 
             SqrtBox["2"]], "+", 
            FractionBox["b", 
             SqrtBox["2"]]}], 
           SqrtBox["2"]], "+", 
          FractionBox[
           RowBox[{
            FractionBox["c", 
             SqrtBox["2"]], "+", 
            FractionBox["d", 
             SqrtBox["2"]]}], 
           SqrtBox["2"]]}], 
         SqrtBox["2"]], "+", 
        FractionBox[
         RowBox[{
          FractionBox[
           RowBox[{
            FractionBox["e", 
             SqrtBox["2"]], "+", 
            FractionBox["f", 
             SqrtBox["2"]]}], 
           SqrtBox["2"]], "+", 
          FractionBox[
           RowBox[{
            FractionBox["g", 
             SqrtBox["2"]], "+", 
            FractionBox["h", 
             SqrtBox["2"]]}], 
           SqrtBox["2"]]}], 
         SqrtBox["2"]]}], 
       SqrtBox["2"]], "-", 
      FractionBox[
       RowBox[{
        FractionBox[
         RowBox[{
          FractionBox[
           RowBox[{
            FractionBox["i", 
             SqrtBox["2"]], "+", 
            FractionBox["k", 
             SqrtBox["2"]]}], 
           SqrtBox["2"]], "+", 
          FractionBox[
           RowBox[{
            FractionBox["j", 
             SqrtBox["2"]], "+", 
            FractionBox["k", 
             SqrtBox["2"]]}], 
           SqrtBox["2"]]}], 
         SqrtBox["2"]], "+", 
        FractionBox[
         RowBox[{
          FractionBox[
           RowBox[{
            FractionBox["l", 
             SqrtBox["2"]], "+", 
            FractionBox["m", 
             SqrtBox["2"]]}], 
           SqrtBox["2"]], "+", 
          FractionBox[
           RowBox[{
            FractionBox["n", 
             SqrtBox["2"]], "+", 
            FractionBox["o", 
             SqrtBox["2"]]}], 
           SqrtBox["2"]]}], 
         SqrtBox["2"]]}], 
       SqrtBox["2"]]}], ")"}]}], ",", 
   RowBox[{
    FractionBox["1", "4"], " ", 
    RowBox[{"(", 
     RowBox[{
      FractionBox[
       RowBox[{
        FractionBox[
         RowBox[{
          FractionBox[
           RowBox[{
            FractionBox["a", 
             SqrtBox["2"]], "+", 
            FractionBox["b", 
             SqrtBox["2"]]}], 
           SqrtBox["2"]], "+", 
          FractionBox[
           RowBox[{
            FractionBox["c", 
             SqrtBox["2"]], "+", 
            FractionBox["d", 
             SqrtBox["2"]]}], 
           SqrtBox["2"]]}], 
         SqrtBox["2"]], "+", 
        FractionBox[
         RowBox[{
          FractionBox[
           RowBox[{
            FractionBox["e", 
             SqrtBox["2"]], "+", 
            FractionBox["f", 
             SqrtBox["2"]]}], 
           SqrtBox["2"]], "+", 
          FractionBox[
           RowBox[{
            FractionBox["g", 
             SqrtBox["2"]], "+", 
            FractionBox["h", 
             SqrtBox["2"]]}], 
           SqrtBox["2"]]}], 
         SqrtBox["2"]]}], 
       SqrtBox["2"]], "-", 
      FractionBox[
       RowBox[{
        FractionBox[
         RowBox[{
          FractionBox[
           RowBox[{
            FractionBox["i", 
             SqrtBox["2"]], "+", 
            FractionBox["k", 
             SqrtBox["2"]]}], 
           SqrtBox["2"]], "+", 
          FractionBox[
           RowBox[{
            FractionBox["j", 
             SqrtBox["2"]], "+", 
            FractionBox["k", 
             SqrtBox["2"]]}], 
           SqrtBox["2"]]}], 
         SqrtBox["2"]], "+", 
        FractionBox[
         RowBox[{
          FractionBox[
           RowBox[{
            FractionBox["l", 
             SqrtBox["2"]], "+", 
            FractionBox["m", 
             SqrtBox["2"]]}], 
           SqrtBox["2"]], "+", 
          FractionBox[
           RowBox[{
            FractionBox["n", 
             SqrtBox["2"]], "+", 
            FractionBox["o", 
             SqrtBox["2"]]}], 
           SqrtBox["2"]]}], 
         SqrtBox["2"]]}], 
       SqrtBox["2"]]}], ")"}]}], ",", 
   RowBox[{
    FractionBox["1", "4"], " ", 
    RowBox[{"(", 
     RowBox[{
      FractionBox[
       RowBox[{
        FractionBox[
         RowBox[{
          FractionBox[
           RowBox[{
            FractionBox["a", 
             SqrtBox["2"]], "+", 
            FractionBox["b", 
             SqrtBox["2"]]}], 
           SqrtBox["2"]], "+", 
          FractionBox[
           RowBox[{
            FractionBox["c", 
             SqrtBox["2"]], "+", 
            FractionBox["d", 
             SqrtBox["2"]]}], 
           SqrtBox["2"]]}], 
         SqrtBox["2"]], "+", 
        FractionBox[
         RowBox[{
          FractionBox[
           RowBox[{
            FractionBox["e", 
             SqrtBox["2"]], "+", 
            FractionBox["f", 
             SqrtBox["2"]]}], 
           SqrtBox["2"]], "+", 
          FractionBox[
           RowBox[{
            FractionBox["g", 
             SqrtBox["2"]], "+", 
            FractionBox["h", 
             SqrtBox["2"]]}], 
           SqrtBox["2"]]}], 
         SqrtBox["2"]]}], 
       SqrtBox["2"]], "-", 
      FractionBox[
       RowBox[{
        FractionBox[
         RowBox[{
          FractionBox[
           RowBox[{
            FractionBox["i", 
             SqrtBox["2"]], "+", 
            FractionBox["k", 
             SqrtBox["2"]]}], 
           SqrtBox["2"]], "+", 
          FractionBox[
           RowBox[{
            FractionBox["j", 
             SqrtBox["2"]], "+", 
            FractionBox["k", 
             SqrtBox["2"]]}], 
           SqrtBox["2"]]}], 
         SqrtBox["2"]], "+", 
        FractionBox[
         RowBox[{
          FractionBox[
           RowBox[{
            FractionBox["l", 
             SqrtBox["2"]], "+", 
            FractionBox["m", 
             SqrtBox["2"]]}], 
           SqrtBox["2"]], "+", 
          FractionBox[
           RowBox[{
            FractionBox["n", 
             SqrtBox["2"]], "+", 
            FractionBox["o", 
             SqrtBox["2"]]}], 
           SqrtBox["2"]]}], 
         SqrtBox["2"]]}], 
       SqrtBox["2"]]}], ")"}]}], ",", 
   RowBox[{
    FractionBox["1", "4"], " ", 
    RowBox[{"(", 
     RowBox[{
      FractionBox[
       RowBox[{
        FractionBox[
         RowBox[{
          FractionBox[
           RowBox[{
            FractionBox["a", 
             SqrtBox["2"]], "+", 
            FractionBox["b", 
             SqrtBox["2"]]}], 
           SqrtBox["2"]], "+", 
          FractionBox[
           RowBox[{
            FractionBox["c", 
             SqrtBox["2"]], "+", 
            FractionBox["d", 
             SqrtBox["2"]]}], 
           SqrtBox["2"]]}], 
         SqrtBox["2"]], "+", 
        FractionBox[
         RowBox[{
          FractionBox[
           RowBox[{
            FractionBox["e", 
             SqrtBox["2"]], "+", 
            FractionBox["f", 
             SqrtBox["2"]]}], 
           SqrtBox["2"]], "+", 
          FractionBox[
           RowBox[{
            FractionBox["g", 
             SqrtBox["2"]], "+", 
            FractionBox["h", 
             SqrtBox["2"]]}], 
           SqrtBox["2"]]}], 
         SqrtBox["2"]]}], 
       SqrtBox["2"]], "-", 
      FractionBox[
       RowBox[{
        FractionBox[
         RowBox[{
          FractionBox[
           RowBox[{
            FractionBox["i", 
             SqrtBox["2"]], "+", 
            FractionBox["k", 
             SqrtBox["2"]]}], 
           SqrtBox["2"]], "+", 
          FractionBox[
           RowBox[{
            FractionBox["j", 
             SqrtBox["2"]], "+", 
            FractionBox["k", 
             SqrtBox["2"]]}], 
           SqrtBox["2"]]}], 
         SqrtBox["2"]], "+", 
        FractionBox[
         RowBox[{
          FractionBox[
           RowBox[{
            FractionBox["l", 
             SqrtBox["2"]], "+", 
            FractionBox["m", 
             SqrtBox["2"]]}], 
           SqrtBox["2"]], "+", 
          FractionBox[
           RowBox[{
            FractionBox["n", 
             SqrtBox["2"]], "+", 
            FractionBox["o", 
             SqrtBox["2"]]}], 
           SqrtBox["2"]]}], 
         SqrtBox["2"]]}], 
       SqrtBox["2"]]}], ")"}]}], ",", 
   RowBox[{
    FractionBox["1", "4"], " ", 
    RowBox[{"(", 
     RowBox[{
      FractionBox[
       RowBox[{
        FractionBox[
         RowBox[{
          FractionBox[
           RowBox[{
            FractionBox["a", 
             SqrtBox["2"]], "+", 
            FractionBox["b", 
             SqrtBox["2"]]}], 
           SqrtBox["2"]], "+", 
          FractionBox[
           RowBox[{
            FractionBox["c", 
             SqrtBox["2"]], "+", 
            FractionBox["d", 
             SqrtBox["2"]]}], 
           SqrtBox["2"]]}], 
         SqrtBox["2"]], "+", 
        FractionBox[
         RowBox[{
          FractionBox[
           RowBox[{
            FractionBox["e", 
             SqrtBox["2"]], "+", 
            FractionBox["f", 
             SqrtBox["2"]]}], 
           SqrtBox["2"]], "+", 
          FractionBox[
           RowBox[{
            FractionBox["g", 
             SqrtBox["2"]], "+", 
            FractionBox["h", 
             SqrtBox["2"]]}], 
           SqrtBox["2"]]}], 
         SqrtBox["2"]]}], 
       SqrtBox["2"]], "-", 
      FractionBox[
       RowBox[{
        FractionBox[
         RowBox[{
          FractionBox[
           RowBox[{
            FractionBox["i", 
             SqrtBox["2"]], "+", 
            FractionBox["k", 
             SqrtBox["2"]]}], 
           SqrtBox["2"]], "+", 
          FractionBox[
           RowBox[{
            FractionBox["j", 
             SqrtBox["2"]], "+", 
            FractionBox["k", 
             SqrtBox["2"]]}], 
           SqrtBox["2"]]}], 
         SqrtBox["2"]], "+", 
        FractionBox[
         RowBox[{
          FractionBox[
           RowBox[{
            FractionBox["l", 
             SqrtBox["2"]], "+", 
            FractionBox["m", 
             SqrtBox["2"]]}], 
           SqrtBox["2"]], "+", 
          FractionBox[
           RowBox[{
            FractionBox["n", 
             SqrtBox["2"]], "+", 
            FractionBox["o", 
             SqrtBox["2"]]}], 
           SqrtBox["2"]]}], 
         SqrtBox["2"]]}], 
       SqrtBox["2"]]}], ")"}]}], ",", 
   RowBox[{
    FractionBox["1", "4"], " ", 
    RowBox[{"(", 
     RowBox[{
      FractionBox[
       RowBox[{
        FractionBox[
         RowBox[{
          FractionBox[
           RowBox[{
            FractionBox["a", 
             SqrtBox["2"]], "+", 
            FractionBox["b", 
             SqrtBox["2"]]}], 
           SqrtBox["2"]], "+", 
          FractionBox[
           RowBox[{
            FractionBox["c", 
             SqrtBox["2"]], "+", 
            FractionBox["d", 
             SqrtBox["2"]]}], 
           SqrtBox["2"]]}], 
         SqrtBox["2"]], "+", 
        FractionBox[
         RowBox[{
          FractionBox[
           RowBox[{
            FractionBox["e", 
             SqrtBox["2"]], "+", 
            FractionBox["f", 
             SqrtBox["2"]]}], 
           SqrtBox["2"]], "+", 
          FractionBox[
           RowBox[{
            FractionBox["g", 
             SqrtBox["2"]], "+", 
            FractionBox["h", 
             SqrtBox["2"]]}], 
           SqrtBox["2"]]}], 
         SqrtBox["2"]]}], 
       SqrtBox["2"]], "-", 
      FractionBox[
       RowBox[{
        FractionBox[
         RowBox[{
          FractionBox[
           RowBox[{
            FractionBox["i", 
             SqrtBox["2"]], "+", 
            FractionBox["k", 
             SqrtBox["2"]]}], 
           SqrtBox["2"]], "+", 
          FractionBox[
           RowBox[{
            FractionBox["j", 
             SqrtBox["2"]], "+", 
            FractionBox["k", 
             SqrtBox["2"]]}], 
           SqrtBox["2"]]}], 
         SqrtBox["2"]], "+", 
        FractionBox[
         RowBox[{
          FractionBox[
           RowBox[{
            FractionBox["l", 
             SqrtBox["2"]], "+", 
            FractionBox["m", 
             SqrtBox["2"]]}], 
           SqrtBox["2"]], "+", 
          FractionBox[
           RowBox[{
            FractionBox["n", 
             SqrtBox["2"]], "+", 
            FractionBox["o", 
             SqrtBox["2"]]}], 
           SqrtBox["2"]]}], 
         SqrtBox["2"]]}], 
       SqrtBox["2"]]}], ")"}]}], ",", 
   RowBox[{
    FractionBox["1", "4"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", 
       FractionBox[
        RowBox[{
         FractionBox[
          RowBox[{
           FractionBox[
            RowBox[{
             FractionBox["a", 
              SqrtBox["2"]], "+", 
             FractionBox["b", 
              SqrtBox["2"]]}], 
            SqrtBox["2"]], "+", 
           FractionBox[
            RowBox[{
             FractionBox["c", 
              SqrtBox["2"]], "+", 
             FractionBox["d", 
              SqrtBox["2"]]}], 
            SqrtBox["2"]]}], 
          SqrtBox["2"]], "+", 
         FractionBox[
          RowBox[{
           FractionBox[
            RowBox[{
             FractionBox["e", 
              SqrtBox["2"]], "+", 
             FractionBox["f", 
              SqrtBox["2"]]}], 
            SqrtBox["2"]], "+", 
           FractionBox[
            RowBox[{
             FractionBox["g", 
              SqrtBox["2"]], "+", 
             FractionBox["h", 
              SqrtBox["2"]]}], 
            SqrtBox["2"]]}], 
          SqrtBox["2"]]}], 
        SqrtBox["2"]]}], "+", 
      FractionBox[
       RowBox[{
        FractionBox[
         RowBox[{
          FractionBox[
           RowBox[{
            FractionBox["i", 
             SqrtBox["2"]], "+", 
            FractionBox["k", 
             SqrtBox["2"]]}], 
           SqrtBox["2"]], "+", 
          FractionBox[
           RowBox[{
            FractionBox["j", 
             SqrtBox["2"]], "+", 
            FractionBox["k", 
             SqrtBox["2"]]}], 
           SqrtBox["2"]]}], 
         SqrtBox["2"]], "+", 
        FractionBox[
         RowBox[{
          FractionBox[
           RowBox[{
            FractionBox["l", 
             SqrtBox["2"]], "+", 
            FractionBox["m", 
             SqrtBox["2"]]}], 
           SqrtBox["2"]], "+", 
          FractionBox[
           RowBox[{
            FractionBox["n", 
             SqrtBox["2"]], "+", 
            FractionBox["o", 
             SqrtBox["2"]]}], 
           SqrtBox["2"]]}], 
         SqrtBox["2"]]}], 
       SqrtBox["2"]]}], ")"}]}], ",", 
   RowBox[{
    FractionBox["1", "4"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", 
       FractionBox[
        RowBox[{
         FractionBox[
          RowBox[{
           FractionBox[
            RowBox[{
             FractionBox["a", 
              SqrtBox["2"]], "+", 
             FractionBox["b", 
              SqrtBox["2"]]}], 
            SqrtBox["2"]], "+", 
           FractionBox[
            RowBox[{
             FractionBox["c", 
              SqrtBox["2"]], "+", 
             FractionBox["d", 
              SqrtBox["2"]]}], 
            SqrtBox["2"]]}], 
          SqrtBox["2"]], "+", 
         FractionBox[
          RowBox[{
           FractionBox[
            RowBox[{
             FractionBox["e", 
              SqrtBox["2"]], "+", 
             FractionBox["f", 
              SqrtBox["2"]]}], 
            SqrtBox["2"]], "+", 
           FractionBox[
            RowBox[{
             FractionBox["g", 
              SqrtBox["2"]], "+", 
             FractionBox["h", 
              SqrtBox["2"]]}], 
            SqrtBox["2"]]}], 
          SqrtBox["2"]]}], 
        SqrtBox["2"]]}], "+", 
      FractionBox[
       RowBox[{
        FractionBox[
         RowBox[{
          FractionBox[
           RowBox[{
            FractionBox["i", 
             SqrtBox["2"]], "+", 
            FractionBox["k", 
             SqrtBox["2"]]}], 
           SqrtBox["2"]], "+", 
          FractionBox[
           RowBox[{
            FractionBox["j", 
             SqrtBox["2"]], "+", 
            FractionBox["k", 
             SqrtBox["2"]]}], 
           SqrtBox["2"]]}], 
         SqrtBox["2"]], "+", 
        FractionBox[
         RowBox[{
          FractionBox[
           RowBox[{
            FractionBox["l", 
             SqrtBox["2"]], "+", 
            FractionBox["m", 
             SqrtBox["2"]]}], 
           SqrtBox["2"]], "+", 
          FractionBox[
           RowBox[{
            FractionBox["n", 
             SqrtBox["2"]], "+", 
            FractionBox["o", 
             SqrtBox["2"]]}], 
           SqrtBox["2"]]}], 
         SqrtBox["2"]]}], 
       SqrtBox["2"]]}], ")"}]}], ",", 
   RowBox[{
    FractionBox["1", "4"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", 
       FractionBox[
        RowBox[{
         FractionBox[
          RowBox[{
           FractionBox[
            RowBox[{
             FractionBox["a", 
              SqrtBox["2"]], "+", 
             FractionBox["b", 
              SqrtBox["2"]]}], 
            SqrtBox["2"]], "+", 
           FractionBox[
            RowBox[{
             FractionBox["c", 
              SqrtBox["2"]], "+", 
             FractionBox["d", 
              SqrtBox["2"]]}], 
            SqrtBox["2"]]}], 
          SqrtBox["2"]], "+", 
         FractionBox[
          RowBox[{
           FractionBox[
            RowBox[{
             FractionBox["e", 
              SqrtBox["2"]], "+", 
             FractionBox["f", 
              SqrtBox["2"]]}], 
            SqrtBox["2"]], "+", 
           FractionBox[
            RowBox[{
             FractionBox["g", 
              SqrtBox["2"]], "+", 
             FractionBox["h", 
              SqrtBox["2"]]}], 
            SqrtBox["2"]]}], 
          SqrtBox["2"]]}], 
        SqrtBox["2"]]}], "+", 
      FractionBox[
       RowBox[{
        FractionBox[
         RowBox[{
          FractionBox[
           RowBox[{
            FractionBox["i", 
             SqrtBox["2"]], "+", 
            FractionBox["k", 
             SqrtBox["2"]]}], 
           SqrtBox["2"]], "+", 
          FractionBox[
           RowBox[{
            FractionBox["j", 
             SqrtBox["2"]], "+", 
            FractionBox["k", 
             SqrtBox["2"]]}], 
           SqrtBox["2"]]}], 
         SqrtBox["2"]], "+", 
        FractionBox[
         RowBox[{
          FractionBox[
           RowBox[{
            FractionBox["l", 
             SqrtBox["2"]], "+", 
            FractionBox["m", 
             SqrtBox["2"]]}], 
           SqrtBox["2"]], "+", 
          FractionBox[
           RowBox[{
            FractionBox["n", 
             SqrtBox["2"]], "+", 
            FractionBox["o", 
             SqrtBox["2"]]}], 
           SqrtBox["2"]]}], 
         SqrtBox["2"]]}], 
       SqrtBox["2"]]}], ")"}]}], ",", 
   RowBox[{
    FractionBox["1", "4"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", 
       FractionBox[
        RowBox[{
         FractionBox[
          RowBox[{
           FractionBox[
            RowBox[{
             FractionBox["a", 
              SqrtBox["2"]], "+", 
             FractionBox["b", 
              SqrtBox["2"]]}], 
            SqrtBox["2"]], "+", 
           FractionBox[
            RowBox[{
             FractionBox["c", 
              SqrtBox["2"]], "+", 
             FractionBox["d", 
              SqrtBox["2"]]}], 
            SqrtBox["2"]]}], 
          SqrtBox["2"]], "+", 
         FractionBox[
          RowBox[{
           FractionBox[
            RowBox[{
             FractionBox["e", 
              SqrtBox["2"]], "+", 
             FractionBox["f", 
              SqrtBox["2"]]}], 
            SqrtBox["2"]], "+", 
           FractionBox[
            RowBox[{
             FractionBox["g", 
              SqrtBox["2"]], "+", 
             FractionBox["h", 
              SqrtBox["2"]]}], 
            SqrtBox["2"]]}], 
          SqrtBox["2"]]}], 
        SqrtBox["2"]]}], "+", 
      FractionBox[
       RowBox[{
        FractionBox[
         RowBox[{
          FractionBox[
           RowBox[{
            FractionBox["i", 
             SqrtBox["2"]], "+", 
            FractionBox["k", 
             SqrtBox["2"]]}], 
           SqrtBox["2"]], "+", 
          FractionBox[
           RowBox[{
            FractionBox["j", 
             SqrtBox["2"]], "+", 
            FractionBox["k", 
             SqrtBox["2"]]}], 
           SqrtBox["2"]]}], 
         SqrtBox["2"]], "+", 
        FractionBox[
         RowBox[{
          FractionBox[
           RowBox[{
            FractionBox["l", 
             SqrtBox["2"]], "+", 
            FractionBox["m", 
             SqrtBox["2"]]}], 
           SqrtBox["2"]], "+", 
          FractionBox[
           RowBox[{
            FractionBox["n", 
             SqrtBox["2"]], "+", 
            FractionBox["o", 
             SqrtBox["2"]]}], 
           SqrtBox["2"]]}], 
         SqrtBox["2"]]}], 
       SqrtBox["2"]]}], ")"}]}], ",", 
   RowBox[{
    FractionBox["1", "4"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", 
       FractionBox[
        RowBox[{
         FractionBox[
          RowBox[{
           FractionBox[
            RowBox[{
             FractionBox["a", 
              SqrtBox["2"]], "+", 
             FractionBox["b", 
              SqrtBox["2"]]}], 
            SqrtBox["2"]], "+", 
           FractionBox[
            RowBox[{
             FractionBox["c", 
              SqrtBox["2"]], "+", 
             FractionBox["d", 
              SqrtBox["2"]]}], 
            SqrtBox["2"]]}], 
          SqrtBox["2"]], "+", 
         FractionBox[
          RowBox[{
           FractionBox[
            RowBox[{
             FractionBox["e", 
              SqrtBox["2"]], "+", 
             FractionBox["f", 
              SqrtBox["2"]]}], 
            SqrtBox["2"]], "+", 
           FractionBox[
            RowBox[{
             FractionBox["g", 
              SqrtBox["2"]], "+", 
             FractionBox["h", 
              SqrtBox["2"]]}], 
            SqrtBox["2"]]}], 
          SqrtBox["2"]]}], 
        SqrtBox["2"]]}], "+", 
      FractionBox[
       RowBox[{
        FractionBox[
         RowBox[{
          FractionBox[
           RowBox[{
            FractionBox["i", 
             SqrtBox["2"]], "+", 
            FractionBox["k", 
             SqrtBox["2"]]}], 
           SqrtBox["2"]], "+", 
          FractionBox[
           RowBox[{
            FractionBox["j", 
             SqrtBox["2"]], "+", 
            FractionBox["k", 
             SqrtBox["2"]]}], 
           SqrtBox["2"]]}], 
         SqrtBox["2"]], "+", 
        FractionBox[
         RowBox[{
          FractionBox[
           RowBox[{
            FractionBox["l", 
             SqrtBox["2"]], "+", 
            FractionBox["m", 
             SqrtBox["2"]]}], 
           SqrtBox["2"]], "+", 
          FractionBox[
           RowBox[{
            FractionBox["n", 
             SqrtBox["2"]], "+", 
            FractionBox["o", 
             SqrtBox["2"]]}], 
           SqrtBox["2"]]}], 
         SqrtBox["2"]]}], 
       SqrtBox["2"]]}], ")"}]}], ",", 
   RowBox[{
    FractionBox["1", "4"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", 
       FractionBox[
        RowBox[{
         FractionBox[
          RowBox[{
           FractionBox[
            RowBox[{
             FractionBox["a", 
              SqrtBox["2"]], "+", 
             FractionBox["b", 
              SqrtBox["2"]]}], 
            SqrtBox["2"]], "+", 
           FractionBox[
            RowBox[{
             FractionBox["c", 
              SqrtBox["2"]], "+", 
             FractionBox["d", 
              SqrtBox["2"]]}], 
            SqrtBox["2"]]}], 
          SqrtBox["2"]], "+", 
         FractionBox[
          RowBox[{
           FractionBox[
            RowBox[{
             FractionBox["e", 
              SqrtBox["2"]], "+", 
             FractionBox["f", 
              SqrtBox["2"]]}], 
            SqrtBox["2"]], "+", 
           FractionBox[
            RowBox[{
             FractionBox["g", 
              SqrtBox["2"]], "+", 
             FractionBox["h", 
              SqrtBox["2"]]}], 
            SqrtBox["2"]]}], 
          SqrtBox["2"]]}], 
        SqrtBox["2"]]}], "+", 
      FractionBox[
       RowBox[{
        FractionBox[
         RowBox[{
          FractionBox[
           RowBox[{
            FractionBox["i", 
             SqrtBox["2"]], "+", 
            FractionBox["k", 
             SqrtBox["2"]]}], 
           SqrtBox["2"]], "+", 
          FractionBox[
           RowBox[{
            FractionBox["j", 
             SqrtBox["2"]], "+", 
            FractionBox["k", 
             SqrtBox["2"]]}], 
           SqrtBox["2"]]}], 
         SqrtBox["2"]], "+", 
        FractionBox[
         RowBox[{
          FractionBox[
           RowBox[{
            FractionBox["l", 
             SqrtBox["2"]], "+", 
            FractionBox["m", 
             SqrtBox["2"]]}], 
           SqrtBox["2"]], "+", 
          FractionBox[
           RowBox[{
            FractionBox["n", 
             SqrtBox["2"]], "+", 
            FractionBox["o", 
             SqrtBox["2"]]}], 
           SqrtBox["2"]]}], 
         SqrtBox["2"]]}], 
       SqrtBox["2"]]}], ")"}]}], ",", 
   RowBox[{
    FractionBox["1", "4"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", 
       FractionBox[
        RowBox[{
         FractionBox[
          RowBox[{
           FractionBox[
            RowBox[{
             FractionBox["a", 
              SqrtBox["2"]], "+", 
             FractionBox["b", 
              SqrtBox["2"]]}], 
            SqrtBox["2"]], "+", 
           FractionBox[
            RowBox[{
             FractionBox["c", 
              SqrtBox["2"]], "+", 
             FractionBox["d", 
              SqrtBox["2"]]}], 
            SqrtBox["2"]]}], 
          SqrtBox["2"]], "+", 
         FractionBox[
          RowBox[{
           FractionBox[
            RowBox[{
             FractionBox["e", 
              SqrtBox["2"]], "+", 
             FractionBox["f", 
              SqrtBox["2"]]}], 
            SqrtBox["2"]], "+", 
           FractionBox[
            RowBox[{
             FractionBox["g", 
              SqrtBox["2"]], "+", 
             FractionBox["h", 
              SqrtBox["2"]]}], 
            SqrtBox["2"]]}], 
          SqrtBox["2"]]}], 
        SqrtBox["2"]]}], "+", 
      FractionBox[
       RowBox[{
        FractionBox[
         RowBox[{
          FractionBox[
           RowBox[{
            FractionBox["i", 
             SqrtBox["2"]], "+", 
            FractionBox["k", 
             SqrtBox["2"]]}], 
           SqrtBox["2"]], "+", 
          FractionBox[
           RowBox[{
            FractionBox["j", 
             SqrtBox["2"]], "+", 
            FractionBox["k", 
             SqrtBox["2"]]}], 
           SqrtBox["2"]]}], 
         SqrtBox["2"]], "+", 
        FractionBox[
         RowBox[{
          FractionBox[
           RowBox[{
            FractionBox["l", 
             SqrtBox["2"]], "+", 
            FractionBox["m", 
             SqrtBox["2"]]}], 
           SqrtBox["2"]], "+", 
          FractionBox[
           RowBox[{
            FractionBox["n", 
             SqrtBox["2"]], "+", 
            FractionBox["o", 
             SqrtBox["2"]]}], 
           SqrtBox["2"]]}], 
         SqrtBox["2"]]}], 
       SqrtBox["2"]]}], ")"}]}], ",", 
   RowBox[{
    FractionBox["1", "4"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", 
       FractionBox[
        RowBox[{
         FractionBox[
          RowBox[{
           FractionBox[
            RowBox[{
             FractionBox["a", 
              SqrtBox["2"]], "+", 
             FractionBox["b", 
              SqrtBox["2"]]}], 
            SqrtBox["2"]], "+", 
           FractionBox[
            RowBox[{
             FractionBox["c", 
              SqrtBox["2"]], "+", 
             FractionBox["d", 
              SqrtBox["2"]]}], 
            SqrtBox["2"]]}], 
          SqrtBox["2"]], "+", 
         FractionBox[
          RowBox[{
           FractionBox[
            RowBox[{
             FractionBox["e", 
              SqrtBox["2"]], "+", 
             FractionBox["f", 
              SqrtBox["2"]]}], 
            SqrtBox["2"]], "+", 
           FractionBox[
            RowBox[{
             FractionBox["g", 
              SqrtBox["2"]], "+", 
             FractionBox["h", 
              SqrtBox["2"]]}], 
            SqrtBox["2"]]}], 
          SqrtBox["2"]]}], 
        SqrtBox["2"]]}], "+", 
      FractionBox[
       RowBox[{
        FractionBox[
         RowBox[{
          FractionBox[
           RowBox[{
            FractionBox["i", 
             SqrtBox["2"]], "+", 
            FractionBox["k", 
             SqrtBox["2"]]}], 
           SqrtBox["2"]], "+", 
          FractionBox[
           RowBox[{
            FractionBox["j", 
             SqrtBox["2"]], "+", 
            FractionBox["k", 
             SqrtBox["2"]]}], 
           SqrtBox["2"]]}], 
         SqrtBox["2"]], "+", 
        FractionBox[
         RowBox[{
          FractionBox[
           RowBox[{
            FractionBox["l", 
             SqrtBox["2"]], "+", 
            FractionBox["m", 
             SqrtBox["2"]]}], 
           SqrtBox["2"]], "+", 
          FractionBox[
           RowBox[{
            FractionBox["n", 
             SqrtBox["2"]], "+", 
            FractionBox["o", 
             SqrtBox["2"]]}], 
           SqrtBox["2"]]}], 
         SqrtBox["2"]]}], 
       SqrtBox["2"]]}], ")"}]}]}], "}"}]], "Output",
 CellChangeTimes->{3.521958088140443*^9, 3.521958531224848*^9}]
}, Open  ]],

Cell["\<\


Dang! Got the original signal fully reconstructed:
\
\>", "Text",
 CellChangeTimes->{{3.52195868449205*^9, 3.521958703280694*^9}, {
  3.5219601960212183`*^9, 3.521960196422604*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"data1", "+", "data2", "+", "data3", "+", "data4", "+", "data5"}], "//",
   "Simplify"}]], "Input",
 CellChangeTimes->{{3.521958094561907*^9, 3.521958117760865*^9}, {
  3.521958166298996*^9, 3.5219581682776937`*^9}, {3.521958492922752*^9, 
  3.521958496016636*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", "h", 
   ",", "k", ",", "i", ",", "j", ",", "k", ",", "l", ",", "m", ",", "n", ",", 
   "o"}], "}"}]], "Output",
 CellChangeTimes->{{3.521958110930175*^9, 3.5219581191566257`*^9}, 
   3.521958169540456*^9, 3.5219584974203377`*^9, 3.521958536194261*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"dwd", "=", 
   RowBox[{"DiscreteWaveletTransform", "[", 
    RowBox[{
     TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
         {"a1", "b1", "c1", "d1"},
         {"a2", "b2", "c2", "d2"},
         {"a3", "b3", "c3", "d3"},
         {"a4", "b4", "c4", "d4"}
        },
        GridBoxAlignment->{
         "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
          "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
        GridBoxSpacings->{"Columns" -> {
            Offset[0.27999999999999997`], {
             Offset[0.7]}, 
            Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
          "Rows" -> {
            Offset[0.2], {
             Offset[0.4]}, 
            Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
      Function[BoxForm`e$, 
       MatrixForm[BoxForm`e$]]], ",", 
     RowBox[{"HaarWavelet", "[", "]"}], ",", 
     RowBox[{"WorkingPrecision", "\[Rule]", "\[Infinity]"}]}], "]"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.522034616322426*^9, 3.522034716894755*^9}, {
  3.522034794088263*^9, 3.5220347945584307`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"dwd", "[", 
  RowBox[{"{", 
   RowBox[{"\"\<TreeView\>\"", ",", "Left"}], "}"}], "]"}]], "Input",
 CellChangeTimes->{3.5220347354684467`*^9}],

Cell[BoxData[
 GraphicsBox[
  TagBox[GraphicsComplexBox[{{0., 1.9999999999999987`}, {0.6666666666666677, 
    0.9999999999999992}, {0.666666666666667, 1.6666666666666659`}, {
    0.6666666666666663, 2.3333333333333326`}, {0.6666666666666656, 
    2.999999999999999}, {1.3333333333333355`, 0.}, {1.3333333333333348`, 
    0.6666666666666667}, {1.3333333333333341`, 1.3333333333333335`}, {
    1.3333333333333335`, 2.}}, {
     {RGBColor[0.5, 0., 0.], Arrowheads[{{0.02893784277879342, 0.7}}], 
      ArrowBox[{1, 2}], ArrowBox[{1, 3}], ArrowBox[{1, 4}], ArrowBox[{1, 5}], 
      ArrowBox[{2, 6}], ArrowBox[{2, 7}], ArrowBox[{2, 8}], 
      ArrowBox[{2, 9}]}, {
      TagBox[
       TooltipBox[InsetBox[
         FrameBox[
          RowBox[{"{", "\<\"\"\>", "}"}],
          Background->RGBColor[1, 1, 0.8],
          FrameStyle->RGBColor[0.94, 0.85, 0.36],
          StripOnInput->False], 1],
        RowBox[{"{", "\"\"", "}"}]],
       Annotation[#, {""}, "Tooltip"]& ], 
      TagBox[
       TooltipBox[InsetBox[
         FrameBox[
          RowBox[{"{", "0", "}"}],
          Background->RGBColor[1, 1, 0.8],
          FrameStyle->RGBColor[0.94, 0.85, 0.36],
          StripOnInput->False], 2],
        RowBox[{"{", "0", "}"}]],
       Annotation[#, {0}, "Tooltip"]& ], 
      TagBox[
       TooltipBox[InsetBox[
         FrameBox[
          RowBox[{"{", "1", "}"}],
          Background->RGBColor[0.87, 0.94, 1],
          FrameStyle->GrayLevel[0.3],
          StripOnInput->False], 3],
        RowBox[{"{", "1", "}"}]],
       Annotation[#, {1}, "Tooltip"]& ], 
      TagBox[
       TooltipBox[InsetBox[
         FrameBox[
          RowBox[{"{", "2", "}"}],
          Background->RGBColor[0.87, 0.94, 1],
          FrameStyle->GrayLevel[0.3],
          StripOnInput->False], 4],
        RowBox[{"{", "2", "}"}]],
       Annotation[#, {2}, "Tooltip"]& ], 
      TagBox[
       TooltipBox[InsetBox[
         FrameBox[
          RowBox[{"{", "3", "}"}],
          Background->RGBColor[0.87, 0.94, 1],
          FrameStyle->GrayLevel[0.3],
          StripOnInput->False], 5],
        RowBox[{"{", "3", "}"}]],
       Annotation[#, {3}, "Tooltip"]& ], 
      TagBox[
       TooltipBox[InsetBox[
         FrameBox[
          RowBox[{"{", 
           RowBox[{"0", ",", "0"}], "}"}],
          Background->RGBColor[0.87, 0.94, 1],
          FrameStyle->GrayLevel[0.3],
          StripOnInput->False], 6],
        RowBox[{"{", 
          RowBox[{"0", ",", "0"}], "}"}]],
       Annotation[#, {0, 0}, "Tooltip"]& ], 
      TagBox[
       TooltipBox[InsetBox[
         FrameBox[
          RowBox[{"{", 
           RowBox[{"0", ",", "1"}], "}"}],
          Background->RGBColor[0.87, 0.94, 1],
          FrameStyle->GrayLevel[0.3],
          StripOnInput->False], 7],
        RowBox[{"{", 
          RowBox[{"0", ",", "1"}], "}"}]],
       Annotation[#, {0, 1}, "Tooltip"]& ], 
      TagBox[
       TooltipBox[InsetBox[
         FrameBox[
          RowBox[{"{", 
           RowBox[{"0", ",", "2"}], "}"}],
          Background->RGBColor[0.87, 0.94, 1],
          FrameStyle->GrayLevel[0.3],
          StripOnInput->False], 8],
        RowBox[{"{", 
          RowBox[{"0", ",", "2"}], "}"}]],
       Annotation[#, {0, 2}, "Tooltip"]& ], 
      TagBox[
       TooltipBox[InsetBox[
         FrameBox[
          RowBox[{"{", 
           RowBox[{"0", ",", "3"}], "}"}],
          Background->RGBColor[0.87, 0.94, 1],
          FrameStyle->GrayLevel[0.3],
          StripOnInput->False], 9],
        RowBox[{"{", 
          RowBox[{"0", ",", "3"}], "}"}]],
       Annotation[#, {0, 3}, "Tooltip"]& ]}}],
   Annotation[#, 
    VertexCoordinateRules -> {{0., 1.9999999999999987`}, {0.6666666666666677, 
     0.9999999999999992}, {0.666666666666667, 1.6666666666666659`}, {
     0.6666666666666663, 2.3333333333333326`}, {0.6666666666666656, 
     2.999999999999999}, {1.3333333333333355`, 0.}, {1.3333333333333348`, 
     0.6666666666666667}, {1.3333333333333341`, 1.3333333333333335`}, {
     1.3333333333333335`, 2.}}]& ],
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  FrameTicks->None,
  PlotRange->All,
  PlotRangePadding->Scaled[0.1]]], "Output",
 CellChangeTimes->{3.522034737433783*^9, 3.522034798002242*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"Normal", "[", "dwd", "]"}], "//", "Simplify"}], "//", 
  "MatrixForm"}]], "Input",
 CellChangeTimes->{
  3.5220347569581203`*^9, {3.5220348663177233`*^9, 3.52203486944265*^9}, {
   3.522034914369314*^9, 3.5220349240093203`*^9}}],

Cell[BoxData[
 TagBox[
  TagBox[
   RowBox[{"(", "\[NoBreak]", 
    TagBox[GridBox[{
       {
        RowBox[{
         RowBox[{"{", "0", "}"}], "\[Rule]", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{
             RowBox[{
              FractionBox["1", "2"], " ", 
              RowBox[{"(", 
               RowBox[{"a1", "+", "a2", "+", "b1", "+", "b2"}], ")"}]}], ",", 
             
             RowBox[{
              FractionBox["1", "2"], " ", 
              RowBox[{"(", 
               RowBox[{"c1", "+", "c2", "+", "d1", "+", "d2"}], ")"}]}]}], 
            "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{
              FractionBox["1", "2"], " ", 
              RowBox[{"(", 
               RowBox[{"a3", "+", "a4", "+", "b3", "+", "b4"}], ")"}]}], ",", 
             
             RowBox[{
              FractionBox["1", "2"], " ", 
              RowBox[{"(", 
               RowBox[{"c3", "+", "c4", "+", "d3", "+", "d4"}], ")"}]}]}], 
            "}"}]}], "}"}]}]},
       {
        RowBox[{
         RowBox[{"{", "1", "}"}], "\[Rule]", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{
             RowBox[{
              FractionBox["1", "2"], " ", 
              RowBox[{"(", 
               RowBox[{"a1", "+", "a2", "-", "b1", "-", "b2"}], ")"}]}], ",", 
             
             RowBox[{
              FractionBox["1", "2"], " ", 
              RowBox[{"(", 
               RowBox[{"c1", "+", "c2", "-", "d1", "-", "d2"}], ")"}]}]}], 
            "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{
              FractionBox["1", "2"], " ", 
              RowBox[{"(", 
               RowBox[{"a3", "+", "a4", "-", "b3", "-", "b4"}], ")"}]}], ",", 
             
             RowBox[{
              FractionBox["1", "2"], " ", 
              RowBox[{"(", 
               RowBox[{"c3", "+", "c4", "-", "d3", "-", "d4"}], ")"}]}]}], 
            "}"}]}], "}"}]}]},
       {
        RowBox[{
         RowBox[{"{", "2", "}"}], "\[Rule]", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{
             RowBox[{
              FractionBox["1", "2"], " ", 
              RowBox[{"(", 
               RowBox[{"a1", "-", "a2", "+", "b1", "-", "b2"}], ")"}]}], ",", 
             
             RowBox[{
              FractionBox["1", "2"], " ", 
              RowBox[{"(", 
               RowBox[{"c1", "-", "c2", "+", "d1", "-", "d2"}], ")"}]}]}], 
            "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{
              FractionBox["1", "2"], " ", 
              RowBox[{"(", 
               RowBox[{"a3", "-", "a4", "+", "b3", "-", "b4"}], ")"}]}], ",", 
             
             RowBox[{
              FractionBox["1", "2"], " ", 
              RowBox[{"(", 
               RowBox[{"c3", "-", "c4", "+", "d3", "-", "d4"}], ")"}]}]}], 
            "}"}]}], "}"}]}]},
       {
        RowBox[{
         RowBox[{"{", "3", "}"}], "\[Rule]", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{
             RowBox[{
              FractionBox["1", "2"], " ", 
              RowBox[{"(", 
               RowBox[{"a1", "-", "a2", "-", "b1", "+", "b2"}], ")"}]}], ",", 
             
             RowBox[{
              FractionBox["1", "2"], " ", 
              RowBox[{"(", 
               RowBox[{"c1", "-", "c2", "-", "d1", "+", "d2"}], ")"}]}]}], 
            "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{
              FractionBox["1", "2"], " ", 
              RowBox[{"(", 
               RowBox[{"a3", "-", "a4", "-", "b3", "+", "b4"}], ")"}]}], ",", 
             
             RowBox[{
              FractionBox["1", "2"], " ", 
              RowBox[{"(", 
               RowBox[{"c3", "-", "c4", "-", "d3", "+", "d4"}], ")"}]}]}], 
            "}"}]}], "}"}]}]},
       {
        RowBox[{
         RowBox[{"{", 
          RowBox[{"0", ",", "0"}], "}"}], "\[Rule]", 
         RowBox[{"{", 
          RowBox[{"{", 
           RowBox[{
            FractionBox["1", "4"], " ", 
            RowBox[{"(", 
             RowBox[{
             "a1", "+", "a2", "+", "a3", "+", "a4", "+", "b1", "+", "b2", "+",
               "b3", "+", "b4", "+", "c1", "+", "c2", "+", "c3", "+", "c4", 
              "+", "d1", "+", "d2", "+", "d3", "+", "d4"}], ")"}]}], "}"}], 
          "}"}]}]},
       {
        RowBox[{
         RowBox[{"{", 
          RowBox[{"0", ",", "1"}], "}"}], "\[Rule]", 
         RowBox[{"{", 
          RowBox[{"{", 
           RowBox[{
            FractionBox["1", "4"], " ", 
            RowBox[{"(", 
             RowBox[{
             "a1", "+", "a2", "+", "a3", "+", "a4", "+", "b1", "+", "b2", "+",
               "b3", "+", "b4", "-", "c1", "-", "c2", "-", "c3", "-", "c4", 
              "-", "d1", "-", "d2", "-", "d3", "-", "d4"}], ")"}]}], "}"}], 
          "}"}]}]},
       {
        RowBox[{
         RowBox[{"{", 
          RowBox[{"0", ",", "2"}], "}"}], "\[Rule]", 
         RowBox[{"{", 
          RowBox[{"{", 
           RowBox[{
            FractionBox["1", "4"], " ", 
            RowBox[{"(", 
             RowBox[{
             "a1", "+", "a2", "-", "a3", "-", "a4", "+", "b1", "+", "b2", "-",
               "b3", "-", "b4", "+", "c1", "+", "c2", "-", "c3", "-", "c4", 
              "+", "d1", "+", "d2", "-", "d3", "-", "d4"}], ")"}]}], "}"}], 
          "}"}]}]},
       {
        RowBox[{
         RowBox[{"{", 
          RowBox[{"0", ",", "3"}], "}"}], "\[Rule]", 
         RowBox[{"{", 
          RowBox[{"{", 
           RowBox[{
            FractionBox["1", "4"], " ", 
            RowBox[{"(", 
             RowBox[{
             "a1", "+", "a2", "-", "a3", "-", "a4", "+", "b1", "+", "b2", "-",
               "b3", "-", "b4", "-", "c1", "-", "c2", "+", "c3", "+", "c4", 
              "-", "d1", "-", "d2", "+", "d3", "+", "d4"}], ")"}]}], "}"}], 
          "}"}]}]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
        "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.5599999999999999]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     Column], "\[NoBreak]", ")"}],
   Function[BoxForm`e$, 
    MatrixForm[BoxForm`e$]]],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{3.522034758474741*^9, 3.522034800503757*^9, 
  3.522034870430632*^9, 3.522034919068267*^9}]
}, Open  ]]
}, Open  ]]
},
WindowSize->{762, 1310},
WindowMargins->{{791, Automatic}, {Automatic, 0}},
PrivateNotebookOptions->{"VersionedStylesheet"->{"Default.nb"[8.] -> False}},
FrontEndVersion->"9.0 for Mac OS X x86 (32-bit, 64-bit Kernel) (January 25, \
2013)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[579, 22, 109, 1, 92, "Title"],
Cell[691, 25, 4503, 124, 763, "Text"],
Cell[CellGroupData[{
Cell[5219, 153, 670, 15, 63, "Input"],
Cell[5892, 170, 266, 8, 28, "Output"]
}, Open  ]],
Cell[6173, 181, 1182, 27, 90, "Input"],
Cell[CellGroupData[{
Cell[7380, 212, 759, 21, 46, "Input"],
Cell[8142, 235, 2002, 37, 230, "Output"]
}, Open  ]],
Cell[10159, 275, 256, 8, 87, "Text"],
Cell[CellGroupData[{
Cell[10440, 287, 921, 23, 63, "Input"],
Cell[11364, 312, 1795, 36, 336, "Output"]
}, Open  ]],
Cell[13174, 351, 3413, 111, 573, "Text"],
Cell[CellGroupData[{
Cell[16612, 466, 329, 8, 80, "Input"],
Cell[16944, 476, 264, 8, 28, "Output"]
}, Open  ]],
Cell[17223, 487, 385, 10, 28, "Input"],
Cell[CellGroupData[{
Cell[17633, 501, 570, 18, 46, "Input"],
Cell[18206, 521, 1856, 34, 230, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[20099, 560, 611, 16, 46, "Input"],
Cell[20713, 578, 1622, 33, 328, "Output"]
}, Open  ]],
Cell[22350, 614, 164, 6, 87, "Text"],
Cell[CellGroupData[{
Cell[22539, 624, 744, 19, 80, "Input"],
Cell[23286, 645, 205, 5, 28, "Output"]
}, Open  ]],
Cell[23506, 653, 743, 26, 76, "Text"],
Cell[24252, 681, 1044, 25, 82, "Input"],
Cell[CellGroupData[{
Cell[25321, 710, 279, 6, 46, "Input"],
Cell[25603, 718, 70, 1, 28, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[25710, 724, 150, 3, 28, "Input"],
Cell[25863, 729, 70, 1, 28, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[25970, 735, 337, 8, 28, "Input"],
Cell[26310, 745, 939, 24, 246, "Output"]
}, Open  ]],
Cell[27264, 772, 107, 1, 30, "Text"],
Cell[27374, 775, 876, 32, 37, "Text"],
Cell[28253, 809, 3067, 72, 179, "Input"],
Cell[CellGroupData[{
Cell[31345, 885, 1221, 27, 80, "Input"],
Cell[32569, 914, 310, 5, 28, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[32916, 924, 1927, 51, 167, "Input"],
Cell[34846, 977, 884, 14, 46, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[35767, 996, 431, 10, 46, "Input"],
Cell[36201, 1008, 1533, 33, 243, "Output"]
}, Open  ]],
Cell[37749, 1044, 541, 19, 37, "Text"],
Cell[38293, 1065, 755, 24, 77, "Input"],
Cell[CellGroupData[{
Cell[39073, 1093, 272, 6, 46, "Input"],
Cell[39348, 1101, 182, 4, 28, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[39567, 1110, 762, 23, 91, "Input"],
Cell[40332, 1135, 657, 12, 46, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[41026, 1152, 338, 8, 28, "Input"],
Cell[41367, 1162, 1630, 35, 229, "Output"]
}, Open  ]],
Cell[43012, 1200, 1431, 33, 165, "Input"],
Cell[CellGroupData[{
Cell[44468, 1237, 134, 3, 28, "Input"],
Cell[44605, 1242, 4862, 160, 331, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[49504, 1407, 189, 4, 28, "Input"],
Cell[49696, 1413, 4582, 117, 238, "Output"]
}, Open  ]],
Cell[54293, 1533, 132, 4, 49, "Text"],
Cell[CellGroupData[{
Cell[54450, 1541, 410, 8, 28, "Input"],
Cell[54863, 1551, 2963, 128, 174, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[57863, 1684, 292, 7, 28, "Input"],
Cell[58158, 1693, 7261, 299, 376, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[65456, 1997, 302, 7, 28, "Input"],
Cell[65761, 2006, 14933, 619, 712, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[80731, 2630, 335, 7, 28, "Input"],
Cell[81069, 2639, 33269, 1251, 2072, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[114375, 3895, 310, 7, 28, "Input"],
Cell[114688, 3904, 33741, 1259, 2072, "Output"]
}, Open  ]],
Cell[148444, 5166, 193, 7, 87, "Text"],
Cell[CellGroupData[{
Cell[148662, 5177, 299, 6, 28, "Input"],
Cell[148964, 5185, 364, 7, 28, "Output"]
}, Open  ]],
Cell[149343, 5195, 1103, 29, 81, "Input"],
Cell[CellGroupData[{
Cell[150471, 5228, 165, 4, 28, "Input"],
Cell[150639, 5234, 4216, 112, 238, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[154892, 5351, 275, 7, 28, "Input"],
Cell[155170, 5360, 6727, 194, 213, "Output"]
}, Open  ]]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
