(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 8.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       157,          7]
NotebookDataLength[    186583,       4450]
NotebookOptionsPosition[    180752,       4262]
NotebookOutlinePosition[    181187,       4279]
CellTagsIndexPosition[    181144,       4276]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["Haar Wavelets: Symbolic Computation", "Title",
 CellChangeTimes->{{3.521588800091734*^9, 3.521588811148778*^9}}],

Cell["\<\




Symbolic computation of wavelets is of paramount importance and effectiveness \
for teaching the Wavelet theory for both programming purposes as well as more \
theoretical mathematical treatments. 

Visualization of the symbolic equations accompanied by the graphical plots \
empowers the novice reader to acquire speedy expertise and relevant insights \
into the theory. 
\
\>", "Text",
 CellChangeTimes->{
  3.5215894865607*^9, {3.521596599725985*^9, 3.521596600116292*^9}, {
   3.521610942050131*^9, 3.521610942158337*^9}}],

Cell[CellGroupData[{

Cell["\<\
\[Phi]: Scaling Function, Father Wavelet \
\>", "Subtitle",
 CellChangeTimes->{{3.5216118343300743`*^9, 3.52161185626717*^9}, {
  3.5216119057446737`*^9, 3.521611908292006*^9}}],

Cell["\<\
Let\[CloseCurlyQuote]s define a simple box function: \
\>", "Text",
 CellChangeTimes->{3.521589515835329*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"BoxFunction", "[", "x0_", "]"}], ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"x", "=", "x0"}], "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{"Boole", "[", 
     RowBox[{
      RowBox[{"0", "\[LessEqual]", "x"}], " ", "&&", " ", 
      RowBox[{"x", "<", "1"}]}], "]"}]}], "\[IndentingNewLine]", 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.5215895068831587`*^9, 3.5215895309657717`*^9}, {
  3.521590482135579*^9, 3.5215904883753633`*^9}}],

Cell[TextData[{
 "Visualize the symbolic form:\n\n",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"BoxFunction", "(", "x", ")"}], "=", 
    RowBox[{"\[Piecewise]", GridBox[{
       {"1", 
        RowBox[{"0", "\[LessEqual]", "x", "<", "1"}]},
       {"0", "otherwise"}
      },
      GridBoxAlignment->{
       "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
        "RowsIndexed" -> {}},
      GridBoxItemSize->{
       "Columns" -> {{Automatic}}, "ColumnsIndexed" -> {}, "Rows" -> {{1.}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.84]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}]}]}], TraditionalForm]]],
 "\n\nVisualize the plot:"
}], "Text",
 CellChangeTimes->{
  3.521589556744101*^9, {3.5215896564792624`*^9, 3.5215896941779003`*^9}, {
   3.52158989440198*^9, 3.5215898961530247`*^9}, {3.521590491400015*^9, 
   3.521590505895707*^9}, {3.52159597066348*^9, 3.521595973418988*^9}, {
   3.521606438131608*^9, 3.521606440934758*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"BoxFunction", "[", "x", "]"}], ",", " ", 
   RowBox[{"{", 
    RowBox[{"x", ",", " ", 
     RowBox[{"-", "2"}], ",", " ", "2"}], "}"}], ",", " ", 
   RowBox[{"PlotRange", "\[Rule]", " ", "All"}], ",", 
   RowBox[{"Filling", "\[Rule]", "Axis"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.521589581189218*^9, 3.52158961392885*^9}, {
  3.521590508627446*^9, 3.521590510404789*^9}, {3.521591331670512*^9, 
  3.5215913320286837`*^9}}],

Cell[BoxData[
 GraphicsBox[GraphicsComplexBox[CompressedData["
1:eJxl1AkwnGcYAOBFlLppUYn7aiwjiDJLdTVFiDhLyYizDcZKiSEoRcRdyiCp
CpFkCRIlSohiN8KOqyruM0kRsgnWuayt0Haavm+jZox55n/P7/d/Kn4hzud4
CQRC1l+/f//VJcu82t/fpxPe/ET2J50PoO2Bh4eFX7X5vgYrPAx531h+F3yf
0sEv/oQL9snUX51I3AFzcmPS6GQOmCr2VK5gZgtcdEo/bCidDU4M9o3SstkE
x/DdiQxbXgf7JvSrj1asga+0zhcUBa2Cf3l2VKRKlQVWkzA/4XJ9EfwzMS1o
do4JfsaoVTYyWgDP61wxoDfMgSXjKo10eWbAOkYrOmUb0+DLFsuPm6LGwNIu
1TlnZAex3xZDvEu9B1w2NZ/1MokG9nSSr5/6shTcJBQz8iiCSv5Hq+SPZnkU
L7nTwWqrzTsmj7rBNtSJPnv3QbClnRQf+/4YONt7LEGvcRrcaa8g6ig1A15W
kY4bLJwDR4Rr+2bLLIDHpiWc/buYYJ/oj18InF4Et2sbZ7Tzs8Ca77YwS61X
yf/uo9BCseRPWwMTuLyVYbPr4G2nVi+GxiZ4ytD7iEYSGxzqJiGpOr0Flst/
7n5IgQOu9rhRvhG1A3Yzi7fuauWCa73Oq5rs/gHmCH3G1+T6Guw8YGqkULAH
fvM94PPUvrvHvfH7IPJy6yge9WAS/7Hy3+ddwN113ha16fVwHrmDTQ/mK5bA
giVjP6XYroBvzb4n68rE8zIX1MoRO439zefWen6swf5M1soNYmgTuGYzWI05
mQ/2PycgX1aB7+M5+8V+bAHW7w42mJNex33HiYLfn8mqhvyAAKJ/w14u5N8Z
LycHsnDeRqqSmcBtnM9YMmny1zGcz2o+SDaD2wyu7x1kOAxcByfvO23mhOI8
YkqNmXIMnKdXON5MZKAW4tuV01OLJRKh/0Qz/eJ2Ec6z61q6IBSN83xuKsbL
050M+cGf5AgqsosgnsY9mbSkhP3D1grz+IYw3+Cond/CIu5z0adisIncivfV
VGLvpws3wV8cSmUVnsV6elHRvteqcR9uSgvHVKYO77M8qx6KYSjMo1jj35zp
h/3dpcJLA+nZEJ+xIeqcI4z18095Bia3YHzXNkuLXyAT6l3rcqQblEVC/jpP
YoO1IeY7FozTLr3E/Ht1+pobbNxXTPHkPadZ3Df2aj9dTIMKpqXcXCxxxnpt
pZO2Z6m4b66Fx+jQA9x3dC2xRILjDvPVTHWW2blhf1bckIm9Zy7Et/VqRZH4
sb5mJM3ZqhbjHztM6fX1JUC8+95XxYeJGD/TQao88RTjE4KqgoeI30B/9W0i
hSaN8dpzI6SrnhSoR6dEDj/cxPyQHbW0HS6ez2SsTEnxcby/lzbYpIgOPJ/1
Tt2gW3ZYX8hUuK2lGM/Hi0pkKAn97/6A+TgXOIernbD/byTlY0eK8iD+28Aq
8Sw2/v9/LbrSefsuxucywuUCbC9D/Hexozl8GjgP0SNIkTqO8W4RRV7lEvj8
gycKrL3KMMgX5K2wUVnB+FWHD9dDwvyhf+uFeMvod/7zvkRCf9AN8MXvZ8TK
24eL+Qff78H9D96nB/d9O/7gcwLhTzRpgMg=
   "], {{{}, 
     {Hue[0.67, 0.6, 0.6], Opacity[0.2], EdgeForm[None], 
      GraphicsGroupBox[
       PolygonBox[{{121, 140, 141, 124, 67, 76, 56, 62, 37, 55, 36, 35, 34, 
        33, 32, 31, 30, 29, 28, 27, 54, 26, 79, 66, 93, 75, 111, 88, 132, 
        103}}]]}, {}, {}}, {{}, {}, 
     {Hue[0.67, 0.6, 0.6], 
      LineBox[{1, 115, 97, 82, 69, 59, 51, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12,
        13, 14, 15, 16, 17, 18, 19, 20, 21, 22, 23, 24, 116, 98, 83, 70, 60, 
       52, 120, 102, 87, 74, 65, 25, 117, 99, 84, 71, 61, 123, 105, 90, 78, 
       126, 108, 94, 130, 113, 134, 53}], 
      LineBox[{121, 103, 132, 88, 111, 75, 93, 66, 79, 26, 54, 27, 28, 29, 30,
        31, 32, 33, 34, 35, 36, 55, 37, 62, 56, 76, 67, 124}], 
      LineBox[{106, 133, 91, 129, 112, 80, 127, 109, 95, 38, 118, 100, 85, 72,
        63, 57, 39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 49, 119, 101, 86, 73, 
       64, 58, 122, 104, 89, 77, 68, 125, 107, 92, 81, 128, 110, 96, 131, 114,
        135, 50}]}, 
     {Hue[0.67, 0.6, 0.6], Opacity[0.2], LineBox[{138, 137}], 
      LineBox[{139, 136}]}}, {{}, {}, {}}}],
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesOrigin->{0, 0},
  Method->{"AxesInFront" -> True},
  PlotRange->{All, All},
  PlotRangeClipping->True,
  PlotRangePadding->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.5215896150672483`*^9, 3.5215913330010967`*^9, 
  3.521669367580902*^9}]
}, Open  ]],

Cell[TextData[{
 "\nSymbol \[Phi] (Phi) represents the above function which in the Wavelet \
theory is coined as Scaling Function:\n\n\n",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"\[Phi]", "(", "x", ")"}], "=", 
    RowBox[{"\[Piecewise]", GridBox[{
       {"1", 
        RowBox[{"0", "\[LessEqual]", "x", "<", "1"}]},
       {"0", "otherwise"}
      },
      GridBoxAlignment->{
       "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
        "RowsIndexed" -> {}},
      GridBoxItemSize->{
       "Columns" -> {{Automatic}}, "ColumnsIndexed" -> {}, "Rows" -> {{1.}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.84]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}]}]}], TraditionalForm]]],
 "\n"
}], "Text",
 CellChangeTimes->{{3.521590166889748*^9, 3.5215902529345207`*^9}, {
  3.521590517963737*^9, 3.5215905203487377`*^9}, {3.521590735627624*^9, 
  3.521590870923903*^9}, {3.521590950029318*^9, 3.521590952815544*^9}, {
  3.521591094475131*^9, 3.521591098557769*^9}, {3.521595977593878*^9, 
  3.5215959805937557`*^9}, {3.5216064440209827`*^9, 3.521606446724725*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"\[Phi]Haar", "[", "x0_", "]"}], ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"x", "=", "x0"}], "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{"Boole", "[", 
     RowBox[{
      RowBox[{"0", "\[LessEqual]", "x"}], " ", "&&", " ", 
      RowBox[{"x", "<", "1"}]}], "]"}]}], "\[IndentingNewLine]", 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.521591016857244*^9, 3.5215910397394667`*^9}, 
   3.521598296694841*^9, 3.521618734616159*^9}],

Cell[TextData[{
 "For scaling purposes to finer and finer details let\[CloseCurlyQuote]s \
define a variation of \[Phi] :\n\n",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     SubscriptBox["\[Phi]", 
      RowBox[{"J", ",", " ", "k"}]], "(", "x", ")"}], "=", " ", 
    RowBox[{
     SuperscriptBox["2", 
      RowBox[{"J", "/", "2"}]], 
     RowBox[{"\[Phi]", "(", 
      RowBox[{
       RowBox[{
        SuperscriptBox["2", "J"], "x"}], "-", "k"}], ")"}]}]}], 
   TraditionalForm]]]
}], "Text",
 CellChangeTimes->{
  3.5215910913607283`*^9, {3.5215941333406982`*^9, 3.521594133940424*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"\[Phi]", "[", 
   RowBox[{"x_", ",", " ", "J_", ",", " ", "k_"}], "]"}], ":=", " ", 
  RowBox[{
   SuperscriptBox["2", 
    RowBox[{"J", "/", "2"}]], " ", 
   RowBox[{"\[Phi]Haar", "[", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["2", "J"], "x"}], ")"}], "-", "k"}], "]"}]}]}]], "Input",\

 CellChangeTimes->{{3.521590919087635*^9, 3.5215909959773083`*^9}, {
  3.521591053152507*^9, 3.521591076428389*^9}, {3.521591114572167*^9, 
  3.521591118271315*^9}}],

Cell[TextData[{
 "\n\nNow let\[CloseCurlyQuote]s keep k = 0 and vary J i.e. scaling. \n\n",
 Cell[BoxData[
  FormBox[
   SubscriptBox["\[Phi]", 
    RowBox[{"0", ",", " ", "0"}]], TraditionalForm]]],
 " which is the BoxFunction\n"
}], "Text",
 CellChangeTimes->{{3.521592039232705*^9, 3.5215920491031933`*^9}, {
  3.5215923240622168`*^9, 3.521592332175083*^9}, {3.5215929762359333`*^9, 
  3.5215930265587587`*^9}, {3.521593104181263*^9, 3.521593106619875*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"\[Phi]", "[", 
    RowBox[{"x", ",", "0", ",", "0"}], "]"}], ",", " ", 
   RowBox[{"{", 
    RowBox[{"x", ",", 
     RowBox[{"-", "1"}], ",", "1"}], "}"}], ",", 
   RowBox[{"Filling", "\[Rule]", "Axis"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.5215912099828367`*^9, 3.521591243212129*^9}, {
  3.521592263028248*^9, 3.521592263228157*^9}}],

Cell[BoxData[
 GraphicsBox[GraphicsComplexBox[CompressedData["
1:eJx11X1MzHEcB/Cr3CQ5VyMal5TQ1XrkWoULoUgpodZ6NM6urHaKrFY5N8pI
RELIqpGHHuTpKEe5dankulzpSF1drrgrEnUzT2Pv7zC/7bfba+/fvT/fP36f
/ebGxAdt06dQKDE/7p+/DmyzwW/fhkSU39eeFsFOzgMt3NY2efBRtAZmPIyf
5jb7HXwr9jF16qtBOOqw8/AL/gA8djwlU8RWw0W0LvP8nn64YK0zT5algvlx
0cm2vn1wisGVPTyNEo7OaJknv9wDn6xR5Rdwu+F7rxcaX7Pqgq3pXiuCzyvg
G8xMrrK3A34trrRkseSwyv6ki+i2DDZJK2U56Elhe9aQfclIE7zfW/NMmFwP
Tw8uywmdUUvmfRJPlcy7B5coVEcGBGVweODsm4qtJ2ChUcrz2qRc9i8Nsxcr
9Sz2hZTD1sP3xz1qhbBv0Ytm/5BaeNV6U4PRW/Xw0cj2DKc7TXC9P2PKBlMp
rJk7Pa31jAxOSrSLPmomh9tf0oO2SzrgqL1L3kz0U8B1dm6H6qhd8PxJ1epi
n26YUR27iprZA1N0+qU8pRL+HFgTIbbpgxWLImfZCFRwwha6idXLftj8RF/I
BIYaLgsrvDSSPABvWZruI6kZhCsjdlp5fHkLjxmtNBBu0sBBUk8WI18L/94H
kh9svuoaSfaDqa+rig0rht2pjpe6Vd5wQ1Wkd2VWMf7vZWibQ/MjfV6975+c
Lid9au1QITOhFC7/GGet7hTAHUzD7NAj52EOh7n99lc++txMBJ1N7aRvtYo7
45DuKnyzsVUcIM2GGyenLzWWXoTrLLMOnqPz0LfRk6av15CEPG5ZjqHF6GHk
LgvXx/S/JfN2R11uFbKvk31W8BuX9x+DdQeqxzzNisg+565+ErsoCn0hponF
O0TpyCWftbbUianIz0o2iFxKOMgrqpznj4yS+TSLNRWBSjI/Na9FRLPJhY97
h8lld8l8+Xv+BfqYD/q1aTIP/3A+8mcBCqfm5gQ4g3stTsbk4nm73ufueeFh
yOPHrTPHdeQ8nalmF865kv1+NzLqnvSYnCeiiCmeY/TP+4P+p+6WjrMK9pPz
ixPNOet2wTNfMbRfS2Pg4YAFH+J5m8n+GSeccuAE/rf/7/f1zxzfA/g7oRXJ
lQ==
   "], {{{}, 
     {Hue[0.67, 0.6, 0.6], Opacity[0.2], EdgeForm[None], 
      GraphicsGroupBox[
       PolygonBox[{{89, 97, 98, 50, 55, 49, 48, 47, 46, 45, 44, 43, 42, 41, 
        40, 39, 38, 37, 36, 35, 34, 33, 32, 31, 30, 29, 28, 27, 54, 26, 67, 
        60, 74, 65, 83, 72, 93, 80}}]]}, {}, {}}, {{}, {}, 
     {Hue[0.67, 0.6, 0.6], 
      LineBox[{1, 85, 76, 68, 61, 56, 51, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 
       13, 14, 15, 16, 17, 18, 19, 20, 21, 22, 23, 24, 86, 77, 69, 62, 57, 52,
        88, 79, 71, 64, 59, 25, 87, 78, 70, 63, 58, 90, 81, 73, 66, 91, 82, 
       75, 92, 84, 94, 53}], 
      LineBox[{89, 80, 93, 72, 83, 65, 74, 60, 67, 26, 54, 27, 28, 29, 30, 31,
        32, 33, 34, 35, 36, 37, 38, 39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 
       49, 55, 50}]}, 
     {Hue[0.67, 0.6, 0.6], Opacity[0.2], LineBox[{96, 95}]}}, {{}, {}, {}}}],
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesOrigin->{0, 0},
  Method->{"AxesInFront" -> True},
  PlotRange->{{-1, 1}, {0., 1.}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02]}]], "Output",
 CellChangeTimes->{3.521591244000854*^9, 3.521592263784713*^9, 
  3.521669373415501*^9}]
}, Open  ]],

Cell[TextData[{
 "\n\n",
 Cell[BoxData[
  FormBox[
   SubscriptBox["\[Phi]", 
    RowBox[{"1", ",", " ", "0"}]], TraditionalForm]]]
}], "Text",
 CellChangeTimes->{{3.521592066771749*^9, 3.521592073396955*^9}, {
  3.52159234042225*^9, 3.521592341881278*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"\[Phi]", "[", 
    RowBox[{"x", ",", "1", ",", "0"}], "]"}], ",", " ", 
   RowBox[{"{", 
    RowBox[{"x", ",", 
     RowBox[{"-", "1"}], ",", "1"}], "}"}], ",", 
   RowBox[{"Filling", "\[Rule]", "Axis"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.521591788604588*^9, 3.521591792834057*^9}, {
  3.52159226836981*^9, 3.5215922684485598`*^9}}],

Cell[BoxData[
 GraphicsBox[GraphicsComplexBox[CompressedData["
1:eJxl1Asw1HkcAHCPHIe25Y5OWRS6LKNSx8h16zqk5LGuopHnXdYsHe0Rhktt
m0dHOapz8qol9CCnaPPYqJ1VcmLFsvJYVousV7LtNLm7mXy/N86MMZ/5f5+/
v/9vQ0ik91EVJSWljH9+//1rTdGfWFqa5ip9/IltZx2jNcrAXV1aE03BU2DS
w8jP7Qxfg++FP1Zb83ICHJS+baaXOQ6WZyWkcilSMJswYJAzPAbO27eNIUiT
gJkRwXEWe0fBCao3YhlTYnDwqXaz7rJh8KUGSU4efQj8YHCz9q2NA2BTouPu
AwUi8J/kVLp4RAge5FWZ2Np2gyVWl2y4NQKwzslyW2vlDrCV7bRVyfwz8Bmn
qeecOD5Y70BF5uG1zdjvLW9Ni9kDcIlIkjHOqgD7Uw3vin64COZoJrxojsmm
tDkkhRYUvaV8JVY2Ou1bCTadqXu3s5kD3svubfPwbQY7u+uqLtzjgy8E9pza
WvsMzPcgrfbS7QBPbdA72ZkrAMdEWwZf0O8G9/QTvUNbhOCg+K9fqe8XgR9Z
2p17pDYA3vRpvbTYdYiyvA+pPtxZLXUYrKRQKWeIxeBFakMAz3wULNoRuN6c
JQFH+RB1NvaPgQ0ujvquIknBFX5FpfNx42CfXUmuLQ0T4KqAYxt3vp8EyzW/
U+UcnAJ7dzjYknJk4I/fAz5Pabu5PRC/D7KKojrcrxhsr7aldEjiBH5SHehU
lVYM55HVybkvKesHaxT23E52GwRfE3+29qAUz8tRwyKTsB/7O47MPv2jEvtL
ZdNF5KhycOWbCFNpHwscelTdsKQM38fowqulxBys/yTCZkRvDvcVkjXOH84o
gHwajRxa84EJ+TeEpZQwGc5byzbepX4d57PTYfU968H5XCT0tecUN8F3Wzt5
nh3nwWeXqG8yo3AegnFtugEP52nVStql3XEV4h+ZpKXkExnQv7eOe2IxD+d5
f7B4TDMe5/negaCi/CQG8iO+ydQwWkiH+EbFHtZrY+zPmM3NVhVgvs1m95Cx
SdznRFBZJ4dyG+8rEbP127HfwIdWpchyj2C9rXHxwVcqcB9Fcr3cQZ+N91m2
y9PwHUEwj1FlaF16CPb31Y0uDuMmQfy5+dXemVpY/+I+/7Cz9RjfsiizUFNP
hHpXWry4NiU0yJ9TZta47sB8rxxh4+lxzL9TvW3T/ALuSzDac4cqxn0TL7dz
CebZ4Mbkq5OF3livqbjP7Qgb981y8usW3Md9u2eZhUS5K8xXKeKXuPtgf9lJ
wU4PfybEN7VaxNmrYf1NsY3eLlUY/9xTtLWtLQrifT/8mL+OjPHDj+3Ldw9g
/Cn6rQgBmQ79zRbJ4Y16GG858sL+sr8f1OOGx3Y9fIP5ke9MU98p8Hz6EvUL
87fj/f16fsE+5jGezxzfmn7NHetrOmg11efj+QSwyTxjzf/dHzCf/Lh8XQUV
+/9lb7Jlfd4ZiP8l7NaajAX8//9p9TT/+k2Mz+JFG9Dcfob4XxO7M1XNcR6y
H92ILcR4n5i8gFIiPv/iJUn2oTwE8jVUyvZumMb4Gc8v5yIZh6B/w/Ek5/hP
/vO+tKN+t6ZR8ft54RIYpMD8le935f4r79OV+y7Hr3y+7L8BC8LXtg==
   "], {{{}, 
     {Hue[0.67, 0.6, 0.6], Opacity[0.2], EdgeForm[None], 
      GraphicsGroupBox[
       PolygonBox[{{121, 140, 141, 124, 67, 76, 56, 62, 37, 55, 36, 35, 34, 
        33, 32, 31, 30, 29, 28, 27, 54, 26, 79, 66, 93, 75, 111, 88, 132, 
        103}}]]}, {}, {}}, {{}, {}, 
     {Hue[0.67, 0.6, 0.6], 
      LineBox[{1, 115, 97, 82, 69, 59, 51, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12,
        13, 14, 15, 16, 17, 18, 19, 20, 21, 22, 23, 24, 116, 98, 83, 70, 60, 
       52, 120, 102, 87, 74, 65, 25, 117, 99, 84, 71, 61, 123, 105, 90, 78, 
       126, 108, 94, 130, 113, 134, 53}], 
      LineBox[{121, 103, 132, 88, 111, 75, 93, 66, 79, 26, 54, 27, 28, 29, 30,
        31, 32, 33, 34, 35, 36, 55, 37, 62, 56, 76, 67, 124}], 
      LineBox[{106, 133, 91, 129, 112, 80, 127, 109, 95, 38, 118, 100, 85, 72,
        63, 57, 39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 49, 119, 101, 86, 73, 
       64, 58, 122, 104, 89, 77, 68, 125, 107, 92, 81, 128, 110, 96, 131, 114,
        135, 50}]}, 
     {Hue[0.67, 0.6, 0.6], Opacity[0.2], LineBox[{138, 137}], 
      LineBox[{139, 136}]}}, {{}, {}, {}}}],
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesOrigin->{0, 0},
  Method->{"AxesInFront" -> True},
  PlotRange->{{-1, 1}, {0., 1.4142135623730951`}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02]}]], "Output",
 CellChangeTimes->{
  3.5215917934297647`*^9, 3.521592269341926*^9, {3.521669376388188*^9, 
   3.5216693825927343`*^9}}]
}, Open  ]],

Cell[TextData[{
 "\n\n",
 Cell[BoxData[
  FormBox[
   SubscriptBox["\[Phi]", 
    RowBox[{"2", ",", " ", "0"}]], TraditionalForm]]]
}], "Text",
 CellChangeTimes->{{3.521592087113048*^9, 3.521592094137336*^9}, {
  3.521592343838991*^9, 3.5215923440082493`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"\[Phi]", "[", 
    RowBox[{"x", ",", "2", ",", "0"}], "]"}], ",", " ", 
   RowBox[{"{", 
    RowBox[{"x", ",", 
     RowBox[{"-", "1"}], ",", "1"}], "}"}], ",", 
   RowBox[{"Filling", "\[Rule]", "Axis"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.52159180173378*^9, 3.5215918100815563`*^9}, {
  3.5215922735119333`*^9, 3.521592274568562*^9}}],

Cell[BoxData[
 GraphicsBox[GraphicsComplexBox[CompressedData["
1:eJxl1Q0w1GkYAPCNM5zYcCGFJVGW8VW3DjmuJCqfCbUnS3e2WcRtHC6DNnep
oYREUd3tqpwip49TW+trx1fysdFmSyzLIl/hrL0mdzfjnufGmdkxv3mf5/8+
z/vf91nj8Bj/bxUIBML5vz///Ldy0RlbWpriEZb/EtrTo+lPJ8EvXqweqw2b
ABvUxKy1138Hvh/ZoLTmzRiYlmk7/Yo1CpblnMjguUjBbGKfXsHAMLhojy1T
cEYCZkWFJZp7DoFPKP6awJwQg8PS2jf13BoAX3wiKShi9IMfvd2idntjH9hE
w3VHwFUR+DdyBkM8KAS/5VcaUSg9YInlRTveAwFYM6WUYrWqE2xJmbIsmX0G
PuU20VGd2AjWDijPPqhbh/v9wV/TtOkRuEQkyRpNLweH+OnfEx3JA1ernuiu
i891Wabr5+JVhieDK8Am048XHeuqwZ7sV23ewXXgXV5aivP3G8HnQ1+m2Tx8
Bm70NlD31er814QJY+2UrssCcHycRdh5nR7wy9ca/hFNQjAtafuI8j4RuN7C
/my9Uh/Y7FOulOPRDzbgRu5SyhgAE+QKpUyxGLzg9+Qw33QILNoWusE0XQKO
DdLQ3Ph6GKyXNxT8iYEUXE69fnM2cRQc5Jzq0fRkDFx5OHqj44dxsEx1p2L1
gQmwf6cTxaBgErx8H3D9dFvZ1lC8H2QFeVUklQN2ULK+2S9xAzdXhbpVnuHA
eTN65mpzKC3gcx8zvKTR7eBDXxTuuhDYBfu5qphnE/fh/q6DMy2FFbi/dHLq
Ojm2FFwxF2Ui7U0HE61t6Jlaz+H52TuppbH38H03R9kNar/HfoVklXMHs65C
Pp1OjnjwkQX5yiPTer980wHxD9kkZ+UbWJ+9Znrvs5dYn7uEoXtWXga+19rF
9+k8h/fHczuVdgTrIZIeZurxsZ7W1anOap0/Q3y90ZnTxRpMqGdz1SGjVnWs
58MBzrBqEtaz34mosKo5HvKjvsxWMZzPhPyR9ac/S3qM+cyZy7mKAsy32+IV
PjyO/XxPu9VV7XIH55WI1frV8AWwvNVym9AR+7FJTAq7Uo79yH/iypx02DjP
ct1bIrfRoJ5jdqTdvAb8PhhWRDzODMd6grXiOEd5qZC/QODmq2dj/Xl7Qo7+
yMX4poVJcyXlZHiebptpMcUB4680+fLsSujwPN8C4dOTo5h/t8rWbHYe+yca
7r7rJ8b+k/PbeUTTXJz36iVGeWbYfy2nd+/XbOw/x43aI/gd+++ZYV3TkHlA
fSnrAlr2F2L/FaLGEq8grGcyReDoHcKC/KXjgcKgH7Afs4Sn/u6VGE9yrelL
M8H1Dh+RTVtbLOQPNDiU7ujD+DTG7SgBmQH7/9kRTFo/jvVYDHY75IdQIZ8X
mfCiZg7zYxZNMhbleF69yTrXirfifH83O+8Q34DntdZqQIepj+el6rS6lluM
53WYTeaTVP83X6Ae2Xey9eV+uP9zByPrDUWn8Pfojslicgz2f0x9qvFGGcaz
k7KWStbheg4/To++9zjONyrDkC3E+AheulJ8L57HujcGkx9LwyFeReGWp/EU
xk/7bH4fwwyE+FOX9k8zVf/zvtRiL1nR/fB+dbuH0uSYvzJ+Zf8r5+3K97Ui
fuU64S8GmFkO
   "], {{{}, 
     {Hue[0.67, 0.6, 0.6], Opacity[0.2], EdgeForm[None], 
      GraphicsGroupBox[
       PolygonBox[{{123, 142, 143, 114, 131, 89, 105, 56, 62, 31, 55, 30, 29, 
        28, 27, 54, 26, 79, 66, 94, 75, 113, 88, 134, 
        104}}]]}, {}, {}}, {{}, {}, 
     {Hue[0.67, 0.6, 0.6], 
      LineBox[{1, 117, 98, 82, 69, 59, 51, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12,
        13, 14, 15, 16, 17, 18, 19, 20, 21, 22, 23, 24, 118, 99, 83, 70, 60, 
       52, 122, 103, 87, 74, 65, 25, 119, 100, 84, 71, 61, 125, 107, 91, 78, 
       129, 111, 96, 132, 115, 136, 53}], 
      LineBox[{123, 104, 134, 88, 113, 75, 94, 66, 79, 26, 54, 27, 28, 29, 30,
        55, 31, 62, 56, 105, 89, 131, 114}], 
      LineBox[{135, 76, 128, 110, 95, 67, 126, 108, 92, 80, 32, 120, 101, 85, 
       72, 63, 57, 33, 34, 35, 36, 37, 38, 39, 40, 41, 42, 43, 44, 45, 46, 47,
        48, 49, 121, 102, 86, 73, 64, 58, 124, 106, 90, 77, 68, 127, 109, 93, 
       81, 130, 112, 97, 133, 116, 137, 50}]}, 
     {Hue[0.67, 0.6, 0.6], Opacity[0.2], LineBox[{140, 139}], 
      LineBox[{141, 138}]}}, {{}, {}, {}}}],
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesOrigin->{0, 0},
  Method->{"AxesInFront" -> True},
  PlotRange->{{-1, 1}, {0., 2.}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02]}]], "Output",
 CellChangeTimes->{3.521591810532546*^9, 3.5215922754131947`*^9, 
  3.52166938449468*^9}]
}, Open  ]],

Cell[TextData[{
 "\n\n",
 Cell[BoxData[
  FormBox[
   SubscriptBox["\[Phi]", 
    RowBox[{"3", ",", " ", "0"}]], TraditionalForm]]]
}], "Text",
 CellChangeTimes->{{3.521592099826734*^9, 3.521592105432555*^9}, {
  3.5215923463145933`*^9, 3.521592346472382*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"\[Phi]", "[", 
    RowBox[{"x", ",", "3", ",", "0"}], "]"}], ",", " ", 
   RowBox[{"{", 
    RowBox[{"x", ",", 
     RowBox[{"-", "1"}], ",", "1"}], "}"}], ",", 
   RowBox[{"Filling", "\[Rule]", "Axis"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.521591819881462*^9, 3.5215918221880713`*^9}, {
  3.521592278732417*^9, 3.521592279170603*^9}}],

Cell[BoxData[
 GraphicsBox[GraphicsComplexBox[CompressedData["
1:eJx11QlMk3cUAHCkMhhirQZxTLkFoRwKIgQqxxSRQ0CYB66DUjYpKSCswoDg
BAtOIAiMwzHkci0i6ooMlMNKLdCAAlOsHFIFKZYVlEMRrY3TbYm+l7CsSdP8
8r33vff+X///zyg8NuiwqoqKSt4/339/bdx0pt+/nxOofPgk3smIYbTNgu/f
XzEtpM+A9W7GajtueAa+GtWpturRNDgsx3b+AXsKrChIyRS4ycEc4qhuyfgk
uMzHliXOkoHZ0fQkC+8n4BTCxUTWjBRMT7uzcfDCOLj4hqykjPkY3DpmrnXZ
eBRsQnLfsa9CAv6dnMmUTgyDx0T1hg4Og2CZVbGd4JoYvPp4rYPNsn6wlcOc
VfVCLzjdY+ZuS1IXeO0+Xv6hde1Y75VoVffGVnC1RHZ6KoMHDgnc0Cj5pgjc
opky0J5Q6NZHSY2oqPrEfZt0mf6J4Dqwyfz1N87tLWBvzoM+/+B2t4/5u/zW
EBavdoHzaENpW5p6wV3+eiv3rukHzxitPX6vVAxOiLek5+kMgocekoIiuofB
Ycnb/1TfIwF3WDpmd6iNgs0+5cu5Xo/BevyoXWqZ42AVpWotSyoFvw68ESoy
fQKW2NPWm2bIwHEHSauNH06CdYueBC/Xk4N51KqahaQp8EGXVK/uG9Pg+tAY
Y+e3T8EKzZ2Elv0z4KB+ioNeySz4w37A66f6Lm2l4f4gqyoboqhcsJA0FB8k
dwPfaqB51Gdx4flUxoV2ujQ1gr862+QT7SQA71YkyI3URVDPXcMin7gH67tP
PL/9Sx3Wl8/OVZHjasF1L6NN5CMZ4DaR06/iH/hw/+6+TdTmug64361ou4m1
L3DeYbJG7qHTFZDPYJAjrr1jQ35Kc2kyW3kT4ps4Bi7q57E/x9UZI71D2J+n
jLkuW3kJ3NhzTxTQnwvObE4rIizHfogGTTm6IuynZ0Wqi1b/OYjvMMw6VU5i
QT/aO1MCynyxn7f7uZOaydjPlxSi6rJbCZAf7Zqvob+YA/lS61ZOZK0Q4lnP
SwsJYsy3M/cLn3yK83wfduFei9tveF5J2D1fTP6Ez8Pa2taCh/tvS1Iy/SwP
51H+yFdQdDh4nhV63o6yD4N+Xp2rd7UfxP+Dfl3E9Zxw7Cd4TTw3UpAK+TZH
L+YuBmL/RT4hkSf5GN/9etZCTf0YPv+/sr9dxcH1Otu9V2BXzYD77S0Zbjsx
hflXGmzNFhZxfqL+7iuBUpz/2Jk7AqJpIbgkMv09JR3nF3JHfL/m4PwFHtRB
cTPOP/icXUlSeEF/xANdtLF8nL9O0lXtdxD7mT0udvYPYeP7qNh4+XYznN8s
sS3Isx7jjxgSRvYn4rx3AyRb+vriIH+806l2xyjGpzEvR4vJTKjfenihU2qA
+ZYTA05nQqiQL4hKvH/zJebHvjHJfKPE9Ro5plNZvhXP92cLi04Jnbhe8yd5
EaIYXC9NygohvxzXK5RDFhlo/ud8gf4U3yk+5wVi/T+cDDevL0uHePOaUVca
CdfnyMq5rvOXMF5oK9BOpuN8BaJ4XYbvUTzfqEx9zjDGq22ueSzTxvjPHunN
vqsNh3gN1QveRnMYPx+w6UUs6wD0y9jnmC3YhvlmWnE/2zACcX8NeNLClP9f
b+n8S8/bpfvnY/zS6x/9N1kYnbk=
   "], {{{}, 
     {Hue[0.67, 0.6, 0.6], Opacity[0.2], EdgeForm[None], 
      GraphicsGroupBox[
       PolygonBox[{{123, 142, 143, 89, 105, 56, 62, 28, 55, 27, 54, 26, 79, 
        66, 94, 75, 113, 88, 134, 104}}]]}, {}, {}}, {{}, {}, 
     {Hue[0.67, 0.6, 0.6], 
      LineBox[{1, 117, 98, 82, 69, 59, 51, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12,
        13, 14, 15, 16, 17, 18, 19, 20, 21, 22, 23, 24, 118, 99, 83, 70, 60, 
       52, 122, 103, 87, 74, 65, 25, 119, 100, 84, 71, 61, 125, 107, 91, 78, 
       129, 111, 96, 132, 115, 136, 53}], 
      LineBox[{123, 104, 134, 88, 113, 75, 94, 66, 79, 26, 54, 27, 55, 28, 62,
        56, 105, 89}], 
      LineBox[{131, 114, 135, 76, 128, 110, 95, 67, 126, 108, 92, 80, 29, 120,
        101, 85, 72, 63, 57, 30, 31, 32, 33, 34, 35, 36, 37, 38, 39, 40, 41, 
       42, 43, 44, 45, 46, 47, 48, 49, 121, 102, 86, 73, 64, 58, 124, 106, 90,
        77, 68, 127, 109, 93, 81, 130, 112, 97, 133, 116, 137, 50}]}, 
     {Hue[0.67, 0.6, 0.6], Opacity[0.2], LineBox[{140, 139}], 
      LineBox[{141, 138}]}}, {{}, {}, {}}}],
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesOrigin->{0, 0},
  Method->{"AxesInFront" -> True},
  PlotRange->{{-1, 1}, {0., 2.8284271247461903`}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02]}]], "Output",
 CellChangeTimes->{3.521591822628817*^9, 3.521592280185858*^9, 
  3.521669387231584*^9}]
}, Open  ]],

Cell[TextData[{
 "\n\n",
 Cell[BoxData[
  FormBox[
   SubscriptBox["\[Phi]", 
    RowBox[{"4", ",", " ", "0"}]], TraditionalForm]]]
}], "Text",
 CellChangeTimes->{{3.5215921120004*^9, 3.52159211681218*^9}, {
  3.521592348508727*^9, 3.521592348654522*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"\[Phi]", "[", 
    RowBox[{"x", ",", "4", ",", "0"}], "]"}], ",", " ", 
   RowBox[{"{", 
    RowBox[{"x", ",", 
     RowBox[{"-", "1"}], ",", "1"}], "}"}], ",", 
   RowBox[{"Filling", "\[Rule]", "Axis"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.521591284078165*^9, 3.521591295868864*^9}, {
  3.521592289094667*^9, 3.521592289465561*^9}}],

Cell[BoxData[
 GraphicsBox[GraphicsComplexBox[CompressedData["
1:eJx11Asw1HkcAPD1Gqxsyx3OySvlWEaoGK/jIifleXVELJowKHIchqTNXRiV
Q+WK0i0d0S4hR5vNYw9JHuuV9X6dR7sSrrXT4+7muu/3zsztzM7OZ37f7+/3
/X3/+/9qB0V6nhAnEAi5f37/+jWyVV58/36ZTfjwietKPRnSIAD39cktNgby
weqPIz823/YCXBPeIrV1dBEckGny8jltASzMTkxj286D6aQx1bzJOXC+s0k0
N30WTIsIjNc/MANOlLgbF82fAgemdO0YKJkEX3k0m5cfNgGuH9fbUr59DKxD
ttt3+CYPfJ+SFjY1PQQe51RqmZkNgGcNr5iyH3DBCsmlZkZiPWBDs2XD4tWn
4PMO/O66+Faw0mFG1lGVJjzvd87Wth314GLe7MWFVAbYz2NbNe94LriOmNjf
FJtj+7fIdnunxDTOeTPBOi8fblg21dn+E3+A/rzT1bsJvN9FUWK9phV8mTqY
Ylz7FNzqqi7vrtgD5msrJfde54JjYwwCLysPgAdHyJ7BbUPggATr36QP8cDN
BuYZzVJjYF1Z1nyR0wRYnRW+XyptEkwQiZdGT02BX3s88ufsnAHz9lDVdqbO
gqO8yArbR+bAqrkz3pLq82CGb+HPq/ELYC+bs05tjxbBlf4nt1u+WQILifYS
dUf4YM8eKzP1PAH4w/uA6xc6y3ZT8f2giIuqwn2LwCl9en1qzTbg9iqqQ2V6
ETyvW1H+LTa11bCfz41a5wgLNthORj+LdAjPs5teefIjE8+bFywXUqJKwcy1
CJ354VTwaAVTn21yH/IbOBY/cc+wwO0RptNKr/B+QxSZS0cv3oT8kBBK8IN3
NKg30FieyrKuhfhauqaN9B2sz1whdfjpINbnOBumkiEqA1d39HLcei6B37h7
j7wXVED+y2GRi7TWQzBJszZTlYP1dcidtdnScxvym7XSLxSQo6G+lO4ahbcb
NRD/5kjRHDEB6/vKiiQu1h4L+Q1k6bjkmCpYj/g8S0ZjPRP2i165niPBxXxT
PZeguSW837cBJb11tvdwXvFoHV/M/QCWu12+t9AF75dxgqejfboebByfEHiD
gfcTfc8SWinTcb7lOD4J3xMA9WRpEcMLvPF+Gszgh5lBWJ+3YkxRKPss5D8L
8O3W4OLzz3X2C/2OhfEvCJLnqVmV4LbXAn0p6SQ470abO9u0OAT2c88baji3
gPkVVSa6q+vYD5LGlxUeU9iPpKtdbNLOHPCS/fEzoeU4rwbudpAYqtiPxqLh
g8fo2I9sB98B7i/Yj4EV2i2y0Any85yqr/GlsR9MXmuxixfWJ0jmWrr60TA/
TertKRr2QzeuwdOxEuPX9BhMpi32o9uNZ9zZGQX5ky0WpfvGMF4yQVzW/SY+
35Sw8gguJQzqM5jut7jq5wv57PC4vsdrmB+5oZO2IcL+DScp3yrYjfP/xeq6
RWwL9s+o3mvFuBT7l9Rpn7rGx3lPtJJrZBVg//zpFI4mEeeRbva9lomNXZCf
f0yWcWUc54/wtPBThgfW98xCa5da/nmsL9/nIxUf7N8p+eXWO2UYL7SW+NVL
BfuXzYlRDTn4Dc5H3zAN+hDGy1z00hTGYv8+GVUXvCsNgngZ8ZID2ssYT/R3
bezQ/9e8cPvsVWT013Af3S1R14xCPPD97HekBogw/8P9/7cfm9c3n7f5//vf
/M3rBMIfTwVxdQ==
   "], {{{}, 
     {Hue[0.67, 0.6, 0.6], Opacity[0.2], EdgeForm[None], 
      GraphicsGroupBox[
       PolygonBox[{{126, 147, 148, 102, 122, 27, 54, 26, 80, 65, 96, 75, 116, 
        89, 139, 106}}]]}, {}, {}}, {{}, {}, 
     {Hue[0.67, 0.6, 0.6], 
      LineBox[{1, 119, 99, 82, 68, 58, 51, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12,
        13, 14, 15, 16, 17, 18, 19, 20, 21, 22, 23, 24, 120, 100, 83, 69, 59, 
       52, 125, 105, 88, 74, 64, 25, 121, 101, 84, 70, 60, 129, 109, 92, 78, 
       133, 113, 97, 136, 117, 140, 53, 142}], 
      LineBox[{126, 106, 139, 89, 116, 75, 96, 65, 80, 26, 54, 27, 122, 102}],
       LineBox[{138, 85, 135, 115, 71, 132, 112, 95, 61, 130, 110, 93, 79, 55,
        127, 107, 90, 76, 66, 28, 123, 103, 86, 72, 62, 56, 29, 30, 31, 32, 
       33, 34, 35, 36, 37, 38, 39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 49, 
       124, 104, 87, 73, 63, 57, 128, 108, 91, 77, 67, 131, 111, 94, 81, 134, 
       114, 98, 137, 118, 141, 50}]}, 
     {Hue[0.67, 0.6, 0.6], Opacity[0.2], LineBox[{144, 143}], 
      LineBox[{146, 145}]}}, {{}, {}, {}}}],
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesOrigin->{0, 0},
  Method->{"AxesInFront" -> True},
  PlotRange->{{-1, 1}, {0., 4.}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02]}]], "Output",
 CellChangeTimes->{3.5215912976442223`*^9, 3.521592290380484*^9, 
  3.521669391670383*^9}]
}, Open  ]],

Cell["\<\


All together: \
\>", "Text",
 CellChangeTimes->{{3.5215921359681883`*^9, 3.52159213808134*^9}, {
  3.5215923509495697`*^9, 3.5215923510733547`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"Evaluate", "[", 
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"\[Phi]", "[", 
       RowBox[{"x", ",", "j", ",", "0"}], "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"j", ",", "0", ",", "4"}], "}"}]}], "]"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"x", ",", 
     RowBox[{"-", "1"}], ",", "1"}], "}"}], ",", 
   RowBox[{"Filling", "\[Rule]", "Axis"}], ",", " ", 
   RowBox[{"PlotRange", "\[Rule]", "All"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.521591151170738*^9, 3.521591181613626*^9}, {
  3.521591307413966*^9, 3.521591310876596*^9}, {3.5215922936741743`*^9, 
  3.521592314195743*^9}}],

Cell[BoxData[
 GraphicsBox[GraphicsComplexBox[CompressedData["
1:eJztmnlYzdsax38adomyjQkNRCqkHHITZ//uMYUTylBHNBiqp0Ii6QqdCung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   "], {{{}, 
     {Hue[0.67, 0.6, 0.6], Opacity[0.2], EdgeForm[None], 
      GraphicsGroupBox[
       PolygonBox[{{89, 686, 687, 50, 55, 49, 48, 47, 46, 45, 44, 43, 42, 41, 
        40, 39, 38, 232, 37, 36, 35, 34, 33, 32, 375, 31, 30, 29, 519, 28, 
        668, 27, 54, 26, 67, 60, 74, 65, 83, 72, 93, 80}}]]}, {}, 
     {Hue[0.9060679774997897, 0.6, 0.6], Opacity[0.2], EdgeForm[None], 
      GraphicsGroupBox[
       PolygonBox[{{217, 684, 685, 220, 163, 172, 152, 158, 133, 151, 132, 
        131, 130, 129, 128, 376, 127, 126, 125, 520, 124, 669, 123, 150, 122, 
        175, 162, 189, 171, 207, 184, 228, 199}}]]}, {}, 
     {Hue[0.1421359549995791, 0.6, 0.6], Opacity[0.2], EdgeForm[None], 
      GraphicsGroupBox[
       PolygonBox[{{360, 682, 683, 351, 368, 326, 342, 293, 299, 268, 292, 
        267, 266, 521, 265, 670, 264, 291, 263, 316, 303, 331, 312, 350, 325, 
        371, 341}}]]}, {}, 
     {Hue[0.37820393249936934`, 0.6, 0.6], Opacity[0.2], EdgeForm[None], 
      GraphicsGroupBox[
       PolygonBox[{{504, 680, 681, 470, 486, 437, 443, 409, 436, 671, 408, 
        435, 407, 460, 447, 475, 456, 494, 469, 515, 485}}]]}, {}, 
     {Hue[0.6142719099991583, 0.6, 0.6], Opacity[0.2], EdgeForm[None], 
      GraphicsGroupBox[
       PolygonBox[{{652, 678, 679, 628, 648, 553, 580, 552, 606, 591, 622, 
        601, 642, 615, 665, 
        632}}]]}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, \
{}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}}, {{}, {}, 
     {Hue[0.67, 0.6, 0.6], 
      LineBox[{1, 85, 76, 68, 61, 56, 51, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 
       13, 14, 15, 16, 17, 18, 19, 20, 21, 22, 23, 24, 86, 77, 69, 62, 57, 52,
        88, 79, 71, 64, 59, 25, 87, 78, 70, 63, 58, 90, 81, 73, 66, 91, 82, 
       75, 92, 84, 94, 53}], 
      LineBox[{89, 80, 93, 72, 83, 65, 74, 60, 67, 26, 54, 27, 668, 28, 519, 
       29, 30, 31, 375, 32, 33, 34, 35, 36, 37, 232, 38, 39, 40, 41, 42, 43, 
       44, 45, 46, 47, 48, 49, 55, 50}]}, 
     {Hue[0.9060679774997897, 0.6, 0.6], 
      LineBox[{97, 211, 193, 178, 165, 155, 147, 98, 99, 100, 101, 102, 103, 
       104, 105, 106, 107, 108, 109, 110, 111, 112, 113, 114, 115, 116, 117, 
       118, 119, 120, 212, 194, 179, 166, 156, 148, 216, 198, 183, 170, 161, 
       121, 213, 195, 180, 167, 157, 219, 201, 186, 174, 222, 204, 190, 226, 
       209, 230, 149}], 
      LineBox[{217, 199, 228, 184, 207, 171, 189, 162, 175, 122, 150, 123, 
       669, 124, 520, 125, 126, 127, 376, 128, 129, 130, 131, 132, 151, 133, 
       158, 152, 172, 163, 220}], 
      LineBox[{202, 229, 187, 225, 208, 176, 223, 205, 191, 134, 214, 196, 
       181, 168, 159, 153, 135, 136, 137, 138, 139, 140, 141, 142, 143, 144, 
       145, 215, 197, 182, 169, 160, 154, 218, 200, 185, 173, 164, 221, 203, 
       188, 177, 224, 206, 192, 227, 210, 231, 146}]}, 
     {Hue[0.1421359549995791, 0.6, 0.6], 
      LineBox[{238, 354, 335, 319, 306, 296, 288, 239, 240, 241, 242, 243, 
       244, 245, 246, 247, 248, 249, 250, 251, 252, 253, 254, 255, 256, 257, 
       258, 259, 260, 261, 355, 336, 320, 307, 297, 289, 359, 340, 324, 311, 
       302, 262, 356, 337, 321, 308, 298, 362, 344, 328, 315, 366, 348, 333, 
       369, 352, 373, 290}], 
      LineBox[{360, 341, 371, 325, 350, 312, 331, 303, 316, 263, 291, 264, 
       670, 265, 521, 266, 267, 292, 268, 299, 293, 342, 326, 368, 351}], 
      LineBox[{372, 313, 365, 347, 332, 304, 363, 345, 329, 317, 269, 357, 
       338, 322, 309, 300, 294, 270, 271, 272, 273, 274, 275, 276, 277, 278, 
       279, 280, 281, 282, 283, 284, 285, 286, 358, 339, 323, 310, 301, 295, 
       361, 343, 327, 314, 305, 364, 346, 330, 318, 367, 349, 334, 370, 353, 
       374, 287}]}, 
     {Hue[0.37820393249936934`, 0.6, 0.6], 
      LineBox[{382, 498, 479, 463, 450, 440, 432, 383, 384, 385, 386, 387, 
       388, 389, 390, 391, 392, 393, 394, 395, 396, 397, 398, 399, 400, 401, 
       402, 403, 404, 405, 499, 480, 464, 451, 441, 433, 503, 484, 468, 455, 
       446, 406, 500, 481, 465, 452, 442, 506, 488, 472, 459, 510, 492, 477, 
       513, 496, 517, 434}], 
      LineBox[{504, 485, 515, 469, 494, 456, 475, 447, 460, 407, 435, 408, 
       671, 436, 409, 443, 437, 486, 470}], 
      LineBox[{512, 495, 516, 457, 509, 491, 476, 448, 507, 489, 473, 461, 
       410, 501, 482, 466, 453, 444, 438, 411, 412, 413, 414, 415, 416, 417, 
       418, 419, 420, 421, 422, 423, 424, 425, 426, 427, 428, 429, 430, 502, 
       483, 467, 454, 445, 439, 505, 487, 471, 458, 449, 508, 490, 474, 462, 
       511, 493, 478, 514, 497, 518, 431}]}, 
     {Hue[0.6142719099991583, 0.6, 0.6], 
      LineBox[{527, 645, 625, 608, 594, 584, 577, 528, 529, 530, 531, 532, 
       533, 534, 535, 536, 537, 538, 539, 540, 541, 542, 543, 544, 545, 546, 
       547, 548, 549, 550, 646, 626, 609, 595, 585, 578, 651, 631, 614, 600, 
       590, 551, 647, 627, 610, 596, 586, 655, 635, 618, 604, 659, 639, 623, 
       662, 643, 666, 579, 673}], 
      LineBox[{652, 632, 665, 615, 642, 601, 622, 591, 606, 552, 580, 553, 
       648, 628}], 
      LineBox[{664, 611, 661, 641, 597, 658, 638, 621, 587, 656, 636, 619, 
       605, 581, 653, 633, 616, 602, 592, 554, 649, 629, 612, 598, 588, 582, 
       555, 556, 557, 558, 559, 560, 561, 562, 563, 564, 565, 566, 567, 568, 
       569, 570, 571, 572, 573, 574, 575, 650, 630, 613, 599, 589, 583, 654, 
       634, 617, 603, 593, 657, 637, 620, 607, 660, 640, 624, 663, 644, 667, 
       576}]}, 
     {Hue[0.67, 0.6, 0.6], Opacity[0.2], LineBox[{96, 233, 95}], 
      LineBox[{236, 377, 235}], LineBox[{237, 234}], LineBox[{380, 522, 379}],
       LineBox[{381, 378}], LineBox[{525, 672, 524}], LineBox[{526, 523}], 
      LineBox[{675, 674}], 
      LineBox[{677, 676}]}}, {{}, {}, {}, {}, {}, {}, {}}}],
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesOrigin->{0, 0},
  Method->{"AxesInFront" -> True},
  PlotRange->{All, All},
  PlotRangeClipping->True,
  PlotRangePadding->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{{3.521591159838154*^9, 3.5215911839037457`*^9}, {
   3.5215913078403463`*^9, 3.521591311410816*^9}, {3.5215922949698353`*^9, 
   3.521592315008503*^9}, 3.521669394671089*^9}]
}, Open  ]],

Cell[TextData[{
 "\nLet\[CloseCurlyQuote]s keep J = 2 and vary k i.e. translate to righ:\n\n\
",
 Cell[BoxData[
  FormBox[
   SubscriptBox["\[Phi]", 
    RowBox[{"2", ",", " ", "0"}]], TraditionalForm]]]
}], "Text",
 CellChangeTimes->{{3.521592508261877*^9, 3.521592519961548*^9}, {
  3.521592595064259*^9, 3.5215926176486607`*^9}, {3.5215928552985907`*^9, 
  3.521592860448964*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"\[Phi]", "[", 
    RowBox[{"x", ",", "2", ",", 
     RowBox[{
      SuperscriptBox["2", "0"], "-", "1"}]}], "]"}], ",", " ", 
   RowBox[{"{", 
    RowBox[{"x", ",", 
     RowBox[{"-", "1"}], ",", "1"}], "}"}], ",", 
   RowBox[{"Filling", "\[Rule]", "Axis"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.521592532251596*^9, 3.5215925796605587`*^9}, {
  3.521592661930634*^9, 3.521592664629942*^9}}],

Cell[BoxData[
 GraphicsBox[GraphicsComplexBox[CompressedData["
1:eJxl1Q0w1GkYAPCNM5zYcCGFJVGW8VW3DjmuJCqfCbUnS3e2WcRtHC6DNnep
oYREUd3tqpwip49TW+trx1fysdFmSyzLIl/hrL0mdzfjnufGmdkxv3mf5/8+
z/vf91nj8Bj/bxUIBML5vz///Ldy0RlbWpriEZb/EtrTo+lPJ8EvXqweqw2b
ABvUxKy1138Hvh/ZoLTmzRiYlmk7/Yo1CpblnMjguUjBbGKfXsHAMLhojy1T
cEYCZkWFJZp7DoFPKP6awJwQg8PS2jf13BoAX3wiKShi9IMfvd2idntjH9hE
w3VHwFUR+DdyBkM8KAS/5VcaUSg9YInlRTveAwFYM6WUYrWqE2xJmbIsmX0G
PuU20VGd2AjWDijPPqhbh/v9wV/TtOkRuEQkyRpNLweH+OnfEx3JA1ernuiu
i891Wabr5+JVhieDK8Am048XHeuqwZ7sV23ewXXgXV5aivP3G8HnQ1+m2Tx8
Bm70NlD31er814QJY+2UrssCcHycRdh5nR7wy9ca/hFNQjAtafuI8j4RuN7C
/my9Uh/Y7FOulOPRDzbgRu5SyhgAE+QKpUyxGLzg9+Qw33QILNoWusE0XQKO
DdLQ3Ph6GKyXNxT8iYEUXE69fnM2cRQc5Jzq0fRkDFx5OHqj44dxsEx1p2L1
gQmwf6cTxaBgErx8H3D9dFvZ1lC8H2QFeVUklQN2ULK+2S9xAzdXhbpVnuHA
eTN65mpzKC3gcx8zvKTR7eBDXxTuuhDYBfu5qphnE/fh/q6DMy2FFbi/dHLq
Ojm2FFwxF2Ui7U0HE61t6Jlaz+H52TuppbH38H03R9kNar/HfoVklXMHs65C
Pp1OjnjwkQX5yiPTer980wHxD9kkZ+UbWJ+9Znrvs5dYn7uEoXtWXga+19rF
9+k8h/fHczuVdgTrIZIeZurxsZ7W1anOap0/Q3y90ZnTxRpMqGdz1SGjVnWs
58MBzrBqEtaz34mosKo5HvKjvsxWMZzPhPyR9ac/S3qM+cyZy7mKAsy32+IV
PjyO/XxPu9VV7XIH55WI1frV8AWwvNVym9AR+7FJTAq7Uo79yH/iypx02DjP
ct1bIrfRoJ5jdqTdvAb8PhhWRDzODMd6grXiOEd5qZC/QODmq2dj/Xl7Qo7+
yMX4poVJcyXlZHiebptpMcUB4680+fLsSujwPN8C4dOTo5h/t8rWbHYe+yca
7r7rJ8b+k/PbeUTTXJz36iVGeWbYfy2nd+/XbOw/x43aI/gd+++ZYV3TkHlA
fSnrAlr2F2L/FaLGEq8grGcyReDoHcKC/KXjgcKgH7Afs4Sn/u6VGE9yrelL
M8H1Dh+RTVtbLOQPNDiU7ujD+DTG7SgBmQH7/9kRTFo/jvVYDHY75IdQIZ8X
mfCiZg7zYxZNMhbleF69yTrXirfifH83O+8Q34DntdZqQIepj+el6rS6lluM
53WYTeaTVP83X6Ae2Xey9eV+uP9zByPrDUWn8Pfojslicgz2f0x9qvFGGcaz
k7KWStbheg4/To++9zjONyrDkC3E+AheulJ8L57HujcGkx9LwyFeReGWp/EU
xk/7bH4fwwyE+FOX9k8zVf/zvtRiL1nR/fB+dbuH0uSYvzJ+Zf8r5+3K97Ui
fuU64S8GmFkO
   "], {{{}, 
     {Hue[0.67, 0.6, 0.6], Opacity[0.2], EdgeForm[None], 
      GraphicsGroupBox[
       PolygonBox[{{123, 142, 143, 114, 131, 89, 105, 56, 62, 31, 55, 30, 29, 
        28, 27, 54, 26, 79, 66, 94, 75, 113, 88, 134, 
        104}}]]}, {}, {}}, {{}, {}, 
     {Hue[0.67, 0.6, 0.6], 
      LineBox[{1, 117, 98, 82, 69, 59, 51, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12,
        13, 14, 15, 16, 17, 18, 19, 20, 21, 22, 23, 24, 118, 99, 83, 70, 60, 
       52, 122, 103, 87, 74, 65, 25, 119, 100, 84, 71, 61, 125, 107, 91, 78, 
       129, 111, 96, 132, 115, 136, 53}], 
      LineBox[{123, 104, 134, 88, 113, 75, 94, 66, 79, 26, 54, 27, 28, 29, 30,
        55, 31, 62, 56, 105, 89, 131, 114}], 
      LineBox[{135, 76, 128, 110, 95, 67, 126, 108, 92, 80, 32, 120, 101, 85, 
       72, 63, 57, 33, 34, 35, 36, 37, 38, 39, 40, 41, 42, 43, 44, 45, 46, 47,
        48, 49, 121, 102, 86, 73, 64, 58, 124, 106, 90, 77, 68, 127, 109, 93, 
       81, 130, 112, 97, 133, 116, 137, 50}]}, 
     {Hue[0.67, 0.6, 0.6], Opacity[0.2], LineBox[{140, 139}], 
      LineBox[{141, 138}]}}, {{}, {}, {}}}],
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesOrigin->{0, 0},
  Method->{"AxesInFront" -> True},
  PlotRange->{{-1, 1}, {0., 2.}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02]}]], "Output",
 CellChangeTimes->{3.521592586659831*^9, 3.521669396574861*^9}]
}, Open  ]],

Cell[TextData[{
 "\n",
 Cell[BoxData[
  FormBox[
   SubscriptBox["\[Phi]", 
    RowBox[{"2", ",", " ", "1"}]], TraditionalForm]]]
}], "Text",
 CellChangeTimes->{{3.521592869699058*^9, 3.521592870474842*^9}, {
  3.521592914331209*^9, 3.5215929145140343`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"\[Phi]", "[", 
    RowBox[{"x", ",", "2", ",", "1"}], "]"}], ",", " ", 
   RowBox[{"{", 
    RowBox[{"x", ",", 
     RowBox[{"-", "1"}], ",", "1"}], "}"}], ",", 
   RowBox[{"Filling", "\[Rule]", "Axis"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.52159264289303*^9, 3.5215926753629417`*^9}, 
   3.5215927260526123`*^9, 3.521592890480978*^9}],

Cell[BoxData[
 GraphicsBox[GraphicsComplexBox[CompressedData["
1:eJx1lAk01XkUxx+SbayNxFiyLzkG0zxDORyNQnHyrCPZkgyhnCxvNCqEKUmW
CaEJz9JCxpSxvYfoyZJ9F3n27dmzZJiZc+pexzm9c/7nnc/5fe+933t/9/+X
dvEhnWclEAhR/z3//6vp7Z/a3p6jET79AprCvC5QmcDt7TxTlc6zwBIVPl9r
ic8Av/CsZud/NwXsFKUx3xMyCbwWGxRJ05sAzuAbEE0cGgNOMdHwbfttFDjk
onOgsvEIcBDb4wDfWQaw8/Umuc6cIeCE8tHEFI/3wCWDSl89lRkAlhXQN7BM
6wP+UyXSgzHcDTxYU3CQSOwEHlVN0KS9bAMWDM4lqrG0AKsS51QpSw3AoT/O
NhcH0oGFLfNifhKpwnofavhr5UqAKX2jdybD8oDPmov/1XcuHriYO6ijyi9O
7zN/z2CRvGGbDyw7X7quU1UMbJzR02hmWwVsaCrEtvKCDnzXseu6elEDMN1M
gve0UMtn1p+VFg5uTW4D9rtyyPnu/k7grn4BklttN7AT+eg4x6k+4FeHtG69
Yh8AVuAqm8g0eg/1JMo8Ddkjh4AJG6y5vgwG8Kp5uUON/Ahw32HHb+TDRoEv
2QgIyvSPAYvGj9jukZgAzjvzR/ZS4CSwje41o9ryKeACBy8Znc1p4DXuY2zF
VrPApJYjRIlEJvCn9wHPIxqffOeI74dH53JlLLEOzqO3Ik0nvJqA7X5IMrxn
3QrziG0t/ns0px+Y82HXs/CTg8DpjH0iVhM4L31O5Ri+U1hff3ihLikf63ff
C2Uc+1AL53zfql+IEnoL7HaeQ5ySg/cxsjK+fTUR87+5qDksvIj9boq5PRry
rwfmGJ8XTXdthvjH3dl67kz0W5QhpcuRhf60BMN6G7rQX/Rcna+4Nfozo7Nd
GXBtBL65bb4ccwn98EkVRYnWoJ/CwGcaJZ04X8VCu4P1vOinp5Tmv5qCfjat
Mse4yejn7e/2djoVOI9xsYh95FKMp26cCJuRwvq+C8lxbG0Yr6lk6jI2veO+
05glnHuxH+84r184+LAf6z0RzGR7zKceSHZ+kIf9RCu2kLPCsR9vTakTtGrc
F8l8t9IoF6zPdHntdO5n9H9riZcUw4P5403Out8sQ71Io3wqURv7y6tbtBAU
wfyLLCEvjQ5j/OnEbuqNSYx/XqihsLSyY7/8CINb7/D7EUxO/+cBA78f1PBH
0w9JmK8ys/ekfcaOfdpipKY4YL/BByzrLJLQT34fnWJqg/W3jD4Or+piv5X1
yoHa7JhfIYBKOl6AeupzxS7KNOptt1xTxVRQP1StnWswgPqPzbZSYtNYX25V
xZMqjHqaZ0B7xTLqfdZlI9c3duyzM9fC+hucR/jMUb2xBpzHIl3NI90U83Ef
4aksS92xz1PT+fdNcB7ht5k8aaHoZ+3ymlieOdbfW5Ygb6CE/f3q/pT/zgru
uzfvHD3rCepfy1YdmO9A/e2rnTFs8uhH5YyHZEY36t1oYex+vVjfxi/FIVsA
9ZysOcbSc6j3pxRHcuWjvvzyNUPyXtSH3reY9+XG/fPvOO7otDH3xfvcrd99
P7v73aXffU74FyBAWR4=
   "], {{{}, 
     {Hue[0.67, 0.6, 0.6], Opacity[0.2], EdgeForm[None], 
      GraphicsGroupBox[
       PolygonBox[{{133, 139, 140, 123, 67, 76, 56, 62, 37, 55, 36, 35, 34, 
        33, 54, 32, 79, 66, 93, 75}}]]}, {}, {}}, {{}, {}, 
     {Hue[0.67, 0.6, 0.6], 
      LineBox[{1, 114, 97, 82, 69, 59, 51, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12,
        13, 14, 15, 16, 17, 18, 19, 20, 21, 22, 23, 24, 25, 26, 27, 28, 29, 
       30, 115, 98, 83, 70, 60, 52, 119, 102, 87, 74, 65, 31, 116, 99, 84, 71,
        61, 122, 105, 90, 78, 125, 108, 94, 53, 120, 103, 131, 88, 128, 111}],
       LineBox[{133, 75, 93, 66, 79, 32, 54, 33, 34, 35, 36, 55, 37, 62, 56, 
       76, 67, 123}], 
      LineBox[{106, 132, 91, 129, 112, 80, 126, 109, 95, 38, 117, 100, 85, 72,
        63, 57, 39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 49, 118, 101, 86, 73, 
       64, 58, 121, 104, 89, 77, 68, 124, 107, 92, 81, 127, 110, 96, 130, 113,
        134, 50}]}, 
     {Hue[0.67, 0.6, 0.6], Opacity[0.2], LineBox[{137, 136}], 
      LineBox[{138, 135}]}}, {{}, {}, {}}}],
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesOrigin->{0, 0},
  Method->{"AxesInFront" -> True},
  PlotRange->{{-1, 1}, {0., 2.}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02]}]], "Output",
 CellChangeTimes->{
  3.521592678162507*^9, {3.5215928870976133`*^9, 3.521592891418013*^9}, {
   3.5216693994633636`*^9, 3.521669404934586*^9}}]
}, Open  ]],

Cell[TextData[{
 "\n\n",
 Cell[BoxData[
  FormBox[
   SubscriptBox["\[Phi]", 
    RowBox[{"2", ",", " ", "2"}]], TraditionalForm]]]
}], "Text",
 CellChangeTimes->{{3.5215929196078987`*^9, 3.5215929246054697`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"\[Phi]", "[", 
    RowBox[{"x", ",", "2", ",", "2"}], "]"}], ",", " ", 
   RowBox[{"{", 
    RowBox[{"x", ",", 
     RowBox[{"-", "1"}], ",", "1"}], "}"}], ",", 
   RowBox[{"Filling", "\[Rule]", "Axis"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.521592692150412*^9, 3.521592695389493*^9}, 
   3.521592731375942*^9, 3.521592894316437*^9}],

Cell[BoxData[
 GraphicsBox[GraphicsComplexBox[CompressedData["
1:eJx1kwkwHGYUxxdVgnW1ZKSWOouoIhsaSWZFS4kwCCERZxtRR8UWy6g4shE1
UsbREdGDdYbYiiQiLHGrUBG3dS4rjrBxhd1K03aavGfMdGd2dn7zvfd////7
9lPzDXG6IEwgEH745/vvrwFFcfH1a14D4c2H1kMPvli/AtzfL7nY6LMMTHoU
8r6p8nPge4EtojLji8DeKUYvRhIWgLfTo5MaKPPADOkJpezpOeDck0bUvu+5
wAlBPpG6NrPA0SK3aNRlDrBPXI/mYMk0cBaLm50bMAX8cFJHqlx9AlhD1tzC
+Wc28B29pADOzDDwZGvlhyYmg8Bc/Szjhvt9wHKXS00MhHqB9U14+oXrXcBX
Pl9+UhPZDqzgXJF2dn8TznvZKtOh+RC4kM29vkCvAPZwVL7L/jITuEYieqAp
PIPylg9zhFTi3ZjAGi9q+WZNNcA2jJFue7cmYEs7eZHNe+3AqV5DcYbVXcDt
9iSig3wv8LKawuWnOX3A4WEHfVIVB4GHxmSd/DqGgb2jjj0TO8UGbj5omtws
OgGsva9uvsB66i2bk+oCLUWTpoEJAuFSKocDvOXI8mzVmgVmk70+0KJzgS+5
ysqpj80BK2XOur1Dmod5Fe6/Fq9HLgC7Ho+17mAtAld6Bqub7SwBb0t8JlLj
sgzs1HvUhJS9AvzmPeD5te6yQ174PtKf1jzglozBufgvQ7cTbSeB8znv7XeZ
x/zabaY/ahii/5ZwATnju2fAszQLwk4n5jEX102TPoXzzWdWO28wcT5f68+e
CAHu3++CmHJhCe4/x0+UcU4f9f+6mqFPCEP934OMZxTWMK9ebGSes+s48K3h
Yor/CuZZofPaHnehXjVD9bhYEfozlaOPdg2hv/Kem+4UBvrLtFY9TXZFf1LE
OosEa/QjrVqdotSKfiZ0lD4mEdDPSG1DxFYu+jn7aiOGWYB+dlwK5iSidvlJ
4M0qCHBeveAL+nNVvA+61KLM/Ab2U1dzMkT6sN9Yx853bgnzJGoG5TFomEff
rGwl2gD10x2e2DUbYx7DyCifmxWY50HMAjW+H/8vl27bylPCMI8K0682xRfn
//FtdJxHL+onrxOd0iTRf01H0NLIFPrPPOnhf7UO+y06D7GZrai/JpRw35qM
/fYOF8kvxdGvQ/ZwffwC9v9WZaS9von51+2dWwZ8MP+2cWid6gH0d4Z6rm/m
I9RrLBi1Pc/A/FolvVlV9Zj/WJHcFMcL/THZ7YV2rjg/J+iEvRAL9Rsf60Ye
Ed31nmj1TlaVWC/dzC85XYl6FPLgtTYB7me65UipxQTWa27pBdYroF5EbzBR
ahT7yWuFVq/kMU9DIK3/0Qb2h/A1kvgC3I/eVx0DK2dwP56fODNWZdD/p1dU
FcPUUU/iqGRj3U+4n/Msy+KuKtxPfv5G210X9LMdun2gwhHnE77WPNx3B/Vj
/Mtlrm9i/TdEXntRGdaHNYylahXjeYTHvhtLfNyPnnuACmMY68e6HTbGe7D+
RF4ii09E/+LCJTZqPKxnhcZaRr2L+/zvvrBediBZ22x21/wBKy9vAe9/73dv
/9773Jt3T//eesLf+E1gvw==
   "], {{{}, 
     {Hue[0.67, 0.6, 0.6], Opacity[0.2], EdgeForm[None], 
      GraphicsGroupBox[
       PolygonBox[{{107, 141, 142, 110, 128, 80, 92, 67, 76, 56, 62, 43, 55, 
        42, 41, 40, 39, 54, 38, 95, 79, 112, 91, 133}}]]}, {}, {}}, {{}, {}, 
     {Hue[0.67, 0.6, 0.6], 
      LineBox[{1, 116, 98, 82, 69, 59, 51, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12,
        13, 14, 15, 16, 17, 18, 19, 20, 21, 22, 23, 24, 25, 26, 27, 28, 29, 
       30, 31, 32, 33, 34, 35, 36, 117, 99, 83, 70, 60, 52, 121, 103, 87, 74, 
       65, 37, 118, 100, 84, 71, 61, 124, 106, 90, 78, 53, 122, 104, 88, 75, 
       127, 109, 94, 130, 113, 135, 66, 125}], 
      LineBox[{107, 133, 91, 112, 79, 95, 38, 54, 39, 40, 41, 42, 55, 43, 62, 
       56, 76, 67, 92, 80, 128, 110}], 
      LineBox[{134, 96, 131, 114, 44, 119, 101, 85, 72, 63, 57, 45, 46, 47, 
       48, 49, 120, 102, 86, 73, 64, 58, 123, 105, 89, 77, 68, 126, 108, 93, 
       81, 129, 111, 97, 132, 115, 136, 50}]}, 
     {Hue[0.67, 0.6, 0.6], Opacity[0.2], LineBox[{139, 138}], 
      LineBox[{140, 137}]}}, {{}, {}, {}}}],
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesOrigin->{0, 0},
  Method->{"AxesInFront" -> True},
  PlotRange->{{-1, 1}, {0., 2.}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02]}]], "Output",
 CellChangeTimes->{3.521592697549725*^9, 3.521592732491708*^9, 
  3.521592894755664*^9}]
}, Open  ]],

Cell[TextData[{
 "\n\n",
 Cell[BoxData[
  FormBox[
   SubscriptBox["\[Phi]", 
    RowBox[{"2", ",", " ", "3"}]], TraditionalForm]]]
}], "Text",
 CellChangeTimes->{{3.521592929666276*^9, 3.5215929371450233`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"\[Phi]", "[", 
    RowBox[{"x", ",", "2", ",", "3"}], "]"}], ",", " ", 
   RowBox[{"{", 
    RowBox[{"x", ",", 
     RowBox[{"-", "1"}], ",", "1"}], "}"}], ",", 
   RowBox[{"Filling", "\[Rule]", "Axis"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.521592702658379*^9, 3.521592706753097*^9}, 
   3.521592737499516*^9, 3.521592898164544*^9}],

Cell[BoxData[
 GraphicsBox[GraphicsComplexBox[CompressedData["
1:eJxd0w0slHEcB/ATtySdl0WzuhZ3zNXN6zlzvbiUounCNC8tOkVNTDMv16S8
XMiECUOtN2clRip0csm7dUyi83KFO87LXYeil7NMtdXvt3m2Z88++z37/r7P
s/3NQ6N9wzYQCITwP/ffp42rqXJtbaGZ8O9K6ONHnX89Dx4c3Kxs4arB5DfR
W513fAbXXWwnGnxSgs9k2y+OpM6Bf+YnZja7zoLLSGNmxbJp8J1j9jEDNxTg
1Eguj+Y5BU7UfpIQo5aDucl9VMljGbhQpCi+EzEBbhy31q+yGANTDNlufnel
4Ge7MyPkk8Pg8Y7aXUymBKygFzo01w+Aja5WMG20+sF05gK9fKkHnHZY/U7I
6wKb+FXnBW5rxX3fOwy6qY3gcqni5hy/GnzaZ8cL6dkCsFAv8UNr3C3X/3aS
a+1MCagBUxZfaVitQrBn2UgvJ6AV7H7cWPtbXRc4N2Qo2a6hB9zFIW/xNu4H
q81Nrr4vHQDHxe7h5ppKwEMfDX3Du4fBZy7vm9noJQW37XHOaiOOga02Nc0K
PCbA5KaL7sRMGZiwsqEiRi4H//ARBXdYToGljJDtlnwF+JK/oZHFx2mwWcFU
gA559r/Z1afuP1rizYH991/z6BYpwbXBURasXyrwT71D2sKTarBv/14muXge
/O884Dyjt9IxBM+HVadzEcUO+7THrTBuXZkBTyW4EX69xX5sXVoeyQvz2JNf
3pbUYF5ykjiAOorfWxpOLAuiY56YJBiwSMd98/yFTnEPzp2N+KM9Q5hnE2jS
SK3BPOK4XtABHXyfp1QzKKcwL3B1OalGgHPb+TVVvB+ar680mF1GO1gfD51W
4T6do41KQQnuY92+6WS3iPknhvPDytzROcKEwAd5mHfuSWrXBTZa2B2pGplA
Uw/GPBS9RHO8zzO+6+L/ffrc3mrpG/ZZFOlrK3Kwz0kNh0Kbxv2sE4qkSRa6
YpvL0dJ0zL+me7iOy0QPWtmMvJegD9xzzKuvRrsyJBmdK+i7EZWrE0o042v5
kVVj7ButoWRqVrBvuMbJ4PoN7Bv62LbUUob9nmaRstKc0PWdZq+LUjA/u4FK
D7ZHyz6QvPv60V6crRufV6DjT28qUWnQVWbZsZ8U6BYxjedCxL7rvf57180J
684P4Tc50rTt
   "], {{{}, 
     {Hue[0.67, 0.6, 0.6], Opacity[0.2], EdgeForm[None], 
      GraphicsGroupBox[
       PolygonBox[{{98, 101, 102, 50, 55, 49, 48, 47, 46, 45, 54, 44, 87, 
        76}}]]}, {}, {}}, {{}, {}, 
     {Hue[0.67, 0.6, 0.6], 
      LineBox[{1, 88, 77, 68, 61, 56, 51, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 
       13, 14, 15, 16, 17, 18, 19, 20, 21, 22, 23, 24, 25, 26, 27, 28, 29, 30,
        31, 32, 33, 34, 35, 36, 37, 38, 39, 40, 41, 42, 89, 78, 69, 62, 57, 
       52, 91, 80, 71, 64, 59, 43, 90, 79, 70, 63, 58, 93, 82, 73, 66, 53, 92,
        81, 72, 65, 95, 84, 75, 60, 94, 83, 74, 97, 86, 67, 96, 85}], 
      LineBox[{98, 76, 87, 44, 54, 45, 46, 47, 48, 49, 55, 50}]}, 
     {Hue[0.67, 0.6, 0.6], Opacity[0.2], LineBox[{100, 99}]}}, {{}, {}, {}}}],
  
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesOrigin->{0, 0},
  Method->{"AxesInFront" -> True},
  PlotRange->{{-1, 1}, {0., 2.}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02]}]], "Output",
 CellChangeTimes->{{3.5215927091460457`*^9, 3.521592738045987*^9}, 
   3.521592898525255*^9, 3.521592940155899*^9, 3.521669407303451*^9}]
}, Open  ]],

Cell["\<\

All together: \
\>", "Text",
 CellChangeTimes->{{3.5215929475999193`*^9, 3.521592951615041*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"Evaluate", "[", 
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"\[Phi]", "[", 
       RowBox[{"x", ",", "2", ",", "k"}], "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"k", ",", "0", ",", 
        RowBox[{
         SuperscriptBox["2", "2"], "-", "1"}]}], "}"}]}], "]"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"x", ",", "0", ",", "1"}], "}"}], ",", 
   RowBox[{"Filling", "\[Rule]", "Axis"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.521592790259466*^9, 3.52159280193512*^9}, 
   3.521592834205421*^9}],

Cell[BoxData[
 GraphicsBox[GraphicsComplexBox[CompressedData["
1:eJztmXtUjfkax9/dhego3e1EculUTIXSoNFPId0YlJBJKk4ySPYcGuM0pZgK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   "], {{{}, 
     {Hue[0.67, 0.6, 0.6], Opacity[0.2], EdgeForm[None], 
      GraphicsGroupBox[
       PolygonBox[{{1, 486, 487, 96, 80, 90, 56, 61, 13, 52, 12, 11, 10, 9, 8,
         7, 6, 5, 4, 3, 2, 51}}]]}, {}, 
     {Hue[0.9060679774997897, 0.6, 0.6], Opacity[0.2], EdgeForm[None], 
      GraphicsGroupBox[
       PolygonBox[{{187, 484, 485, 155, 161, 124, 154, 123, 122, 121, 120, 
        119, 118, 117, 116, 115, 114, 153, 113, 165, 152, 192, 176, 
        209}}]]}, {}, 
     {Hue[0.1421359549995791, 0.6, 0.6], Opacity[0.2], EdgeForm[None], 
      GraphicsGroupBox[
       PolygonBox[{{358, 482, 483, 361, 304, 313, 293, 299, 274, 292, 273, 
        272, 271, 270, 269, 268, 267, 266, 265, 264, 291, 263, 316, 303, 330, 
        312, 348, 325, 369, 340}}]]}, {}, 
     {Hue[0.37820393249936934`, 0.6, 0.6], Opacity[0.2], EdgeForm[None], 
      GraphicsGroupBox[
       PolygonBox[{{462, 480, 481, 429, 434, 428, 427, 426, 425, 424, 423, 
        422, 421, 420, 419, 418, 433, 417, 455, 446, 464, 453, 
        475}}]]}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, \
{}, {}, {}, {}, {}}, {{}, {}, 
     {Hue[0.67, 0.6, 0.6], 
      LineBox[{1, 51, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 52, 13, 61, 56, 90, 
       80, 96}], LineBox[CompressedData["
1:eJwt0EdOQgEARdHvBmyoqKD4EaUqaAJEIdgbUgL2iBBdAIzYM8vgDByc3OnL
C/8m/fFCEARdHhnyyjUD+jQp80mHey6pscg7LW5pcEaFJZZZYZUIa6yzQZRN
tpixTYw4O+ySYI+QJPukOGBq+KGmyZAlR54CRxxTpMQJH7S544Jzqnz9f/DA
FXW+6fHEDT+88MyIN345ZQ4qcxOx
       "]]}, 
     {Hue[0.9060679774997897, 0.6, 0.6], 
      LineBox[{100, 212, 194, 179, 168, 158, 150, 101, 102, 103, 104, 105, 
       106, 107, 108, 109, 110, 111, 213, 195, 180, 169, 159, 151, 217, 199, 
       184, 173, 164, 112, 214, 196, 181, 170, 223, 205, 190, 227, 210, 160, 
       220, 202, 230}], 
      LineBox[{187, 209, 176, 192, 152, 165, 113, 153, 114, 115, 116, 117, 
       118, 119, 120, 121, 122, 123, 154, 124, 161, 155}], 
      LineBox[{218, 200, 229, 185, 226, 208, 174, 224, 206, 191, 166, 221, 
       203, 188, 177, 125, 215, 197, 182, 171, 162, 156, 126, 127, 128, 129, 
       130, 131, 132, 133, 134, 135, 136, 374, 137, 138, 139, 140, 141, 142, 
       143, 144, 145, 146, 147, 148, 216, 198, 183, 172, 163, 157, 219, 201, 
       186, 175, 167, 222, 204, 189, 178, 225, 207, 193, 228, 211, 231, 
       149}]}, 
     {Hue[0.1421359549995791, 0.6, 0.6], 
      LineBox[{238, 352, 334, 319, 306, 296, 288, 239, 240, 241, 242, 243, 
       244, 245, 246, 247, 248, 249, 250, 251, 252, 253, 254, 255, 256, 257, 
       258, 259, 260, 261, 353, 335, 320, 307, 297, 289, 357, 339, 324, 311, 
       302, 262, 354, 336, 321, 308, 298, 360, 342, 327, 315, 363, 345, 331, 
       367, 350, 371, 290}], 
      LineBox[{358, 340, 369, 325, 348, 312, 330, 303, 316, 263, 291, 264, 
       265, 266, 267, 268, 269, 270, 271, 272, 273, 292, 274, 299, 293, 313, 
       304, 361}], 
      LineBox[{343, 370, 328, 366, 349, 317, 364, 346, 332, 275, 355, 337, 
       322, 309, 300, 294, 276, 277, 278, 279, 280, 281, 282, 283, 284, 285, 
       286, 356, 338, 323, 310, 301, 295, 359, 341, 326, 314, 305, 362, 344, 
       329, 318, 365, 347, 333, 368, 351, 372, 287}]}, 
     {Hue[0.37820393249936934`, 0.6, 0.6], LineBox[CompressedData["
1:eJwNxm1OgQEAAODXUbpPvxzBAXIBUZRKKJX0XSeILfIR04cZYi1Kah3G8+PZ
npVINLwWCoJglZhMGdClwQP3rBMnwQabJEmxxTZpdthljwz7ZMmR54BDChxx
zAlFTilxxjkXXHLFNTfcMmPIM02qlPnmnVeeeOSOL0a80KLGDxN6dKgwZ8wb
bX75oM8fn/xTZ8ES35s01w==
       "]], 
      LineBox[{462, 475, 453, 464, 446, 455, 417, 433, 418, 419, 420, 421, 
       422, 423, 424, 425, 426, 427, 428, 434, 429}]}, 
     {Hue[0.67, 0.6, 0.6], Opacity[0.2], LineBox[{99, 233, 98}], 
      LineBox[{236, 375, 235}], LineBox[{237, 234}], LineBox[{378, 377}], 
      LineBox[{379, 477, 376}], 
      LineBox[{479, 478}]}}, {{}, {}, {}, {}, {}, {}}}],
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesOrigin->{0, 0},
  Method->{"AxesInFront" -> True},
  PlotRange->{{0, 1}, {0., 2.}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02]}]], "Output",
 CellChangeTimes->{{3.521592808232078*^9, 3.5215928352878523`*^9}, 
   3.521669408925777*^9}]
}, Open  ]],

Cell["", "Text"],

Cell[TextData[{
 "Let\[CloseCurlyQuote]s study the support of the function ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["\[Phi]", 
    RowBox[{"J", ",", " ", "k"}]], TraditionalForm]]],
 "  (where it is nonzero), first plot for J = 2, k = 0 and the second plot \
for J = 3, k = 1:"
}], "Text",
 CellChangeTimes->{{3.521595750434794*^9, 3.521595759579007*^9}, {
  3.5215960173755617`*^9, 3.521596039586635*^9}, {3.5216464137408*^9, 
  3.521646433521743*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"g1", "=", 
   RowBox[{"Plot", "[", 
    RowBox[{
     RowBox[{"\[Phi]", "[", 
      RowBox[{"x", ",", "2", ",", "0"}], "]"}], ",", " ", 
     RowBox[{"{", 
      RowBox[{"x", ",", 
       RowBox[{"-", "0.5"}], ",", "0.5"}], "}"}], ",", 
     RowBox[{"Filling", "\[Rule]", "Axis"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"J", "=", " ", "2"}], ";", " ", 
  RowBox[{"k", " ", "=", " ", "0"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"g2", " ", "=", " ", 
   RowBox[{"Graphics", "[", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"Arrow", "[", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"0.4", ",", " ", "0.5"}], "}"}], ",", " ", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{
            SuperscriptBox["2", 
             RowBox[{"-", "J"}]], " ", 
            RowBox[{"(", 
             RowBox[{"k", "+", "1"}], ")"}]}], ",", " ", "0"}], "}"}]}], 
        "}"}], "]"}], ",", " ", 
      RowBox[{"Text", "[", 
       RowBox[{"\"\<\!\(\*SuperscriptBox[\(2\), \(-J\)]\)(k+1)\>\"", ",", 
        RowBox[{"{", 
         RowBox[{"0.4", ",", " ", 
          RowBox[{"0.5", "+", "0.1"}]}], "}"}]}], "]"}]}], "}"}], " ", 
    "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"g3", " ", "=", " ", 
    RowBox[{"Graphics", "[", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"Arrow", "[", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"0.2", ",", " ", "0.5"}], "}"}], ",", " ", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{
             SuperscriptBox["2", 
              RowBox[{"-", "J"}]], " ", 
             RowBox[{"(", 
              RowBox[{"k", "+", "0"}], ")"}]}], ",", " ", "0"}], "}"}]}], 
         "}"}], "]"}], ",", " ", 
       RowBox[{"Text", "[", 
        RowBox[{"\"\<\!\(\*SuperscriptBox[\(2\), \(-J\)]\)k\>\"", ",", 
         RowBox[{"{", 
          RowBox[{"0.2", ",", " ", 
           RowBox[{"0.5", "+", "0.1"}]}], "}"}]}], "]"}]}], "}"}], " ", 
     "]"}]}], ";"}], "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{"Show", "[", 
  RowBox[{"g1", ",", " ", "g2", ",", " ", "g3"}], "]"}]}], "Input",
 CellChangeTimes->{{3.5215941818763227`*^9, 3.521594203914977*^9}, {
   3.521594237634488*^9, 3.521594241909358*^9}, 3.5215943228946733`*^9, {
   3.521594386003837*^9, 3.521594505093388*^9}, {3.5215945366770477`*^9, 
   3.521594545383442*^9}, {3.52159458784813*^9, 3.521594590656487*^9}, {
   3.521594623971312*^9, 3.521594632309053*^9}, {3.521594689320177*^9, 
   3.5215947902617283`*^9}, {3.521595664018621*^9, 3.521595668464366*^9}}],

Cell[BoxData[
 GraphicsBox[{GraphicsComplexBox[CompressedData["
1:eJxl1AkwnGcYAOBFlLppUYn7aiwjiNKlSlKEiGsbJRVn6hikZEsw1LlxlUSR
VByRBnFECRKilo2wsSLu2zoaQuRwU+xkaDuj79tRM8Y887/n9/s/Bc9Ashcn
gUBI+/v3n7+axhJv9vam6YT9n9Ae6kWf5inw4CD/mxaPSbDM48CP9aUnwA/9
27iFJ8fB7qnaK2NxY+DtjIgkuvEouFBoSir7xTA477Q2ZSB5CBwX4BGmZjkI
juAqD6Us9oM9YnqUh0v7wNeb5rLz/HrBv08fFahQ7AYriZicPHurE1xDTPKb
mWWCpxnV8np6T8FzGtd16HWtYNGoMj1Njhawht6yRvE6DRxvutjbEFYPFj9b
mX5Osgb7/ckQZiqXg4tZc2mvqbfALvbSD1gXqOAGvoihJyHxxvs0+WyGQzbW
qQCstNK4Y/CkDGxZONZl41QDNrMW49p8WA++5jYSo1VPA7fbyAjaibWAFxXE
o/pzWsEhweoe1ySegkcmRMjeTCbYPfyLVzxnOsGt6voprdzdYNUPaQtFFr3/
miBD8zfjTuoDE9icZZSZfvCWfZMrQ2UQzNJ1O6JCHQIHOYqIKk4Mg6WyXjod
khkFVzrfLlkPGwM7GkVbMJvGwdWuFxUN3rPA23xfcTU4TILJfYZ6MtlT4P3v
AZ8ndt077obfB5GTXevvnAUmcR8r+WNOF9xR62ZanZwF55HR3/BorvQ5mLdg
5LcEqx7wnZmPJB0W8LxMeNXShc5gf5PZ1Wc3q7D/wtLybWLQTXDVRoDSwngw
2NuLR7q4FN/Hy81Xe5HZWL8jQGdWfA33HSXyXj2XdhXyfXyI3nW7FMgvHy0x
9l3CeesL5Yx47uJ8+qLU8ecjOJ/5nJ9kCjsX/KCzn2HbFwW+sme/kR6E8wjJ
1adKMXCeTv5oI4G+nyG+VT45MV/EE/qPNdIvb+XhPO8diub5wnGerw2FODk6
vCA/4Mt0XtnNSIhvZp+ivpPD/pTVnEyuAczXOWrtOf8W97nsXtrfYJyP9xUr
rvPEfCz4m0OJSznnsZ5WWLhHbiXuw06gbRtKZOJ9lmn+zF/XDuaRrfJuTPXE
/k5iwUW+9ECIT1kXJKfzY/2s0y6+V2gYz9xaUuPmCYB6uUw7uk6xI+SvccTV
Wehivl32aHPsa8y/X6utur6J+wrJnrpvP4P7Rt7ooQupxIObE359W0DGei1F
41bnC3HfDFPn4YFHuO/walyByPbnMF8Vq73Y2hH7L0UNGNi4UCC+pVMtjMSN
9VVDm8nm1Rjfa8vS6upyh3in3e/yDxMx/kUbqezkFMbH+FUEDBC/hf7KW0T/
ZnGMV58dIt1wsYJ6dP/QwccbmB+4o5S0w8bzGY+UKMg/jvf3u/VNUkgbns9a
u6bfHWusz2fI30LLx/NxLSQy5Pj+d3/AfNuXtg9X2mP/bpL8sSN5P0D8j74V
wmmb+P//veBy+917GJ/BCJbysboA8T9FDqdzqeA8RGc/2cJRjHcMyXMtEcHn
n0zKLO2WkSGfl7PUUmEZ41dsP10LpJhD/6ZL0WbhH/znfQkE/aLpcwK/nyFz
N3c25h98vwf3P3ifHtz3QPzB54S/APQ3UyY=
    "], {{{}, 
      {Hue[0.67, 0.6, 0.6], Opacity[0.2], EdgeForm[None], 
       GraphicsGroupBox[
        PolygonBox[{{121, 140, 141, 124, 67, 76, 56, 62, 37, 55, 36, 35, 34, 
         33, 32, 31, 30, 29, 28, 27, 54, 26, 79, 66, 93, 75, 111, 88, 132, 
         103}}]]}, {}, {}}, {{}, {}, 
      {Hue[0.67, 0.6, 0.6], 
       LineBox[{1, 115, 97, 82, 69, 59, 51, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 
        12, 13, 14, 15, 16, 17, 18, 19, 20, 21, 22, 23, 24, 116, 98, 83, 70, 
        60, 52, 120, 102, 87, 74, 65, 25, 117, 99, 84, 71, 61, 123, 105, 90, 
        78, 126, 108, 94, 130, 113, 134, 53}], 
       LineBox[{121, 103, 132, 88, 111, 75, 93, 66, 79, 26, 54, 27, 28, 29, 
        30, 31, 32, 33, 34, 35, 36, 55, 37, 62, 56, 76, 67, 124}], 
       LineBox[{106, 133, 91, 129, 112, 80, 127, 109, 95, 38, 118, 100, 85, 
        72, 63, 57, 39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 49, 119, 101, 86, 
        73, 64, 58, 122, 104, 89, 77, 68, 125, 107, 92, 81, 128, 110, 96, 131,
         114, 135, 50}]}, 
      {Hue[0.67, 0.6, 0.6], Opacity[0.2], LineBox[{138, 137}], 
       LineBox[{139, 136}]}}, {{}, {}, {}}}], {
    ArrowBox[NCache[{{0.4, 0.5}, {Rational[1, 4], 0}}, {{0.4, 0.5}, {
       0.25, 0}}]], 
    InsetBox["\<\"\\!\\(\\*SuperscriptBox[\\(2\\), \\(-J\\)]\\)(k+1)\"\>", \
{0.4, 0.6}]}, {ArrowBox[{{0.2, 0.5}, {0, 0}}], 
    InsetBox["\<\"\\!\\(\\*SuperscriptBox[\\(2\\), \\(-J\\)]\\)k\"\>", \
{0.2, 0.6}]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesOrigin->{0, 0},
  Method->{"AxesInFront" -> True},
  PlotRange->{{-0.5, 0.5}, {0., 2.}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02]}]], "Output",
 CellChangeTimes->{
  3.521594204579707*^9, 3.521594242289535*^9, 3.5215943244161863`*^9, 
   3.521594506435894*^9, 3.5215945466140223`*^9, 3.521594591646016*^9, {
   3.5215946253354597`*^9, 3.521594632792625*^9}, {3.521594737159689*^9, 
   3.521594790618635*^9}, 3.5215956690930233`*^9, 3.521669412447504*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"g1", "=", 
   RowBox[{"Plot", "[", 
    RowBox[{
     RowBox[{"\[Phi]", "[", 
      RowBox[{"x", ",", "3", ",", "1"}], "]"}], ",", " ", 
     RowBox[{"{", 
      RowBox[{"x", ",", 
       RowBox[{"-", "0.5"}], ",", "0.5"}], "}"}], ",", 
     RowBox[{"Filling", "\[Rule]", "Axis"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"J", "=", " ", "3"}], ";", " ", 
  RowBox[{"k", " ", "=", " ", "1"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"g2", " ", "=", " ", 
   RowBox[{"Graphics", "[", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"Arrow", "[", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"0.4", ",", " ", "0.5"}], "}"}], ",", " ", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{
            SuperscriptBox["2", 
             RowBox[{"-", "J"}]], " ", 
            RowBox[{"(", 
             RowBox[{"k", "+", "1"}], ")"}]}], ",", " ", "0"}], "}"}]}], 
        "}"}], "]"}], ",", " ", 
      RowBox[{"Text", "[", 
       RowBox[{"\"\<\!\(\*SuperscriptBox[\(2\), \(-J\)]\)(k+1)\>\"", ",", 
        RowBox[{"{", 
         RowBox[{"0.4", ",", " ", 
          RowBox[{"0.5", "+", "0.1"}]}], "}"}]}], "]"}]}], "}"}], " ", 
    "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"g3", " ", "=", " ", 
    RowBox[{"Graphics", "[", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"Arrow", "[", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"0.2", ",", " ", "0.5"}], "}"}], ",", " ", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{
             SuperscriptBox["2", 
              RowBox[{"-", "J"}]], " ", 
             RowBox[{"(", 
              RowBox[{"k", "+", "0"}], ")"}]}], ",", " ", "0"}], "}"}]}], 
         "}"}], "]"}], ",", " ", 
       RowBox[{"Text", "[", 
        RowBox[{"\"\<\!\(\*SuperscriptBox[\(2\), \(-J\)]\)k\>\"", ",", 
         RowBox[{"{", 
          RowBox[{"0.2", ",", " ", 
           RowBox[{"0.5", "+", "0.1"}]}], "}"}]}], "]"}]}], "}"}], " ", 
     "]"}]}], ";"}], "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{"Show", "[", 
  RowBox[{"g1", ",", " ", "g2", ",", " ", "g3"}], "]"}]}], "Input",
 CellChangeTimes->{{3.521595523213394*^9, 3.521595661050846*^9}}],

Cell[BoxData[
 GraphicsBox[{GraphicsComplexBox[CompressedData["
1:eJx1lAk01XkUxy3Zx9pIjCX7kmMwzTPI4WgUipPdSLYkQygnyxsNxQtTkpQJ
WcpORZgSnvc8e3ayr8eTJbKTJcPMnFP3Os6Zd87/vPM5v++993vv7/7/ki4+
5heZGBgYov59/vtX0T00s7s7SmX48gtoI3ldoowAd3VxzdCch4HFKn2+1RAd
An7lWcPCOzwA7BSlttgf2g+8ERsUSdXtA07nGRGOH+sBTjJW8333Rzdw6GXn
QEWjLuAg5rwA37lOYOcbbTI9OR3AcRUT8Uke7cBlowrfPJdqBZbm09O3TGkC
LlKK9KCPNwCP1hYeIRDqgCeU49Spr6uB+YNzCSqMNGBlwoJy5goZOOznufbS
wBJgQcv8mF+EirDep1reBpk84MzBibsfSCnA581E/xq8QAIu5QzqrvIL0/3K
P9IZxW/apgJLL5ZvalXlAhul97eY2hYBG5gIMK+9KgG+59h7Q7WEDFxvKsZ9
VoCm26Id4pbyhFVvTlIwuDOxGtjv2lHne4fqgHuH+MzdGhqAnYjHp9jONAFX
H9W4Xc3SCizHQZ7OMGyHemJkTwOWyA5ghi2mXF96J/C6WYVDrWwX8OAxx+9k
Sd3AV2z4+KWGeoCFH763PSDWB5x/7kn2SmA/sI1OiGFDxQBwoYOXlNb2IPAG
5wnmUqthYPMObYJY/Ajwl/cBzyNanv3giO+HR88qLZZQBufRO5Em015UYLuf
EgzuW1fBPGI7S99M5DQDs6f2vgg/3QacRj8oZDWN89JjV4zhOYP19caXGhMK
sH7f/TD6iU9v4Jzne9VLUQIUYLeLbKKZOXgf79emdq/HY/63l9XHBZex320R
t6dj/uXAbFOLwmmulRCf15et6z6PfkvSJXTYstCfBj9poLkX/UUvNPqKWqM/
03rmayOuFcC3ds1WY66gHx6JkijhWvRTHPhCrawH5ytfbHekiRv99JdT/deT
0M+2VcYkJxH9tP5pb6dVifOYEok4SCzHeMrWKdJHCazvu5T4gPkdxqsrmLhM
zu6575T5MnZW7Mf7gddvbDzYj/WBiPlEe8ynGkh0fpyP/UTLdxCzwrEfb3WJ
U9Qa3BfxArfyKBesP+9S53ThV/R/e4XbPIYL8z80Pu9+i4x6oRbZZIIm9pff
uGzBL4T5lxlDXxsew/iz8X2Umx8w/mWxmtzK2p798mMY3RnG70cwMe3vx3T8
flDCn86mmmM+WsbAafv0Pfu0Q09OcsB+gw9bNlokoJ+CwfpMExusv2P4eXxd
B/ulNSkGarJgfrkAivnJQtRTXsr3Zs6i3nbHNVlECfVjNZq5+iOo/9xuKyEy
i/Vl1pU8KYKop3oGdFWuot5nUzpyc2vPPjtzLG2+xXmEfzyuO9mM81iuV/FI
M8F8nNpcNHLynn2emS14ZIzzCL8zz5UShn42rm6I5JthfVZynKy+Avb3u/tz
3rtruO/e3Av1Wc9QXydddXixG/V3rvfEMMuiH6VzHuLpfah3o5JY/Aawvo1f
kkM2H+rZmXKMJBdQ759ZGslRgPqKqyEGRFbUhz2yWPTlxP3z7z7p6LQ1+r/3
uV+//3729/tVv//8K/8DcoaQMg==
    "], {{{}, 
      {Hue[0.67, 0.6, 0.6], Opacity[0.2], EdgeForm[None], 
       GraphicsGroupBox[
        PolygonBox[{{133, 139, 140, 123, 67, 76, 56, 62, 37, 55, 36, 35, 34, 
         33, 54, 32, 79, 66, 93, 75}}]]}, {}, {}}, {{}, {}, 
      {Hue[0.67, 0.6, 0.6], 
       LineBox[{1, 114, 97, 82, 69, 59, 51, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 
        12, 13, 14, 15, 16, 17, 18, 19, 20, 21, 22, 23, 24, 25, 26, 27, 28, 
        29, 30, 115, 98, 83, 70, 60, 52, 119, 102, 87, 74, 65, 31, 116, 99, 
        84, 71, 61, 122, 105, 90, 78, 125, 108, 94, 53, 120, 103, 131, 88, 
        128, 111}], 
       LineBox[{133, 75, 93, 66, 79, 32, 54, 33, 34, 35, 36, 55, 37, 62, 56, 
        76, 67, 123}], 
       LineBox[{106, 132, 91, 129, 112, 80, 126, 109, 95, 38, 117, 100, 85, 
        72, 63, 57, 39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 49, 118, 101, 86, 
        73, 64, 58, 121, 104, 89, 77, 68, 124, 107, 92, 81, 127, 110, 96, 130,
         113, 134, 50}]}, 
      {Hue[0.67, 0.6, 0.6], Opacity[0.2], LineBox[{137, 136}], 
       LineBox[{138, 135}]}}, {{}, {}, {}}}], {
    ArrowBox[NCache[{{0.4, 0.5}, {Rational[1, 4], 0}}, {{0.4, 0.5}, {
       0.25, 0}}]], 
    InsetBox["\<\"\\!\\(\\*SuperscriptBox[\\(2\\), \\(-J\\)]\\)(k+1)\"\>", \
{0.4, 0.6}]}, {
    ArrowBox[NCache[{{0.2, 0.5}, {Rational[1, 8], 0}}, {{0.2, 0.5}, {
       0.125, 0}}]], 
    InsetBox["\<\"\\!\\(\\*SuperscriptBox[\\(2\\), \\(-J\\)]\\)k\"\>", \
{0.2, 0.6}]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesOrigin->{0, 0},
  Method->{"AxesInFront" -> True},
  PlotRange->{{-0.5, 0.5}, {0., 2.8284271247461903`}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02]}]], "Output",
 CellChangeTimes->{
  3.521595540999791*^9, {3.521595609008329*^9, 3.521595674699345*^9}, 
   3.521669415634653*^9}]
}, Open  ]],

Cell[TextData[{
 "\nTherefore the base of the ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["\[Phi]", 
    RowBox[{"J", ",", " ", "k"}]], TraditionalForm]]],
 " can be characterized as follows:\n\n",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     SubscriptBox["\[Phi]", 
      RowBox[{"J", ",", " ", "k"}]], "(", "x", ")"}], "=", 
    RowBox[{"\[Piecewise]", GridBox[{
       {
        SuperscriptBox["2", 
         RowBox[{"J", "/", "2"}]], 
        RowBox[{
         RowBox[{
          SuperscriptBox["2", 
           RowBox[{"-", "J"}]], "k"}], "\[LessEqual]", "x", "\[LessEqual]", 
         RowBox[{
          SuperscriptBox["2", 
           RowBox[{"-", "J"}]], 
          RowBox[{"(", 
           RowBox[{"k", "+", "1"}], ")"}]}]}]},
       {"0", "otherwise"}
      },
      GridBoxAlignment->{
       "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
        "RowsIndexed" -> {}},
      GridBoxItemSize->{
       "Columns" -> {{Automatic}}, "ColumnsIndexed" -> {}, "Rows" -> {{1.}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.84]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}]}]}], TraditionalForm]]],
 "\n\n\n"
}], "Text",
 CellChangeTimes->{{3.52159577111331*^9, 3.5215957873474007`*^9}, {
   3.521595866730994*^9, 3.5215959526122847`*^9}, 3.521596045830488*^9, {
   3.521596283064907*^9, 3.521596283065002*^9}, {3.5215963317649183`*^9, 
   3.5215963317656107`*^9}, {3.521596688719171*^9, 3.5215967146030483`*^9}, {
   3.521606457037096*^9, 3.521606459072289*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["The Inner Product & Reconstruction ", "Subtitle",
 CellChangeTimes->{{3.521596671910523*^9, 3.521596675643319*^9}, {
  3.521600950694525*^9, 3.5216009539313173`*^9}}],

Cell[TextData[{
 "The following integral equation forms an inner poduct over a given Real \
function space:\n\n",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     SubscriptBox["c", 
      RowBox[{"J", ",", " ", "k"}]], "=", " ", 
     RowBox[{
      RowBox[{
       SubsuperscriptBox["\[Integral]", "0", "1"], 
       RowBox[{
        RowBox[{"f", "(", "x", ")"}], 
        RowBox[{
         SubscriptBox["\[Phi]", 
          RowBox[{"J", ",", " ", "k"}]], "(", "x", ")"}], 
        RowBox[{"\[DifferentialD]", "x"}]}]}], " ", "=", " ", 
      RowBox[{"<", "f"}]}]}], ",", 
    RowBox[{
     SubscriptBox["\[Phi]", 
      RowBox[{"J", ",", " ", "k"}]], ">", " "}]}], TraditionalForm]]],
 "\n\nIf we treat the ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["\[Phi]", 
    RowBox[{"J", ",", " ", "k"}]], TraditionalForm]]],
 " as basis for a functional vector space the coefficients ",
 Cell[BoxData[
  FormBox[
   SubsuperscriptBox[
    RowBox[{"{", 
     SubscriptBox["c", 
      RowBox[{"J", ",", " ", "k"}]], "}"}], 
    RowBox[{"k", "=", "0"}], 
    RowBox[{
     SuperscriptBox["2", "J"], "-", "1"}]], TraditionalForm]]],
 "can linearly sum up a new function ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["f", "J"], TraditionalForm]]],
 ":\n\n",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     SubscriptBox["f", "J"], "(", "x", ")"}], " ", "=", " ", 
    RowBox[{
     UnderoverscriptBox["\[Sum]", 
      RowBox[{"k", "=", "0"}], 
      RowBox[{
       SuperscriptBox["2", "J"], "-", "1"}]], 
     RowBox[{
      SubscriptBox["c", 
       RowBox[{"J", ",", " ", "k"}]], 
      RowBox[{
       SubscriptBox["\[Phi]", 
        RowBox[{"J", ",", " ", "k"}]], "(", "x", ")"}]}]}]}], 
   TraditionalForm]]],
 "\n\nExample 1 \n\n"
}], "Text",
 CellChangeTimes->{{3.521596720283742*^9, 3.521596847268067*^9}, {
  3.521596907201714*^9, 3.521596959571642*^9}, {3.5215969907826567`*^9, 
  3.5215970482302027`*^9}, {3.521597087068089*^9, 3.5215971845615683`*^9}, {
  3.521597307226967*^9, 3.521597323244938*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"Make", " ", "up", " ", "a", " ", "new", " ", "function"}], " ", 
   "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"f", "[", "t_", "]"}], " ", ":=", " ", 
    RowBox[{"Sin", "[", 
     RowBox[{"8", "*", "t"}], "]"}]}], ";"}]}]], "Input",
 CellChangeTimes->{{3.5215974809946136`*^9, 3.521597487539905*^9}, {
   3.521598407728393*^9, 3.521598431363063*^9}, 3.521598521136654*^9, {
   3.521599088671135*^9, 3.5215991034679613`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{
     RowBox[{"Let", "'"}], "s", " ", "look", " ", "at", " ", "J"}], " ", "=", 
    " ", 
    RowBox[{
     RowBox[{"4", " ", "and", " ", "k"}], " ", "=", " ", "0"}]}], " ", "*)"}],
   "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"J", " ", "=", " ", "4"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"k", " ", "=", " ", "0"}], ";"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{"Integrate", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"f", "[", "x", "]"}], "*", 
      RowBox[{"\[Phi]", "[", 
       RowBox[{"x", ",", "J", ",", "k"}], "]"}]}], ",", 
     RowBox[{"{", 
      RowBox[{"x", ",", "0", ",", "1"}], "}"}]}], "]"}], 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.5215973495501833`*^9, 3.521597442065049*^9}, {
   3.521597492211553*^9, 3.521597568209922*^9}, {3.521597604099599*^9, 
   3.521597604628631*^9}, {3.521597658025292*^9, 3.521597709430616*^9}, {
   3.521597778793446*^9, 3.5215978484140377`*^9}, {3.521597882290588*^9, 
   3.521597907943774*^9}, 3.5215980165454283`*^9, {3.521598583850473*^9, 
   3.5215986029742203`*^9}, {3.521599108409955*^9, 3.5215991256661263`*^9}}],

Cell[BoxData[
 SuperscriptBox[
  RowBox[{"Sin", "[", 
   FractionBox["1", "4"], "]"}], "2"]], "Output",
 CellChangeTimes->{
  3.5215978519946747`*^9, {3.5215978834669857`*^9, 3.5215979020036297`*^9}, 
   3.52159802242082*^9, 3.5215984133574657`*^9, 3.521598524960682*^9, {
   3.521598590099325*^9, 3.5215986045475492`*^9}, 3.521669422661435*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{
     RowBox[{"Let", "'"}], "s", " ", "look", " ", "at", " ", "J"}], " ", "=", 
    " ", 
    RowBox[{
     RowBox[{"4", " ", "and", " ", "k"}], " ", "=", " ", "1"}]}], " ", "*)"}],
   "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"J", " ", "=", " ", "4"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"k", " ", "=", " ", "1"}], ";"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{"Integrate", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"f", "[", "x", "]"}], "*", 
      RowBox[{"\[Phi]", "[", 
       RowBox[{"x", ",", "J", ",", "k"}], "]"}]}], ",", 
     RowBox[{"{", 
      RowBox[{"x", ",", "0", ",", "1"}], "}"}]}], "]"}], 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.5215979151988*^9, 3.521597916920718*^9}, 
   3.5215980204182587`*^9, {3.52159858674431*^9, 3.5215986083742733`*^9}, {
   3.521599133533998*^9, 3.521599138199439*^9}}],

Cell[BoxData[
 RowBox[{
  FractionBox["1", "2"], " ", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"Cos", "[", 
     FractionBox["1", "2"], "]"}], "-", 
    RowBox[{"Cos", "[", "1", "]"}]}], ")"}]}]], "Output",
 CellChangeTimes->{
  3.52159791857194*^9, 3.521598024805766*^9, {3.52159841448708*^9, 
   3.521598437830645*^9}, 3.521598526310814*^9, {3.5215985923011436`*^9, 
   3.521598610054336*^9}, 3.521669424832233*^9}]
}, Open  ]],

Cell[TextData[{
 "\nLet\[CloseCurlyQuote]s calculate the sum ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    UnderoverscriptBox["\[Sum]", 
     RowBox[{"k", "=", "0"}], 
     RowBox[{
      SuperscriptBox["2", "J"], "-", "1"}]], 
    RowBox[{
     SubscriptBox["c", 
      RowBox[{"J", ",", " ", "k"}]], 
     RowBox[{
      SubscriptBox["\[Phi]", 
       RowBox[{"J", ",", " ", "k"}]], "(", "x", ")"}]}]}], 
   TraditionalForm]]],
 " :\n"
}], "Text",
 CellChangeTimes->{{3.521597930621565*^9, 3.5215979760733*^9}, {
  3.5215991432186003`*^9, 3.521599145884527*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{"Make", " ", "a", " ", "list", " ", "of", " ", "all", " ", 
     FormBox[
      RowBox[{
       SubscriptBox["\[Phi]", 
        RowBox[{"J", ",", " ", "k"}]], "(", "x", ")"}],
      TraditionalForm], " ", "functions"}], ",", " ", 
    RowBox[{
    "however", " ", "make", " ", "sure", " ", "the", " ", "variable", " ", 
     "is", " ", "changed", " ", "from", " ", "x", " ", "to", " ", "t", " ", 
     "to", " ", "avoid", " ", "confusion"}]}], " ", "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{"list", " ", "=", " ", 
   RowBox[{"Table", " ", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"\[Phi]", "[", 
       RowBox[{"t", ",", "J", ",", "k"}], "]"}], "*", 
      RowBox[{"Integrate", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"f", "[", "x", "]"}], "*", 
         RowBox[{"\[Phi]", "[", 
          RowBox[{"x", ",", "J", ",", "k"}], "]"}]}], ",", 
        RowBox[{"{", 
         RowBox[{"x", ",", "0", ",", "1"}], "}"}]}], "]"}]}], ",", " ", 
     RowBox[{"{", 
      RowBox[{"k", ",", " ", "0", ",", 
       RowBox[{
        SuperscriptBox["2", "J"], "-", "1"}]}], "}"}]}], "]"}], 
   " "}]}]], "Input",
 CellChangeTimes->{{3.521597983928706*^9, 3.521598008534349*^9}, {
  3.521598038915798*^9, 3.5215980455618887`*^9}, {3.521598149667354*^9, 
  3.521598189797986*^9}, {3.521598375425344*^9, 3.521598380139195*^9}, {
  3.52159915046605*^9, 3.5215991952540894`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"4", " ", 
    RowBox[{"Boole", "[", 
     RowBox[{
      RowBox[{"0", "\[LessEqual]", 
       RowBox[{"16", " ", "t"}]}], "&&", 
      RowBox[{
       RowBox[{"16", " ", "t"}], "<", "1"}]}], "]"}], " ", 
    SuperscriptBox[
     RowBox[{"Sin", "[", 
      FractionBox["1", "4"], "]"}], "2"]}], ",", 
   RowBox[{"2", " ", 
    RowBox[{"Boole", "[", 
     RowBox[{
      RowBox[{"0", "\[LessEqual]", 
       RowBox[{
        RowBox[{"-", "1"}], "+", 
        RowBox[{"16", " ", "t"}]}]}], "&&", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "1"}], "+", 
        RowBox[{"16", " ", "t"}]}], "<", "1"}]}], "]"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"Cos", "[", 
       FractionBox["1", "2"], "]"}], "-", 
      RowBox[{"Cos", "[", "1", "]"}]}], ")"}]}], ",", 
   RowBox[{"2", " ", 
    RowBox[{"Boole", "[", 
     RowBox[{
      RowBox[{"0", "\[LessEqual]", 
       RowBox[{
        RowBox[{"-", "2"}], "+", 
        RowBox[{"16", " ", "t"}]}]}], "&&", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "2"}], "+", 
        RowBox[{"16", " ", "t"}]}], "<", "1"}]}], "]"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"Cos", "[", "1", "]"}], "-", 
      RowBox[{"Cos", "[", 
       FractionBox["3", "2"], "]"}]}], ")"}]}], ",", 
   RowBox[{"2", " ", 
    RowBox[{"Boole", "[", 
     RowBox[{
      RowBox[{"0", "\[LessEqual]", 
       RowBox[{
        RowBox[{"-", "3"}], "+", 
        RowBox[{"16", " ", "t"}]}]}], "&&", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "3"}], "+", 
        RowBox[{"16", " ", "t"}]}], "<", "1"}]}], "]"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"Cos", "[", 
       FractionBox["3", "2"], "]"}], "-", 
      RowBox[{"Cos", "[", "2", "]"}]}], ")"}]}], ",", 
   RowBox[{"2", " ", 
    RowBox[{"Boole", "[", 
     RowBox[{
      RowBox[{"0", "\[LessEqual]", 
       RowBox[{
        RowBox[{"-", "4"}], "+", 
        RowBox[{"16", " ", "t"}]}]}], "&&", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "4"}], "+", 
        RowBox[{"16", " ", "t"}]}], "<", "1"}]}], "]"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"Cos", "[", "2", "]"}], "-", 
      RowBox[{"Cos", "[", 
       FractionBox["5", "2"], "]"}]}], ")"}]}], ",", 
   RowBox[{"2", " ", 
    RowBox[{"Boole", "[", 
     RowBox[{
      RowBox[{"0", "\[LessEqual]", 
       RowBox[{
        RowBox[{"-", "5"}], "+", 
        RowBox[{"16", " ", "t"}]}]}], "&&", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "5"}], "+", 
        RowBox[{"16", " ", "t"}]}], "<", "1"}]}], "]"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"Cos", "[", 
       FractionBox["5", "2"], "]"}], "-", 
      RowBox[{"Cos", "[", "3", "]"}]}], ")"}]}], ",", 
   RowBox[{"2", " ", 
    RowBox[{"Boole", "[", 
     RowBox[{
      RowBox[{"0", "\[LessEqual]", 
       RowBox[{
        RowBox[{"-", "6"}], "+", 
        RowBox[{"16", " ", "t"}]}]}], "&&", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "6"}], "+", 
        RowBox[{"16", " ", "t"}]}], "<", "1"}]}], "]"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"Cos", "[", "3", "]"}], "-", 
      RowBox[{"Cos", "[", 
       FractionBox["7", "2"], "]"}]}], ")"}]}], ",", 
   RowBox[{"2", " ", 
    RowBox[{"Boole", "[", 
     RowBox[{
      RowBox[{"0", "\[LessEqual]", 
       RowBox[{
        RowBox[{"-", "7"}], "+", 
        RowBox[{"16", " ", "t"}]}]}], "&&", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "7"}], "+", 
        RowBox[{"16", " ", "t"}]}], "<", "1"}]}], "]"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"Cos", "[", 
       FractionBox["7", "2"], "]"}], "-", 
      RowBox[{"Cos", "[", "4", "]"}]}], ")"}]}], ",", 
   RowBox[{"2", " ", 
    RowBox[{"Boole", "[", 
     RowBox[{
      RowBox[{"0", "\[LessEqual]", 
       RowBox[{
        RowBox[{"-", "8"}], "+", 
        RowBox[{"16", " ", "t"}]}]}], "&&", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "8"}], "+", 
        RowBox[{"16", " ", "t"}]}], "<", "1"}]}], "]"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"Cos", "[", "4", "]"}], "-", 
      RowBox[{"Cos", "[", 
       FractionBox["9", "2"], "]"}]}], ")"}]}], ",", 
   RowBox[{"2", " ", 
    RowBox[{"Boole", "[", 
     RowBox[{
      RowBox[{"0", "\[LessEqual]", 
       RowBox[{
        RowBox[{"-", "9"}], "+", 
        RowBox[{"16", " ", "t"}]}]}], "&&", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "9"}], "+", 
        RowBox[{"16", " ", "t"}]}], "<", "1"}]}], "]"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"Cos", "[", 
       FractionBox["9", "2"], "]"}], "-", 
      RowBox[{"Cos", "[", "5", "]"}]}], ")"}]}], ",", 
   RowBox[{"2", " ", 
    RowBox[{"Boole", "[", 
     RowBox[{
      RowBox[{"0", "\[LessEqual]", 
       RowBox[{
        RowBox[{"-", "10"}], "+", 
        RowBox[{"16", " ", "t"}]}]}], "&&", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "10"}], "+", 
        RowBox[{"16", " ", "t"}]}], "<", "1"}]}], "]"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"Cos", "[", "5", "]"}], "-", 
      RowBox[{"Cos", "[", 
       FractionBox["11", "2"], "]"}]}], ")"}]}], ",", 
   RowBox[{"2", " ", 
    RowBox[{"Boole", "[", 
     RowBox[{
      RowBox[{"0", "\[LessEqual]", 
       RowBox[{
        RowBox[{"-", "11"}], "+", 
        RowBox[{"16", " ", "t"}]}]}], "&&", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "11"}], "+", 
        RowBox[{"16", " ", "t"}]}], "<", "1"}]}], "]"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"Cos", "[", 
       FractionBox["11", "2"], "]"}], "-", 
      RowBox[{"Cos", "[", "6", "]"}]}], ")"}]}], ",", 
   RowBox[{"2", " ", 
    RowBox[{"Boole", "[", 
     RowBox[{
      RowBox[{"0", "\[LessEqual]", 
       RowBox[{
        RowBox[{"-", "12"}], "+", 
        RowBox[{"16", " ", "t"}]}]}], "&&", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "12"}], "+", 
        RowBox[{"16", " ", "t"}]}], "<", "1"}]}], "]"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"Cos", "[", "6", "]"}], "-", 
      RowBox[{"Cos", "[", 
       FractionBox["13", "2"], "]"}]}], ")"}]}], ",", 
   RowBox[{"2", " ", 
    RowBox[{"Boole", "[", 
     RowBox[{
      RowBox[{"0", "\[LessEqual]", 
       RowBox[{
        RowBox[{"-", "13"}], "+", 
        RowBox[{"16", " ", "t"}]}]}], "&&", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "13"}], "+", 
        RowBox[{"16", " ", "t"}]}], "<", "1"}]}], "]"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"Cos", "[", 
       FractionBox["13", "2"], "]"}], "-", 
      RowBox[{"Cos", "[", "7", "]"}]}], ")"}]}], ",", 
   RowBox[{"2", " ", 
    RowBox[{"Boole", "[", 
     RowBox[{
      RowBox[{"0", "\[LessEqual]", 
       RowBox[{
        RowBox[{"-", "14"}], "+", 
        RowBox[{"16", " ", "t"}]}]}], "&&", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "14"}], "+", 
        RowBox[{"16", " ", "t"}]}], "<", "1"}]}], "]"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"Cos", "[", "7", "]"}], "-", 
      RowBox[{"Cos", "[", 
       FractionBox["15", "2"], "]"}]}], ")"}]}], ",", 
   RowBox[{"2", " ", 
    RowBox[{"Boole", "[", 
     RowBox[{
      RowBox[{"0", "\[LessEqual]", 
       RowBox[{
        RowBox[{"-", "15"}], "+", 
        RowBox[{"16", " ", "t"}]}]}], "&&", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "15"}], "+", 
        RowBox[{"16", " ", "t"}]}], "<", "1"}]}], "]"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"Cos", "[", 
       FractionBox["15", "2"], "]"}], "-", 
      RowBox[{"Cos", "[", "8", "]"}]}], ")"}]}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.521598048358795*^9, 3.521598160456545*^9, 3.5215981918501253`*^9, 
   3.52159830856209*^9, 3.521598381939169*^9, {3.5215984170905943`*^9, 
   3.521598441169663*^9}, 3.5215985297089367`*^9, {3.521598596234272*^9, 
   3.521598613474216*^9}, 3.5216694284346046`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{
    "Add", " ", "all", " ", "the", " ", "above", " ", "functions", " ", 
     "into", " ", "a", " ", "sum"}], ",", " ", 
    RowBox[{"basically", " ", "the", " ", "integral", " ", "sum"}]}], " ", 
   "*)"}], "\[IndentingNewLine]", 
  RowBox[{"fJ", "=", 
   RowBox[{"Plus", "@@", "list"}]}]}]], "Input",
 CellChangeTimes->{{3.5215980889342537`*^9, 3.521598092442225*^9}, {
  3.5215982048169107`*^9, 3.5215982086746073`*^9}, {3.521599203265855*^9, 
  3.521599221568069*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"2", " ", 
   RowBox[{"Boole", "[", 
    RowBox[{
     RowBox[{"0", "\[LessEqual]", 
      RowBox[{
       RowBox[{"-", "1"}], "+", 
       RowBox[{"16", " ", "t"}]}]}], "&&", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "1"}], "+", 
       RowBox[{"16", " ", "t"}]}], "<", "1"}]}], "]"}], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"Cos", "[", 
      FractionBox["1", "2"], "]"}], "-", 
     RowBox[{"Cos", "[", "1", "]"}]}], ")"}]}], "+", 
  RowBox[{"2", " ", 
   RowBox[{"Boole", "[", 
    RowBox[{
     RowBox[{"0", "\[LessEqual]", 
      RowBox[{
       RowBox[{"-", "2"}], "+", 
       RowBox[{"16", " ", "t"}]}]}], "&&", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "2"}], "+", 
       RowBox[{"16", " ", "t"}]}], "<", "1"}]}], "]"}], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"Cos", "[", "1", "]"}], "-", 
     RowBox[{"Cos", "[", 
      FractionBox["3", "2"], "]"}]}], ")"}]}], "+", 
  RowBox[{"2", " ", 
   RowBox[{"Boole", "[", 
    RowBox[{
     RowBox[{"0", "\[LessEqual]", 
      RowBox[{
       RowBox[{"-", "3"}], "+", 
       RowBox[{"16", " ", "t"}]}]}], "&&", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "3"}], "+", 
       RowBox[{"16", " ", "t"}]}], "<", "1"}]}], "]"}], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"Cos", "[", 
      FractionBox["3", "2"], "]"}], "-", 
     RowBox[{"Cos", "[", "2", "]"}]}], ")"}]}], "+", 
  RowBox[{"2", " ", 
   RowBox[{"Boole", "[", 
    RowBox[{
     RowBox[{"0", "\[LessEqual]", 
      RowBox[{
       RowBox[{"-", "4"}], "+", 
       RowBox[{"16", " ", "t"}]}]}], "&&", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "4"}], "+", 
       RowBox[{"16", " ", "t"}]}], "<", "1"}]}], "]"}], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"Cos", "[", "2", "]"}], "-", 
     RowBox[{"Cos", "[", 
      FractionBox["5", "2"], "]"}]}], ")"}]}], "+", 
  RowBox[{"2", " ", 
   RowBox[{"Boole", "[", 
    RowBox[{
     RowBox[{"0", "\[LessEqual]", 
      RowBox[{
       RowBox[{"-", "5"}], "+", 
       RowBox[{"16", " ", "t"}]}]}], "&&", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "5"}], "+", 
       RowBox[{"16", " ", "t"}]}], "<", "1"}]}], "]"}], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"Cos", "[", 
      FractionBox["5", "2"], "]"}], "-", 
     RowBox[{"Cos", "[", "3", "]"}]}], ")"}]}], "+", 
  RowBox[{"2", " ", 
   RowBox[{"Boole", "[", 
    RowBox[{
     RowBox[{"0", "\[LessEqual]", 
      RowBox[{
       RowBox[{"-", "6"}], "+", 
       RowBox[{"16", " ", "t"}]}]}], "&&", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "6"}], "+", 
       RowBox[{"16", " ", "t"}]}], "<", "1"}]}], "]"}], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"Cos", "[", "3", "]"}], "-", 
     RowBox[{"Cos", "[", 
      FractionBox["7", "2"], "]"}]}], ")"}]}], "+", 
  RowBox[{"2", " ", 
   RowBox[{"Boole", "[", 
    RowBox[{
     RowBox[{"0", "\[LessEqual]", 
      RowBox[{
       RowBox[{"-", "7"}], "+", 
       RowBox[{"16", " ", "t"}]}]}], "&&", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "7"}], "+", 
       RowBox[{"16", " ", "t"}]}], "<", "1"}]}], "]"}], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"Cos", "[", 
      FractionBox["7", "2"], "]"}], "-", 
     RowBox[{"Cos", "[", "4", "]"}]}], ")"}]}], "+", 
  RowBox[{"2", " ", 
   RowBox[{"Boole", "[", 
    RowBox[{
     RowBox[{"0", "\[LessEqual]", 
      RowBox[{
       RowBox[{"-", "8"}], "+", 
       RowBox[{"16", " ", "t"}]}]}], "&&", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "8"}], "+", 
       RowBox[{"16", " ", "t"}]}], "<", "1"}]}], "]"}], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"Cos", "[", "4", "]"}], "-", 
     RowBox[{"Cos", "[", 
      FractionBox["9", "2"], "]"}]}], ")"}]}], "+", 
  RowBox[{"2", " ", 
   RowBox[{"Boole", "[", 
    RowBox[{
     RowBox[{"0", "\[LessEqual]", 
      RowBox[{
       RowBox[{"-", "9"}], "+", 
       RowBox[{"16", " ", "t"}]}]}], "&&", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "9"}], "+", 
       RowBox[{"16", " ", "t"}]}], "<", "1"}]}], "]"}], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"Cos", "[", 
      FractionBox["9", "2"], "]"}], "-", 
     RowBox[{"Cos", "[", "5", "]"}]}], ")"}]}], "+", 
  RowBox[{"2", " ", 
   RowBox[{"Boole", "[", 
    RowBox[{
     RowBox[{"0", "\[LessEqual]", 
      RowBox[{
       RowBox[{"-", "10"}], "+", 
       RowBox[{"16", " ", "t"}]}]}], "&&", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "10"}], "+", 
       RowBox[{"16", " ", "t"}]}], "<", "1"}]}], "]"}], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"Cos", "[", "5", "]"}], "-", 
     RowBox[{"Cos", "[", 
      FractionBox["11", "2"], "]"}]}], ")"}]}], "+", 
  RowBox[{"2", " ", 
   RowBox[{"Boole", "[", 
    RowBox[{
     RowBox[{"0", "\[LessEqual]", 
      RowBox[{
       RowBox[{"-", "11"}], "+", 
       RowBox[{"16", " ", "t"}]}]}], "&&", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "11"}], "+", 
       RowBox[{"16", " ", "t"}]}], "<", "1"}]}], "]"}], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"Cos", "[", 
      FractionBox["11", "2"], "]"}], "-", 
     RowBox[{"Cos", "[", "6", "]"}]}], ")"}]}], "+", 
  RowBox[{"2", " ", 
   RowBox[{"Boole", "[", 
    RowBox[{
     RowBox[{"0", "\[LessEqual]", 
      RowBox[{
       RowBox[{"-", "12"}], "+", 
       RowBox[{"16", " ", "t"}]}]}], "&&", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "12"}], "+", 
       RowBox[{"16", " ", "t"}]}], "<", "1"}]}], "]"}], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"Cos", "[", "6", "]"}], "-", 
     RowBox[{"Cos", "[", 
      FractionBox["13", "2"], "]"}]}], ")"}]}], "+", 
  RowBox[{"2", " ", 
   RowBox[{"Boole", "[", 
    RowBox[{
     RowBox[{"0", "\[LessEqual]", 
      RowBox[{
       RowBox[{"-", "13"}], "+", 
       RowBox[{"16", " ", "t"}]}]}], "&&", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "13"}], "+", 
       RowBox[{"16", " ", "t"}]}], "<", "1"}]}], "]"}], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"Cos", "[", 
      FractionBox["13", "2"], "]"}], "-", 
     RowBox[{"Cos", "[", "7", "]"}]}], ")"}]}], "+", 
  RowBox[{"2", " ", 
   RowBox[{"Boole", "[", 
    RowBox[{
     RowBox[{"0", "\[LessEqual]", 
      RowBox[{
       RowBox[{"-", "14"}], "+", 
       RowBox[{"16", " ", "t"}]}]}], "&&", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "14"}], "+", 
       RowBox[{"16", " ", "t"}]}], "<", "1"}]}], "]"}], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"Cos", "[", "7", "]"}], "-", 
     RowBox[{"Cos", "[", 
      FractionBox["15", "2"], "]"}]}], ")"}]}], "+", 
  RowBox[{"2", " ", 
   RowBox[{"Boole", "[", 
    RowBox[{
     RowBox[{"0", "\[LessEqual]", 
      RowBox[{
       RowBox[{"-", "15"}], "+", 
       RowBox[{"16", " ", "t"}]}]}], "&&", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "15"}], "+", 
       RowBox[{"16", " ", "t"}]}], "<", "1"}]}], "]"}], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"Cos", "[", 
      FractionBox["15", "2"], "]"}], "-", 
     RowBox[{"Cos", "[", "8", "]"}]}], ")"}]}], "+", 
  RowBox[{"4", " ", 
   RowBox[{"Boole", "[", 
    RowBox[{
     RowBox[{"0", "\[LessEqual]", 
      RowBox[{"16", " ", "t"}]}], "&&", 
     RowBox[{
      RowBox[{"16", " ", "t"}], "<", "1"}]}], "]"}], " ", 
   SuperscriptBox[
    RowBox[{"Sin", "[", 
     FractionBox["1", "4"], "]"}], "2"]}]}]], "Output",
 CellChangeTimes->{
  3.5215982097467337`*^9, 3.521598311309845*^9, {3.521598419394683*^9, 
   3.521598443621161*^9}, 3.521598532686325*^9, 3.5215986168485603`*^9, 
   3.521669432482685*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
   "Plot", " ", "the", " ", "original", " ", "f", " ", "which", " ", "was", 
    " ", "the", " ", "Sin", " ", "with", " ", "the", " ", "fJ"}], " ", "*)"}],
   "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"g1", "=", 
     RowBox[{"Plot", "[", 
      RowBox[{
       RowBox[{"fJ", "/.", 
        RowBox[{"{", 
         RowBox[{"t", "\[Rule]", "x"}], "}"}]}], ",", " ", 
       RowBox[{"{", 
        RowBox[{"x", ",", " ", "0", ",", " ", "1"}], "}"}]}], "]"}]}], " ", 
    ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"g2", "=", 
     RowBox[{"Plot", "[", 
      RowBox[{
       RowBox[{"f", "[", "x", "]"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{"x", ",", " ", "0", ",", " ", "1"}], "}"}]}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{"Show", "[", 
    RowBox[{"g1", ",", " ", "g2", ",", " ", 
     RowBox[{"PlotRange", "\[Rule]", "All"}]}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.521598217767166*^9, 3.52159827586502*^9}, {
  3.5215983501798067`*^9, 3.521598355769196*^9}, {3.5215983861350718`*^9, 
  3.5215983884860764`*^9}, {3.521598460053459*^9, 3.521598504056242*^9}, {
  3.521598567503191*^9, 3.521598571482473*^9}, {3.521599241182616*^9, 
  3.521599257684524*^9}}],

Cell[BoxData[
 GraphicsBox[{{{}, {}, 
    {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJxNzmk41IsCBnBjGApjJyNbUceSlKWjo/5IyVYpW+cWKSolp6RIJWpKhXTO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      "]]}}, {{}, {}, 
    {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwdmXk8VP/3x0VlK3tKaSHKzkeLopyICEkiSyGiRSlb0kLaJBFFskYhkpBs
Zbn2fadsWWbGMszMfStblvi9v79/5j6e4z3e55zX65x7348r4XDD1ImdjY1N
DH/872rgRG8rHTfXVP7/6xPN1Uc3uw6K7QWpyqytA2KOsCc+MvarmA4EP9tw
OkPMEwyburLjxMyA8n5DcIDYY7BwnCt+hdet3V23W1MsHPqVnx4NxuvkTYcn
1TclQcKGk/6BeF3EH7YXWiI58IDr6+5neN3XWgtD59WVYGn1LnPydxK43lho
L3rVCbwrD87pbcsEg3NJN0To/SB9iqRXPM+BglCjreWyNLjVfBAip79BeiKv
TNyeMeBTyh2p4/oOzlHHe/y0xiApWCVoUfw7KKG3emdPjkGb0e4eW93v4Ljz
oe608xjIN4h4SEd8h1ieGIW8d2MwWIM+ZKsVws91PWOe6+mgV5bM13SnCIzV
9boK+ukwsEMid/lFEbh1DFVcmaCDp1/sWZXEInhVYl0pMEeHdxCWGtZQBOVk
A/OIwDgsFvtpW4sXw9fogJOy2uOQ+f2s11hxMRS6fuISTRqHjTmCA6tWEbDy
KuX+4fMTcC5o0WxYlAAjo5DomGsT8N5xpKFagYB718OtWN4ToLDh27fnlgT4
PZ9Mv/pyArS9zr/ekEVAqzUXd0fZBOyPtfgQrlwKcTOxaXo7GGBv+8EmdaAU
Os2ULr/vYMBjgy1RUeOlAKcfGDsPMODD/tDOwOlSENu1KC89zgAm3x1DF54y
GHQ5U+CxzAAv4sRB1f1lsHoq5bmHDBOCdsyIFAWXgUFjeff8bSbkUY82thwq
B5ZHjCqbMAt+6j/4HaxXDgYmH42mtrBgNqNE1Mi0HH6Nn9LrkWKB2t2D9rWX
ysE8wKXZZz8LCoSVZ0tflcMM+TtHxooF33Q278iml8M61H6fPZYFvWkWuq5T
5dDrqNQikcSCBYHXzkrL5eB2srRsTzoL1Pv5c9OEKyBTlu2hchELvt9cY5Co
WQHtL17w+PexoOjDpEd4eAVoR3xXSN9Iwq91SlGm8RVgaynDNb2NhCX3qyUC
aRWwRv76SaVdJByGUa5gogLkUu+L3NlLQklXX9yTiQrg/ce2/boJCQRXTY3X
kUrYfI92t+oJCeXOcVusmJXQ9ZK9SXyUhK/jV6/azlbC3fl+vhMMEpIuqxde
YKuCY2Fzym6TJDy52GV9XaQKgiV6OF8vkKDvIBj96FAVyFfxdBnwIWixerIp
I6gKYg/d0XfZg6C0+/TlrxFVML8rLaJXDUGWhWRBQUIVXFIS/KBxCMErc8Ki
IqcKtnmmrerRQXDm1HxE968qeHp4h4+fOYJf+i4bOBSrIfFr1NYHngiaajSc
uNSqQdUssVDWG0HJMZ7c9VrVcNgtbVX1XQTxOilmm8yroamB16/nIQKHI5Qw
RZ9q6BdM3n4tFMFpIpOm+rQaLlSyd30JQ6Cj6bvnwMtq2GP1Up4RgUD60JYO
7eRqeCmqlnIgDgFdzVzIsqkaJt5fr9b8iKAnb6eDTVc1WMkv6kikI6jf9+eL
A6UaeumSFnMZCD7tCTnlMlMNp7N+/Oebg+C6cl3ow601oKL94/1sCQK7jDdD
T3fXwD25XQk3yxCYKF5UCf6vBtS9c2ToFQhU5Tla3+jWwPCO/K6UWgQzuw7z
f3apgQNeKWEv2xBoUrVrAr3x/+s/XtTTgcA/Tv/+5Uc1oJextF/4JwJRETO0
M6oG0vPub7PuRWDbYpWyKqkGEibPPLv0C8GHQDu7wYwaGIk20r44gGD/qqst
0ZU1sLWVEa1GReBb5PrUu6UGVke0H+AZRlB9ywvO9NbAtLapRPMIAgvyQabg
JI7fkdIsO47Auy8yJGBLLUSf2fZUBWG9I97qXdxVC2nO9xyDJxFwmSatHP2v
FkK5M/z7fiOIqs28sXKsFm7qyL0xnEZAfZS7u/9ULaxdZ/7YZQaBHBQOfj9X
C+J5wjl+swi+51af9HKvBfMWi547fxGwuzVymvnUAmqcarKfR2Cg0E78F1AL
zvUmHOoL2E9jXbf4w2ohkZ/3Nscigr73/cqsuFoY/FKlVIJZypY2Vp9aC7/D
5KSclxBcExuPT/1aCw4XJyw5/yHI6SQt/EtqITKlqPE15qWQaX7HulqYSrS7
v2EZ+8VwoUarsxb+3Ix09ccctJbNb/tgLRxbuyeBjrmzbM2Bf+P477zsfIdW
EGz14Z3sna4F63WD3/wwXzwgmFqwUguWZ9MS8zBnTImej+CpA/0thg39mGcz
xDd5bqgD0cOZKrOYNZ0lW0/tqANdv4aOFcz+0jIByvJ1MOcek7OAuXlI8cj6
/XUw5ibRMYpZNHbP34kjdeCZelG5ErOtxcGsWsM6eClwt+4V5g9CcPnDmTqo
cr/5zhQz2aSz47F9HWy/6JHPgXn/M4Nu+2t1sNskivcDzue+jkko3KqDJkeh
twcx166Y6299WAcWHwRulOD6CBSeZVsMqgODkUbfvZgtvewLut/UwYlS/6YY
XN+E/y655r2vg/VJj89O4/rTmddkwj/j/RqEZTUxq6S6D7kV1EHP4YD9t7F+
pdt8TRSb6+CufJhQBdabq/cRF29PHdz4PkVpm8P98vpZKZ1WB5VFTX/asD8o
vK9Vkubr4ItQU28y9pNcTTT9wep6MKD8yb49hcD9YUKCHX89tG0Ka9b8g/0z
/0lgi3Q9UHxetMdiv25p0p4C5XqgnlNdb0wi2Puu54fjwXrYuiLk/oeJwOk4
Z0zGiXrIjCkpEpnA+Uc5SGt71YPQVaOLBA3v7zLPecmvHiLvAAcP7p8FrdCJ
54H1UHLHpkVvCIHCRHHmj7d4/cmpuVjcfyHqYupXauoh7Mvr+M+dCFL5ssRf
tNXDlrcN9S/bcf7UYyvZffVw3MJR/korgj+BnpVLqB40fmmE/m7A87GvxTh0
UwMczRJiv1KOQPye/4X8Kw1gsz/nwhSeR/tMth775dEAVr3ulrxpCIylcmRW
+TYA2/WBV6IpWM9GCsvgVQP80XvYv/Yd7j/xw94D3xvglMFjpnE4go/FU0Fr
1jVCftZ1UV88X8tfBt6QE20E0z/ESj2ev71OEqYndzSCQqe0Dq8bgnV8JzdG
7W2E/1I1hp2uIHC1TXunYNMIPw+s+vzICvtp5Xze6YxG2PNjZ5MDnv9GJ0of
6hY0wmiL9eCSKoILMdtPqpU3QoyLwnCgEoJQtYGxzT8bQT75YeNDaQTjN86K
Uf81wvz83uNUIQSxQ+b3XE80gYJi0XN7fH/KVsrVd7BoglvMn/Ea+P5Ve09k
g5l9E0gPqFZyU0iY2dTxWe1mE+T0f9N9+JME41Mmg8uxTXC4/YzTcCkJq8oN
tIOZTZD50HPyehgJmwTS+O7PNsHeKD+O58EkKNly97myNYNQscDxmKckWC/U
eJiJNIMuF+kZeZeEHFXd5C2HmiEs9nfomgskXEwErrTnzVD5LW0qXZmExsd7
m6vlWuDc+oCt2qX4fs/fwP5yXwts8dKh6BewIDXKXu3skRbI+LW4QzuLBY8y
XiQg8xYYCFiUXJeA13fT3Tc9aAG2bTORy754vXzcRueuFih7/vrteXUWaI8/
zFqr3QqVIWf696Yw4bZSc/1VvVYoIVHqqzgmZHmIjbQatcIuxgY3WhgTti1n
isVYtEJu4CcuWz8mzAv1P1R2aQWFsPK2fEu8/pCauWVkK3B2C1at4mTC9lDG
/EeyFSKoSYoC1gwosb//MXuqFXQCPqm+OckA2z3CVoV/W+Htc+dLwroMiP2p
XtDI3gZa0sWuDGUGbNoa6IVE26B3tZn35jUMEEqTmdoLbdD6Zo+o9+cJWFPp
xCRC2oAuN37EZHYcGHODAz9U2oF41OR96wod8i6FlBvsb4dT1rJK5mfp4Nel
+YHQaAePqIwXu0/QQTQ/zuXjsXb4Mh17NU2Fjp8nzy7dO9cOLz1Xn5SdG4Po
6Z9iUgHtsOXLZKzgwzHQ/91k5j7YDgYCR52LQkYhaaKwnu9FB/RVLVbxBg0D
39YUNDzcCYazl2vEFYYg6EruxQSpn8A15EMzsemC2SOfhi/f7wL104f74xfw
nFWtzBGt6IYAuTvvFvNSYDCj8nmbRC8YUwMM/UYIYtG5M0b2Th84/tOK4/Bp
J+S1OJcvFv6CEKRfofSjj9B7L3Hpy8YBgGMHLma8oRK3ttpJUs4NwiQjcJrz
zijhYKJy5pf9IBRIh+ipBowSxo9WBXZdHIRmqsbA6YhRYtd44u8m10HQEU8t
vZc9SnTm0Eu/Px6EjCj1MseJUULFyN0uPH0QZiRX/Q2wHCPod57E6i0NwknT
MJl/inRi4oz85XdsQ1BhtitijQadOD8pzL6dYwiufm58u1qfThjuHNm3mWsI
9rgqu4za0wnJZ0/jBISGQM9zm/uB13Si1azx2j/pIRAoPlIjuEAnFJjmvF0n
huCs0qH8W0XjRIGZERFoMgSJlOvnDerGiaPF2h6ap4fA0CdQV/DnOGH9Qrkv
2XIIZFnK6XfROPFMhfuT54UhEJk/frxcYoIY9SwyELqN+btaleDjCSLhn2Tg
iaQhsM1pm3sFDELhopjmqpQhyGHfeohqwCDym/n/5HwcAg6l8+ukzzCI5vgl
K/HMISg6eOzQk2sM4p/WT1nGtyFYvUfMMDOSQVj7P6sLaBmC1IqximSSQQjz
T3JVLgxB7IyawUIok2gvDnx6/N8QuNofquWNZhKvrkmvbVnB+Z4qpwsmMgmh
emuO3tUUcHBdYV/Kwfyk6h/iowBDeuaAXjeTEFiM/rNlJwWkUq7G54mziHVj
ur88DCmQq1fOoMSyiMbXQ9bzJyjQwtWw/UESiwjSudvja0KBqmWPIJF0FsH7
PuvnM3MKFMclcGwqZBE8Nlva4u0oENSlJfqym0VwdUxWNXhQQPX8P+3jgiSx
mojJ3BlLAcrNIKeS2yTRe0hHf/AtBYS2i0g5+JFE5nfmUPQ7Cqznnkme8ycJ
67zDQkIpeL2179hcGEl8+TzoyZZNgc3duutPfCYJ29id6v01FHh2WPeMXj9J
7N3c2B5ZTwF6lTJ9DY0kuCM9r5o1UaCb/Qp/Hp0kcsKqYhvaKbDjvbIwY4ok
eJ9fWvnWT4HHvHYpKdyIKLj9qTJiigLJZkvtl1UR8WLutI3pLAWMopaegRoi
Ltxcmlk/T4FvNxYzOA8hgs/txO4nyxTw3sinfk0XEU6X0TMPbiro+edu9LdA
hProG0nldVR48jd1Ff0sIgQcjxRO8FFBLMNXX+M8IorsXjLtRahw8ELlcO5l
RAhZ7Dlpsp0K57yGdix6I4Le2TfGK0mF/fn938fuIaLY9LFfjRQVTGTPvK/y
Q8Rl4x9fNOWoIG/01NQ8ABElurdEFPdRYU2ZIGdlBCKu7i3s4TakQt/Flyb9
WYgobf2RXnCCCr8+WQi1fkXEBpfJ+5dMqHArffXLnDxEEMnSu6rMqfC2epgw
LUKE8MZQd7/zVNA9QC2lVeP9vqbpKl+gwosTP4851uF4TlZtGnCiAjAW7/9s
QMSlgIUSjatUQIZ3OUNbEVE478g7d5MKpyf5jS16cP4R9weSvalg9FLGxKkP
10s1+ovZXSo8P2z1z7EfEfxXWyyy/ajAuuRqfpCCCEfOCTn7R1QY7I9bXk9D
xLfE1cv8/lS4e9LtZOcw1uPXwSSX51So5R8c3kfH+nmb3RJ/QYXl2andbeOI
WL/hhkFDKBVieJP4bRmIyD+RNCkTQQXmnGC9EYmIdRMlFV2RVGgT9o3JQIiw
9++J8I+hwsZRCh/7b0TwEnyHhxOoYH1ib4/PFCLOn5UVCEukQnbfauUP04jI
nTtK0/pAhQThl1KlM4jgCbfNm0ylgo+49beGWUTYqdx+Fv8J6/96jFk7h4ic
xrBzxhlU4I2oKcn/iwjuKxnK/7KokP75hVLkPCK+vqP9sM6jgmmhzqjiIiK4
NJdTub9RIUPeR5GG2aZ3072CQio+PysLBi4hIttrz8lLJVTwEhd8KfkPEZzC
xpKiZVR4xPqVno75XOblmcoKKiTPmznKLCPii+GjWo9qKqRFauW/xryWHhcj
WUeF2Ri35GnMZx8XXG9roEK08Xcl3RVEZO3o0PJrpsKFm3OmTzGvKWaJKLdh
fY15hQoxW1tx0fs7qJAfNnB1CHPmjGRh0E8qiHudPz+HefWrwy80eqhw7b0/
wucDwkrJ0n6ijwoTmifE8PmAyKh33xs1QIUmRl7/CGaOS8Gc+hQqaFY0HqrA
bMmR2jtLo4KF1dv9+HxAfI4v/5w8SoUtRVoN+HxAsB/q9zMbp8JVj46F1Zgt
uudOczCp8NfPqyoV55PuKbQ7m6TCgfNm8pqYVwkqLpz/TQXjtXEKeBISZz7r
NfFPU2Ge4l93GPOn4w4JJbO4nn3G7Km4vnsVJDRhngrxfCZn+DGX8A31EYtU
SFHLlnbGeuj9fnv7yDIVbP7luhYsIKK1w2ZjGRsNMpgJagtYT6s88VwtDhoE
eBffUcZMjewzLV9Dg7J5a3VLrP+0jdWLCh4aOBVdV3mM/eJzZJOCznoa/JCP
vfQU+2ntzq66Sn4aXGYWiPtiv4nRzdZUi9DgyhtH9mN/EKHpbnKvdhsNcneK
1AILETVm/JuPS9BA2kl2cQD73UStOb9uJw303s5kuk0gwmHJcKpehgbC36cS
3MYQ8dRfz7lJlQaC72y+9A3h/ryylst4Hw3OuAyybxxERLRhVXKzGg3uVm7q
08X9mS5wlNJyCMcjGyLpi/u5NVrTsv0Y3v9TiqRVG87X59+M6XEayPoOlai0
4HztisI6DGmw0s9NX2zE+Uqpt3Sa0ODTpZTha7U4n8x9x7qsafBV53rCtxJE
vH85TbOwwfmvcS5WxPNHwfPrg247GpySq7n++hvO9+B/xT2ONOD3/P4KcnA+
FQp7f12ngef0rn/LqYhgJDPazrnRQCXrcy//B0R4BqTd6PeggUXJYXORRJzv
CZlPA940UJ+T3fU3FufTtVOS8pAGkruFreRDETHD2CwwGkEDPyaPpJYnIsLj
xmpio2hwZK1wvoYrIvaczLl/OpYGREpux+5riHDLPoFK39HgrcDpT50XEMHy
9muOSadBz99tPA9METGyZjToVDkNHj4wOLFLERGP87N1uKpooBlcbKgug4id
V+4vldTQwCUE/YGdeP40brqm0ITrq12ms0MMEf2vDA05u2nwYBtVbd9qRPzY
/oW7mEWD+OSR+9ldJOHZ5lPmMUmDUrMEeWobSQg/MrgtN0UD099dKRyNJHFq
lEZ/85cGw8QrcfFSkmhKF6115xiGYaebOokpJFF18J6/jNgwuBlorF/vSRK5
p/U4wnWG4e84rfUCO0kEGBY8EdcbhjATuYdmiyzi3FFZruTjw+D3Z5XiwWkW
wb6Hd32e8TDYPG29MzDCIoyFWkS7LYchanhcL6qWRdBbz8iJuwzDBvdKaH/O
IjYbXzyV9HoYppzA9hI3i2DpdnUoRA5Dmq2iVD8biyg9rH8mN3oYqj5K6Ov9
ZRIXFeXOVscPw9WZsfy/o0zi6zrSkf4RPwdr341srWASRg03vRVKhqFp2v22
xV0mcV//SXzO6DDo+M8+66MwiHbby+dUxofhMRx1E+1mEFI3DcXSGcPwhWNb
3LFmBlH/TjAscXIYQm+8b/P/ziBEFuP8Xy0MQ6d8y6anrxhE6uc8F1e+ETDy
93wceIRBtArRNRT2j8BsgG9jQfgEIdFv0J34ZASsM/NFE7aNE4HlGpnmASMA
97x8QHCc+JOi4M/5fATYbXoedXCME+XufHuvho5A9CTraQ+dTjhytYeoxowA
uiQlZptNJ1L3WOmVZY3AOuVNLcZH6YRS4KW8gb4RKBDfvm7x3BihrvY4XEx1
FKqXsv78cR0hzm1rmV/VMQoBbs9EM25SiJn6YKrrgzH4jyrgZ2vaQ0SutvU0
laJDkaaqi5VDCyE8kPuevZIO79I5DYpu5hNrfB6YHXQbh9KLacmu9V+B7aNt
JlVoAlJXnXmz6mcTuEdnBguVT0CdZuiRMsMeKJYP4BK8zoDz340KDBwoIGjg
rvCQjwnvzMtyl8+NQEIZP6+6IBN4cuxuy7mMgMrBz+O/hZmQMkVaGPmMgLEM
/YO9GBO8/2zUd48bgcC1thJaUni9hbj0sf4RWF1xXJRNnQmbPzg7cZ4dhVkN
CTZfJyYcc2x+VWw8Br8UWztuFzHhlnHwkZsbxiGeIejDQTAhlOw045UcB4eP
p3cFlzHhWuk5wzdK4zAu1eWdUM2Em1//1YfqjcPsloGtNa1M+PNjWwD37XEQ
5GFeEhlhwrpahaT1veNwbJRzKWM9CwaWz4Zqhk8Ad9Lx5AMCLKCdZnk8jZ+A
RvvnxuVCLLCe+i+hKm0CTvfzvfuxkQUf3IlSibIJON+54diSBAukXY8lWbIm
4G75ztDj+1nQrSUpWnyUAVlvQWrYlgUbe2LCtekMmLozxWlvz4KCW4TFwm8G
7LdIYfRfYIFogZdhyiIDCvn5v3ZdZoFY1KfcIVznar8BrQZ3FjRzOyu27WVC
n4OPXbY/Cwr3D99O9mXC2t2F0X4ZLFi9b57KzsOC4xw3fP/hc/uBL2z1Vjju
oEFJhztf8ffyfO7Jm1kgGBko64nP+b3OV/5ulmeBOLd1waVyFnD5Wj3xNWSB
KuPvD+OfLNh3VpMuFcgCm8z9gluXcX5btRd68DXP+i9fKxsJhmLzA5ZrSeBb
+33dIw4SJILzNtavJ6H03GGucS4SbJlFtx6JkyDJo7OSI0xCuV5c+KmDJIw6
nmIZyZJgGW9/1dKVBE0BYcaKPAkBjo84F71IeFPYSc9WIsGF3aEyxIcEfSHL
4U17ScjwtwsPCSQhjbDtG9YkQe0guwY9kYTrm6/V3TMjYfgUQ2qxg4TqKsUa
ZQsSdnJu9yjpIWG7G6qkWpHQUCea6zFIQmuNe6m+HQlN5lPcORMkqN68nS/i
TIKipWLWczYEcy3+yen3SdC7KF4fLovA5K5+ot1DElp+fJXzUkKQuovnndAT
EnI771oe34PA2ic41hvHte1Ar1DVIQRFcuFhOq9JqBQdrhY8icDvybsHv9JI
eJ/E77DsimD9LU4D+88k7I5sqcj3RBB92UVoNJOE1U416Y7eCL4aHkxEOSTI
Hg3hi7qPYFSwrZKdwPHqToxfDUbgzqEW/LSMhP3xWTZloQhWpmPN11WSYML+
8gRPOIJN3ZdHN9SRcFH5RqxXNALDt2xcsrgujKMOHQUfEHSHXGz9/IOEGpM3
q9M+InB80Bip2o3jl1mb+iIdga9jpOyhfhKOvl45opqNIEtOxfDkGInn171Y
ahGCw+IRwp3jJExy3D5yg0BQv36pz5JJwjvF9caoDAFtsuaaw29c/3Te93XV
CETz7V7cXMQ6m/cKjbUgSEytOrPwjwS6IovO145AJVp++31c94HmfRJynQiO
+8xlBqzBOmiK5qp3I7h3NKQthh9BzyTzdOUgAu59M1E7hBAwJB2ln1IQROw6
65AsguDzJGl6mIYgk3v3VIYYAnavYOLRKAJqS4lI+U4Et4Jkm7yZCG6USfUf
24VAkmXu8pOFYCk7MLlBBsHs7RzH3QjBhogz+38oYh1yZs8k/kbw/mnRspUK
gpnDAybNfxAo3ZasGVBF4Jm2Es+cQqB/jrSgqyG4IKF8iGMWQecJsx0u6gia
914JWMRsD9/pv7Evqg/vkxmbQ0Cq7PjiBQicWvdtqf6L4I6k/+1FLZz3UyF7
fB4AThGmlp8OggIO73mbBQTha0x51ughKGRtHBZdxHnSt8bwGSEwbhrNcFhC
EBD35PyAMdbZ7mPrmn9YT1OWdMYp7DMtb6kozEc4zRk+ZghMU3nSxJcRiBcV
ZZ2wQDAftd0+FPNfVymvrdYItk/4HMfnAeiQDtJgnUMAh6Yd9P/3PqB3iq3Y
DoEBh9XnIMyBIWergxwQ5D0IlCn73/sDnYrn55wQvKm73omf50F7Xu6UwmUE
H4qmsv73PmBbxivRJWcc3zr+kv+9L5h3WOhrcEGQdLBkcRpz50aHdzG4Lx69
Xuvcizmrse7iVQ8ErkdmuLIwBz34T0HDC0GcXHz3TcyX90f95rmNgCIs0SOP
WYfBlt97F+/3PJ6nHce/PeHyvTTf//nlmMtlzAtmrVp3HiBoczNchXA9fnIf
4DR4jEB93Xi1E+bskvhGsadY36ALJY24ni88OF+NP0MwHbKWvhOzs8wNi29B
CMT8pHWu4vrr9v8UfxaCgOfNlo73WJ8drzSplq8QrO03fF2P9Vs69iFF5jWC
LzISz6lY35ysm6q1uA+vqAYL07AfQp36597E4Ton7khpmEFwdbNu8aUEBHIP
TF2TprEvH4voc+I+jfg2lLwL+235wL31XanYj/95C7dO4rxYtPYPnxDsOSn1
7Qr2a6jFV5tjX/A+d/wzXbC/r63bslM0B/tkTd6q7gnsz7KH9JE8BFrKrBeq
43heyJl6PMF9/IOv0KZgBEHv4LcD5riPN0Zwv6Ph/skLl1iWKkcQa9MiuYL7
6/ryZEBlDQK76ScjawcQ/GoLecvRgfuVkf/I6gf2qf/chQ589X37/uda/H24
hp1sIu7bIBsr16RWrHuyUo42/p3GxvF7WQ0Ivns31T3AcTzt89q6Ds+LCMV9
Iadw3OdJ1zqNEgRu1FgzCZxXOodP9dlCBDJG1wZLcV1OPnnw7VougtWrOpNC
cR/JeV3OtsHzaShXw/k81kHATZMdMvH8dU5UVsG6Jgu+SBPA8+zNdt6Z//ku
JHM8vR3X8f8ARFXp7Q==
      "]]}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesOrigin->{0, 0},
  PlotRange->All,
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02]}]], "Output",
 CellChangeTimes->{{3.52159824648643*^9, 3.521598267208596*^9}, 
   3.5215983140607033`*^9, 3.521598389860264*^9, {3.521598421395258*^9, 
   3.521598445789652*^9}, {3.521598489645241*^9, 3.521598535321662*^9}, 
   3.52159857226263*^9, 3.521598621293223*^9, 3.521669435269886*^9}]
}, Open  ]],

Cell[TextData[{
 "\nOh! Wow! Therefore the ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["f", "J"], "(", "x", ")"}], TraditionalForm]]],
 " is some sort of reconstructionfor ",
 StyleBox["f",
  FontSlant->"Italic"],
 " based upon the linear vector sum of the form ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    UnderoverscriptBox["\[Sum]", 
     RowBox[{"k", "=", "0"}], 
     RowBox[{
      SuperscriptBox["2", "J"], "-", "1"}]], 
    RowBox[{
     SubscriptBox["c", 
      RowBox[{"J", ",", " ", "k"}]], 
     RowBox[{
      SubscriptBox["\[Phi]", 
       RowBox[{"J", ",", " ", "k"}]], "(", "x", ")"}]}]}], 
   TraditionalForm]]],
 ".\n\n\n\n"
}], "Text",
 CellChangeTimes->{{3.521598981486245*^9, 3.521599073250255*^9}, {
   3.521600045840745*^9, 3.521600046087214*^9}, {3.5216005528419027`*^9, 
   3.521600552953827*^9}, 3.521605866791739*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Scaling Equation Or Dilation Equation ", "Subtitle",
 CellChangeTimes->{{3.5216000142265463`*^9, 3.5216000429920187`*^9}}],

Cell[TextData[{
 "\n\nSpecial case for Haar Wavelets:\n\n",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"\[Phi]Haar", "(", "x", ")"}], "=", " ", 
    RowBox[{
     RowBox[{"\[Phi]Haar", "(", 
      RowBox[{"2", "x"}], ")"}], "+", 
     RowBox[{"\[Phi]Haar", "(", 
      RowBox[{
       RowBox[{"2", "x"}], "-", "1"}], ")"}]}]}], TraditionalForm]]],
 "\n\n"
}], "Text",
 CellChangeTimes->{{3.521600055100361*^9, 3.521600059328327*^9}, {
  3.521600110487412*^9, 3.521600153868744*^9}, {3.521600390749661*^9, 
  3.521600434312777*^9}, {3.521600532792552*^9, 3.5216005498735933`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"g1", "=", 
  RowBox[{"Plot", "[", 
   RowBox[{
    RowBox[{"\[Phi]Haar", "[", 
     RowBox[{"2", " ", "x"}], "]"}], " ", ",", " ", 
    RowBox[{"{", 
     RowBox[{"x", ",", " ", 
      RowBox[{"-", "1"}], ",", " ", "1"}], "}"}], ",", 
    RowBox[{"Filling", "\[Rule]", "Axis"}]}], 
   "]"}]}], "\[IndentingNewLine]", 
 RowBox[{"g2", "=", 
  RowBox[{"Plot", "[", 
   RowBox[{
    RowBox[{"\[Phi]Haar", "[", 
     RowBox[{
      RowBox[{"2", " ", "x"}], " ", "-", "1"}], "]"}], ",", " ", 
    RowBox[{"{", 
     RowBox[{"x", ",", " ", 
      RowBox[{"-", "1"}], ",", " ", "1"}], "}"}], ",", 
    RowBox[{"Filling", "\[Rule]", "Axis"}]}], 
   "]"}]}], "\[IndentingNewLine]", 
 RowBox[{"g3", " ", "=", " ", 
  RowBox[{"Plot", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"\[Phi]Haar", "[", 
      RowBox[{"2", " ", "x"}], "]"}], " ", "+", " ", 
     RowBox[{"\[Phi]Haar", "[", 
      RowBox[{
       RowBox[{"2", " ", "x"}], " ", "-", "1"}], "]"}]}], ",", " ", 
    RowBox[{"{", 
     RowBox[{"x", ",", " ", 
      RowBox[{"-", "1"}], ",", " ", "1"}], "}"}], ",", 
    RowBox[{"Filling", "\[Rule]", "Axis"}]}], 
   "]"}]}], "\[IndentingNewLine]"}], "Input",
 CellChangeTimes->{{3.521600443773843*^9, 3.5216004449992332`*^9}, {
  3.5216004775889797`*^9, 3.52160051357439*^9}, {3.521600571304226*^9, 
  3.521600637760639*^9}, {3.521611030552297*^9, 3.5216110337018127`*^9}}],

Cell[BoxData[
 GraphicsBox[GraphicsComplexBox[CompressedData["
1:eJxl1As01XccAPCLjHnebDSV92O5HEnGwey2hkjyWKIjzy2cSyMjnAzd5DXq
DjUTqS4hIlMk3JvHPZRMXO8rj8uV5/Ue7umw7ax9v5s5x3E+5/99/v7+PzXf
YOdzwgQCIe3P37/+6pMVZra3F5iE9z8RHfHn/Rl8cHe35EyDzzxY6Xnwxyb7
58BPAptFZd/MgL1TDy0OUKfBG+mXkpjkKTBdZlgxa2wSnHP8UCg7mQemBvlE
6thOgC+JPIgIneeCfeI6NHuLxsA36nlZOZRR8LORA1Kl6sNgDeKRo6duc8C/
kpIo3PF+8AirQtXYuBfM07thyKxig3fHFBvrC3WC9YwX9ApWXoGvWM6/rols
AcufKqOd2dOI/X5nybZqPgMXcHhp0/FlYA+n/Y8532SCayQu9TSGZ5D/1iL5
M66Q8mW3crDGYu2mWWMN2JY+0H7SrRFsZS8nsvakBXzdqy/OoPoVuOWkkrSj
XCd4Xk0+piubDQ4P0/W5rtAL7hsiOvu19oO9oz5/K3aCA27SNUlpEh0Ga39Y
N5VvM0r+Zx+lukAr0aQxMEEgXBzK5YLXneo9WVoTYI6R1z6teB44xJW4W31o
EqyYOeG2S2kKXOZ+p3AlchrsahFr01o/A67wPK9u9m4WvCHxlUiNyzzYudPc
WCmLD37/PeDzxPaSw174fZCEBZWB7vlgU9GDhaM8S/CLSi/LiuR8OI/0rpqn
vKIhsHhe38MEuxHwPe5He1ym8LyOiOvQZE5g/yPjSy9/Kcf+U/yFO6SQYnD5
apDG1GA82O+c2P6CInwfE2tvt6OzsP6LIMNx+WXct58kfu1M2m3I9/cn+VVt
USH/QX8hOYCP81bTVSzE7uN8JrvjB1/14XzWPMqeFEEJ+HFbF8uh8xr46rbT
Ki0E55FRqU5VZOE8bZKxFlKddyG+STU5MZcYCv0HapkX13Nwnncu+ZMSUTjP
1+YywkIvwiE/6AuauPJaKsQzBMfi51Swf+hSdoYIG/MND9j7Ts7iPhe9i7pq
yA/xvuJQ276c/Al8elciP/ss1jOIjPK5VYb7CBLqNswV6HifZVi/DDTyhnmU
y/1qU32xv5tcWH4AMxbiU1aknWmSWD/zuEfA1TqMb13n64iKRUO9W62OTMMC
f8hfFqJW2RhhvmNWP+PyNOY/qjykvbKG+8ooH3vkxMV9o292MGW0MsCMhLuz
ec5YryF/0O4sHfdNt3TvZT/FfXuXqHnEDRuYr5zTUmDviv35MWyzkx5UiG9o
04k0FcX62hEMZ+sKjH/twDFobw+BeLetb3P3kjB+rNm0+OgwxsdRSoPYJAr0
11wnBTLkMV53vMf0poc71GMGRnQ/X8X84E2NpE0Bns9gtEJe7mG8v+dW1kzD
m/F8llv0Kffssb6EuWRDXS6ejyedxFKR+N/9AfNtXNjYW+aE/X8zVT24L+cK
xP8QUCqbtob//99JL7TcL8H4dFaYor/d9xD/Y3QvTUQL5yG5U5Tp/RjvGp7j
WUjE55+8UeJvFftCvrhwka3aAsYvOny6HBx6GvrXX4i1ivrgX+9LKuRnfX8n
/H56rL28BZi/8/3u3H/nfbpz3//G73xOIPwBTAB3+A==
   "], {{{}, 
     {Hue[0.67, 0.6, 0.6], Opacity[0.2], EdgeForm[None], 
      GraphicsGroupBox[
       PolygonBox[{{121, 140, 141, 124, 67, 76, 56, 62, 37, 55, 36, 35, 34, 
        33, 32, 31, 30, 29, 28, 27, 54, 26, 79, 66, 93, 75, 111, 88, 132, 
        103}}]]}, {}, {}}, {{}, {}, 
     {Hue[0.67, 0.6, 0.6], 
      LineBox[{1, 115, 97, 82, 69, 59, 51, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12,
        13, 14, 15, 16, 17, 18, 19, 20, 21, 22, 23, 24, 116, 98, 83, 70, 60, 
       52, 120, 102, 87, 74, 65, 25, 117, 99, 84, 71, 61, 123, 105, 90, 78, 
       126, 108, 94, 130, 113, 134, 53}], 
      LineBox[{121, 103, 132, 88, 111, 75, 93, 66, 79, 26, 54, 27, 28, 29, 30,
        31, 32, 33, 34, 35, 36, 55, 37, 62, 56, 76, 67, 124}], 
      LineBox[{106, 133, 91, 129, 112, 80, 127, 109, 95, 38, 118, 100, 85, 72,
        63, 57, 39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 49, 119, 101, 86, 73, 
       64, 58, 122, 104, 89, 77, 68, 125, 107, 92, 81, 128, 110, 96, 131, 114,
        135, 50}]}, 
     {Hue[0.67, 0.6, 0.6], Opacity[0.2], LineBox[{138, 137}], 
      LineBox[{139, 136}]}}, {{}, {}, {}}}],
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesOrigin->{0, 0},
  Method->{"AxesInFront" -> True},
  PlotRange->{{-1, 1}, {0., 1.}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02]}]], "Output",
 CellChangeTimes->{
  3.5216005151474447`*^9, {3.521600616312611*^9, 3.52160063868596*^9}, 
   3.521611034891534*^9, 3.521669440957592*^9}],

Cell[BoxData[
 GraphicsBox[GraphicsComplexBox[CompressedData["
1:eJx11Q1Qy3EYB/BNUqRX4qKJ2rpKomSd5JaXTl7qUku59DKUl+oiqbldSnak
4+qou6RDTZpe9cpojZK6lJnebb3NloqtmNTGnZe7PA/u7O5/u889z77P8/vd
/W+rDsb4hs8hEAjhP59f3w60JePfv08ICLOfBCE7+ki9EtzZqTf+lKEAk57E
LHYx/wCuiXymbdg/Dg677DjZlzIGnrnKShXQRsEcgwGz7OERcO4ux9iOS3Jw
ShSDabtTBmZpFSXEKqRgRrKQ3M0dBmfx5dm5x4fAjwZtFpZYDoCtjNy30m+K
wZV2qcelb3vBg00VK6nUbrDcPstJUNsBNj57j+pAFIHtqRP2Bao28Pntilc8
ZjPYlF6WsX9pA8770mTYQn4ELhDLr4yxy8DBe82rxYcywbwFrK6G09dov71B
SlxxLrAcbDX5WO3awAPv5PS1ewc2gD28TLSmaprB6aE9yesetIGbvUn6PiYi
sGKV6dnXOR3g03GrGelLusE9EiPfiJZecNgZt3c6e8TgxtUuaY3aA2Dr+XWj
dzyHZj1JI9VFeminDoMJmjn3YqVS8PRefkgTRQYWO4cup7Dl4BMBRsaWkhGw
WaYscC5pFFwWdLtQxRwDB2xO8mzhj4MrQqItXb+9B88s2KbF81eAfUWbqKRs
JXj2fcD6xfbi9aH4flx9zXso50rgvLq3ekov7B4E50sXLfUfxfO769pmGOzB
PPe3H1uvl2OemvJVGK/B+4wI1zEv4OJ92iUx8+gB/eCi3kLaUSXOczFmv2nr
wbwS4Y0gGgfzMj0t/JwDMG/AxmwNiYB5fY8F8dO5f+SlTMhMNdhfr9nB/mCB
53Gy8To48h7nXSBH5XEScJ69a7GS5YC/f5g4FnuuE+/rROluE1ocznt5ipUc
LML+NJW+b4Yeztvaul5c3oT9n4gptZ7OWL9f5WitmsJ9VN70Z10M3GfG6WSd
xTLMp3BFWVX1uI/bXeMhaSjm50Rt8Sbysf/pC1vmRm2cZ9Co5vpVYD952i6y
3hTr8aJo/YVvsB6jtkpVa3A/u8MtXcp9uF/IWjrnoyHOO8D3KGyrwv3y8z8/
r/bHPMIx8oaOSuxPPFpieGUK63ECSTqlEC1p9/ncL0TzTyZ5nJmH+xp1pVm7
ygb/e95/8/+uw/8H+AdVfcbk
   "], {{{}, 
     {Hue[0.67, 0.6, 0.6], Opacity[0.2], EdgeForm[None], 
      GraphicsGroupBox[
       PolygonBox[{{83, 100, 101, 50, 55, 49, 48, 47, 46, 45, 44, 43, 42, 41, 
        40, 39, 54, 38, 76, 67, 85, 74, 96}}]]}, {}, {}}, {{}, {}, 
     {Hue[0.67, 0.6, 0.6], 
      LineBox[{1, 87, 77, 68, 61, 56, 51, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 
       13, 14, 15, 16, 17, 18, 19, 20, 21, 22, 23, 24, 25, 26, 27, 28, 29, 30,
        31, 32, 33, 34, 35, 36, 88, 78, 69, 62, 57, 52, 90, 80, 71, 64, 59, 
       37, 89, 79, 70, 63, 58, 92, 82, 73, 66, 53, 91, 81, 72, 65, 94, 84, 75,
        95, 86, 97, 60, 93}], 
      LineBox[{83, 96, 74, 85, 67, 76, 38, 54, 39, 40, 41, 42, 43, 44, 45, 46,
        47, 48, 49, 55, 50}]}, 
     {Hue[0.67, 0.6, 0.6], Opacity[0.2], LineBox[{99, 98}]}}, {{}, {}, {}}}],
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesOrigin->{0, 0},
  Method->{"AxesInFront" -> True},
  PlotRange->{{-1, 1}, {0., 1.}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02]}]], "Output",
 CellChangeTimes->{
  3.5216005151474447`*^9, {3.521600616312611*^9, 3.52160063868596*^9}, 
   3.521611034891534*^9, 3.5216694409642153`*^9}],

Cell[BoxData[
 GraphicsBox[GraphicsComplexBox[CompressedData["
1:eJx11X1Qy3EcB/BVdpKs1REdS0podVFYt8JCyFNPnnJdj451K1c3Ra5UZkc5
EXkIebrqFCnJ0yij7BqVrLHS6GG1rNiKjNo5T8e9vyfnd/e7373u/f19Pt8/
vp/fb1pUXNBWYwqFEv3z/vV05Vj3ff/eL6b8uXY1CrdzH+jgFy/G9j2K1MKM
h3HjPaa8h2/FPKZavOmDIw65DbwS9MJDx5IzxBwNnE9rs8nt7IHzVrnx5Zlq
WBAbmeS0shtONrmyi69VwZHpjdMVRZ3wiSp1bh6vA77XPsu8xL4NdqB7L1l/
XgnfYGbwVF0tcLuk3I7FUsBqlxPu4tty2DK1mOVqJINdWP0uhYP18D4f7XNR
Ui08YX1p9uaJ1aTfZ4mFdPo9uFCpzuoVlsKhgVNuKrcch0VmyS+rE3M4vzXA
ma8yst0bXAY7DNwf9qwWwSvzXzX4BVfDy9Zamehv1cJHwpvT59yph2v9GOMC
rGSwdtqE1KYzcjgxwTnyiLUCbn5ND9ombYEjdi94O3qNEq5x9jhYQ22DZ4yp
1BT4dsCMyphl1IxOmGIwLuarVPCXwKowiWM3rJwXPtlRqIbjN9Et7V/3wDbH
u4NHMTRwacjFy4NJvfCmhWm+0qo+uDxsu73n13fwkNlSE9EGLRwk82IxcnXw
n3kg+YGGq3PDyXwwjQ0VMSEFMJs6+3KH2gd+UhHuU55ZgPe9TZ2yaWtIPe+u
D09Pl5F6Gl3/RWZ8MVz2KdZB0yqEW5imhzdnnYe5XOa2298EqOdhKWytbyb1
lqt5Ew8arsI365ok/rLDcN3YtIXmsktwjV3mgXN0Puqt86IZGz1JRB67KNvU
Vn8IufustVE970i/nRFFTSLONTLPSkHd4p6jsGF/5ZCXdT6Z55zlT2PmRaBe
sFVCQbQ4Dbn0i86JOjoF+VlpgNi9kIv8eoXbjEE96U+zXXE9UEX6p5xsFNMc
c+BjPiEK+V3SX/FBcIE+5Iv6ulS5p1+oAPlzf+WchoZ4OJ1XEitn8rDeuesl
+2RoCPK4YYeMYQPZT2uK9YVzc8l8vx/UsxMfk/2E5TMlU83+OT+o/4xtN3ty
3j6yf0mCDXf1DnjSG4buW3EUPOA/82McfyOZP/P4U67cQOR7oksssvTtyB/V
OSWxqWQ+R+Yj9zPyfP++Ov6zfmQ/CuXv7wH+N/APctrjng==
   "], {{{}, 
     {Hue[0.67, 0.6, 0.6], Opacity[0.2], EdgeForm[None], 
      GraphicsGroupBox[{
        PolygonBox[{{38, 103, 104, 50, 55, 49, 48, 47, 46, 45, 44, 43, 42, 41,
          40, 39}}], 
        PolygonBox[{{89, 101, 102, 95, 37, 36, 35, 34, 33, 32, 31, 30, 29, 28,
          27, 54, 26, 67, 60, 74, 65, 83, 72, 93, 
         80}}]}]}, {}, {}}, {{}, {}, 
     {Hue[0.67, 0.6, 0.6], 
      LineBox[{1, 85, 76, 68, 61, 56, 51, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 
       13, 14, 15, 16, 17, 18, 19, 20, 21, 22, 23, 24, 86, 77, 69, 62, 57, 52,
        88, 79, 71, 64, 59, 25, 87, 78, 70, 63, 58, 90, 81, 73, 66, 91, 82, 
       75, 92, 84, 94, 53}], 
      LineBox[{89, 80, 93, 72, 83, 65, 74, 60, 67, 26, 54, 27, 28, 29, 30, 31,
        32, 33, 34, 35, 36, 37, 95}], 
      LineBox[{38, 39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 49, 55, 50}]}, 
     {Hue[0.67, 0.6, 0.6], Opacity[0.2], LineBox[{97, 100, 96}], 
      LineBox[{99, 98}]}}, {{}, {}, {}}}],
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesOrigin->{0, 0},
  Method->{"AxesInFront" -> True},
  PlotRange->{{-1, 1}, {0., 1.}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02]}]], "Output",
 CellChangeTimes->{
  3.5216005151474447`*^9, {3.521600616312611*^9, 3.52160063868596*^9}, 
   3.521611034891534*^9, 3.521669440970533*^9}]
}, Open  ]],

Cell[TextData[{
 "\n\nGeneral form of Scaling/Dilation equation for Haar Wavelets:\n\n",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"\[Phi]Haar", "(", 
     RowBox[{
      RowBox[{
       SuperscriptBox["2", 
        RowBox[{"J", "-", "1"}]], "x"}], "-", "k"}], ")"}], "=", " ", 
    RowBox[{
     RowBox[{"\[Phi]Haar", "(", 
      RowBox[{
       RowBox[{
        SuperscriptBox["2", "J"], "x"}], "-", 
       RowBox[{"2", " ", "k"}]}], ")"}], "+", 
     RowBox[{"\[Phi]Haar", "(", 
      RowBox[{
       RowBox[{
        SuperscriptBox["2", "J"], "x"}], "-", 
       RowBox[{"2", " ", "k"}], "-", "1"}], ")"}]}]}], TraditionalForm]]]
}], "Text",
 CellChangeTimes->{{3.5216009789215717`*^9, 3.521601074289184*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"J", " ", "=", " ", "4"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"k", " ", "=", " ", "3"}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{"g1", "=", 
  RowBox[{"Plot", "[", 
   RowBox[{
    RowBox[{"\[Phi]Haar", "[", 
     RowBox[{
      RowBox[{
       SuperscriptBox["2", "J"], " ", "x"}], "-", 
      RowBox[{"2", " ", "k"}]}], "]"}], " ", ",", " ", 
    RowBox[{"{", 
     RowBox[{"x", ",", " ", 
      RowBox[{"-", "1"}], ",", " ", "1"}], "}"}], ",", 
    RowBox[{"Filling", "\[Rule]", "Axis"}]}], 
   "]"}]}], "\[IndentingNewLine]", 
 RowBox[{"g2", "=", 
  RowBox[{"Plot", "[", 
   RowBox[{
    RowBox[{"\[Phi]Haar", "[", 
     RowBox[{
      RowBox[{
       SuperscriptBox["2", "J"], " ", "x"}], "-", 
      RowBox[{"2", " ", "k"}], "-", "1"}], "]"}], ",", " ", 
    RowBox[{"{", 
     RowBox[{"x", ",", " ", 
      RowBox[{"-", "1"}], ",", " ", "1"}], "}"}], ",", 
    RowBox[{"Filling", "\[Rule]", "Axis"}]}], 
   "]"}]}], "\[IndentingNewLine]", 
 RowBox[{"g3", " ", "=", " ", 
  RowBox[{"Plot", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"\[Phi]Haar", "[", 
      RowBox[{
       RowBox[{
        SuperscriptBox["2", "J"], " ", "x"}], "-", 
       RowBox[{"2", " ", "k"}]}], "]"}], " ", "+", " ", 
     RowBox[{"\[Phi]Haar", "[", 
      RowBox[{
       RowBox[{
        SuperscriptBox["2", "J"], " ", "x"}], "-", 
       RowBox[{"2", " ", "k"}], "-", "1"}], "]"}]}], ",", " ", 
    RowBox[{"{", 
     RowBox[{"x", ",", " ", 
      RowBox[{"-", "1"}], ",", " ", "1"}], "}"}], ",", 
    RowBox[{"Filling", "\[Rule]", "Axis"}]}], "]"}]}], "\[IndentingNewLine]", 

 RowBox[{
  RowBox[{"g4", " ", "=", " ", 
   RowBox[{"Plot", "[", 
    RowBox[{
     RowBox[{"\[Phi]Haar", "[", 
      RowBox[{
       RowBox[{
        SuperscriptBox["2", 
         RowBox[{"J", "-", "1"}]], " ", "x"}], "-", " ", "k"}], "]"}], ",", 
     " ", 
     RowBox[{"{", 
      RowBox[{"x", ",", " ", 
       RowBox[{"-", "1"}], ",", " ", "1"}], "}"}], ",", 
     RowBox[{"Filling", "\[Rule]", "Axis"}]}], "]"}]}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]"}], "Input",
 CellChangeTimes->{{3.521601086931252*^9, 3.521601091902074*^9}, {
  3.5216011359520617`*^9, 3.521601240519989*^9}, {3.521601284636775*^9, 
  3.521601305201268*^9}, {3.5216110412860107`*^9, 3.521611046135509*^9}}],

Cell[BoxData[
 GraphicsBox[GraphicsComplexBox[CompressedData["
1:eJx1lAs0lGkYxyfW0tjcwq4YQjSYhIpi27EWx7WTS2kjjA0dtDJti8Yls9qs
M13RWlp0BikaZN2KEbJkqaYZZphyN8vIpS27brvttkfP03bOzjnfmfM7z/99
n///eb/v1Q+J9g6VIRAIF/95Xv+bUzWlr17NNhFWf7EPU4+Gc2eABQJFaTNt
Gph0N1rdRucZcHXkPTnlp1LgYJblXB9zEnjhEiOtiToBzFYa0MoelgBfcbOk
878bB2ZG0eJMXMeAGbI3YunTI8C0Uw839ZYMA2c1jmdfiRgCvj1I/qDMYADY
UMXewTdPDHzLNC1iZFQEPNhWudHauhd4nJJl1VTDB1ZNum5tvoYHTLGepRS9
6AL+xnH6UX1cO7CGL+fC5x+2YL/f25Q7Nt0GLhKPn51M5QAf8tL5SfxFJnA9
kdHTciKD+oZ3jKzRTTlQDmw4d2fRtqUe2JXd173nQAuwk6ea7Hx1O/D5IOEp
i9ou4PY9pHV71XjA0/oaSY9z+MAnvjKjndfsBRY+UfEO6xCt8hw1OP7jX+U9
xMCtZjbprXIDoDde2zBR6DIETGqIdJJLGwYmLMlcp4+MAP/h1RjYZjQGLN4e
pG2UOg58zE9F1eCJBFgrc+zAe6QJYI5/wbUXcZPAfruTXToapcCVgUcNbFem
gBeIn8nW75sG9ubZWZOyZ4BXvwesn+ku3RaE34ele8FshUgA9WJyXt/JaCGw
Tmmxjg2xH+Zz6XF93XjJE6gr5Atvfus+CGyvYHJByQP72Y8+7/yhHPudr+mv
ad6F/c49OEySa8XzSThSpnx2Hs8jLFRep6gEz+N+lNWoxm+Yjz8YSi6I7QHm
MoVZc9p4vqbJcVd9/Z5CvZatt1u+GP3ZqKb2dwnR3yfPYje4SfH9Yeq7UDuj
0F/Zw1x/Khv9Zbro+Wz3Q39KerUsrTb0x9SQZZHJ6O9Wz+3a6jac7wBZawuJ
gP5W9hVKiPHoL4eRskzVQr1zwkFHjhfOv3Pry+NmdMxLf56TIcvH9VZkzxDJ
FObTPOPsca4F86107npU9inmo9iWzjDMMY9FXDwtl4N5DlbwGqMImIeSXOaS
nYP+6hIn6SkC9KdbHnaHFYJ+1I2OswxmsN9Gnmm6mjHqM90OHTndgPqdlPvG
/DncP2pz+l+uiajfmy3ipkyivqLK0vjFPOZlCraEVnAwb13+rY90Kdh/wSqm
QW8D5m0u7HcPYGPen/+s6z33DN/XSR+ji2tPox+jEl5WFRf9lIvbizz90A9v
cUqQIcJ+rGW1m44qqDeO5Xo7V6J+nuAQ7SjG/fu86PoJ4agfvrfrusMA6qNv
bCNsrkB9VbFD+JAd6hl+ewdo7+P70RQZK7j78q31i4Zpi0s4r52MqzHNhTgv
TeJsw3599B+41Zf9XBnnRbRTbG74EeeVUEgZzR/BeblwaTscTqK/gEana11V
6G8hZmEDxwv9WBwmx3d1Yz/m9z5zdCLqv1w3215cinrfyKT1iY9wf5VwiVVW
AOpN/SN02SLUP1A/VhhUhHrpnZq4RQvU9zezmDnLWFeQKXHVn8X1+yV5uWba
qL98We4XRclb9+X0elsTVZz31z3OQcFLuP7f600W69mv460I/zfvu/fhu/r/
nu+7egLhb9MAac4=
   "], {{{}, 
     {Hue[0.67, 0.6, 0.6], Opacity[0.2], EdgeForm[None], 
      GraphicsGroupBox[
       PolygonBox[{{114, 144, 145, 61, 71, 36, 54, 35, 80, 65, 
        137}}]]}, {}, {}}, {{}, {}, 
     {Hue[0.67, 0.6, 0.6], 
      LineBox[{1, 116, 97, 82, 68, 58, 51, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12,
        13, 14, 15, 16, 17, 18, 19, 20, 21, 22, 23, 24, 25, 26, 27, 28, 29, 
       30, 31, 32, 33, 117, 98, 83, 69, 59, 52, 121, 102, 87, 74, 64, 34, 118,
        99, 84, 70, 60, 125, 106, 91, 78, 53, 122, 103, 88, 131, 112, 75, 128,
        109, 136, 94, 133, 140}], 
      LineBox[{114, 137, 65, 80, 35, 54, 36, 71, 61}], 
      LineBox[{126, 107, 135, 92, 132, 113, 79, 129, 110, 95, 55, 123, 104, 
       89, 76, 66, 37, 119, 100, 85, 72, 62, 56, 38, 39, 40, 41, 42, 43, 44, 
       45, 46, 47, 48, 49, 120, 101, 86, 73, 63, 57, 124, 105, 90, 77, 67, 
       127, 108, 93, 81, 130, 111, 96, 134, 115, 138, 50}]}, 
     {Hue[0.67, 0.6, 0.6], Opacity[0.2], LineBox[{142, 141}], 
      LineBox[{143, 139}]}}, {{}, {}, {}}}],
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesOrigin->{0, 0},
  Method->{"AxesInFront" -> True},
  PlotRange->{{-1, 1}, {0., 1.}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02]}]], "Output",
 CellChangeTimes->{
  3.5216012433058*^9, {3.5216012851053133`*^9, 3.521601306426155*^9}, 
   3.5216110471384373`*^9, 3.5216694449129457`*^9}],

Cell[BoxData[
 GraphicsBox[GraphicsComplexBox[CompressedData["
1:eJxdkwkw3HcUx5ellDobSSWOOBPLmNCEiqabURRB2cFKxLGCCFJh4iqJkA0q
UkYko0iCdQarqqHrWHHNaiNV97HiWEsccUedE21n9L3Ef+Y///nMe+/7vu/9
fn8Vz0CKtyCBQIj/9/3vq0s+OLu7u9hA2HvCOuhXL7MXgHt6xGcbafPAis8D
DxgqvAF+5t8iLPVqFtgjSW9pMHYGeCM1MqGBPA3MkByRTx+fAs6y0gvu/mES
ODaAFq5lyQeOJD4NC57nAdNudaj3FY0DP6ifTM/yGwOuGT3+SanqCLCa9FkT
h8dc4F9ICX68iQHg0daKowYGfcCTOg/0G6q6gWVuFhvoCnQC6xgs6uSvtgPf
Np3/ixXOAZZzYKacP9SE/f5ulWpTrwHO507em6EzgV3tFX7lXkoDZolF9jaF
3Cf/z6d4AkoxzuXAaku1m6ebWMCWjMGXts5NwGY2ssS1ZxzgZPf+Wyeq24E5
tooSdrKdwPMqcje7MrqBQ65r05IP9gH3D0tTfNoGgD0ivnwtYs0FbtY2TGwW
HtnjJbLmx3XTeRZjEFes8zcTThgHJmwJFgfzeMDr9vVurRp8YO5J9yMa9Eng
a1RpGdXhKWD5NL6zkOI0MNMlu3A1fAaYeibaoq1+FrjC7arq6Z054A2xr4ks
x3lgSqexgWL6AvDe/4Dx+Jcln7vj/6FQUqBgKDYE8dQu1m+TRcMwv+iT/rK4
c6PAubxPDzlO4z7OimqlSFqj/tmJ5T9+Kkf9rWaXatsrgxDf1NjuCN3Cfft4
iyjkF+G++Wuvd6PSUf/3AP0JuRWc56vU5RjlEvRLig7PcaC+gvqnA4Vk3wX0
W81QPiNSgP4MZehD7f3oz9euij70Gfor7ch0ITPQ351d+7cp19CPpHJ1knwr
+ilTsv625AL6GaxtCF3Pwv47jnlTYhHY3zzqginTHvfL3vqG/kYZ9YOXM+4T
uzFf/7iN59Qc+s1+eMk/ewnvb5x6QA4jDP06CcUvZFxEvRPhEbRMJvrle22e
CtJHv0rlPrVJntjvaCcpUVYT/SWuSlBSxFEvzcrV904d5nd9/0KO+yf2DziW
+M7yBtavCMRWWZzEerv0AXbMDNb/XKmnubqG89UZ1bjdHsb5Vm0dWnppqM+O
y5l7QkG9xryhcxcZOB9B1E7LQQnnK+dy8m2o2C9pW7bMVBr9Nb7QCjcSRj3N
MDbFvALzyfmVX0iwsL/zO69Hh0mYP95iVGwygvmVBSaXx4xRX32d5M+Ww3wf
u4mVIj7qNfiH9Tx/i/WBm2oJm1u4D6u73gPXu3AfJK+23gUnrF/h6Prl2qC+
mLF4Y90j3MeP57dzzQ7gPjaCNg4z7bFfk3Q821UY/d7wLZW6t4b39zuJRU5B
CeaH1hyz0mRi/7tRfSlEDexPcvFTYgxgPjUky61QGuNZ3lShpkGsFxUsslRZ
xHynqceZ2kfQT31QtFnER+/dZ+PA8eRFrA/tNXf32MJ6dePCKyI7GB9ucX64
QXzvPPbF95///vk/3M/+OIHwD12BTQw=
   "], {{{}, 
     {Hue[0.67, 0.6, 0.6], Opacity[0.2], EdgeForm[None], 
      GraphicsGroupBox[
       PolygonBox[{{116, 134, 135, 117, 65, 73, 54, 60, 37, 64, 53, 89, 75, 
        105, 85, 125, 99}}]]}, {}, {}}, {{}, {}, 
     {Hue[0.67, 0.6, 0.6], 
      LineBox[{1, 109, 92, 78, 67, 57, 51, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12,
        13, 14, 15, 16, 17, 18, 19, 20, 21, 22, 23, 24, 25, 26, 27, 28, 29, 
       30, 31, 32, 33, 34, 35, 110, 93, 79, 68, 58, 52, 114, 97, 83, 72, 63, 
       36, 111, 94, 80, 69, 119, 102, 88, 123, 107, 127, 59, 129}], 
      LineBox[{116, 99, 125, 85, 105, 75, 89, 53, 64, 37, 60, 54, 73, 65, 
       117}], LineBox[{100, 126, 86, 122, 106, 76, 120, 103, 90, 38, 112, 95, 
       81, 70, 61, 55, 39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 49, 113, 96, 
       82, 71, 62, 56, 115, 98, 84, 74, 66, 118, 101, 87, 77, 121, 104, 91, 
       124, 108, 128, 50}]}, 
     {Hue[0.67, 0.6, 0.6], Opacity[0.2], LineBox[{131, 130}], 
      LineBox[{133, 132}]}}, {{}, {}, {}}}],
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesOrigin->{0, 0},
  Method->{"AxesInFront" -> True},
  PlotRange->{{-1, 1}, {0., 1.}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02]}]], "Output",
 CellChangeTimes->{
  3.5216012433058*^9, {3.5216012851053133`*^9, 3.521601306426155*^9}, 
   3.5216110471384373`*^9, 3.521669444951263*^9}],

Cell[BoxData[
 GraphicsBox[GraphicsComplexBox[CompressedData["
1:eJx1lQtU02UYxgdzoiMR5GIgw0CgAcvEC4hmIxKbFzywRCgvMBIiwLgYDkRF
FgrZRBL1rIWCMm5C41LcFIYD1xBBRW6DEchgyH0IkoAUlcfeVzmnnbOz8zvf
8z3v877f9//P1CeY6atOIBCS/vn++7uabjA4N6eqJLz6sB/EHv5SNArc1KQ5
KGaNAFNuB+vZGw8DFwXeIS39fRDYm2s71sYZAJ66EBVfSe8HTtPqNOR19wEn
77ANa/xOCcwJYkVYbe8FjiLeYIeNKIBZpx6Yt2R1A1+qUPKSAx4D3+yivpVr
1gm8StvRac9VOXChdXyAokcG3CUpeMfOrgVYSbu0trK4EVjnZLbdarUGYJqd
ipY+UQf87daRh2URUmD9PcLEz5ZXYb0/JEtrzG8Cp8uV5wZihcAH3Ix/lX9x
EbiMHNVcFZ5E/483KNRMYjzzgFeN3ZreVFUGvD2trX63ZxWws8sy4mSRFPi8
V+upNSV1wNLdlCWuyxqAR0z1Tz7iNwKHf2PDOm/QAtzaoc30q5G94jG6d+QH
TzR2yYGrbezPVpM6gS0Xl/cLGI9hP6U80JkU3w1MmFHPDlMogJ+7VRyUWPQC
y9d7rbCIVQKHeGjrmHX0ARte7PVcQOkHFu5LzZyIGAD22BLNqKkYBC44eNhs
0+wQ8BT5Y2KZ+wgws2GzHYU3CvzqecD1uPqcdV74fNjuTFXly5pgPYN6te1Y
cCuwcU6GsT25HeZx4VFZqTKrA3hRSuvPZ3Z2AV9X6C5378d5OS6yStTahfUd
e57W/piH9c8XtxeLHbB+wv1DFFI1npefr4ZxehaeR+/kk7njPPS/G7S2R38c
+23s8qWmspuBRZzWS2Mr8LxvyDLp/qOYtyRt5RaNDMxnrxPbXteK+T4cZhvt
GMT7xDFl0GuDMN/pObdniSGYR2tlCddQgnk4+kQulYp5CptvlhRJcL5ttyqP
Pk/GPLPugj5yJObhR8W8oBuivvb9Z0dswrAf0cwnscMrsX7YU34SsRH3r6W6
+PQNYT8Gcdt2JVRhP7O1Dg9zP8J+9i6IG+XvR781EZGsn4TYz+f5DRVBBOyH
Fp3L4PExn0me3y2uD9bXszjCNRtF/7MTS5iJmuh/cccB/9PlqN9Iu2vZOIZ+
42qcYsZ61LvyZKKYAdTn/2JrOTGJ/XGa3vPNF2J/pSmFb5vQsL7ozLWhFCb6
iQXtO/enYX+//VnakjCM93HgU4sfFp/GPHlyabqLB9ZvmB5qSpKhv/ieVYQD
Cf0t2SLmtgLUTxKcgrfK0c/zr0NXjKxR333HIdupE/XBN9YR3s1Hvflz60CR
PuqjPFw7WQvxPlQGsptuP3tt//Sq+OkZnM/GqGuhYgHOx4CsKt9rivnHpasD
rrugP3mzprj8Cs7nuIDWk6LA+TBErA1OxzDfVOiUkdAN6685RI2sq0f/E/65
S89N4n3/eolKmpGD+j2BJ3VPPES/74+3JBItMI/1vgCTNBnq7+uFCLzSUe8R
nnwwUxv17WIuh/8C1xepZ203VeH+itBo58iFqL98mXRPs++199+I7iYrHZzv
0eZtXt4zuN98c+ZXGrP4/zH38oM8f33+/Zg/D4nn5SniLNZ/uZ0o+9/1N89/
fh4C4c339fx6BMLfI0KFMw==
   "], {{{}, 
     {Hue[0.67, 0.6, 0.6], Opacity[0.2], EdgeForm[None], 
      GraphicsGroupBox[{PolygonBox[{{55, 146, 147, 123, 67, 76, 56, 62, 37}}],
         PolygonBox[{{112, 144, 145, 136, 36, 54, 35, 79, 66, 
         134}}]}]}, {}, {}}, {{}, {}, 
     {Hue[0.67, 0.6, 0.6], 
      LineBox[{1, 114, 96, 82, 69, 59, 51, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12,
        13, 14, 15, 16, 17, 18, 19, 20, 21, 22, 23, 24, 25, 26, 27, 28, 29, 
       30, 31, 32, 33, 115, 97, 83, 70, 60, 52, 119, 101, 87, 74, 65, 34, 116,
        98, 84, 71, 61, 122, 104, 90, 78, 53, 120, 102, 88, 128, 110, 75, 125,
        107, 133, 93, 130, 141}], 
      LineBox[{112, 134, 66, 79, 35, 54, 36, 136}], 
      LineBox[{55, 37, 62, 56, 76, 67, 123}], 
      LineBox[{105, 132, 91, 129, 111, 80, 126, 108, 94, 38, 117, 99, 85, 72, 
       63, 57, 39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 49, 118, 100, 86, 73, 
       64, 58, 121, 103, 89, 77, 68, 124, 106, 92, 81, 127, 109, 95, 131, 113,
        135, 50}]}, 
     {Hue[0.67, 0.6, 0.6], Opacity[0.2], LineBox[{138, 137}], 
      LineBox[{140, 139}], LineBox[{143, 142}]}}, {{}, {}, {}}}],
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesOrigin->{0, 0},
  Method->{"AxesInFront" -> True},
  PlotRange->{{-1, 1}, {0., 1.}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02]}]], "Output",
 CellChangeTimes->{
  3.5216012433058*^9, {3.5216012851053133`*^9, 3.521601306426155*^9}, 
   3.5216110471384373`*^9, 3.521669444953438*^9}],

Cell[BoxData[
 GraphicsBox[GraphicsComplexBox[CompressedData["
1:eJx1lAkwnGcYxxdRsuqKIyWOOrvYKpIQ0nRVQ52ZEEKbxFXUIMWmghBiS2jq
apDZqoTEfdTVullBlAgJcS2rxDriXnHUUa0eo8+Tmuk3s/PNb97/+3/+z/O+
3yq4+tq4cxMIhLi/fn+/NSmSc7u7nEbC3hP4LPLy54wl4L4+gbkml0Vg2Ye+
4noyC8AV3o94hX+ZA3aO1V4eos0Cb94OiWmkzABnCo1K0cengdPMtam9X08B
03xcgtTMJoFDeAoCqYtsYJcbz5QH8saBUxqm6GleL4Brx0hvFimOAiuJGBrZ
3mMBl6vHeLEnmMBjrWVv6+oOAE+RU3QaK3uBRcPydTW5eoDJuhxy9mon8Fen
F7trgtqAJWyLEz853Iz1fm0VbleuBc5mTcXNRhYDX7KW+Yn1WTJwDTGkvzkg
ifIvH2dzyUU4lAArLddtGTTXAJtlDnWdcWgGNrY6xLNe0Qac4DR4Q6uqE7jt
jKzg2UM9wIsKEmHPU3uBA77UcEmQHAAeHBGx8Whn7vEyxTn4/Zd8lizgFg29
Wy28o8CqB+tnskxfwH7Zem9j3phxYMI2dz6VzQbesG5wbFWZBGYdczqiEjkF
7GcvIqo4Mg0slTzpcEB2Brj4QkbuatAssP2pcNP2hjngMsfLigY788CbxI94
auwWgW16TurK0peA974HXI/uKjzqhN+HtkUGp5TZB+s5pHtD13wHgWUKc2T0
iMMwj9vPa6qn8kaA+dMHf7hpMQb8gC122G4G52XIr5YoZIn1DSdedXxXgvUT
Kocrm/SxfvxTN1neFjwvD3c+mew8PI/J9Ze7oXT0f+yjMyGxgv32jrmTMgL7
gRm0wZTlI3jeBcxciucS5q3KlD/Fl4P59EQjhzsHMd8HC4HS5nN4n2gKppQO
H8wXtWu9luiHeYTkq2KlWjEPTYInlkTCPOX9tVUVrTjfobrGqxtpmGfHLmua
GIx5UkMifqNIob7jvbUrGlTsh7H9ceSCPNanvkpN4unF/TokK9fpeexHMtrE
Mr4Z+9np0O8u+hD7OX8gein1IvppBQW7fF+M/Xxa2tPgQ8B+yOFFpvRUzCdX
4lEX64r1xVWuxCouof+tVUGbRAH0Tza/5BlVj/oT5Meqvcvot8JFqzQ9hvqz
dCYjYhb1pT9qq66uY3+0vnfdS4uxv+r08rfkyFifcfP+fLoN+jVlDVtczMT+
fv69eiB+Ae/j7DmVbw9GYZ4SVlu2lT3W79ma70tion/TE7UgfV70Vw1k2JiU
oX6dYOR7moV+Dn+43ZVWR/34I/18o1HU+xYcJbxTinrlDXVvhgTqPYuE49b5
8D40egf2PVx7bf+WUszWNs7nRMh9/6YsnI8kkVN/XgHzr7Rpej2wQn/iSYGm
+rs4n9As8kQ6G+djynA5bnQN8236b0oXW2N9LTdScGcX+l//JzDe9y8EOW05
hai39Q4Tu96Nft+EDiTyqGAe9QtecplM1D8V98tyyka9fUCaY64I6unnlqnE
TVzn584zU+Dg/gb/cOPgN1B/5w7vE4Hp1/7/FsUM1ERxvlf7TZyctzn/O//9
57+/3/15/rt/v55A+BMpUGVG
   "], {{{}, 
     {Hue[0.67, 0.6, 0.6], Opacity[0.2], EdgeForm[None], 
      GraphicsGroupBox[
       PolygonBox[{{112, 140, 141, 123, 67, 76, 56, 62, 37, 55, 36, 54, 35, 
        79, 66, 134}}]]}, {}, {}}, {{}, {}, 
     {Hue[0.67, 0.6, 0.6], 
      LineBox[{1, 114, 96, 82, 69, 59, 51, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12,
        13, 14, 15, 16, 17, 18, 19, 20, 21, 22, 23, 24, 25, 26, 27, 28, 29, 
       30, 31, 32, 33, 115, 97, 83, 70, 60, 52, 119, 101, 87, 74, 65, 34, 116,
        98, 84, 71, 61, 122, 104, 90, 78, 53, 120, 102, 88, 128, 110, 75, 125,
        107, 133, 93, 130}], 
      LineBox[{112, 134, 66, 79, 35, 54, 36, 55, 37, 62, 56, 76, 67, 123}], 
      LineBox[{105, 132, 91, 129, 111, 80, 126, 108, 94, 38, 117, 99, 85, 72, 
       63, 57, 39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 49, 118, 100, 86, 73, 
       64, 58, 121, 103, 89, 77, 68, 124, 106, 92, 81, 127, 109, 95, 131, 113,
        135, 50}]}, 
     {Hue[0.67, 0.6, 0.6], Opacity[0.2], LineBox[{138, 137}], 
      LineBox[{139, 136}]}}, {{}, {}, {}}}],
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesOrigin->{0, 0},
  Method->{"AxesInFront" -> True},
  PlotRange->{{-1, 1}, {0., 1.}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02]}]], "Output",
 CellChangeTimes->{
  3.5216012433058*^9, {3.5216012851053133`*^9, 3.521601306426155*^9}, 
   3.5216110471384373`*^9, 3.5216694449594717`*^9}]
}, Open  ]],

Cell[TextData[{
 "\n\n",
 StyleBox["\[Psi]: Wavelet Function, Mother Wavelet ", "Subtitle"]
}], "Text",
 CellChangeTimes->{{3.5216118748559923`*^9, 3.521611995089778*^9}}],

Cell[TextData[{
 "\nLet\[CloseCurlyQuote]s calculate ",
 StyleBox["f0",
  FontSlant->"Italic"],
 " and ",
 StyleBox["f1",
  FontSlant->"Italic"],
 " for an aribitrary function:\n"
}], "Text",
 CellChangeTimes->{
  3.5216120047464647`*^9, {3.5216120718811607`*^9, 3.521612108366488*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"Make", " ", "up", " ", "a", " ", "new", " ", "function"}], " ", 
   "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"f", "[", "t_", "]"}], " ", ":=", " ", 
    RowBox[{"Sin", "[", 
     RowBox[{"8", "*", "t"}], "]"}]}], ";"}], " "}]], "Input",
 CellChangeTimes->{{3.521612133864358*^9, 3.521612143742442*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{
     RowBox[{"Let", "'"}], "s", " ", "look", " ", "at", " ", "J"}], " ", "=", 
    " ", 
    RowBox[{
     RowBox[{"0", " ", "and", " ", "k"}], " ", "=", " ", "0"}]}], " ", "*)"}],
   "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"J", " ", "=", " ", "0"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"k", " ", "=", " ", "0"}], ";"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{
    SubscriptBox["c", 
     RowBox[{"0", ",", "0"}]], "=", 
    RowBox[{"Integrate", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"f", "[", "x", "]"}], "*", 
       RowBox[{"\[Phi]", "[", 
        RowBox[{"x", ",", "J", ",", "k"}], "]"}]}], ",", 
      RowBox[{"{", 
       RowBox[{"x", ",", "0", ",", "1"}], "}"}]}], "]"}]}]}]}]], "Input",
 CellChangeTimes->{{3.5216123253654547`*^9, 3.521612346898057*^9}}],

Cell[BoxData[
 FractionBox[
  SuperscriptBox[
   RowBox[{"Sin", "[", "4", "]"}], "2"], "4"]], "Output",
 CellChangeTimes->{3.5216123499469624`*^9, 3.521613423035364*^9, 
  3.521616192208336*^9, 3.521669451068733*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{
     RowBox[{"Let", "'"}], "s", " ", "look", " ", "at", " ", "J"}], " ", "=", 
    " ", 
    RowBox[{
     RowBox[{"1", " ", "and", " ", "k"}], " ", "=", " ", "0"}]}], " ", "*)"}],
   "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"J", " ", "=", " ", "1"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"k", " ", "=", " ", "0"}], ";"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{
    SubscriptBox["c", 
     RowBox[{"1", ",", "0"}]], "=", 
    RowBox[{"Integrate", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"f", "[", "x", "]"}], "*", 
       RowBox[{"\[Phi]", "[", 
        RowBox[{"x", ",", "J", ",", "k"}], "]"}]}], ",", 
      RowBox[{"{", 
       RowBox[{"x", ",", "0", ",", "1"}], "}"}]}], "]"}]}], 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.521612165996574*^9, 3.521612178355033*^9}, {
  3.521612236537633*^9, 3.5216122488240232`*^9}}],

Cell[BoxData[
 FractionBox[
  SuperscriptBox[
   RowBox[{"Sin", "[", "2", "]"}], "2"], 
  RowBox[{"2", " ", 
   SqrtBox["2"]}]]], "Output",
 CellChangeTimes->{3.52161218067654*^9, 3.5216122514688807`*^9, 
  3.521612354284197*^9, 3.521613424336912*^9, 3.521616195245077*^9, 
  3.521669452335099*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{
     RowBox[{"Let", "'"}], "s", " ", "look", " ", "at", " ", "J"}], " ", "=", 
    " ", 
    RowBox[{
     RowBox[{"1", " ", "and", " ", "k"}], " ", "=", " ", "1"}]}], " ", "*)"}],
   "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"J", " ", "=", " ", "1"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"k", " ", "=", " ", "1"}], ";"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{
    SubscriptBox["c", 
     RowBox[{"1", ",", "1"}]], "=", 
    RowBox[{"Integrate", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"f", "[", "x", "]"}], "*", 
       RowBox[{"\[Phi]", "[", 
        RowBox[{"x", ",", "J", ",", "k"}], "]"}]}], ",", 
      RowBox[{"{", 
       RowBox[{"x", ",", "0", ",", "1"}], "}"}]}], "]"}]}]}]}]], "Input",
 CellChangeTimes->{{3.5216121881159697`*^9, 3.521612193346301*^9}, {
   3.521612257951415*^9, 3.521612262080085*^9}, 3.521612339483988*^9}],

Cell[BoxData[
 FractionBox[
  RowBox[{
   RowBox[{"Cos", "[", "4", "]"}], "-", 
   RowBox[{"Cos", "[", "8", "]"}]}], 
  RowBox[{"4", " ", 
   SqrtBox["2"]}]]], "Output",
 CellChangeTimes->{3.521612195341555*^9, 3.521612263833329*^9, 
  3.5216123580049133`*^9, 3.521613426172351*^9, 3.5216161968968077`*^9, 
  3.5216694543829203`*^9}]
}, Open  ]],

Cell[TextData[{
 "From above construct ",
 StyleBox["f0",
  FontSlant->"Italic"],
 " and",
 StyleBox[" f1",
  FontSlant->"Italic"],
 " as the linear sum of the vectors ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["\[Phi]", 
     RowBox[{"J", ",", " ", "k"}]], "(", "x", ")"}], TraditionalForm]]],
 ":"
}], "Text",
 CellChangeTimes->{{3.52161256693007*^9, 3.5216126036193523`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"f0", " ", "[", "x_", "]"}], ":=", " ", 
  RowBox[{
   SubscriptBox["c", 
    RowBox[{"0", ",", "0"}]], "*", 
   RowBox[{"\[Phi]Haar", "[", "x", "]"}]}]}]], "Input",
 CellChangeTimes->{{3.5216124156853533`*^9, 3.521612429311849*^9}, {
  3.521614616256796*^9, 3.521614651875214*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"f1", "[", "x_", "]"}], " ", ":=", " ", 
  RowBox[{
   RowBox[{
    SubscriptBox["c", 
     RowBox[{"1", ",", "0"}]], "*", 
    RowBox[{"\[Phi]", "[", 
     RowBox[{"x", ",", "1", ",", "0"}], "]"}]}], "+", " ", 
   RowBox[{
    SubscriptBox["c", 
     RowBox[{"1", ",", "1"}]], "*", 
    RowBox[{"\[Phi]", "[", 
     RowBox[{"x", ",", "1", ",", "1"}], "]"}]}]}]}]], "Input",
 CellChangeTimes->{{3.521612453218391*^9, 3.5216125321094418`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Plot", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"f", "[", "x", "]"}], ",", 
      RowBox[{"f0", "[", "x", "]"}], ",", 
      RowBox[{"f1", "[", "x", "]"}], ",", " ", 
      RowBox[{
       RowBox[{"f1", "[", "x", "]"}], "-", 
       RowBox[{"f0", "[", "x", "]"}]}]}], "}"}], "  ", ",", " ", 
    RowBox[{"{", 
     RowBox[{"x", ",", " ", "0", ",", " ", "1"}], "}"}], ",", 
    RowBox[{"PlotStyle", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"Blue", ",", " ", "Red", ",", "Green", ",", "Dashed"}], 
      "}"}]}]}], "]"}], " ", "\[IndentingNewLine]", 
  "\[IndentingNewLine]"}]], "Input",
 CellChangeTimes->{{3.5216126779229383`*^9, 3.521612707096018*^9}, {
  3.521612738567638*^9, 3.521612784015726*^9}, {3.5216128860407877`*^9, 
  3.521612907652739*^9}, {3.5216130021855783`*^9, 3.5216130090452337`*^9}, {
  3.5216749658532352`*^9, 3.521674973918096*^9}}],

Cell[BoxData[
 GraphicsBox[{{{}, {}, 
    {RGBColor[0, 0, 1], LineBox[CompressedData["
1:eJwdmXk8Vd/Xx0VlKnNKaSDKzFeDoqyICEkiQyGiQSlT0kCaJBFFMkYhkpBM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      "]]}, 
    {RGBColor[1, 0, 0], LineBox[CompressedData["
1:eJxTTMoPSmViYGAwBWIQ7ZX64uKBl6F2n1LfXP8efMh+gah/W5dkiz2M38ix
Wb1TcgqcHxG5cP2Hj0vgfO7/jTHucuvhfNXAdy8Od2+B88vPWdrP+LITzhff
IniPkXE/nL/tkfOZ8zaH4PxDWXOlI98cgfO/qtnyr809Ducz/VwtIK16Cs43
+5+wLXjdGTj/TIvJuWNa5+F8+Qmvf658dwHOf/39/r2rBpfg/CWvdp/i67sM
5/PJLn//5MkVOL8nc2vaApVrcP43h9VPMuqvw/klRke2iB2+AeffX3ek+6Li
LTj/d9aV2ZpVt+F8bUf2f2m778D57osU0zeK30OEl2y80sOY+3A+Axg8gPN1
3oRyX/dF8IX5P3Ac+YXgs+yfvV55zkM4P9tk901O70dw/mrPpAX7viH4X19L
CTyb9hjO3xrszjzF5QmcX+/ROn/LMwRf8a7XjcWtT+F8K/OWKZJGz+D8GLnz
PxkvI/hfT/U+Kmh8DufPYIkrCVJ5gXD/va2LmI4g+Ky1jSGWhS8R/l8Zt/6R
0Cs4v2jW+l6hQwj+Xu0ODsG813C+oFeRThPfGzj/ju6Fy5V7EPwN8+xVnsS9
hfNj15sJyv5D8BtaFzbeWfUOzl/7QnY2n897OF+pRcSDfRmCP12e++v//wg+
AP438wQ=
      "]]}, 
    {RGBColor[0, 1, 0], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBWIQ7ZX64uKBl6F2iZNymYNLb9kvEPVv65JssYfxGzk2
q3dKToHzIyIXrv/wcQmcz/2/McZdbj2crxr47sXh7i1wfvk5S/sZX3bC+eJb
BO8xMu6H87c9cj5z3uYQnH8oa6505JsjcP5XNVv+tbnH4Xymn6sFpFVPwflm
/xO2Ba87A+efaTE5d0zrPJwvP+H1z5XvLsD5r7/fv3fV4BKcv+TV7lN8fZfh
fD7Z5e+fPLkC5/dkbk1boHINzv/msPpJRv11OL/E6MgWscM34Pz76450X1S8
Bef/zroyW7PqNpyv7cj+L233HTjffZFi+kbxewj98QdcPHch+OWy8UoPY+7D
+QY+RfFT1iD49ibX2o/9QvABeFDYKA==
      "]], LineBox[CompressedData["
1:eJxTTMoPSmViYGBQAWIQ/fCpyJ45TA/s70QwhW9zOrA/4YMwkzwzgn+t88/s
OawIvrfyU1MpDgTfLGxbpigvgq/U2T5XQAjB//lOk5VdBsG/EHIm568qgl+n
IGjzyhLB13kTyn3dF8Ff8Fepy3cJgi/M/4HjyC8En2X/7PXKcx7C+dkmu29y
ej+C81d7Ji3Y9w3B//paSuDZtMdw/tZgd+YpLk/g/HqP1vlbniH4ine9bixu
fQrnW5m3TJE0egbnx8id/8l4GcH/eqr3UUHjczh/BktcSZDKC4T7721dxHQE
wWetbQyxLHwJ5zOsjFv/SOgVnF80a32v0CEEf692B4dg3ms4X9CrSKeJ7w2c
f0f3wuXKPQj+hnn2Kk/i3sL5sevNBGX/IfgNrQsb76x6B+evfSE7m8/nPSI+
W0Q82Jch+NPlub/+/4/gAwDBix17
      "]]}, 
    {Hue[0.37820393249936934`, 0.6, 0.6], Dashing[{Small, Small}], 
     LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBWIQ7ZX64uKBl6F2GfHl4uHeF+0XiPq3dUm22MP4jRyb
1Tslp8D5EZEL13/4uATO5/7fGOMutx7OVw189+Jw9xY4v/ycpf2MLzvhfPEt
gvcYGffD+dseOZ85b3MIzj+UNVc68s0ROP+rmi3/2tzjcD7Tz9UC0qqn4Hyz
/wnbgtedgfPPtJicO6Z1Hs6Xn/D658p3F+D819/v37tqcAnOX/Jq9ym+vstw
Pp/s8vdPnlyB83syt6YtULkG539zWP0ko/46nF9idGSL2OEbcP79dUe6Lyre
gvN/Z12ZrVl1G87XdmT/l7b7DpzvvkgxfaP4PYT++AMunrsQ/HLZeKWHMffh
fAOfovgpaxB8e5Nr7cd+IfgATZ3RPw==
      "]], LineBox[CompressedData["
1:eJxTTMoPSmViYGBQAWIQ/fCpyJ45TA/s0+PLxcO9L+5P+CDMJM+M4F/r/DN7
DiuC76381FSKA8E3C9uWKcqL4Ct1ts8VEELwf77TZGWXQfAvhJzJ+auK4Ncp
CNq8skTwdd6Ecl/3RfAX/FXq8l2C4Avzf+A48gvBZ9k/e73ynIdwfrbJ7puc
3o/g/NWeSQv2fUPwv76WEng27TGcvzXYnXmKyxM4v96jdf6WZwi+4l2vG4tb
n8L5VuYtUySNnsH5MXLnfzJeRvC/nup9VND4HM6fwRJXEqTyAuH+e1sXMR1B
8FlrG0MsC1/C+Qwr49Y/EnoF5xfNWt8rdAjB36vdwSGY9xrOF/Qq0mniewPn
39G9cLlyD4K/YZ69ypO4t3B+7HozQdl/CH5D68LGO6vewflrX8jO5vN5j4jP
FhEP9mUI/nR57q///yP4AOs/C8M=
      "]]}, {}}, {{}, {}, {}, {}, {}, {}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesOrigin->{0, 0},
  PlotRange->{{0, 1}, {-0.9999999693146271, 0.9999999176616333}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02]}]], "Output",
 CellChangeTimes->{
  3.521612707757491*^9, {3.521612766943076*^9, 3.5216127848976393`*^9}, {
   3.521612900823839*^9, 3.521612908131769*^9}, 3.52161300951056*^9, 
   3.521613430775402*^9, {3.5216146256196003`*^9, 3.5216146587901773`*^9}, 
   3.521616201552134*^9, 3.5216694614274683`*^9, {3.521674967299479*^9, 
   3.521674974488121*^9}}]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"df", "[", "x_", "]"}], " ", ":=", " ", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         SubscriptBox["c", 
          RowBox[{"1", ",", "1"}]]}], "+", 
        SubscriptBox["c", 
         RowBox[{"1", ",", "0"}]]}], ")"}], " ", 
      RowBox[{"\[Phi]Haar", "[", 
       RowBox[{"2", " ", "x"}], "]"}]}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        SubscriptBox["c", 
         RowBox[{"1", ",", "0"}]], "-", 
        SubscriptBox["c", 
         RowBox[{"1", ",", "1"}]]}], ")"}], " ", 
      RowBox[{"\[Phi]Haar", "[", 
       RowBox[{
        RowBox[{"2", " ", "x"}], " ", "-", "1"}], "]"}]}]}], " ", ")"}], "/", 
   
   SqrtBox["2"], " "}]}]], "Input",
 CellChangeTimes->{{3.52161307080147*^9, 3.521613210583013*^9}, {
  3.521616146436653*^9, 3.5216161629279757`*^9}, {3.521619422001644*^9, 
  3.521619447013198*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"df", "[", "x", "]"}], ",", " ", 
   RowBox[{"{", 
    RowBox[{"x", ",", " ", "0", ",", " ", "1"}], "}"}], ",", " ", 
   RowBox[{"Filling", "\[Rule]", "Axis"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.5216132213491087`*^9, 3.521613235400646*^9}, {
  3.521614809026675*^9, 3.521614824464662*^9}, {3.521616001501183*^9, 
  3.521616002320342*^9}}],

Cell[BoxData[
 GraphicsBox[GraphicsComplexBox[CompressedData["
1:eJxTTMoPSmViYGDwAGIQ7ZX64uKBl6F2afHl4uHeF+0bOTard0pOsYfxIyIX
rv/wcQmcz/2/McZdbj2crxr47sXh7i1wfvk5S/sZX3bC+eJbBO8xMu6H87c9
cj5z3uYQnH8oa6505JsjcP5XNVv+tbnH4Xymn6sFpFVPwflm/xO2Ba87A+ef
aTE5d0zrPJwvP+H1z5XvLsD5r7/fv3fV4BKcv+TV7lN8fZfhfD7Z5e+fPLkC
5/dkbk1boHINzv/msPpJRv11OL/E6MgWscM34Pz76450X1S8Bef/zroyW7Pq
Npyv7cj+L233HTjffZFi+kbxe4jwko1XehhzH87XeRPKfd33AYy/X5j/A8eR
Xwg+y/7Z65XnPITzs0123+T0fgTnr/ZMWrDvG4L/9bWUwLNpj+H8rcHuzFNc
nsD59R6t87c8Q/AV73rdWNz6FM63Mm+ZImn0DM6PkTv/k/Eygv/1VO+jgsbn
cP4MlriSIJUXCPff27qI6QiCz1rbGGJZ+BLOZ1gZt/6R0Cs4v2jW+l6hQwj+
Xu0ODsG813C+oFeRThPfGzj/ju6Fy5V7EPwN8+xVnsS9hfNj15sJyv5D8Bta
FzbeWfUOzl/7QnY2n897OH+6PPfX//8R/AWi/m1dki2I+I4/4OK5CxF/9ibX
2o/9QsTfgr9KXb5LEPGl1CLiwb4MYZ6BT1H8lDUI9RdCzuT8VUVS39k+V0AI
wa9TELR5ZYngeys/NZXiQPB/vtNkZZdB8BM+CDPJMyP4ZmHbMkV5EfyHT0X2
zGFC8K91/pk9hxW3PLr/GMDggb3O8vuPtU6+sYGVHwxQAFMP48PCE8aHmQ/j
AwDGLALt
   "], {{
     {Hue[0.67, 0.6, 0.6], Opacity[0.2], EdgeForm[None], 
      GraphicsGroupBox[
       PolygonBox[{{50, 71, 72, 64, 62, 65, 60, 63, 58, 61, 57, 59, 26, 54, 
        27, 28, 29, 30, 31, 32, 33, 34, 35, 36, 37, 38, 39, 40, 41, 42, 43, 
        44, 45, 46, 47, 48, 49, 55}}]]}, 
     {Hue[0.67, 0.6, 0.6], Opacity[0.2], EdgeForm[None], 
      GraphicsGroupBox[
       PolygonBox[{{1, 69, 70, 53, 56, 25, 52, 24, 23, 22, 21, 20, 19, 18, 17,
         16, 15, 14, 13, 12, 11, 10, 9, 8, 7, 6, 5, 4, 3, 2, 
        51}}]]}, {}, {}}, {{}, {}, 
     {Hue[0.67, 0.6, 0.6], 
      LineBox[{1, 51, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 
       18, 19, 20, 21, 22, 23, 24, 52, 25, 56, 53}], 
      LineBox[{64, 62, 65, 60, 63, 58, 61, 57, 59, 26, 54, 27, 28, 29, 30, 31,
        32, 33, 34, 35, 36, 37, 38, 39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 
       49, 55, 50}]}, 
     {Hue[0.67, 0.6, 0.6], Opacity[0.2], 
      LineBox[{67, 68, 66}]}}, {{}, {}, {}}}],
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesOrigin->{0, 0},
  Method->{"AxesInFront" -> True},
  PlotRange->{{0, 1}, {-0.2702234009898262, 0.2702234009898262}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02]}]], "Output",
 CellChangeTimes->{
  3.521613236477841*^9, 3.521613373530925*^9, 3.5216134331131563`*^9, 
   3.5216146333958607`*^9, 3.521614665297862*^9, {3.521614799311541*^9, 
   3.52161482494075*^9}, 3.521616003934247*^9, 3.521616206257846*^9, 
   3.5216194564867353`*^9, 3.5216694956731663`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  SubscriptBox["d", 
   RowBox[{"0", ",", "0"}]], "=", " ", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", 
      SubscriptBox["c", 
       RowBox[{"1", ",", "1"}]]}], "+", 
     SubscriptBox["c", 
      RowBox[{"1", ",", "0"}]]}], ")"}], "/", 
   SqrtBox["2"], " "}]}]], "Input",
 CellChangeTimes->{{3.521615143709968*^9, 3.5216151668085403`*^9}, {
  3.521619344766625*^9, 3.521619346966361*^9}}],

Cell[BoxData[
 FractionBox[
  RowBox[{
   RowBox[{"-", 
    FractionBox[
     RowBox[{
      RowBox[{"Cos", "[", "4", "]"}], "-", 
      RowBox[{"Cos", "[", "8", "]"}]}], 
     RowBox[{"4", " ", 
      SqrtBox["2"]}]]}], "+", 
   FractionBox[
    SuperscriptBox[
     RowBox[{"Sin", "[", "2", "]"}], "2"], 
    RowBox[{"2", " ", 
     SqrtBox["2"]}]]}], 
  SqrtBox["2"]]], "Output",
 CellChangeTimes->{3.521615179566957*^9, 3.521619348633918*^9, 
  3.5216694998575773`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"\[Psi]", "[", "x_", "]"}], ":=", "  ", 
  RowBox[{
   RowBox[{"\[Phi]Haar", "[", 
    RowBox[{"2", " ", "x"}], "]"}], "-", 
   RowBox[{"\[Phi]Haar", "[", 
    RowBox[{
     RowBox[{"2", " ", "x"}], " ", "-", "1"}], 
    "]"}]}]}], "\[IndentingNewLine]", 
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"\[Psi]", "[", "x", "]"}], ",", " ", 
   RowBox[{"{", 
    RowBox[{"x", ",", " ", 
     RowBox[{"-", "1"}], ",", " ", "1"}], "}"}], ",", 
   RowBox[{"Filling", "\[Rule]", "Axis"}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.521615193748*^9, 3.521615266342825*^9}, {
  3.5216159561387167`*^9, 3.5216159564736357`*^9}}],

Cell[BoxData[
 GraphicsBox[GraphicsComplexBox[CompressedData["
1:eJx11Q0w22ccB/BgGUMjbJirqHpbhdNSiwvrYhutvlHWrnrO667i0GNGq8ew
NNfiqjXazlatbuLQKjWtSSuy0py0mJLWW9RLiIVKaM2Q29W2a/d9rnbLXe5/
n/v9/s/ve88/zz8bY5JCDutSKJTUv7//XN04FjOrq3NiyqvPsW7+EW6LBn70
yGjmbrQaZvyS9I6X9Sx8K+Ee1eTJDBx12n1+kDcNLxdl5Io5KricNmJVMj4F
l+5yT5HlKWFeYnS6885JOEPv6rEUtQKOzul26Ksah8+LlCWl8WPw7dFNxjV2
I7A93ffj/Zfl8E/M3HjFxAA8Kqm3ZbH6YKXreQ9xoww2zapmuen0wK6sOdeK
hU74hJ/6oTC9HTbfX1t4yLKVzPtDYiJ1uA1XyJUF0/xaODzY+qb883Ow0DDj
cWtaMeel5jnvK3Rsvg6tg+3n76x4twrhneWDXYGhrbD/XjO9xVvt8NnI/pwt
P3fC7YGMdfvMemD1RvOs3u9lcFqqS/RZiz64f5geEisdgKOOf/Cb/h453Obi
ld9GHYGd3mpWCQLG/rWY0ZzgT80dhyla3eoUhQJeChZFSBwnYbln5HpHvhJO
Pkg3tRuegq3OTYa+wVDBtWFXKhfSp+GD27IDpKIZuD7iiJ33n0/hZcNP9IQH
1HBIjw+LUaKBX50HUj/VdW1rJDkfTF1tQ0KYAGZTN1eOKf3g+w2RfvV5AuxH
Ua+wSVk1DBuU9V8/uXsU/lHxtuUBFdkvXwPnQtoeMt934tmD7+rIfJVm7goz
uRqu+z3RXjXEh2MP61tXVJHnMcA0OHOo4DLqXC4ztvEFD/WrA5WcOA3J42XK
H+rsJ/O2K+Mt87XX4JsdvZKgnjNwh1H2NuOeH+A227xTl+gpWG/wjvjoUilZ
/1Mfmq7O/TT0J35YaGCzeBr1Fu0O/uwGsh8em/bGTD0leY5GVfUKOdfJ+0PO
6/ho6htYe7J52ceinLw/irc/SPCMwvqhZqmCOHE26vkL60IKjcg86ZLGmaqf
if6L0n1ijwou+p/r8BoDPEn/jQZ3p4VFko9ms+NGsILky7zQLaY5FsNFfmF9
siaSr+8Zr4y+HIB5miyZd2A4D/W7Hc7pbCqZ9zBIvqWrKxn1nPiaRBkzHvc7
LDETWsxJv8vEY/aF8DD0J63Y565oSd6hTIuyS1vJ+2h2YZGddo/kjShnSjYY
/uf3jnm/sm03ry89gfpXcTUmBYvkeRdJUq24u79E/d0nDM2L6hh4Pui950kp
n6Ff9EW2//E3SX4n4+Rv3bjB/7sfa/OsPY9r87y8jnEEmtVgwyZf0ev3r+3H
/yP8+nwK5S88tzIf
   "], {{
     {Hue[0.67, 0.6, 0.6], Opacity[0.2], EdgeForm[None], 
      GraphicsGroupBox[
       PolygonBox[{{50, 115, 116, 91, 106, 81, 94, 74, 84, 38, 57, 39, 40, 41,
         42, 43, 44, 45, 46, 47, 48, 49, 58}}]]}, 
     {Hue[0.67, 0.6, 0.6], Opacity[0.2], EdgeForm[None], 
      GraphicsGroupBox[
       PolygonBox[{{100, 113, 114, 102, 65, 71, 56, 62, 37, 55, 36, 35, 34, 
        33, 32, 31, 30, 29, 28, 27, 54, 26, 73, 64, 82, 70, 93, 79, 105, 
        89}}]]}, {}, {}}, {{}, {}, 
     {Hue[0.67, 0.6, 0.6], 
      LineBox[{1, 96, 85, 75, 66, 59, 51, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 
       13, 14, 15, 16, 17, 18, 19, 20, 21, 22, 23, 24, 97, 86, 76, 67, 60, 52,
        99, 88, 78, 69, 63, 25, 98, 87, 77, 68, 61, 101, 90, 80, 72, 103, 92, 
       83, 104, 95, 107, 53}], 
      LineBox[{100, 89, 105, 79, 93, 70, 82, 64, 73, 26, 54, 27, 28, 29, 30, 
       31, 32, 33, 34, 35, 36, 55, 37, 62, 56, 71, 65, 102}], 
      LineBox[{91, 106, 81, 94, 74, 84, 38, 57, 39, 40, 41, 42, 43, 44, 45, 
       46, 47, 48, 49, 58, 50}]}, 
     {Hue[0.67, 0.6, 0.6], Opacity[0.2], LineBox[{110, 109}], 
      LineBox[{111, 112, 108}]}}, {{}, {}, {}}}],
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesOrigin->{0, 0},
  Method->{"AxesInFront" -> True},
  PlotRange->{{-1, 1}, {-1., 1.}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02]}]], "Output",
 CellChangeTimes->{{3.5216152594211063`*^9, 3.521615266797414*^9}, 
   3.521615957015594*^9, 3.521619351567553*^9, 3.52166950311202*^9}]
}, Open  ]],

Cell[TextData[{
 "Therefore:\n\n",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     RowBox[{
      SubscriptBox["f", "1"], "(", "x", ")"}], " ", "-", " ", 
     RowBox[{
      SubscriptBox["f", "0"], "(", "x", ")"}]}], " ", "=", " ", 
    RowBox[{
     SubscriptBox["d", 
      RowBox[{"0", ",", "0"}]], 
     RowBox[{"\[Psi]", "(", "x", ")"}], " "}]}], TraditionalForm]]],
 "\n\nAs plot below renders the equality:"
}], "Text",
 CellChangeTimes->{{3.521674443100667*^9, 3.521674580458901*^9}, {
  3.521675164687392*^9, 3.521675175710099*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SubscriptBox["d", 
       RowBox[{"0", ",", "0"}]], "*", 
      RowBox[{"\[Psi]", "[", "x", "]"}]}], ",", " ", 
     RowBox[{
      RowBox[{"f1", "[", "x", "]"}], "-", 
      RowBox[{"f0", "[", "x", "]"}]}]}], "}"}], ",", " ", 
   RowBox[{"{", 
    RowBox[{"x", ",", " ", "0", ",", " ", "1"}], "}"}], ",", 
   RowBox[{"PlotStyle", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"Green", ",", 
      RowBox[{"{", 
       RowBox[{"Black", ",", "Thick", ",", "Dashed"}], "}"}]}], "}"}]}]}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.5216152809583473`*^9, 3.521615305743384*^9}, {
  3.5216159639911127`*^9, 3.521615964293242*^9}, {3.521675069900259*^9, 
  3.521675141873528*^9}, {3.521675182635395*^9, 3.521675183161067*^9}}],

Cell[BoxData[
 GraphicsBox[{{{}, {}, 
    {RGBColor[0, 1, 0], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBWIQ7ZX64uKBl6F2afHl4uHeF+0XiPq3dUm22MP4jRyb
1Tslp8D5EZEL13/4uATO5/7fGOMutx7OVw189+Jw9xY4v/ycpf2MLzvhfPEt
gvcYGffD+dseOZ85b3MIzj+UNVc68s0ROP+rmi3/2tzjcD7Tz9UC0qqn4Hyz
/wnbgtedgfPPtJicO6Z1Hs6Xn/D658p3F+D819/v37tqcAnOX/Jq9ym+vstw
Pp/s8vdPnlyB83syt6YtULkG539zWP0ko/46nF9idGSL2OEbcP79dUe6Lyre
gvN/Z12ZrVl1G87XdmT/l7b7DpzvvkgxfaP4PYT++AMunrsQ/HLZeKWHMffh
fAOfovgpaxB8e5Nr7cd+IfgAGQ3RBQ==
      "]], LineBox[CompressedData["
1:eJxTTMoPSmViYGBQAWIQ/fCpyJ45TA/s0+LLxcO9L+5P+CDMJM+M4F/r/DN7
DiuC76381FSKA8E3C9uWKcqL4Ct1ts8VEELwf77TZGWXQfAvhJzJ+auK4Ncp
CNq8skTwdd6Ecl/3RfAX/FXq8l2C4Avzf+A48gvBZ9k/e73ynIdwfrbJ7puc
3o/g/NWeSQv2fUPwv76WEng27TGcvzXYnXmKyxM4v96jdf6WZwi+4l2vG4tb
n8L5VuYtUySNnsH5MXLnfzJeRvC/nup9VND4HM6fwRJXEqTyAuH+e1sXMR1B
8FlrG0MsC1/C+Qwr49Y/EnoF5xfNWt8rdAjB36vdwSGY9xrOF/Qq0mniewPn
39G9cLlyD4K/YZ69ypO4t3B+7HozQdl/CH5D68LGO6vewflrX8jO5vN5j4jP
FhEP9mUI/nR57q///yP4AMK/C58=
      "]]}, 
    {GrayLevel[0], Thickness[Large], Dashing[{Small, Small}], 
     LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBWIQ7ZX64uKBl6F2GfHl4uHeF+0XiPq3dUm22MP4jRyb
1Tslp8D5EZEL13/4uATO5/7fGOMutx7OVw189+Jw9xY4v/ycpf2MLzvhfPEt
gvcYGffD+dseOZ85b3MIzj+UNVc68s0ROP+rmi3/2tzjcD7Tz9UC0qqn4Hyz
/wnbgtedgfPPtJicO6Z1Hs6Xn/D658p3F+D819/v37tqcAnOX/Jq9ym+vstw
Pp/s8vdPnlyB83syt6YtULkG539zWP0ko/46nF9idGSL2OEbcP79dUe6Lyre
gvN/Z12ZrVl1G87XdmT/l7b7DpzvvkgxfaP4PYT++AMunrsQ/HLZeKWHMffh
fAOfovgpaxB8e5Nr7cd+IfgATZ3RPw==
      "]], LineBox[CompressedData["
1:eJxTTMoPSmViYGBQAWIQ/fCpyJ45TA/s0+PLxcO9L+5P+CDMJM+M4F/r/DN7
DiuC76381FSKA8E3C9uWKcqL4Ct1ts8VEELwf77TZGWXQfAvhJzJ+auK4Ncp
CNq8skTwdd6Ecl/3RfAX/FXq8l2C4Avzf+A48gvBZ9k/e73ynIdwfrbJ7puc
3o/g/NWeSQv2fUPwv76WEng27TGcvzXYnXmKyxM4v96jdf6WZwi+4l2vG4tb
n8L5VuYtUySNnsH5MXLnfzJeRvC/nup9VND4HM6fwRJXEqTyAuH+e1sXMR1B
8FlrG0MsC1/C+Qwr49Y/EnoF5xfNWt8rdAjB36vdwSGY9xrOF/Qq0mniewPn
39G9cLlyD4K/YZ69ypO4t3B+7HozQdl/CH5D68LGO6vewflrX8jO5vN5j4jP
FhEP9mUI/nR57q///yP4AOs/C8M=
      "]]}, {}}, {{}, {}, {}, {}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesOrigin->{0, 0},
  PlotRange->{{0, 1}, {-0.2702234009898263, 0.27022340098982633`}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02]}]], "Output",
 CellChangeTimes->{
  3.521615306724441*^9, 3.5216159647907867`*^9, 3.521619354238043*^9, 
   3.521669507214896*^9, {3.521675088735673*^9, 3.521675116586607*^9}, 
   3.521675148830401*^9, 3.521675184085266*^9}]
}, Open  ]],

Cell[TextData[{
 "Or\n\n",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     SubscriptBox["f", "1"], "(", "x", ")"}], "  ", "=", " ", 
    RowBox[{
     RowBox[{
      SubscriptBox["c", 
       RowBox[{"0", ",", "0"}]], 
      RowBox[{"\[Phi]", "(", "x", ")"}]}], " ", "+", 
     RowBox[{
      SubscriptBox["d", 
       RowBox[{"0", ",", "0"}]], 
      RowBox[{"\[Psi]", "(", "x", ")"}], " "}]}]}], TraditionalForm]]],
 "\n\nLet\[CloseCurlyQuote]s plot and see:"
}], "Text",
 CellChangeTimes->{{3.521674590429226*^9, 3.521674686409245*^9}, {
  3.521675157237084*^9, 3.52167515777699*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{
       SubscriptBox["c", 
        RowBox[{"0", ",", "0"}]], "*", 
       RowBox[{"\[Phi]Haar", "[", "x", "]"}]}], "+", 
      RowBox[{
       SubscriptBox["d", 
        RowBox[{"0", ",", "0"}]], "*", 
       RowBox[{"\[Psi]", "[", "x", "]"}]}]}], ",", " ", 
     RowBox[{"f1", "[", "x", "]"}]}], "}"}], ",", " ", 
   RowBox[{"{", 
    RowBox[{"x", ",", " ", "0", ",", " ", "1"}], "}"}], ",", 
   RowBox[{"PlotStyle", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"Green", ",", 
      RowBox[{"{", 
       RowBox[{"Black", ",", "Thick", ",", "Dashed"}], "}"}]}], "}"}]}]}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.521674697426427*^9, 3.5216747439608603`*^9}, {
   3.521674784690617*^9, 3.521674800990274*^9}, {3.5216748384354*^9, 
   3.52167492557075*^9}, 3.521675145066794*^9, {3.521675188776141*^9, 
   3.5216751975959663`*^9}}],

Cell[BoxData[
 GraphicsBox[{{{}, {}, 
    {RGBColor[0, 1, 0], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBWIQ7ZX64uKBl6F28ZNymYNLb9kvEPVv65JssYfxGzk2
q3dKToHzIyIXrv/wcQmcz/2/McZdbj2crxr47sXh7i1wfvk5S/sZX3bC+eJb
BO8xMu6H87c9cj5z3uYQnH8oa6505JsjcP5XNVv+tbnH4Xymn6sFpFVPwflm
/xO2Ba87A+efaTE5d0zrPJwvP+H1z5XvLsD5r7/fv3fV4BKcv+TV7lN8fZfh
fD7Z5e+fPLkC5/dkbk1boHINzv/msPpJRv11OL/E6MgWscM34Pz76450X1S8
Bef/zroyW7PqNpyv7cj+L233HTjffZFi+kbxewj98QdcPHch+OWy8UoPY+7D
+QY+RfFT1iD49ibX2o/9QvABQ8DX7g==
      "]], LineBox[CompressedData["
1:eJxTTMoPSmViYGBQAWIQ/fCpyJ45TA/sb0UwhW9zOrA/4YMwkzwzgn+t88/s
OawIvrfyU1MpDgTfLGxbpigvgq/U2T5XQAjB//lOk5VdBsG/EHIm568qgl+n
IGjzyhLB13kTyn3dF8Ff8Fepy3cJgi/M/4HjyC8En2X/7PXKcx7C+dkmu29y
ej+C81d7Ji3Y9w3B//paSuDZtMdw/tZgd+YpLk/g/HqP1vlbniH4ine9bixu
fQrnW5m3TJE0egbnx8id/8l4GcH/eqr3UUHjczh/BktcSZDKC4T7721dxHQE
wWetbQyxLHwJ5zOsjFv/SOgVnF80a32v0CEEf692B4dg3ms4X9CrSKeJ7w2c
f0f3wuXKPQj+hnn2Kk/i3sL5sevNBGX/IfgNrQsb76x6B+evfSE7m8/nPSI+
W0Q82Jch+NPlub/+/4/gAwBwix0z
      "]]}, 
    {GrayLevel[0], Thickness[Large], Dashing[{Small, Small}], 
     LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBWIQ7ZX64uKBl6F2iZNymYNLb9kvEPVv65JssYfxGzk2
q3dKToHzIyIXrv/wcQmcz/2/McZdbj2crxr47sXh7i1wfvk5S/sZX3bC+eJb
BO8xMu6H87c9cj5z3uYQnH8oa6505JsjcP5XNVv+tbnH4Xymn6sFpFVPwflm
/xO2Ba87A+efaTE5d0zrPJwvP+H1z5XvLsD5r7/fv3fV4BKcv+TV7lN8fZfh
fD7Z5e+fPLkC5/dkbk1boHINzv/msPpJRv11OL/E6MgWscM34Pz76450X1S8
Bef/zroyW7PqNpyv7cj+L233HTjffZFi+kbxewj98QdcPHch+OWy8UoPY+7D
+QY+RfFT1iD49ibX2o/9QvABeFDYKA==
      "]], LineBox[CompressedData["
1:eJxTTMoPSmViYGBQAWIQ/fCpyJ45TA/s70QwhW9zOrA/4YMwkzwzgn+t88/s
OawIvrfyU1MpDgTfLGxbpigvgq/U2T5XQAjB//lOk5VdBsG/EHIm568qgl+n
IGjzyhLB13kTyn3dF8Ff8Fepy3cJgi/M/4HjyC8En2X/7PXKcx7C+dkmu29y
ej+C81d7Ji3Y9w3B//paSuDZtMdw/tZgd+YpLk/g/HqP1vlbniH4ine9bixu
fQrnW5m3TJE0egbnx8id/8l4GcH/eqr3UUHjczh/BktcSZDKC4T7721dxHQE
wWetbQyxLHwJ5zOsjFv/SOgVnF80a32v0CEEf692B4dg3ms4X9CrSKeJ7w2c
f0f3wuXKPQj+hnn2Kk/i3sL5sevNBGX/IfgNrQsb76x6B+evfSE7m8/nPSI+
W0Q82Jch+NPlub/+/4/gAwDBix17
      "]]}, {}}, {{}, {}, {}, {}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesOrigin->{0, 0},
  PlotRange->{{0, 1}, {-0.1270358967637496, 0.413410905215903}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02]}]], "Output",
 CellChangeTimes->{
  3.52167474495331*^9, {3.521674793465877*^9, 3.521674802001268*^9}, {
   3.5216748545404043`*^9, 3.5216749265562983`*^9}, 3.5216751523669653`*^9, 
   3.5216751987686977`*^9}]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
WindowSize->{1792, 875},
WindowMargins->{{Automatic, 54}, {Automatic, 18}},
PrivateNotebookOptions->{"VersionedStylesheet"->{"Default.nb"[8.] -> False}},
FrontEndVersion->"9.0 for Mac OS X x86 (32-bit, 64-bit Kernel) (January 25, \
2013)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[579, 22, 118, 1, 92, "Title"],
Cell[700, 25, 540, 16, 163, "Text"],
Cell[CellGroupData[{
Cell[1265, 45, 187, 4, 51, "Subtitle"],
Cell[1455, 51, 119, 3, 30, "Text"],
Cell[1577, 56, 506, 13, 63, "Input"],
Cell[2086, 71, 1187, 30, 121, "Text"],
Cell[CellGroupData[{
Cell[3298, 105, 488, 11, 28, "Input"],
Cell[3789, 118, 3119, 56, 244, "Output"]
}, Open  ]],
Cell[6923, 177, 1318, 31, 140, "Text"],
Cell[8244, 210, 500, 13, 63, "Input"],
Cell[8747, 225, 598, 19, 71, "Text"],
Cell[9348, 246, 516, 15, 35, "Input"],
Cell[9867, 263, 460, 10, 129, "Text"],
Cell[CellGroupData[{
Cell[10352, 277, 400, 10, 28, "Input"],
Cell[10755, 289, 2442, 47, 246, "Output"]
}, Open  ]],
Cell[13212, 339, 257, 8, 69, "Text"],
Cell[CellGroupData[{
Cell[13494, 351, 399, 10, 28, "Input"],
Cell[13896, 363, 3209, 59, 245, "Output"]
}, Open  ]],
Cell[17120, 425, 260, 8, 69, "Text"],
Cell[CellGroupData[{
Cell[17405, 437, 401, 10, 28, "Input"],
Cell[17809, 449, 3170, 59, 246, "Output"]
}, Open  ]],
Cell[20994, 511, 260, 8, 69, "Text"],
Cell[CellGroupData[{
Cell[21279, 523, 400, 10, 28, "Input"],
Cell[21682, 535, 3171, 58, 245, "Output"]
}, Open  ]],
Cell[24868, 596, 255, 8, 69, "Text"],
Cell[CellGroupData[{
Cell[25148, 608, 398, 10, 28, "Input"],
Cell[25549, 620, 3215, 59, 246, "Output"]
}, Open  ]],
Cell[28779, 682, 160, 6, 68, "Text"],
Cell[CellGroupData[{
Cell[28964, 692, 666, 17, 28, "Input"],
Cell[29633, 711, 9741, 160, 243, "Output"]
}, Open  ]],
Cell[39389, 874, 383, 10, 88, "Text"],
Cell[CellGroupData[{
Cell[39797, 888, 454, 12, 35, "Input"],
Cell[40254, 902, 3144, 58, 246, "Output"]
}, Open  ]],
Cell[43413, 963, 258, 8, 50, "Text"],
Cell[CellGroupData[{
Cell[43696, 975, 400, 10, 28, "Input"],
Cell[44099, 987, 3123, 58, 246, "Output"]
}, Open  ]],
Cell[47237, 1048, 213, 7, 69, "Text"],
Cell[CellGroupData[{
Cell[47475, 1059, 397, 10, 28, "Input"],
Cell[47875, 1071, 3100, 57, 246, "Output"]
}, Open  ]],
Cell[50990, 1131, 211, 7, 69, "Text"],
Cell[CellGroupData[{
Cell[51226, 1142, 397, 10, 28, "Input"],
Cell[51626, 1154, 2408, 46, 246, "Output"]
}, Open  ]],
Cell[54049, 1203, 107, 4, 49, "Text"],
Cell[CellGroupData[{
Cell[54181, 1211, 575, 16, 35, "Input"],
Cell[54759, 1229, 7337, 130, 242, "Output"]
}, Open  ]],
Cell[62111, 1362, 16, 0, 30, "Text"],
Cell[62130, 1364, 457, 11, 34, "Text"],
Cell[CellGroupData[{
Cell[62612, 1379, 2664, 71, 125, "Input"],
Cell[65279, 1452, 3692, 67, 247, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[69008, 1524, 2293, 66, 125, "Input"],
Cell[71304, 1592, 3518, 67, 246, "Output"]
}, Open  ]],
Cell[74837, 1662, 1722, 47, 167, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[76596, 1714, 172, 2, 51, "Subtitle"],
Cell[76771, 1718, 2017, 64, 241, "Text"],
Cell[78791, 1784, 507, 12, 46, "Input"],
Cell[CellGroupData[{
Cell[79323, 1800, 1246, 30, 131, "Input"],
Cell[80572, 1832, 345, 7, 47, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[80954, 1844, 972, 27, 114, "Input"],
Cell[81929, 1873, 417, 11, 48, "Output"]
}, Open  ]],
Cell[82361, 1887, 563, 19, 77, "Text"],
Cell[CellGroupData[{
Cell[82949, 1910, 1453, 37, 54, "Input"],
Cell[84405, 1949, 7856, 257, 196, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[92298, 2211, 543, 13, 46, "Input"],
Cell[92844, 2226, 7486, 255, 197, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[100367, 2486, 1300, 33, 97, "Input"],
Cell[101670, 2521, 14323, 242, 230, "Output"]
}, Open  ]],
Cell[116008, 2766, 858, 28, 134, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[116903, 2799, 128, 1, 51, "Subtitle"],
Cell[117034, 2802, 586, 16, 143, "Text"],
Cell[CellGroupData[{
Cell[117645, 2822, 1392, 38, 80, "Input"],
Cell[119040, 2862, 3199, 59, 246, "Output"],
Cell[122242, 2923, 2460, 47, 247, "Output"],
Cell[124705, 2972, 2638, 51, 247, "Output"]
}, Open  ]],
Cell[127358, 3026, 722, 22, 89, "Text"],
Cell[CellGroupData[{
Cell[128105, 3052, 2352, 69, 169, "Input"],
Cell[130460, 3123, 3167, 59, 247, "Output"],
Cell[133630, 3184, 3028, 56, 247, "Output"],
Cell[136661, 3242, 3258, 60, 247, "Output"],
Cell[139922, 3304, 3115, 58, 247, "Output"]
}, Open  ]],
Cell[143052, 3365, 171, 4, 68, "Text"],
Cell[143226, 3371, 286, 10, 56, "Text"],
Cell[143515, 3383, 386, 10, 43, "Input"],
Cell[CellGroupData[{
Cell[143926, 3397, 906, 27, 91, "Input"],
Cell[144835, 3426, 216, 5, 49, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[145088, 3436, 982, 29, 107, "Input"],
Cell[146073, 3467, 298, 8, 53, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[146408, 3480, 978, 28, 91, "Input"],
Cell[147389, 3510, 333, 9, 50, "Output"]
}, Open  ]],
Cell[147737, 3522, 393, 15, 29, "Text"],
Cell[148133, 3539, 316, 8, 30, "Input"],
Cell[148452, 3549, 476, 14, 30, "Input"],
Cell[CellGroupData[{
Cell[148953, 3567, 916, 22, 73, "Input"],
Cell[149872, 3591, 14393, 248, 231, "Output"]
}, Open  ]],
Cell[164280, 3842, 946, 30, 38, "Input"],
Cell[CellGroupData[{
Cell[165251, 3876, 404, 9, 27, "Input"],
Cell[165658, 3887, 2486, 49, 229, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[168181, 3941, 434, 14, 38, "Input"],
Cell[168618, 3957, 473, 17, 64, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[169128, 3979, 652, 18, 43, "Input"],
Cell[169783, 3999, 2980, 56, 239, "Output"]
}, Open  ]],
Cell[172778, 4058, 550, 17, 86, "Text"],
Cell[CellGroupData[{
Cell[173353, 4079, 815, 22, 33, "Input"],
Cell[174171, 4103, 2493, 50, 229, "Output"]
}, Open  ]],
Cell[176679, 4156, 595, 19, 86, "Text"],
Cell[CellGroupData[{
Cell[177299, 4179, 935, 26, 53, "Input"],
Cell[178237, 4207, 2475, 50, 229, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
